(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1355202,      70932]*)
(*NotebookOutlinePosition[   1384180,      71998]*)
(*  CellTagsIndexPosition[   1384136,      71994]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["Example # 6 : Simple Quadrupole Magnet ",
  FontSize->24]], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Version : 0.5", "Text",
  PageWidth->PaperWidth,
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
This example considers a  simple quadrupole. Note that it has been \
derived  quickly and its  design has not been optimized at all. This example \
is in some way similar to the simple dipole magnet of Example#5.nb and all \
the remaks made in that case  are valid here. It  is an iron dominated \
structure. The user should at least first read the introduction of \
Example#5.nb before playing with  this one. The quadrupole presents \
hyperbolic pole faces with a chamfer. This example makes use of more \
sophisticated capabilities built-in Mathematica for plotting the result. \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Load and Initialize Radia", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "The following instruction loads the Radia package and returns the Radia  \
version number.It also turn off some warnings and load additionnal ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" packages used for plotting. ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
<<Radia`;
Off[General::\"spell1\"];
<<Graphics`MultipleListPlot`;
<<Graphics`PlotField3D`;\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Radia Version: \"\>", "\[InvisibleSpace]", 
        StyleBox["4.09299999999999997`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], "\[InvisibleSpace]", "\<\" is loaded\"\>"}],
      SequenceForm[ "Radia Version: ", 4.093, " is loaded"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Radia is copyright ESRF, Grenoble France \nPortions copyright 1997 \
Wolfram Research, Inc."\)], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Defining The Model", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["A routine to create the geometry.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Nn=4;
ironcolor={0,0.5,1};coilcolor={1,0,0};
depth=1.2*width/2;
If[hyp<0.2,hyp=0.2];

geo[]:=(
rap=0.5;
ct={0,0,0};
z0=gap/2;y0=width/2;
amax=N[hyp*ArcSinh[y0/z0]];dz=z0*(Cosh[amax]-1);
qq=N[Table[{z0*Sinh[a/hyp],z0*Cosh[a]},{a,0,amax*(1+2/np),amax/np}]];
hh=qq[[np+1]][[2]]+height*rap-dz;
qq[[np+2]]={qq[[np+1]][[1]],hh};
qq[[np+3]]={0,hh};
g1=radObjThckPgn[thick/4,thick/2,qq];
radObjDivMag[g1,n1];
\t
g2=radObjRecMag[{thick/4,width/4,gap/2+height*(1/2+rap/2)},{thick/2,width/2,\
height*(1-rap)}];
radObjDivMag[g2,n2];

gg=radObjCnt[{g1,g2}];\t\t
gp=radObjCutMag[gg,{thick/2-chamfer-gap/2,0,0},{1,0,-1}][[1]];

g3=radObjRecMag[{thick/4,width/4,gap/2+height+depth/2},{thick/2,width/2,depth}\
];

cy={\"cyl\",{{0,width/2,gap/2+height},{1,0,0}},{0,0,gap/2+height},2*depth/\
width};
radObjDivMag[g3,{nr3,np3,nx},cy];

tan=N[Tan[2*Pi/2/Nn]];
len=tan*(height+gap/2)-width/2;
g4=radObjRecMag[{thick/4,width/2+len/2,gap/2+height+depth/2},{thick/2,len,\
depth}];
radObjDivMag[g4,n4];

posy=width/2+len;posz=posy/tan;
g5=radObjThckPgn[thick/4,thick/2,{{posy,posz},{posy,posz+depth},{posy+depth*\
tan,posz+depth}}];
cyl={\"cyl\",{{0,posy,posz},{1,0,0}},{0,posy,posz+depth},1};
\t\t\t
radObjDivMag[g5,{nr5,np5,nx},cyl];

Rmax=Rmin-width/2+gap/2+offset-2;
coil1=radObjRaceTrk[{0,0,gap/2+height/2+offset/2},{Rmin,Rmax},{thick,width-2*\
Rmin},height-offset,3,CurDens];
radObjDrwAtr[coil1,coilcolor];

hh=(height-offset)/2;

coil2=radObjRaceTrk[{0,0,gap/2+height-hh/2},{Rmax,Rmax+hh*0.8},{thick,width-2*\
Rmin},hh,3,CurDens];
radObjDrwAtr[coil2,coilcolor];
\t\t
g=radObjCnt[{gp,g3,g4,g5}];
radObjDrwAtr[g,ironcolor];
\t
gd=radObjCnt[{g}];
\t
RadTrfZerPerp[gd,ct,{1,0,0}];
RadTrfZerPerp[gd,ct,{0,1,0}];

t=radObjCnt[{gd,coil1,coil2}];
RadTrfZerPara[t,ct,{0,N[Cos[Pi/Nn]],N[Sin[Pi/Nn]]}];

radTrfMlt[t,radTrfRot[ct,{1,0,0},4*Pi/Nn],Nn/2];
radMatApl[g,ironmat];
radTrfOrnt[t,radTrfRot[{0,0,0},{1,0,0},N[Pi/Nn]]];)

(* ------  For the Harmonic Analysis --------- *)
\t
harm[Obj_,{y_,z_,ro_},Np_]:=Module[{},{Np,ro,Table[
radFldInt[Obj,\"inf\",\"ibz\",N[{-1,y+ro*Cos[tet],z+ro*Sin[tet]}],N[{1,y+ro*\
Cos[tet],z+ro*Sin[tet]}]]+
radFldInt[Obj,\"inf\",\"iby\",{-1,y+ro*Cos[tet],z+ro*Sin[tet]},{1,y+ro*Cos[\
tet],z+ro*Sin[tet]}]*I,{tet,0,2*Pi*(1-1/Np),2*Pi/Np}]}]

multipole[w_List,q_]:=( \
w[[3]].Table[Exp[-2*I*Pi/w[[1]]*q*p],{p,0,w[[1]]-1}]/w[[1]]/w[[2]]^q)\
\>", 
  "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Creating the Geometry and Solving", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Creating and solving the magnetic structure. Note that the results \
are strongly dependent on the segmentation parameters. nx and ny are easy to \
use numbers  which determine the segmentation in the length of the qaudrupole \
and in the plane of the pole. Change them and watch the periodic part of the \
iron to see what segmentation it represents. Note it may happen (in rare \
cases) for some geometry and values of nx and ny that the relaxation is \
either unstable or uncomplete. This will be reported in the result of the \
computation , the cure is typically to reduce one of the index nx or ny and \
increase the other one. 
The shape of the pole is a  hyperbole approximated by 2 x np flat segments. \
The parameter np is  important if one cares of removing the dodecapole over a \
large range around the axis. The parameter hyp define the shape of the pole \
faces. hyp=1 is a perfect hyperbolic shape, lower values result in flat \
poles, higher values gives poles with more curvature. One easily check that \
even with a low segmentation the dodecapole is minimzed for a value of hyp \
close to 1 as expected for a non saturated quadrupole.  
Taking as a reference a computation made with nx=10;ny=6; n1={nx,ny,{10,1}}; \
n2=n1 ;np3=4;nr3=ny; n4={nx,8,ny}; np5=4;nr5=ny; occupying 190 Mbytes and \
taking 6 hours of cpu time  one obtains a gradient of 15.43 T / m. The \
segmentation parameters used below gives the gradient with a 1% precision  \
within   17 seconds of solving  and  little memory. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
np=4;                 \t(* see above *)
hyp=1;\t\t\t\t\t(* must be > 0.2 *)

gap=40;\t\t\t\t\t(* magnetic gap *)
width=30;\t\t\t\t(* pole width *)
height=50;\t\t\t\t(* height of iron in coil *)
thick=60;\t\t\t\t(* length of Quad *)
chamfer=8;\t\t\t\t

(* coils *)

CurDens=-3;\t\t\t\t(* current density A/mm2 *)
Rmin=2;offset=10;

(* segmentation parameters *)

nx=2;ny=2;
n1={nx,ny,{3,1}};
n2={nx,ny,{3,1}};
np3=2;nr3=ny;
n4={nx,3,ny};
np5=Ceiling[np3/2];nr5=ny;

t0=AbsoluteTime[];
radUtiDelAll[];
ironmat=radMatSatIso[{2000,2},{0.1,2},{0.1,2}];
geo[];
size=radObjDegFre[t];

t1=AbsoluteTime[];
Nmax=1000;
res=RadSolve[t,0.00001,Nmax];
t2=AbsoluteTime[];
Bz=radFld[t,\"Bz\",{0,1,0}]*1000;\t
Iz=radFldInt[t,\"inf\",\"ibz\",{-1,1,0},{1,1,0}];
Iz1=radFldInt[t,\"inf\",\"ibz\",{-1,10,0},{1,10,0}]/10;
\t
Print[\"Mag_Max  H_Max  N_Iter = \",N[res[[2]],3],\" T \",N[res[[3]],3],\" T \
\",res[[4]]];
If[res[[4]]==Nmax,Print[\"Unstable or Uncomplete Relaxation\"],];
Print[\"Built & Solved in \",Round[t1-t0],\" & \",Round[t2-t1], \" \
seconds\"];
Print[\"Interaction Matrix : \",size,\" X \",size,\" or \", \
N[size*size*4/1000000,2],\" Mbytes\"];
Print[\" Gradient = \", N[Bz,4],\" T/m \"];
Print[\"Int. Quad. @ 1 mm = \", N[Iz,5],\"T\"];
Print[\"Delta Int. Quad. @ 10 mm = \", N[100*(Iz1/Iz-1),2],\"%\"];\
\>", 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Mag_Max  H_Max  N_Iter = \"\>", "\[InvisibleSpace]", 
        StyleBox["1.30271446527097078`",
          StyleBoxAutoDelete->True,
          PrintPrecision->3], "\[InvisibleSpace]", "\<\" T \"\>", 
        "\[InvisibleSpace]", 
        StyleBox["0.00077751745640638239`",
          StyleBoxAutoDelete->True,
          PrintPrecision->3], "\[InvisibleSpace]", "\<\" T \"\>", 
        "\[InvisibleSpace]", "850"}],
      SequenceForm[ 
      "Mag_Max  H_Max  N_Iter = ", 1.3027144652709708, " T ", 
        0.00077751745640638234, " T ", 850],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("Built & Solved in "\[InvisibleSpace]4
        \[InvisibleSpace]" & "\[InvisibleSpace]6
        \[InvisibleSpace]" seconds"\),
      SequenceForm[ "Built & Solved in ", 4, " & ", 6, " seconds"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "\<\"Interaction Matrix : \"\>", "\[InvisibleSpace]", "162", 
        "\[InvisibleSpace]", "\<\" X \"\>", "\[InvisibleSpace]", "162", 
        "\[InvisibleSpace]", "\<\" or \"\>", "\[InvisibleSpace]", 
        StyleBox["0.104976000000000002`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2], "\[InvisibleSpace]", "\<\" Mbytes\"\>"}],
      SequenceForm[ 
      "Interaction Matrix : ", 162, " X ", 162, " or ", 0.104976, " Mbytes"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\" Gradient = \"\>", "\[InvisibleSpace]", 
        StyleBox["14.8054761786123538`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], "\[InvisibleSpace]", "\<\" T/m \"\>"}],
      SequenceForm[ " Gradient = ", 14.805476178612354, " T/m "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Int. Quad. @ 1 mm = \"\>", "\[InvisibleSpace]", 
        StyleBox["1.08554238910558865`",
          StyleBoxAutoDelete->True,
          PrintPrecision->5], "\[InvisibleSpace]", "\<\"T\"\>"}],
      SequenceForm[ "Int. Quad. @ 1 mm = ", 1.0855423891055886, "T"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Delta Int. Quad. @ 10 mm = \"\>", "\[InvisibleSpace]", 
        StyleBox["0.0958186542990402401`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2], "\[InvisibleSpace]", "\<\"%\"\>"}],
      SequenceForm[ "Delta Int. Quad. @ 10 mm = ", 0.09581865429904024, "%"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Harmonic Analysis of the Field Integrals", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Sequence of Integrated Dipole [T mm], Quadrupole[T], Sextupole [T / mm],.. \
The real (imaginary) part is the normal (skew) component. The functions   ",
    Evaluatable->False,
    AspectRatioFixed->True],
  "harm",
  StyleBox[" and m",
    Evaluatable->False,
    AspectRatioFixed->True],
  "ultipole",
  StyleBox[" are dedined in the section \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  "Defining The Model",
  StyleBox[
  "\". As expected, the next dominant  multipole following the quadrupole is \
the dodecapole. ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(nharm = 10; radius = 2; y = 0; z = 0; \n
    w = harm[t, {y, z, radius}, nharm]; \n
    mm = Table[multipole[w, i], {i, 0, nharm - 1}]; \nN[mm, 4]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          StyleBox["4.29664526180317807`*^-11",
            StyleBoxAutoDelete->True,
            PrintPrecision->4], "+", 
          RowBox[{
            StyleBox["6.09931372075323086`*^-10",
              StyleBoxAutoDelete->True,
              PrintPrecision->4], " ", "I"}]}], ",", 
        RowBox[{
          RowBox[{
            StyleBox["1.08554260013836834`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4], "\[InvisibleSpace]"}], "+", 
          RowBox[{
            StyleBox["2.5673856046580088`*^-10",
              StyleBoxAutoDelete->True,
              PrintPrecision->4], " ", "I"}]}], ",", 
        RowBox[{
          StyleBox["7.38608507688809368`*^-11",
            StyleBoxAutoDelete->True,
            PrintPrecision->4], "-", 
          RowBox[{
            StyleBox["9.20365783585452845`*^-11",
              StyleBoxAutoDelete->True,
              PrintPrecision->4], " ", "I"}]}], ",", 
        RowBox[{
          StyleBox["3.14302958659418152`*^-11",
            StyleBoxAutoDelete->True,
            PrintPrecision->4], "-", 
          RowBox[{
            StyleBox["1.38215550116171925`*^-12",
              StyleBoxAutoDelete->True,
              PrintPrecision->4], " ", "I"}]}], ",", 
        RowBox[{
          RowBox[{"-", 
            StyleBox["1.74233426297742948`*^-11",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "+", 
          RowBox[{
            StyleBox["4.0053627081704235`*^-12",
              StyleBoxAutoDelete->True,
              PrintPrecision->4], " ", "I"}]}], ",", 
        RowBox[{
          StyleBox["1.10709482754184351`*^-7",
            StyleBoxAutoDelete->True,
            PrintPrecision->4], "-", 
          RowBox[{
            StyleBox["3.10870926223394405`*^-11",
              StyleBoxAutoDelete->True,
              PrintPrecision->4], " ", "I"}]}], ",", 
        RowBox[{
          StyleBox["2.55772000801179899`*^-12",
            StyleBoxAutoDelete->True,
            PrintPrecision->4], "-", 
          RowBox[{
            StyleBox["3.13163367821430105`*^-12",
              StyleBoxAutoDelete->True,
              PrintPrecision->4], " ", "I"}]}], ",", 
        RowBox[{
          RowBox[{"-", 
            StyleBox["6.23563839452501156`*^-12",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "-", 
          RowBox[{
            StyleBox["2.88230377065712417`*^-13",
              StyleBoxAutoDelete->True,
              PrintPrecision->4], " ", "I"}]}], ",", 
        RowBox[{
          RowBox[{"-", 
            StyleBox["7.02652649606227974`*^-13",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "-", 
          RowBox[{
            StyleBox["6.54291898438685848`*^-13",
              StyleBoxAutoDelete->True,
              PrintPrecision->4], " ", "I"}]}], ",", 
        RowBox[{
          RowBox[{"-", 
            StyleBox["9.19737615061311153`*^-13",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], "+", 
          RowBox[{
            StyleBox["3.56335360524040467`*^-13",
              StyleBoxAutoDelete->True,
              PrintPrecision->4], " ", "I"}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnetic Field Plots ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Here are a few plots of magnetic field and field integrals. ", "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(ob = t; z = 0; x1 = 0; x2 = 30; ymax = 40; Npt = 20; \n\n
    bz1 = radFldLst[ob, "\<Bz\>", {x1, 0, z}, {x1, ymax, z}, Npt, "\<arg\>", 
        0]; \nbz2 = 
      radFldLst[ob, "\<Bz\>", {x2, 0, z}, {x2, ymax, z}, Npt, "\<arg\>", 0]; 
    \n\nMultipleListPlot[bz1, bz2, \n\tPlotJoined \[Rule] True, \n\t
      Frame -> True, \n\tRotateLabel\  -> \ False, \n\t
      GridLines\  -> \ Automatic, \n\tSymbolShape -> None, \n\t
      PlotStyle -> {GrayLevel[0], Dashing[{Dash}]}, \n\tPlotLabel -> "\<\>", 
      \n\tFrameLabel -> \ {"\<Y [mm]\>", "\<Bz [T]\>"}\n]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 0.0147151 1.71697 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -20.0625 -21 ]
[.5 -0.0125 20.0625 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10056 -24 -4.5 ]
[-0.0125 .10056 0 4.5 ]
[-0.0125 .18641 -18 -4.5 ]
[-0.0125 .18641 0 4.5 ]
[-0.0125 .27226 -24 -4.5 ]
[-0.0125 .27226 0 4.5 ]
[-0.0125 .35811 -18 -4.5 ]
[-0.0125 .35811 0 4.5 ]
[-0.0125 .44396 -24 -4.5 ]
[-0.0125 .44396 0 4.5 ]
[-0.0125 .52981 -18 -4.5 ]
[-0.0125 .52981 0 4.5 ]
[-0.0125 .61566 -24 -4.5 ]
[-0.0125 .61566 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -64 -6 ]
[-0.01875 .30902 -24 6 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .10056 m
1 .10056 L
s
0 .18641 m
1 .18641 L
s
0 .27226 m
1 .27226 L
s
0 .35811 m
1 .35811 L
s
0 .44396 m
1 .44396 L
s
0 .52981 m
1 .52981 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(20)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(30)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(40)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -81.0625 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 541.000000 16.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(@) show
81.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.125000 13.000000 moveto
(D) show
99.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10056 m
.00625 .10056 L
s
[(0.05)] -0.0125 .10056 1 0 Mshowa
0 .18641 m
.00625 .18641 L
s
[(0.1)] -0.0125 .18641 1 0 Mshowa
0 .27226 m
.00625 .27226 L
s
[(0.15)] -0.0125 .27226 1 0 Mshowa
0 .35811 m
.00625 .35811 L
s
[(0.2)] -0.0125 .35811 1 0 Mshowa
0 .44396 m
.00625 .44396 L
s
[(0.25)] -0.0125 .44396 1 0 Mshowa
0 .52981 m
.00625 .52981 L
s
[(0.3)] -0.0125 .52981 1 0 Mshowa
0 .61566 m
.00625 .61566 L
s
[(0.35)] -0.0125 .61566 1 0 Mshowa
.125 Mabswid
0 .03188 m
.00375 .03188 L
s
0 .04905 m
.00375 .04905 L
s
0 .06622 m
.00375 .06622 L
s
0 .08339 m
.00375 .08339 L
s
0 .11773 m
.00375 .11773 L
s
0 .1349 m
.00375 .1349 L
s
0 .15207 m
.00375 .15207 L
s
0 .16924 m
.00375 .16924 L
s
0 .20358 m
.00375 .20358 L
s
0 .22075 m
.00375 .22075 L
s
0 .23792 m
.00375 .23792 L
s
0 .25509 m
.00375 .25509 L
s
0 .28943 m
.00375 .28943 L
s
0 .3066 m
.00375 .3066 L
s
0 .32377 m
.00375 .32377 L
s
0 .34094 m
.00375 .34094 L
s
0 .37528 m
.00375 .37528 L
s
0 .39245 m
.00375 .39245 L
s
0 .40962 m
.00375 .40962 L
s
0 .42679 m
.00375 .42679 L
s
0 .46113 m
.00375 .46113 L
s
0 .4783 m
.00375 .4783 L
s
0 .49547 m
.00375 .49547 L
s
0 .51264 m
.00375 .51264 L
s
0 .54698 m
.00375 .54698 L
s
0 .56415 m
.00375 .56415 L
s
0 .58132 m
.00375 .58132 L
s
0 .59849 m
.00375 .59849 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -125 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 541.000000 16.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bz) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
81.000000 13.000000 moveto
(@) show
87.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 13.000000 moveto
(D) show
99.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10056 m
1 .10056 L
s
.99375 .18641 m
1 .18641 L
s
.99375 .27226 m
1 .27226 L
s
.99375 .35811 m
1 .35811 L
s
.99375 .44396 m
1 .44396 L
s
.99375 .52981 m
1 .52981 L
s
.99375 .61566 m
1 .61566 L
s
.125 Mabswid
.99625 .03188 m
1 .03188 L
s
.99625 .04905 m
1 .04905 L
s
.99625 .06622 m
1 .06622 L
s
.99625 .08339 m
1 .08339 L
s
.99625 .11773 m
1 .11773 L
s
.99625 .1349 m
1 .1349 L
s
.99625 .15207 m
1 .15207 L
s
.99625 .16924 m
1 .16924 L
s
.99625 .20358 m
1 .20358 L
s
.99625 .22075 m
1 .22075 L
s
.99625 .23792 m
1 .23792 L
s
.99625 .25509 m
1 .25509 L
s
.99625 .28943 m
1 .28943 L
s
.99625 .3066 m
1 .3066 L
s
.99625 .32377 m
1 .32377 L
s
.99625 .34094 m
1 .34094 L
s
.99625 .37528 m
1 .37528 L
s
.99625 .39245 m
1 .39245 L
s
.99625 .40962 m
1 .40962 L
s
.99625 .42679 m
1 .42679 L
s
.99625 .46113 m
1 .46113 L
s
.99625 .4783 m
1 .4783 L
s
.99625 .49547 m
1 .49547 L
s
.99625 .51264 m
1 .51264 L
s
.99625 .54698 m
1 .54698 L
s
.99625 .56415 m
1 .56415 L
s
.99625 .58132 m
1 .58132 L
s
.99625 .59849 m
1 .59849 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .01472 m
.07393 .06823 L
.12406 .12176 L
.17419 .17531 L
.22431 .22892 L
.27444 .28264 L
.32456 .3365 L
.37469 .39046 L
.42481 .44416 L
.47494 .49648 L
.52506 .54459 L
.57519 .58292 L
.62531 .60332 L
.67544 .59812 L
.72556 .56656 L
.77569 .51781 L
.82581 .46397 L
.87594 .41244 L
.92607 .36544 L
.97619 .32218 L
s
[ .04 .015 ] 0 setdash
.02381 .01472 m
.07393 .04796 L
.12406 .0812 L
.17419 .11446 L
.22431 .14778 L
.27444 .18128 L
.32456 .2151 L
.37469 .24944 L
.42481 .28438 L
.47494 .31959 L
.52506 .35382 L
.57519 .38419 L
.62531 .40599 L
.67544 .41367 L
.72556 .40426 L
.77569 .38044 L
.82581 .34881 L
.87594 .31527 L
.92607 .28269 L
.97619 .25117 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{367, 226.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005_0000hQ000`40O003h00OogooL7oo003oOom`
Ool00?moog1oo`00ogooL7oo003oOom`Ool00?moog1oo`00ogooL7oo003oOom`Ool00?moog1oo`00
eWoo0P003Woo0P00Qgoo003FOol00`00Oomoo`0>Ool00`00Oomoo`25Ool00<Uoo`<000Yoo`0?001o
ogooOol007oo001oo`00Ool007oo001oo`00009oo`03001oogoo08Eoo`00bWoo00<007ooOol02Goo
00l007ooOomoo`00Ool007oo001oo`00Ool007oo00000Woo00<007ooOol0QGoo003:Ool00`00Oomo
o`09Ool03`00Oomoogoo001oo`00Ool007oo001oo`00Ool00002Ool00`00Oomoo`25Ool00<Uoo`<0
00Yoo`0?001oogooOol007oo001oo`00Ool007oo001oo`00009oo`03001oogoo08Eoo`00bGoo00<0
07oo00002Woo00<007ooOol030000Woo00<007ooOol0QGoo0038Ool200000goo00000009Ool2000>
Ool20027Ool00?moog1oo`00ogooL7oo003oOom`Ool00?moog1oo`00Bgoo0P00@Goo0`0017oo0P00
?Goo10000goo0P00?Woo0`0017oo0P00?Woo0`000goo0P001Goo001:Ool01000Oomoo`00@Goo00<0
07ooOol00Woo00@007ooOol003eoo`03001oogoo009oo`04001oogoo0010Ool01000Oomoo`000Woo
00<007ooOol0?7oo00D007ooOomoo`00009oo`03001oogoo009oo`00BWoo00@007ooOol0045oo`03
001oogoo009oo`04001oogoo000nOol01@00Oomoogoo00000Woo00<007ooOol0?Woo00@007ooOol0
009oo`03001oogoo03Yoo`@0009oo`04001oogoo0004Ool004Yoo`04001oogoo0011Ool00`00Oomo
o`02Ool01000Oomoo`00?goo00@007ooOol0009oo`03001oogoo03aoo`8000=oo`04001oogoo000l
Ool00`00Ool00003Ool01000Oomoo`0017oo001:Ool01000Oomoo`00@Goo00<007ooOol00Woo00@0
07ooOol003aoo`04001oogoo0002Ool01000Oomoo`00@7oo00@007ooOol0009oo`03001oogoo03Yo
o`03001oo`0000=oo`04001oogoo0004Ool004]oo`80045oo`8000Eoo`8003ioo`8000Aoo`8003io
o`<000Aoo`8003ioo`8000Aoo`8000Eoo`00ogooL7oo003oOom`Ool00?moog1oo`00ogooL7oo003o
Oom`Ool004Eoool002X0005oo`00AGoo00<007ooOol017oo00<007ooOol02goo00<007ooOol02goo
00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo
00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo
00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo
00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol017oo0@000Goo000mOol2
0006Ool00`00Oomoo`1;Ool00`0?Oomoo`13Ool00`0?Oomoo`14Ool00`0?Oomoo`1:Ool10001Ool0
03aoo`04001oogoo0005Ool00`00Oomoo`1;Ool00`0?Oomoo`13Ool00`0?Oomoo`14Ool00`0?Oomo
o`1:Ool10001Ool003aoo`04001oogoo0005Ool30004Ool20015Ool00`0?Oomoo`13Ool00`0?Oomo
o`14Ool00`0?Oomoo`19Ool20001Ool003aoo`04001oogoo0005Ool00`00Oomoo`04Ool01000Ool0
0000@goo00<03gooOol0@goo00<03gooOol0A7oo00<03gooOol0BWoo0@000Goo000lOol01000Oomo
o`001Goo00<007ooOol01Goo00@007ooOol0049oo`0300moogoo04=oo`0300moogoo04Aoo`0300mo
ogoo04Yoo`40005oo`00?Goo0P001Woo00<007ooOol01Woo00<007ooOol00P00@7oo00<03gooOol0
@goo00<03gooOol0A7oo00<03gooOol0BWoo0@000Goo0015Ool00`00Oomoo`07Ool01000Oomoogoo
0P00?Woo00<03gooOol0@goo00<03gooOol0A7oo00<03gooOol0BWoo0@000Goo0015Ool20009Ool0
0`00Oomoo`02Ool00`00Oomoo`0kOol00`0?Oomoo`13Ool00`0?Oomoo`14Ool00`0?Oomoo`19Ool2
0001Ool004Eoo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo03Yoo`0300moogoo04=oo`03
00moogoo04Aoo`0300moogoo04Yoo`40005oo`00AGoo00<007ooOol02Woo00<007ooOol0?Woo00<0
3gooOol0@goo00<03gooOol0A7oo00<03gooOol0BWoo0@000Goo0015Ool00`00Oomoo`0;Ool00`00
Oomoo`0mOol00`0?Oomoo`13Ool00`0?Oomoo`14Ool00`0?Oomoo`1:Ool10001Ool004Eoo`03001o
ogoo00aoo`03001oogoo00=oo`03001oogoo03Ioo`0300moogoo04=oo`0300moogoo04Aoo`0300mo
ogoo04Yoo`40005oo`00AGoo0P003Woo00<007ooOol00goo0P00=Woo00<03gooOol0@goo00<03goo
Ool0A7oo00<03gooOol0BGoo0P000Goo0015Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool2000dOol0
0`0?Oomoo`13Ool00`0?Oomoo`14Ool00`0?Oomoo`1:Ool10001Ool004Eoo`03001oogoo00moo`03
001oogoo00Eoo`80039oo`0300moogoo04=oo`0300moogoo04Aoo`0300moogoo04Yoo`40005oo`00
AGoo00<007ooOol047oo00<007ooOol01Woo00<007ooOol0;goo00<03gooOol0@goo00<03gooOol0
A7oo00<03gooOol0BWoo0@000Goo0015Ool00`00Oomoo`0AOol00`00Oomoo`06Ool2000_Ool00`0?
Oomoo`13Ool00`0?Oomoo`14Ool00`0?Oomoo`1:Ool10001Ool004Eoo`8001=oo`03001oogoo00Mo
o`03001oogoo02aoo`0300moogoo04=oo`0300moogoo04Aoo`0300moogoo04Uoo`80005oo`00AGoo
00<007ooOol04goo00<007ooOol0=Goo00<03gooOol0@goo00<03gooOol0A7oo00<03gooOol0BWoo
0@000Goo0015Ool00`00Oomoo`0COol00`00Oomoo`0eOol00`0?Oomoo`13Ool00`0?Oomoo`14Ool0
0`0?Oomoo`1:Ool10001Ool004Eoo`03001oogoo01Aoo`03001oogoo00Qoo`8002Yoo`0300moogoo
04=oo`0300moogoo04Aoo`0300moogoo04Yoo`40005oo`00AGoo00<007ooOol05Goo00<007ooOol0
2Goo00<007ooOol09goo00<03gooOol0@goo00<03gooOol0A7oo00<03gooOol0BWoo0@000Goo0015
Ool2000GOol00`00Oomoo`09Ool2000WOol00`0?Oomoo`13Ool00`0?Oomoo`14Ool00`0?Oomoo`19
Ool20001Ool004Eoo`03001oogoo01Moo`03001oogoo00Yoo`8002Eoo`0300moogoo04=oo`0300mo
ogoo04Aoo`0300moogoo04Yoo`40005oo`00AGoo00<007ooOol067oo00<007ooOol02goo00<007oo
Ool08Woo00<03gooOol0@goo00<03gooOol0A7oo00<03gooOol0BWoo0@000Goo000[Ool20004Ool2
0004Ool20003Ool30006Ool00`00Oomoo`0IOol00`00Oomoo`0;Ool2000ROol00`0?Oomoo`13Ool0
0`0?Oomoo`14Ool00`0?Oomoo`1:Ool10001Ool002Yoo`04001oogoo0003Ool20003Ool01000Oomo
o`001Goo00<007ooOol00goo00<007ooOol06Woo00<007ooOol037oo00<007ooOol07goo00<03goo
Ool0@goo00<03gooOol0A7oo00<03gooOol0BWoo0@000Goo000ZOol01000Oomoo`0027oo00@007oo
Ool000Eoo`03001oogoo00=oo`<001/03`0300003`0?0?l03`L03`80005oo`00:Woo00@007ooOol0
00Qoo`04001oogoo0002Ool30006Ool00`00Oomoo`0LOol00`00Oomoo`0/Ool00`0?Oomoo`13Ool0
0`0?Oomoo`14Ool00`0?Oomoo`1:Ool10001Ool002Yoo`04001oogoo0008Ool01000Oomoo`000Woo
00<007ooOol01Woo00<007ooOol07Goo00<007ooOol03Goo0P0077oo00<03gooOol0@goo00<03goo
Ool0A7oo00<03gooOol0BWoo0@000Goo000[Ool2000:Ool20003Ool40005Ool00`00Oomoo`0NOol0
0`00Oomoo`0>Ool2000JOol00`0?Oomoo`13Ool00`0?Oomoo`14Ool00`0?Oomoo`1:Ool10001Ool0
04Eoo`03001oogoo01moo`03001oogoo00moo`8001Qoo`0300moogoo04=oo`0300moogoo04Aoo`03
00moogoo04Yoo`40005oo`00AGoo0P008Goo00<007ooOol047oo00<007ooOol05Goo00<03gooOol0
@goo00<03gooOol0A7oo00<03gooOol0BGoo0P000Goo0015Ool00`00Oomoo`0QOol00`00Oomoo`0@
Ool00`00Oomoo`0DOol00`0?Oomoo`13Ool00`0?Oomoo`14Ool00`0?Oomoo`1:Ool10001Ool004Eo
o`03001oogoo029oo`03001oogoo011oo`03001oogoo01=oo`0300moogoo04=oo`0300moogoo04Ao
o`0300moogoo04Yoo`40005oo`00AGoo00<007ooOol08goo00<007ooOol047oo00<007ooOol04Woo
00<03gooOol0@goo00<03gooOol0A7oo00<03gooOol0BWoo0@000Goo0015Ool00`00Oomoo`0TOol0
0`00Oomoo`0@Ool00`00Oomoo`0AOol00`0?Oomoo`13Ool00`0?Oomoo`14Ool00`0?Oomoo`1:Ool1
0001Ool004Eoo`03001oogoo02Eoo`03001oogoo02=oo`0300moogoo04=oo`0300moogoo04Aoo`03
00moogoo04Yoo`40005oo`00AGoo0P009goo00<007ooOol04Goo0P003goo00<03gooOol0@goo00<0
3gooOol0A7oo00<03gooOol0BGoo0P000Goo0015Ool00`00Oomoo`0WOol00`00Oomoo`0BOol2000=
Ool00`0?Oomoo`13Ool00`0?Oomoo`14Ool00`0?Oomoo`1:Ool10001Ool004Eoo`03001oogoo02Qo
o`03001oogoo01=oo`8000]oo`0300moogoo04=oo`0300moogoo04Aoo`0300moogoo04Yoo`40005o
o`00AGoo00<007ooOol0:Goo00<007ooOol057oo00<007ooOol027oo00<03gooOol0@goo00<03goo
Ool0A7oo00<03gooOol0BWoo0@000Goo0015Ool00`00Oomoo`0ZOol00`00Oomoo`0DOol00`00Oomo
o`07Ool00`0?Oomoo`13Ool00`0?Oomoo`14Ool00`0?Oomoo`1:Ool10001Ool004Eoo`8002aoo`03
001oogoo01Aoo`03001oogoo00Ioo`0300moogoo04=oo`0300moogoo04Aoo`0300moogoo04Uoo`80
005oo`00AGoo00<007ooOol0;7oo00<007ooOol057oo00<007ooOol01Goo00<03gooOol0@goo00<0
3gooOol0A7oo00<03gooOol0BWoo0@000Goo0015Ool00`00Oomoo`0]Ool00`00Oomoo`0DOol00`00
Oomoo`04Ool00`0?Oomoo`13Ool00`0?Oomoo`14Ool00`0?Oomoo`1:Ool10001Ool004Eoo`03001o
ogoo02ioo`03001oogoo01Yoo`0300moogoo04=oo`0300moogoo04Aoo`0300moogoo04Yoo`40005o
o`00AGoo00<007ooOol0;goo00<007ooOol05Woo0P0000=oo`0?Ool0A7oo00<03gooOol0A7oo00<0
3gooOol0BWoo0@000Goo0015Ool2000aOol00`00Oomoo`0GOol00`0000moo`14Ool00`0?Oomoo`14
Ool00`0?Oomoo`19Ool20001Ool004Eoo`03001oogoo035oo`03001oogoo01Moo`8004Aoo`0300mo
ogoo04Aoo`0300moogoo04Yoo`40005oo`00AGoo00<007ooOol0<Goo00<007ooOol05goo00<03goo
0000@goo00<03gooOol0A7oo00<03gooOol0BWoo0@000Goo000aOol20004Ool20003Ool30006Ool0
0`00Oomoo`0bOol00`00Oomoo`0FOol00`0?Oomoo`020011Ool00`0?Oomoo`14Ool00`0?Oomoo`1:
Ool10001Ool0031oo`04001oogoo0003Ool20004Ool00`00Oomoo`05Ool00`00Oomoo`0cOol00`00
Oomoo`0EOol00`0?Oomoo`02Ool00`00Oomoo`0nOol00`0?Oomoo`14Ool00`0?Oomoo`1:Ool10001
Ool0031oo`04001oogoo0009Ool00`00Oomoo`05Ool3000d00l00`0000l03`0J00l00`0000l03`3@
00l20001Ool0031oo`04001oogoo0009Ool00`00Oomoo`05Ool00`00Oomoo`0eOol00`00Oomoo`0C
Ool00`0?Oomoo`04Ool00`00Oomoo`0lOol00`0?Oomoo`14Ool00`0?Oomoo`1:Ool10001Ool0031o
o`04001oogoo0009Ool00`00Oomoo`05Ool00`00Oomoo`0fOol00`00Oomoo`0BOol00`0?Oomoo`13
Ool00`0?Oomoo`14Ool00`0?Oomoo`1:Ool10001Ool0035oo`8000Uoo`8000Moo`03001oogoo03Mo
o`03001oogoo015oo`0300moogoo00Moo`8003Yoo`0300moogoo04Aoo`0300moogoo04Yoo`40005o
o`00AGoo00<007ooOol0>7oo00<007ooOol047oo00<03gooOol02Goo00<007ooOol0=goo00<03goo
Ool0A7oo00<03gooOol0BWoo0@000Goo0015Ool2000jOol00`00Oomoo`0?Ool00`0?Oomoo`0:Ool2
000gOol00`0?Oomoo`14Ool00`0?Oomoo`19Ool20001Ool004Eoo`03001oogoo03Yoo`03001oogoo
00ioo`0300moogoo00aoo`8003Eoo`0300moogoo04Aoo`0300moogoo04Yoo`40005oo`00AGoo00<0
07ooOol0>goo00<007ooOol03Goo00<03gooOol03Woo00<007ooOol0<Woo00<03gooOol0A7oo00<0
3gooOol0BWoo0@000Goo0015Ool00`00Oomoo`0lOol00`00Oomoo`0<Ool00`0?Oomoo`0?Ool00`00
Oomoo`0aOol00`0?Oomoo`14Ool00`0?Oomoo`1:Ool10001Ool004Eoo`03001oogoo03eoo`03001o
ogoo00]oo`0300moogoo011oo`03001oogoo031oo`0300moogoo04Aoo`0300moogoo04Yoo`40005o
o`00AGoo0P00?goo00<007ooOol02Woo00<03gooOol04Goo00<007ooOol0;goo00<03gooOol0A7oo
00<03gooOol0BGoo0P000Goo0015Ool00`00Oomoo`0oOol00`00Oomoo`09Ool00`0?Oomoo`13Ool0
0`0?Oomoo`14Ool00`0?Oomoo`1:Ool10001Ool004Eoo`03001oogoo041oo`03001oogoo00Qoo`03
00moogoo01Eoo`8002aoo`0300moogoo04Aoo`0300moogoo04Yoo`40005oo`00AGoo00<007ooOol0
@7oo00<007ooOol027oo00<03gooOol05goo00<007ooOol0:Goo00<03gooOol0A7oo00<03gooOol0
BWoo0@000Goo0015Ool00`00Oomoo`11Ool00`00Oomoo`07Ool00`0?Oomoo`0HOol2000YOol00`0?
Oomoo`14Ool00`0?Oomoo`1:Ool10001Ool004Eoo`8004=oo`03001oogoo00Ioo`0300moogoo01Yo
o`03001oogoo02Ioo`0300moogoo04Aoo`0300moogoo04Uoo`80005oo`00AGoo00<007ooOol0@goo
00<007ooOol01Goo00<03gooOol06goo0P009Woo00<03gooOol0A7oo00<03gooOol0BWoo0@000Goo
0015Ool00`00Oomoo`14Ool00`00Oomoo`04Ool00`0?Oomoo`0MOol00`00Oomoo`0SOol00`0?Oomo
o`14Ool00`0?Oomoo`1:Ool10001Ool004Eoo`03001oogoo04Eoo`03001oogoo00=oo`0300moogoo
01ioo`03001oogoo029oo`0300moogoo04Aoo`0300moogoo04Yoo`40005oo`00AGoo00<007ooOol0
AWoo00<007ooOol00Woo00<03gooOol07goo00<007ooOol08Goo00<03gooOol0A7oo00<03gooOol0
@Woo0P001Woo0@000Goo0015Ool20018Ool01@00Oomoogoo00l0AGoo00<03gooOol0A7oo00<03goo
Ool0@Goo00<007ooOol01Goo0P000Goo0015Ool00`00Oomoo`17Ool01@00Oomoogoo00l0AGoo00<0
3gooOol0A7oo00<03gooOol0@7oo00<007ooOol01goo0@000Goo0015Ool00`00Oomoo`18Ool01000
Oomoo`0?97oo0P007goo00<03gooOol0A7oo00<03gooOol0BWoo0@000Goo000[Ool20004Ool20003
Ool30003Ool30006Ool00`00Oomoo`19Ool00`00Ool03`0VOol2000MOol00`0?Oomoo`14Ool00`0?
Oomoo`1:Ool10001Ool002Yoo`04001oogoo0003Ool20004Ool00`00Oomoo`05Ool00`00Oomoo`03
Ool00`00Oomoo`1:Ool00`0000moo`0WOol00`00Oomoo`0JOol00`0?Oomoo`14Ool00`0?Oomoo`0k
Ool2000=Ool10001Ool002Yoo`04001oogoo0009Ool00`00Oomoo`05Ool00`00Oomoo`03Ool3001;
00l00`0000l03`0W00l2002M00l2000>00l20001Ool002Yoo`04001oogoo0009Ool00`00Oomoo`02
Ool30006Ool00`00Oomoo`1;Ool00`0?001oo`0YOol2000HOol00`0?Oomoo`14Ool00`0?Oomoo`0g
Ool2000AOol10001Ool002Yoo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Oomoo`1;Ool00`0?Ool0000[Ool00`00Oomoo`0EOol00`0?Oomoo`14Ool00`0?Oomoo`0eOol2000C
Ool10001Ool002]oo`8000Uoo`8000Aoo`@000Eoo`03001oogoo04]oo`0400moogoo000[Ool00`00
Oomoo`0DOol00`0?Oomoo`14Ool00`0?Oomoo`0dOol00`00Oomoo`0COol10001Ool004Eoo`03001o
ogoo04]oo`0400moogoo0012Ool00`0?Oomoo`14Ool00`0?Oomoo`0cOol00`00Oomoo`0DOol10001
Ool004Eoo`8004aoo`0500moogooOol00011Ool00`0?Oomoo`14Ool00`0?Oomoo`0bOol00`00Oomo
o`0DOol20001Ool004Eoo`03001oogoo04]oo`0300moogoo009oo`03001oogoo02]oo`80015oo`03
00moogoo04Aoo`0300moogoo04Yoo`40005oo`005goo0P0027oo0P008Woo00<007ooOol0Bgoo00<0
3gooOol00goo00<007ooOol0;7oo00<007ooOol03Woo00<03gooOol0A7oo00<03gooOol0;Goo0P00
6goo0@000Goo000GOol00`00Oomoo`08Ool00`00Oomoo`0POol00`00Oomoo`1;Ool00`0?Oomoo`04
Ool00`00Oomoo`0/Ool00`00Oomoo`0=Ool00`0?Oomoo`14Ool00`0?Oomoo`0/Ool00`00Oomoo`0K
Ool10001Ool0009oo`@000=oo`@000Yoo`03001oogoo009oo`<000=oo`03001oogoo021oo`03001o
ogoo04]oo`0300moogoo00Eoo`03001oogoo02aoo`8000eoo`0300moogoo04Aoo`0300moogoo02]o
o`03001oogoo01aoo`40005oo`000goo00@007ooOol000=oo`03001oogoo00Yoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo021oo`8004aoo`0300moogoo00Ioo`03001oogoo02eoo`03001o
ogoo00Yoo`0300moogoo04Aoo`0300moogoo02Uoo`8001ioo`80005oo`000goo00@007ooOol000=o
o`8000]oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo021oo`03001oogoo04]oo`0300mo
ogoo00Moo`03001oogoo02eoo`03001oogoo00Uoo`0300moogoo04Aoo`0300moogoo02Qoo`03001o
ogoo01moo`40005oo`000goo0`001Goo00<007ooOol02Goo00T007ooOomoo`00Ool007oo00000Woo
00<007ooOol087oo00<007ooOol0Bgoo00<03gooOol027oo00<007ooOol0;Goo00<007ooOol027oo
00<03gooOol0A7oo00<03gooOol09goo00<007ooOol087oo0@000Goo0003Ool01000Oomoo`000Woo
10002Woo00T007ooOomoo`00Ool007oo00000Woo00<007ooOol087oo00<007ooOol0Bgoo00<03goo
Ool02Goo00<007ooOol0;Goo00<007ooOol01goo00<03gooOol0A7oo00<03gooOol09Goo0P008goo
0@000Goo0002Ool4000AOol20002Ool500000goo0000000ROol00`00Oomoo`1;Ool00`0?Oomoo`0:
Ool00`00Oomoo`0fOol00`0?Oomoo`14Ool00`0?Oomoo`0TOol00`00Oomoo`0SOol10001Ool004Eo
o`8004aoo`0300moogoo00]oo`03001oogoo02moo`8000Aoo`0300moogoo04Aoo`0300moogoo049o
o`8000Eoo`80005oo`00AGoo00<007ooOol0Bgoo00<03gooOol037oo00<007ooOol0<7oo00D007oo
Oomoo`0?04Ioo`0300moogoo021oo`8001moo`03001oogoo00Ioo`40005oo`00AGoo00<007ooOol0
Bgoo00<03gooOol03Goo00<007ooOol0<7oo0P0000=oo`0?Ool0AGoo00<03gooOol07goo00<007oo
Ool07Woo00<007ooOol01goo0@000Goo0015Ool00`00Oomoo`1;Ool00`0?Oomoo`0>Ool00`00Oomo
o`0aOol00`0000moo`15Ool00`0?Oomoo`0MOol2000POol00`00Oomoo`08Ool10001Ool004Eoo`03
001oogoo04]oo`0300moogoo00moo`03001oogoo035oo`03001oogoo04Aoo`0300moogoo01aoo`03
001oogoo01moo`03001oogoo00Uoo`40005oo`00AGoo00<007ooOol0Bgoo00<03gooOol03goo00<0
07ooOol0<Goo00<03`000000A7oo00<03gooOol06goo00<007ooOol07goo00<007ooOol02Woo0@00
0Goo0015Ool2001<Ool00`0?Oomoo`0@Ool00`00Oomoo`0`Ool0100?Oomoo`00@goo00<03gooOol0
6Goo0P0087oo0P0037oo0P000Goo0015Ool00`00Oomoo`1;Ool00`0?Oomoo`0AOol00`00Oomoo`0_
Ool01@0?Oomoogoo0000@Woo00<03gooOol067oo00<007ooOol07goo00<007ooOol03Goo0@000Goo
0015Ool00`00Oomoo`1;Ool00`0?Oomoo`0BOol00`00Oomoo`0^Ool00`0?Oomoo`14Ool00`0?Oomo
o`0GOol00`00Oomoo`0OOol00`00Oomoo`0>Ool10001Ool0035oo`8000Aoo`8000=oo`@000Eoo`03
001oogoo04]oo`0300moogoo01=oo`03001oogoo02eoo`0300moogoo00Eoo`8003eoo`0300moogoo
03Qoo`03001oogoo00moo`40005oo`00<7oo00@007ooOol000=oo`8000Aoo`03001oogoo00Eoo`03
001oogoo04]oo`0300moogoo01Aoo`03001oogoo02aoo`0300moogoo00Moo`03001oogoo03Yoo`03
00moogoo019oo`8002=oo`03001oogoo011oo`40005oo`00<7oo00@007ooOol000Yoo`03001oogoo
00Aoo`<006<03`0300003`0?03H03`8004h03`0300003`0?02803`0300003`0?01003`80005oo`00
<7oo00@007ooOol000]oo`03001oogoo00=oo`03001oogoo04]oo`0300moogoo01Ioo`03001oogoo
02Yoo`0300moogoo00Yoo`03001oogoo03Moo`0300moogoo00moo`8002Aoo`03001oogoo019oo`40
005oo`00<7oo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`1;Ool00`0?Oomoo`0GOol0
0`00Oomoo`0YOol00`0?Oomoo`0;Ool00`00Oomoo`0fOol00`0?Oomoo`0>Ool00`00Oomoo`0SOol0
0`00Oomoo`0COol10001Ool0035oo`8000Yoo`8000Ioo`03001oogoo04]oo`0300moogoo01Qoo`03
001oogoo02Qoo`0300moogoo00aoo`8003Ioo`0300moogoo00eoo`03001oogoo02=oo`03001oogoo
01Aoo`40005oo`00AGoo00<007ooOol0Bgoo00<03gooOol06Goo00<007ooOol09goo00<03gooOol0
3Woo00<007ooOol0<goo00<03gooOol02goo0P009Goo00<007ooOol05Goo0@000Goo0015Ool2001<
Ool00`0?Oomoo`0JOol00`00Oomoo`0VOol00`0?Oomoo`0?Ool00`00Oomoo`0bOol00`0?Oomoo`0:
Ool00`00Oomoo`0TOol00`00Oomoo`0EOol20001Ool004Eoo`03001oogoo04]oo`0300moogoo01]o
o`03001oogoo02Eoo`0300moogoo04Aoo`0300moogoo00Uoo`03001oogoo02Aoo`03001oogoo01Mo
o`40005oo`00AGoo00<007ooOol0Bgoo00<03gooOol077oo00<007ooOol097oo00<03gooOol04Woo
0`00;goo00<03gooOol0;goo00<007ooOol067oo0@000Goo0015Ool00`00Oomoo`1;Ool00`0?Oomo
o`0MOol00`00Oomoo`0SOol00`0?Oomoo`0EOol2000]Ool00`0?Oomoo`04Ool2000XOol00`00Oomo
o`0IOol10001Ool004Eoo`03001oogoo04]oo`0300moogoo01ioo`03001oogoo029oo`0300moogoo
01Moo`8002]oo`0300moogoo009oo`8002Uoo`03001oogoo01Yoo`40005oo`00AGoo0P00C7oo00<0
3gooOol07Woo00<007ooOol08Woo00<03gooOol06Goo0P00:Goo00<03goo00000P00:Woo00<007oo
Ool06Woo0P000Goo0015Ool00`00Oomoo`1;Ool00`0?Oomoo`0OOol00`00Oomoo`0QOol00`0?Oomo
o`0KOol2000WOol2000/Ool00`00Oomoo`0LOol10001Ool004Eoo`03001oogoo04]oo`0300moogoo
021oo`03001oogoo021oo`0300moogoo01eoo`03001oogoo029oo`80000300moogoo02Yoo`03001o
ogoo01eoo`40005oo`00AGoo00<007ooOol0Bgoo00<03gooOol08Goo00<007ooOol07goo00<03goo
Ool08Goo00<007ooOol07Goo00@007ooOol03b]oo`03001oogoo01ioo`40005oo`00AGoo00<007oo
Ool0Bgoo00<03gooOol08Woo00<007ooOol07Woo00<03gooOol08Woo1`004Goo10001Woo00<03goo
Ool0:7oo00<007ooOol07goo0@000Goo0015Ool2001<Ool00`0?Oomoo`0SOol00`00Oomoo`0MOol0
0`0?Oomoo`0YOol50006Ool6000:Ool00`0?Oomoo`0WOol00`00Oomoo`0OOol20001Ool004Eoo`03
001oogoo04]oo`0300moogoo02Aoo`03001oogoo01aoo`0300moogoo035oo`<0011oo`0300moogoo
02Ioo`03001oogoo025oo`40005oo`00AGoo00<007ooOol0Bgoo00<03gooOol09Goo00<007ooOol0
6goo00<03gooOol0A7oo00<03gooOol09Goo00<007ooOol08Woo0@000Goo0015Ool00`00Oomoo`1;
Ool00`0?Oomoo`0VOol00`00Oomoo`0JOol00`0?Oomoo`14Ool00`0?Oomoo`0TOol00`00Oomoo`0S
Ool10001Ool004Eoo`03001oogoo04]oo`0300moogoo02Moo`03001oogoo01Uoo`0300moogoo04Ao
o`0300moogoo02=oo`03001oogoo02Aoo`40005oo`00AGoo0P00C7oo00<03gooOol0:7oo00<007oo
Ool067oo00<03gooOol0A7oo00<03gooOol08Woo00<007ooOol097oo0P000Goo0015Ool00`00Oomo
o`1;Ool00`0?Oomoo`0YOol00`00Oomoo`0GOol00`0?Oomoo`14Ool00`0?Oomoo`0QOol00`00Oomo
o`0VOol10001Ool004Eoo`03001oogoo04]oo`0300moogoo02Yoo`03001oogoo01Ioo`0300moogoo
04Aoo`0300moogoo021oo`03001oogoo02Moo`40005oo`00:goo0P0017oo0P000goo10000Woo0`00
1Woo00<007ooOol0Bgoo00<03gooOol0:goo00<007ooOol05Goo00<03gooOol0A7oo00<03gooOol0
7goo00<007ooOol0:7oo0@000Goo000ZOol01000Oomoo`000goo0P0017oo00<007ooOol01Goo00<0
07ooOol00goo00<007ooOol0Bgoo00<03gooOol0;7oo00<007ooOol057oo00<03gooOol0A7oo00<0
3gooOol07Woo00<007ooOol0:Goo0@000Goo000ZOol01000Oomoo`002Woo00<007ooOol017oo00<0
07ooOol00goo0`00N`0?00<0000?00l0NP0?00<0000?00l0:@0?0P000Goo000ZOol01000Oomoo`00
2goo00<007ooOol00`001Woo00<007ooOol0Bgoo00<03gooOol0;Goo00<007ooOol04goo00<03goo
Ool0A7oo00<03gooOol077oo00<007ooOol0:goo0@000Goo000ZOol01000Oomoo`0027oo00@007oo
Ool0009oo`03001oogoo00Ioo`03001oogoo04]oo`0300moogoo02ioo`03001oogoo019oo`0300mo
ogoo04Aoo`0300moogoo01]oo`03001oogoo02aoo`40005oo`00:goo0P002Woo0P000goo10001Goo
00<007ooOol0Bgoo00<03gooOol0;goo00<007ooOol04Goo00<03gooOol0A7oo00<03gooOol06Woo
00<007ooOol0;Goo0@000Goo0015Ool00`00Oomoo`1;Ool00`0?Oomoo`0`Ool00`00Oomoo`0@Ool0
0`0?Oomoo`14Ool00`0?Oomoo`0IOol00`00Oomoo`0^Ool10001Ool004Eoo`8004aoo`0300moogoo
035oo`03001oogoo00moo`0300moogoo04Aoo`0300moogoo01Qoo`03001oogoo02ioo`80005oo`00
AGoo00<007ooOol0Bgoo00<03gooOol0<Woo00<007ooOol03Woo00<03gooOol0A7oo00<03gooOol0
5goo00<007ooOol0<7oo0@000Goo0015Ool00`00Oomoo`1;Ool00`0?Oomoo`0cOol00`00Oomoo`0=
Ool00`0?Oomoo`14Ool00`0?Oomoo`0GOol00`00Oomoo`0`Ool10001Ool004Eoo`03001oogoo04]o
o`0300moogoo03Aoo`03001oogoo00aoo`0300moogoo04Aoo`0300moogoo01Ioo`03001oogoo035o
o`40005oo`00AGoo00<007ooOol0Bgoo00<03gooOol0=Goo00<007ooOol02goo00<03gooOol0A7oo
00<03gooOol05Goo00<007ooOol0<Woo0@000Goo0015Ool2001<Ool00`0?Oomoo`0fOol00`00Oomo
o`0:Ool00`0?Oomoo`14Ool00`0?Oomoo`0DOol00`00Oomoo`0bOol20001Ool004Eoo`03001oogoo
04]oo`0300moogoo03Moo`03001oogoo00Uoo`0300moogoo04Aoo`0300moogoo01=oo`03001oogoo
03Aoo`40005oo`00AGoo00<007ooOol0Bgoo00<03gooOol0>7oo00<007ooOol027oo00<03gooOol0
A7oo00<03gooOol04Woo00<007ooOol0=Goo0@000Goo0015Ool00`00Oomoo`1;Ool00`0?Oomoo`0i
Ool00`00Oomoo`07Ool00`0?Oomoo`14Ool00`0?Oomoo`0AOol00`00Oomoo`0fOol10001Ool004Eo
o`03001oogoo04]oo`0300moogoo03Yoo`03001oogoo00Ioo`0300moogoo04Aoo`0300moogoo011o
o`03001oogoo03Moo`40005oo`00AGoo0P00C7oo00<03gooOol0>goo00<007ooOol01Goo00<03goo
Ool0A7oo00<03gooOol03goo00<007ooOol0=goo0P000Goo0015Ool00`00Oomoo`1;Ool00`0?Oomo
o`0lOol20005Ool00`0?Oomoo`14Ool00`0?Oomoo`0>Ool00`00Oomoo`0iOol10001Ool004Eoo`03
001oogoo04]oo`0300moogoo03ioo`03001oogoo009oo`0300moogoo04Aoo`0300moogoo00eoo`03
001oogoo03Yoo`40005oo`00AGoo00<007ooOol0Bgoo00<03gooOol0?goo00D007ooOomoo`0?04Io
o`0300moogoo00aoo`03001oogoo03]oo`40005oo`00AGoo00<007ooOol0Bgoo00<03gooOol0@7oo
00@007ooOol03dIoo`0300moogoo00]oo`03001oogoo03aoo`40005oo`00AGoo0P00C7oo00<03goo
Ool0@Goo00<007oo00l0AWoo00<03gooOol02Woo00<007ooOol0?7oo0P000Goo0015Ool00`00Oomo
o`1;Ool00`0?Oomoo`12Ool00`0000moo`15Ool00`0?Oomoo`09Ool00`00Oomoo`0nOol10001Ool0
04Eoo`03001oogoo04]oo`0300moogoo04=oo`03001oogoo04Aoo`0300moogoo00Moo`80045oo`40
005oo`00AGoo00<007ooOol0Bgoo00<03gooOol0@goo00<03`00Ool0A7oo00<03gooOol01Woo00<0
07ooOol0@Goo0@000Goo000aOol20004Ool20003Ool30006Ool00`00Oomoo`1;Ool00`0?Oomoo`13
Ool00`0?Ool00014Ool00`0?Oomoo`05Ool00`00Oomoo`12Ool10001Ool0031oo`04001oogoo0003
Ool20006Ool00`00Oomoo`03Ool00`00Oomoo`1;Ool00`0?Oomoo`13Ool0100?Oomoo`00@goo00<0
3gooOol017oo00<007ooOol0@goo0@000Goo000`Ool01000Oomoo`002goo00<007ooOol00goo0`00
U@0?00<0000?00l0AP0?00<0000?00l0@`0?0P000Goo000`Ool01000Oomoo`002Goo0P001Woo00<0
07ooOol0Bgoo00<03gooOol0@goo00<03gooOol00Woo00<007ooOol0?goo00<03gooOol00Woo00<0
07ooOol0AGoo0@000Goo000`Ool01000Oomoo`002goo00<007ooOol00goo00<007ooOol0Bgoo00<0
3gooOol0@goo00<03gooOol00goo00<007ooOol0?Woo00D03gooOomoo`0004Qoo`40005oo`00<Goo
0P002Goo0`001Woo00<007ooOol0Bgoo00<03gooOol0@goo00<03gooOol017oo00<007ooOol0?Goo
00@03gooOol004Uoo`40005oo`00AGoo00<007ooOol0Bgoo00<03gooOol0@goo00<03gooOol01Goo
0P00?Goo00<03goo0000BWoo0@000Goo0015Ool2001<Ool00`0?Oomoo`13Ool00`0?Oomoo`07Ool0
0`00Oomoo`0jOol00`0?001oo`19Ool20001Ool004Eoo`03001oogoo04]oo`0300moogoo04=oo`03
00moogoo00Qoo`03001oogoo03Uoo`03001oogoo04Yoo`40005oo`00AGoo00<007ooOol0Bgoo00<0
3gooOol0@goo00<03gooOol02Goo00<007ooOol0=goo00<0000?Ool0Bgoo0@000Goo0015Ool00`00
Oomoo`1;Ool00`0?Oomoo`13Ool00`0?Oomoo`0:Ool2000fOol00`00Ool03`1<Ool10001Ool004Eo
o`03001oogoo04]oo`0300moogoo04=oo`0300moogoo00aoo`03001oogoo039oo`04001oogoo00m<
Ool10001Ool004Eoo`8004aoo`0300moogoo04=oo`0300moogoo00eoo`03001oogoo02moo`8000=o
o`0300moogoo04Uoo`80005oo`00AGoo00<007ooOol0Bgoo00<03gooOol0@goo00<03gooOol03Woo
0P00;Woo00<007ooOol00goo00<03gooOol0BWoo0@000Goo0015Ool00`00Oomoo`1;Ool00`0?Oomo
o`13Ool00`0?Oomoo`0@Ool00`00Oomoo`0YOol20006Ool00`0?Oomoo`1:Ool10001Ool004Eoo`03
001oogoo04]oo`0300moogoo04=oo`0300moogoo015oo`03001oogoo02Moo`03001oogoo00Ioo`03
00moogoo04Yoo`40005oo`00AGoo00<007ooOol0Bgoo00<03gooOol0@goo00<03gooOol04Woo00<0
07ooOol097oo0P002Goo00<03gooOol0BWoo0@000Goo0015Ool2001<Ool00`0?Oomoo`13Ool00`0?
Oomoo`0COol2000SOol00`00Oomoo`09Ool00`0?Oomoo`19Ool20001Ool004Eoo`03001oogoo04]o
o`0300moogoo04=oo`0300moogoo01Eoo`<001ioo`8000aoo`0300moogoo04Yoo`40005oo`00AGoo
00<007ooOol0Bgoo00<03gooOol0@goo00<03gooOol067oo0P006goo00<007ooOol037oo00<03goo
Ool0BWoo0@000Goo0015Ool00`00Oomoo`1;Ool00`0?Oomoo`13Ool00`0?Oomoo`0JOol3000FOol2
000?Ool00`0?Oomoo`1:Ool10001Ool004Eoo`03001oogoo04]oo`0300moogoo04=oo`0300moogoo
01eoo`8001=oo`03001oogoo00moo`0300moogoo04Yoo`40005oo`00AGoo0P00C7oo00<03gooOol0
@goo00<03gooOol07goo0`0027oo20004Woo00<03gooOol0BGoo0P000Goo0015Ool00`00Oomoo`1;
Ool00`0?Oomoo`13Ool00`0?Oomoo`0ROol8000JOol00`0?Oomoo`1:Ool10001Ool004Eoo`03001o
ogoo04]oo`0300moogoo04=oo`0300moogoo04Aoo`0300moogoo04Yoo`40005oo`00:goo0P0017oo
0P000goo0`000goo0`001Woo00<007ooOol0Bgoo00<03gooOol0@goo00<03gooOol0A7oo00<03goo
Ool0BWoo0@000Goo000ZOol01000Oomoo`000goo0P001Woo00<007ooOol00goo00<007ooOol00goo
00<007ooOol017oo00<007ooOol0A7oo00<007ooOol0@goo00<007ooOol0A7oo00<007ooOol0@goo
00<007ooOol017oo0@000Goo000ZOol01000Oomoo`002goo00<007ooOol00goo00<007ooOol00goo
0`0017oo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo00<007oo
Ool02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007oo
Ool02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007oo
Ool02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007oo
Ool02goo00<007ooOol00goo0P000Goo000ZOol01000Oomoo`002Goo0P000goo0`001Wooo`00:P00
0Goo000ZOol01000Oomoo`002goo00@007ooOol00?mooc=oo`00:goo0P002Goo0`000goo1000ogoo
<7oo003oOom`Ool00?moog1oo`00ogooL7oo003oOom`Ool00?moog1oo`00ogooL7oo003oOom`Ool0
0?moog1oo`00\
\>"],
  ImageRangeCache->{{{0, 366}, {225.688, 0}} -> {-10.8591, -0.0709385, 
  0.141741, 0.00196554}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ob = t; z = 0; ymax = 10; \nRadPlotOptions[\ ]; \n
    Iz0 = radFldInt[ob, "\<inf\>", "\<ibz\>", {\(-1\), 1, z}, {1, 1, z}]; \n\n
    Plot[\((radFldInt[ob, "\<inf\>", "\<ibz\>", {\(-1\), y, z}, {1, y, z}]/
              \((y*Iz0)\) - 1)\)*100, {y, 0, ymax}, \n
      FrameLabel -> {"\<Y [mm]\>", "\<dIz [%]\>", 
          "\<Z = \>"<>ToString[z]<>"\< mm\>", "\<\>"}]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.158612 4.64111 [
[.02381 -0.0125 -5 -14 ]
[.02381 -0.0125 5 0 ]
[.21429 -0.0125 -5 -14 ]
[.21429 -0.0125 5 0 ]
[.40476 -0.0125 -5 -14 ]
[.40476 -0.0125 5 0 ]
[.59524 -0.0125 -5 -14 ]
[.59524 -0.0125 5 0 ]
[.78571 -0.0125 -5 -14 ]
[.78571 -0.0125 5 0 ]
[.97619 -0.0125 -8 -14 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.0625 -28 ]
[.5 -0.0125 21.0625 -14 ]
[-0.0125 .06579 -33.25 -7 ]
[-0.0125 .06579 0 7 ]
[-0.0125 .15861 -10 -7 ]
[-0.0125 .15861 0 7 ]
[-0.0125 .25143 -25 -7 ]
[-0.0125 .25143 0 7 ]
[-0.0125 .34426 -25 -7 ]
[-0.0125 .34426 0 7 ]
[-0.0125 .43708 -25 -7 ]
[-0.0125 .43708 0 7 ]
[-0.0125 .5299 -25 -7 ]
[-0.0125 .5299 0 7 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -73.3125 -7 ]
[-0.01875 .30902 -33.25 7 ]
[ 0 .61803 .125 0 ]
[.5 .63053 -26.3125 0 ]
[.5 .63053 26.3125 14 ]
[ 1 0 .125 0 ]
[ -0.0005 -0.0005 0 0 ]
[ 1.0005 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .61803 L
s
.40476 0 m
.40476 .61803 L
s
.59524 0 m
.59524 .61803 L
s
.78571 0 m
.78571 .61803 L
s
0 .06579 m
1 .06579 L
s
0 .15861 m
1 .15861 L
s
0 .25143 m
1 .25143 L
s
0 .34426 m
1 .34426 L
s
0 .43708 m
1 .43708 L
s
0 .5299 m
1 .5299 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.0625 -32 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
74.625000 14.000000 moveto
(@) show
78.562500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
97.187500 14.000000 moveto
(D) show
101.125000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
0 .06579 m
.00625 .06579 L
s
gsave
-0.0125 .06579 -94.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 .15861 m
.00625 .15861 L
s
gsave
-0.0125 .15861 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .25143 m
.00625 .25143 L
s
gsave
-0.0125 .25143 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.02) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .34426 m
.00625 .34426 L
s
gsave
-0.0125 .34426 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.04) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .43708 m
.00625 .43708 L
s
gsave
-0.0125 .43708 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.06) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .5299 m
.00625 .5299 L
s
gsave
-0.0125 .5299 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.08) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .089 m
.00375 .089 L
s
0 .1122 m
.00375 .1122 L
s
0 .13541 m
.00375 .13541 L
s
0 .18182 m
.00375 .18182 L
s
0 .20502 m
.00375 .20502 L
s
0 .22823 m
.00375 .22823 L
s
0 .27464 m
.00375 .27464 L
s
0 .29785 m
.00375 .29785 L
s
0 .32105 m
.00375 .32105 L
s
0 .36746 m
.00375 .36746 L
s
0 .39067 m
.00375 .39067 L
s
0 .41387 m
.00375 .41387 L
s
0 .46028 m
.00375 .46028 L
s
0 .48349 m
.00375 .48349 L
s
0 .5067 m
.00375 .5067 L
s
0 .04258 m
.00375 .04258 L
s
0 .01938 m
.00375 .01938 L
s
0 .55311 m
.00375 .55311 L
s
0 .57631 m
.00375 .57631 L
s
0 .59952 m
.00375 .59952 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -134.312 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dIz) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
81.250000 14.000000 moveto
(@) show
85.187500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(%) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
95.125000 14.000000 moveto
(D) show
99.062500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
gsave
.5 .63053 -87.3125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.312500 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
84.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
93.000000 14.000000 moveto
(mm) show
111.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99375 .06579 m
1 .06579 L
s
.99375 .15861 m
1 .15861 L
s
.99375 .25143 m
1 .25143 L
s
.99375 .34426 m
1 .34426 L
s
.99375 .43708 m
1 .43708 L
s
.99375 .5299 m
1 .5299 L
s
.125 Mabswid
.99625 .089 m
1 .089 L
s
.99625 .1122 m
1 .1122 L
s
.99625 .13541 m
1 .13541 L
s
.99625 .18182 m
1 .18182 L
s
.99625 .20502 m
1 .20502 L
s
.99625 .22823 m
1 .22823 L
s
.99625 .27464 m
1 .27464 L
s
.99625 .29785 m
1 .29785 L
s
.99625 .32105 m
1 .32105 L
s
.99625 .36746 m
1 .36746 L
s
.99625 .39067 m
1 .39067 L
s
.99625 .41387 m
1 .41387 L
s
.99625 .46028 m
1 .46028 L
s
.99625 .48349 m
1 .48349 L
s
.99625 .5067 m
1 .5067 L
s
.99625 .04258 m
1 .04258 L
s
.99625 .01938 m
1 .01938 L
s
.99625 .55311 m
1 .55311 L
s
.99625 .57631 m
1 .57631 L
s
.99625 .59952 m
1 .59952 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.001 w
0 .15861 m
1 .15861 L
s
.02381 0 m
.02381 .61803 L
s
.002 w
.02381 .01472 m
.02499 .15857 L
.02605 .15857 L
.02729 .15856 L
.02846 .15856 L
.02954 .15857 L
.03053 .15856 L
.03163 .15857 L
.03279 .15857 L
.03395 .15856 L
.0352 .15857 L
.03638 .15856 L
.03746 .15856 L
.03876 .15856 L
.03948 .15856 L
.04014 .15856 L
.04141 .15856 L
.04262 .15857 L
.04383 .15857 L
.04495 .15857 L
.04626 .15856 L
.04748 .15857 L
.04871 .15856 L
.04936 .15856 L
.05006 .15857 L
.05079 .15856 L
.05148 .15857 L
.05278 .15857 L
.05395 .15857 L
.05519 .15857 L
.05624 .15857 L
.05741 .15856 L
.05866 .15856 L
.05936 .15857 L
.06001 .15857 L
.06119 .15857 L
.06244 .15857 L
.0631 .15857 L
.0638 .15857 L
.06509 .15857 L
.06633 .15857 L
.06748 .15857 L
.06873 .15857 L
.06944 .15857 L
.0701 .15857 L
.07078 .15857 L
.07144 .15857 L
.07218 .15857 L
.07287 .15857 L
.07404 .15857 L
Mistroke
.07528 .15857 L
.07645 .15857 L
.07751 .15857 L
.07876 .15857 L
.07947 .15857 L
.08012 .15857 L
.08131 .15857 L
.08257 .15857 L
.08327 .15857 L
.08394 .15857 L
.08519 .15857 L
.08589 .15857 L
.08654 .15857 L
.08725 .15857 L
.088 .15857 L
.08925 .15858 L
.09041 .15858 L
.09169 .15858 L
.09241 .15858 L
.09307 .15858 L
.09374 .15858 L
.09446 .15858 L
.09575 .15858 L
.09868 .15858 L
.10458 .15859 L
.11485 .1586 L
.12064 .15862 L
.12597 .15863 L
.13577 .15866 L
.14613 .15869 L
.15559 .15874 L
.16574 .1588 L
.18407 .15894 L
.19423 .15905 L
.20528 .15919 L
.2254 .15951 L
.24515 .15995 L
.26615 .16055 L
.28559 .16126 L
.30387 .1621 L
.34252 .1645 L
.36254 .16613 L
.38363 .1682 L
.42171 .17296 L
.46223 .17976 L
.50125 .18834 L
.54271 .20005 L
.58266 .21428 L
.6211 .23109 L
.66198 .25282 L
Mistroke
.70135 .27792 L
.73921 .30634 L
.77952 .34167 L
.81831 .38105 L
.85955 .42913 L
.89928 .48191 L
.93749 .53898 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{412, 254.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006L0000oQ000`40O003h00OogooWGoo003oOonM
Ool00?mooieoo`00kGoo0`005Goo0`00U7oo003]Ool00`00Oomoo`0GOol00`00Oomoo`2BOol00>Ao
o`<000Ioo`04001oogooOol3000017oo000007oo1@0000Aoo`00001oo`8000Aoo`03001oogoo099o
o`00iGoo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`001Goo00<007ooOol0TWoo003UOol00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`2BOol00>Eoo`03001oogoo00Eoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo099o
o`00i7oo00<007oo00001Woo00<007ooOol00Woo0P0000Eoo`00001oo`00009oo`800005Ool00000
Ool00005Ool00`00Oomoo`2BOol00>Aoo`03001oo`0000Ioo`04001oogooOol200001Goo001oogoo
00000Woo0P0000Eoo`00Oomoo`0000Ioo`03001oogoo099oo`00hgoo00D007ooOomoo`0000Eoo`03
001oogoo01Moo`03001oogoo099oo`00hWoo0`0000Aoo`00000000Aoo`<001Eoo`<009Aoo`00ogoo
WGoo003oOonMOol00?mooieoo`00ogooWGoo003oOonMOol00?mooieoo`00EWoo0`00>goo1000?Goo
00<007ooOol0>Woo0`00?7oo0`00>Goo0`000Woo0`001goo001EOol01@00Oomoogoo0000>Woo00D0
07ooOomoo`0003aoo`03001oogoo03Uoo`05001oogooOol0000jOol01@00Oomoogoo0000>Goo00@0
07ooOol000=oo`03001oogoo00Aoo`00EGoo00D007ooOomoo`0003]oo`03001oogoo03Yoo`H003Uo
o`05001oogooOol0000jOol01@00Oomoogoo0000>Goo00@007ooOol000=oo`03001oogoo00Aoo`00
EGoo00D007ooOomoo`0003aoo`03001oogoo03Uoo`04001oogoo000kOol01@00Oomoogoo0000>Woo
00D007ooOomoo`0003Uoo`04001oogoo0003Ool00`00Oomoo`04Ool005Eoo`05001oogooOol0000m
Ool00`00Oomoo`0iOol00`00Ool0000kOol4000lOol3000jOol01000Oomoo`000goo00<007ooOol0
17oo001EOol01@00Oomoogoo0000?Goo00<007ooOol0>Woo0P00?7oo00<007ooOol0>goo00D007oo
Oomoo`0003Uoo`04001oogoo0003Ool00`00Oomoo`04Ool005Eoo`05001oogooOol0000jOol01000
Oomoo`00?7oo0P00?7oo0P00?7oo00D007ooOomoo`0003Uoo`04001oogoo0003Ool00`00Oomoo`04
Ool005Ioo`<003aoo`8003ioo`03001oogoo03aoo`8003]oo`<003Uoo`8000=oo`<000Moo`00ogoo
WGoo003oOonMOol00?mooieoo`00ogooWGoo003oOonMOol0051oool004/0009oo`00D7oo00<007oo
Ool01Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol03Goo00<007oo
Ool037oo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<007oo
Ool03Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol037oo00<007oo
Ool03Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol03Goo00<007oo
Ool037oo00<007ooOol01Goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`00
Oomoo`0kOol00`00Oomoo`0lOol00`00Oomoo`0lOol00`00Oomoo`0kOol00`00Oomoo`05Ool10001
Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`03
00moogoo03aoo`0300moogoo04=oo`40005oo`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo
00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol0@goo0@000Goo0Goo001@
Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0l
Ool00`0?Oomoo`13Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo
03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo04=oo`40005oo`5oo`00D7oo0P001Woo
00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol0@Woo
0P000Woo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol0
0`0?Oomoo`0lOol00`0?Oomoo`13Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03ao
o`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo04=oo`40005oo`5oo`00
D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0
?7oo00<03gooOol0@goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomo
o`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`13Ool10001Ool1Ool0051oo`03001o
ogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300mo
ogoo04=oo`40005oo`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<0
3gooOol0?7oo00<03gooOol0?7oo00<03gooOol0@goo0@000Goo0Goo001@Ool20006Ool00`00Oomo
o`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`12Ool20002Ool0
051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo
03aoo`0300moogoo04=oo`40005oo`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03goo
Ool0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol0@goo0@000Goo0Goo001@Ool00`00
Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?
Oomoo`13Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`03
00moogoo03aoo`0300moogoo03aoo`0300moogoo04=oo`40005oo`5oo`00D7oo00<007ooOol01Goo
00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol0@goo
0@000Goo0Goo000fOol30003Ool00`00Oomoo`030002Ool40008Ool00`00Oomoo`05Ool00`00Oomo
o`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`13Ool10001Ool1
Ool003Eoo`05001oogooOol00004Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300mo
ogoo04=oo`40005oo`5oo`00=Goo00D007ooOomoo`0000Aoo`05001oogooOol00002Ool00`00Oomo
o`08Ool3000500l00`0000l03`3o00lm00l30002Ool002ioo`P000=oo`03001oogoo009oo`05001o
ogooOol00003Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol0
0`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`13Ool10001Ool1Ool003Eoo`05001oogooOol0
0004Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0?7oo00<0
3gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol0@goo0@000Goo0Goo000eOol0
1@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo00Eoo`03001o
ogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo04=oo`40005o
o`5oo`00=Goo00D007ooOomoo`0000Aoo`07001oogooOol007oo00000Woo00<007ooOol01Woo00<0
07ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<0
3gooOol0@goo0@000Goo0Goo000fOol30006Ool30003Ool20009Ool00`00Oomoo`05Ool00`00Oomo
o`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`13Ool10001Ool1
Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300mo
ogoo03aoo`0300moogoo04=oo`40005oo`5oo`00D7oo0P001Woo00<007ooOol0?7oo00<03gooOol0
>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol0@Woo0P000Woo001@Ool00`00Oomoo`05
Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`13
Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo
03aoo`0300moogoo03aoo`0300moogoo04=oo`40005oo`5oo`00D7oo00<007ooOol01Goo00<007oo
Ool0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol0@goo0@000Goo
0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?
Oomoo`0lOol00`0?Oomoo`13Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`03
00moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo04=oo`40005oo`5oo`00D7oo
00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo
00<03gooOol0@goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0k
Ool00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`13Ool10001Ool1Ool0051oo`8000Ioo`03
001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo049oo`80
009oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<0
3gooOol0?7oo00<03gooOol0@goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol0
0`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`13Ool10001Ool1Ool0051o
o`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03ao
o`0300moogoo04=oo`40005oo`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0
>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol0@goo0@000Goo0Goo001@Ool00`00Oomo
o`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomo
o`13Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300mo
ogoo03aoo`0300moogoo03aoo`0300moogoo04=oo`40005oo`5oo`00D7oo00<007ooOol01Goo00<0
07ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol0@goo0@00
0Goo0Goo001@Ool20006Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomo
o`0lOol00`0?Oomoo`12Ool20002Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo
03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo04=oo`40005oo`5oo`00D7oo00<007oo
Ool01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03goo
Ool0@goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?
Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`13Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03
001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo04=oo`40
005oo`5oo`00AGoo0`0027oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03goo
Ool0?7oo00<03gooOol0?7oo00<03gooOol0@goo0@000Goo0Goo0014Ool01@00Oomoogoo00001goo
00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo
00<03gooOol0@goo0@000Goo0Goo0014Ool01@00Oomoogoo00001gooo`00B`000Woo0014Ool01@00
Oomoogoo00001goo00<007ooOol01Goo00<007ooOol0>7oo:@006Goo00<03gooOol0?7oo00<03goo
Ool0?7oo00<03gooOol0@goo0@000Goo0Goo0014Ool01@00Oomoogoo00001goo00<007ooOol01Goo
00<007ooOol0?7oo00<03gooOol08Woo2@0047oo00<03gooOol0?7oo00<03gooOol0?7oo00<03goo
Ool0@goo0@000Goo0Goo0014Ool01@00Oomoogoo00001goo00<007ooOol01Goo00<007ooOol0?7oo
00<03gooOol0:goo3@000goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol0@goo0@000Goo
0Goo0014Ool01@00Oomoogoo00001goo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>7oo
1`00>goo00<03gooOol0?7oo00<03gooOol0@goo0@000Goo0Goo0015Ool30008Ool00`00Oomoo`05
Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol0100?Oomoogoo1P00=Goo00<03gooOol0?7oo00<03goo
Ool0@goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?
Oomoo`07Ool7000^Ool00`0?Oomoo`0lOol00`0?Oomoo`13Ool10001Ool1Ool0051oo`03001oogoo
00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo00ioo`D002Uoo`0300moogoo03aoo`03
00moogoo04=oo`40005oo`5oo`00D7oo0P001Woo00<007ooOol0?7oo00<03gooOol0>goo00<03goo
Ool04goo1@0097oo00<03gooOol0?7oo00<03gooOol0@Woo0P000Woo001@Ool00`00Oomoo`05Ool0
0`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0HOol4000POol00`0?Oomoo`0lOol00`0?Oomo
o`13Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300mo
ogoo01aoo`@001aoo`0300moogoo03aoo`0300moogoo04=oo`40005oo`5oo`00D7oo00<007ooOol0
1Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol087oo0`006Goo00<03gooOol0?7oo00<0
3gooOol0@goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol0
0`0?Oomoo`0SOol4000EOol00`0?Oomoo`0lOol00`0?Oomoo`13Ool10001Ool1Ool0051oo`03001o
ogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo02Moo`<0019oo`0300moogoo03ao
o`0300moogoo04=oo`40005oo`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0
>goo00<03gooOol0:Woo0`003goo00<03gooOol0?7oo00<03gooOol0@goo0@000Goo0Goo001@Ool0
0`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0]Ool3000<Ool00`0?Oomo
o`0lOol00`0?Oomoo`13Ool10001Ool1Ool0051oo`8000Ioo`03001oogoo03aoo`0300moogoo03]o
o`0300moogoo031oo`<000Uoo`0300moogoo03aoo`0300moogoo049oo`80009oo`00D7oo00<007oo
Ool01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0<goo0P001goo00<03gooOol0?7oo
00<03gooOol0@goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0k
Ool00`0?Oomoo`0eOol30004Ool00`0?Oomoo`0lOol00`0?Oomoo`13Ool10001Ool1Ool0051oo`03
001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03Qoo`80009oo`0300moogoo
03aoo`0300moogoo04=oo`40005oo`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03goo
Ool0>goo00<03gooOol0>Woo0`00?Woo00<03gooOol0@goo0@000Goo0Goo001@Ool00`00Oomoo`05
Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?0000000lOol00`0?Oomoo`13
Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo
03aoo`0300moogoo008003Yoo`0300moogoo04=oo`40005oo`5oo`00D7oo0P001Woo00<007ooOol0
?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol00Woo0`00=goo00<03gooOol0@Woo0P00
0Woo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?
Oomoo`05Ool2000eOol00`0?Oomoo`13Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo
03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo00Moo`8003=oo`0300moogoo04=oo`40
005oo`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo
00<03gooOol02Goo0P00<Goo00<03gooOol0@goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00
Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0;Ool2000_Ool00`0?Oomoo`13
Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo
03aoo`0300moogoo00eoo`8002eoo`0300moogoo04=oo`40005oo`5oo`00=Woo0`000goo00<007oo
Ool00`000Woo100027oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0
?7oo00<03gooOol03goo0P00:goo00<03gooOol0@goo0@000Goo0Goo000eOol01@00Oomoogoo0000
17oo00L007ooOomoo`00Ool00003Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0lOol0
0`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0AOol2000YOol00`0?Oomoo`13Ool10001Ool1
Ool003Eoo`05001oogooOol00004Ool01@00Oomoogoo00000Woo00<007ooOol027oo0`001@0?00<0
000?00l0c`0?0P00J`0?0`000Woo000eOol01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`03
001oogoo00Moo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`03
00moogoo01Eoo`03001oogoo02Aoo`0300moogoo04=oo`40005oo`5oo`00=Goo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?
Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0FOol2000TOol00`0?Oomoo`13Ool10001Ool1Ool0
03Eoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol067oo00<007ooOol08Goo
00<03gooOol0@goo0@000Goo0Goo000eOol01@00Oomoogoo000017oo00L007ooOomoo`00Ool00002
Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0l
Ool00`0?Oomoo`0IOol2000QOol00`0?Oomoo`13Ool10001Ool1Ool003Ioo`<000Ioo`<000=oo`80
00Uoo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo
01]oo`03001oogoo01ioo`0300moogoo04=oo`40005oo`5oo`00D7oo00<007ooOol01Goo00<007oo
Ool0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol077oo00<007ooOol07Goo00<03goo
Ool0@goo0@000Goo0Goo001@Ool20006Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0l
Ool00`0?Oomoo`0MOol2000MOol00`0?Oomoo`12Ool20002Ool0051oo`03001oogoo00Eoo`03001o
ogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo01moo`03001oogoo01Yoo`0300mo
ogoo04=oo`40005oo`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<0
3gooOol0?7oo00<03gooOol087oo0P006Woo00<03gooOol0@goo0@000Goo0Goo001@Ool00`00Oomo
o`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0ROol00`00Oomo
o`0GOol00`0?Oomoo`13Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300mo
ogoo03]oo`0300moogoo03aoo`0300moogoo02=oo`03001oogoo01Ioo`0300moogoo04=oo`40005o
o`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<0
3gooOol097oo0P005Woo00<03gooOol0@goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomo
o`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0VOol00`00Oomoo`0COol00`0?Oomo
o`13Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300mo
ogoo03aoo`0300moogoo02Moo`03001oogoo019oo`0300moogoo04=oo`40005oo`5oo`005Goo0`00
37oo0`00:Goo0P001Woo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0
:7oo0P004Woo00<03gooOol0@Woo0P000Woo000EOol00`00Oomoo`0>Ool00`00Oomoo`0WOol00`00
Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0ZOol00`00
Oomoo`0?Ool00`0?Oomoo`13Ool10001Ool1Ool000Aoo`P00003Ool0000000<000=oo`03001oogoo
00=oo`03001oogoo00<000Eoo`03001oogoo02Moo`03001oogoo00Eoo`03001oogoo03aoo`0300mo
ogoo03]oo`0300moogoo03aoo`0300moogoo02]oo`03001oogoo00ioo`0300moogoo04=oo`40005o
o`5oo`000goo00D007ooOomoo`00009oo`05001oogooOol00002Ool01@00Oomoogoo00001Woo00<0
07oo00000Woo00<007ooOol00Woo00<007ooOol09goo00<007ooOol01Goo00<007ooOol0?7oo00<0
3gooOol0>goo00<03gooOol0?7oo00<03gooOol0;7oo0P003Woo00<03gooOol0@goo0@000Goo0Goo
0003Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol017oo00H0
07oo000007oo0004Ool00`00Oomoo`0WOol00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0k
Ool00`0?Oomoo`0lOol00`0?Oomoo`0^Ool00`00Oomoo`0;Ool00`0?Oomoo`13Ool10001Ool1Ool0
00=oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00
Ool000020004Ool00`00Oomoo`0WOol00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol0
0`0?Oomoo`0lOol00`0?Oomoo`0_Ool00`00Oomoo`0:Ool00`0?Oomoo`13Ool10001Ool1Ool000=o
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00Woo00@007ooOomoo`<00003Ool0
07oo00Moo`03001oogoo02Moo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300mo
ogoo03aoo`0300moogoo031oo`03001oogoo00Uoo`0300moogoo04=oo`40005oo`5oo`0017oo1000
0Woo00<007ooOol01@000goo00D007ooOomoo`00009oo`03001oo`0000Moo`03001oogoo02Moo`03
001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo035oo`03
001oogoo00Qoo`0300moogoo04=oo`40005oo`5oo`001goo00@007ooOol000Yoo`04001oogooOol2
000017oo001oo`001goo00<007ooOol09goo0P001Woo00<007ooOol0?7oo00<03gooOol0>goo00<0
3gooOol0?7oo00<03gooOol0<Woo00<007ooOol01goo00<03gooOol0@Woo0P000Woo0006Ool20000
17oo000000002Goo0`000Woo1P0017oo0`00:Goo00<007ooOol01Goo00<007ooOol0?7oo00<03goo
Ool0>goo00<03gooOol0?7oo00<03gooOol0<goo0P001goo00<03gooOol0@goo0@000Goo0Goo001@
Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0e
Ool00`00Oomoo`04Ool00`0?Oomoo`13Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo
03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03Ioo`03001oogoo00=oo`0300moogoo
04=oo`40005oo`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03goo
Ool0?7oo00<03gooOol0=goo00<007ooOol00Woo00<03gooOol0@goo0@000Goo0Goo000fOol30003
Ool00`00Oomoo`030005Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomo
o`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0hOol01@00Oomoogoo00l0AGoo0@000Goo0Goo000eOol0
1@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo00Eoo`03001o
ogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03Uoo`04001oogoo00m5Ool10001
Ool1Ool003Eoo`05001oogooOol00004Ool01P00Oomoogoo001oo`H000Ioo`<000D03`0300003`0?
0?H03`0300003`0?04<03`<0009oo`00=Goo00D007ooOomoo`0000Aoo`07001oogooOol007oo0000
0Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0
?7oo00<03gooOol0>goo00<0000?Ool0A7oo0@000Goo0Goo000eOol01@00Oomoogoo000017oo00D0
07ooOomoo`00009oo`03001oo`0000Qoo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]o
o`0300moogoo03aoo`0300moogoo03aoo`03001oogoo04=oo`40005oo`5oo`00=Goo00D007ooOomo
o`0000Aoo`05001oogooOol00003Ool20008Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomo
o`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?001oo`13Ool10001Ool1Ool003Eoo`05001o
ogooOol00004Ool01@00Oomoogoo00000goo0P0027oo00<007ooOol01Goo00<007ooOol0?7oo00<0
3gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03goo0000@goo0@000Goo0Goo000fOol3
0006Ool30005Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol0
0`0?Oomoo`0lOol00`0?Oomoo`0lOol0100?Oomoo`00@Woo0@000Goo0Goo001@Ool00`00Oomoo`05
Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol01@0?Oomoogoo
0000@Goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?
Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`02Ool00`00Oomoo`0nOol10001Ool1Ool0051oo`80
00Ioo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo
00=oo`03001oogoo03aoo`80009oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0
>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol017oo00<007ooOol0?7oo0@000Goo0Goo
001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomo
o`0lOol00`0?Oomoo`05Ool00`00Oomoo`0kOol10001Ool1Ool0051oo`03001oogoo00Eoo`03001o
ogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo00Ioo`03001o
ogoo03Yoo`40005oo`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<0
3gooOol0?7oo00<03gooOol0?7oo00<03gooOol01goo00<007ooOol0>Goo0@000Goo0Goo001@Ool0
0`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol0
0`0?Oomoo`07Ool00`00Oomoo`0iOol10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03ao
o`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo00Qoo`03001oogoo03Qo
o`40005oo`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0
?7oo00<03gooOol0?7oo00<03gooOol02Goo00<007ooOol0=goo0@000Goo0Goo001@Ool20006Ool0
0`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`0:Ool0
0`00Oomoo`0eOol20002Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`03
00moogoo03aoo`0300moogoo03aoo`0300moogoo00]oo`03001oogoo03Eoo`40005oo`5oo`00D7oo
00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo
00<03gooOol037oo00<007ooOol0=7oo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0l
Ool00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`0=Ool00`00Oomoo`0c
Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo
03aoo`0300moogoo03aoo`0300moogoo00ioo`03001oogoo039oo`40005oo`5oo`00D7oo00<007oo
Ool01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03goo
Ool03Woo00<007ooOol0<Woo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?
Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`0?Ool00`00Oomoo`0aOol10001
Ool1Ool0051oo`8000Ioo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo
03aoo`0300moogoo011oo`03001oogoo02moo`80009oo`00D7oo00<007ooOol01Goo00<007ooOol0
?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol04Goo00<007ooOol0
;goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomo
o`0lOol00`0?Oomoo`0lOol00`0?Oomoo`0BOol00`00Oomoo`0^Ool10001Ool1Ool0051oo`03001o
ogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300mo
ogoo01=oo`03001oogoo02eoo`40005oo`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<0
3gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol057oo00<007ooOol0;7oo0@00
0Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol0
0`0?Oomoo`0lOol00`0?Oomoo`0EOol00`00Oomoo`0[Ool10001Ool1Ool003Ioo`<000=oo`03001o
ogoo00<000=oo`<000Qoo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo
03aoo`0300moogoo03aoo`0300moogoo01Eoo`03001oogoo02]oo`40005oo`5oo`00=Goo00D007oo
Oomoo`0000Aoo`07001oogooOol007oo00000goo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol05Woo00<007oo
Ool0:Woo0@000Goo0Goo000eOol01@00Oomoogoo000017oo00L007ooOomoo`00Ool00003Ool00`00
Oomoo`05Ool3000500l00`0000l03`3o00lC00l00`0000l03`0W00l30002Ool003Eoo`05001oogoo
Ool00004Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo01Qoo`03001oogoo
02Qoo`40005oo`5oo`00=Goo00D007ooOomoo`0000Aoo`06001oogooOol007oo100027oo00<007oo
Ool01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03goo
Ool067oo00<007ooOol0:7oo0@000Goo0Goo000eOol01@00Oomoogoo000017oo00D007ooOomoo`00
009oo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo
03aoo`0300moogoo03aoo`0300moogoo01Uoo`03001oogoo02Moo`40005oo`5oo`00=Goo00D007oo
Oomoo`0000Aoo`05001oogooOol00002Ool20009Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?
Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`0JOol00`00Oomoo`0VOol10001
Ool1Ool003Ioo`<000Ioo`<000Eoo`8000Moo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo
03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo01Yoo`03001oogoo02Ioo`40005oo`5o
o`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03goo
Ool0?7oo00<03gooOol06goo00<007ooOol09Goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00
Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`0LOol00`00
Oomoo`0TOol10001Ool1Ool0051oo`8000Ioo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo
03aoo`0300moogoo03aoo`0300moogoo01eoo`03001oogoo029oo`80009oo`00D7oo00<007ooOol0
1Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol0
7Goo00<007ooOol08goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomo
o`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`0NOol00`00Oomoo`0ROol10001Ool1
Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300mo
ogoo03aoo`0300moogoo01moo`03001oogoo025oo`40005oo`5oo`00D7oo00<007ooOol01Goo00<0
07ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol07goo00<0
07ooOol08Goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol0
0`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`0POol00`00Oomoo`0POol10001Ool1Ool0051o
o`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03ao
o`0300moogoo025oo`03001oogoo01moo`40005oo`5oo`00D7oo0P001Woo00<007ooOol0?7oo00<0
3gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol08Woo00<007ooOol07Goo0P00
0Woo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?
Oomoo`0lOol00`0?Oomoo`0ROol00`00Oomoo`0NOol10001Ool1Ool0051oo`03001oogoo00Eoo`03
001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo02=oo`03
001oogoo01eoo`40005oo`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo
00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol097oo00<007ooOol077oo0@000Goo0Goo001@
Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0l
Ool00`0?Oomoo`0UOol00`00Oomoo`0KOol10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo
03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo02Eoo`03001oogoo
01]oo`40005oo`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03goo
Ool0?7oo00<03gooOol0?7oo00<03gooOol09Woo00<007ooOol06Woo0@000Goo0Goo001@Ool00`00
Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?
Oomoo`0WOol00`00Oomoo`0IOol10001Ool1Ool0051oo`8000Ioo`03001oogoo03aoo`0300moogoo
03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo02Moo`03001oogoo01Qoo`80009oo`00
D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0
?7oo00<03gooOol0:7oo00<007ooOol067oo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomo
o`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`0YOol00`00Oomo
o`0GOol10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300mo
ogoo03aoo`0300moogoo03aoo`0300moogoo02Yoo`03001oogoo01Ioo`40005oo`5oo`00D7oo00<0
07ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<0
3gooOol0:Woo00<007ooOol05Woo0@000Goo0Goo000fOol30003Ool00`00Oomoo`030003Ool30008
Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0l
Ool00`0?Oomoo`0[Ool00`00Oomoo`0EOol10001Ool1Ool003Eoo`05001oogooOol00004Ool01`00
Oomoogoo001oo`0000=oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo
03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo02aoo`03001oogoo01Aoo`40005oo`5o
o`00=Goo00D007ooOomoo`0000Aoo`07001oogooOol007oo00000goo00<007ooOol01Goo0`001@0?
00<0000?00l0o`0?:00?00<0000?00l04P0?0`000Woo000eOol01@00Oomoogoo000017oo00L007oo
Oomoo`00Ool00003Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0k
Ool00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`0]Ool00`00Oomoo`0COol10001Ool1Ool0
03Eoo`05001oogooOol00004Ool01@00Oomoogoo00000Woo0`0027oo00<007ooOol01Goo00<007oo
Ool0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol0;Woo00<007oo
Ool04Woo0@000Goo0Goo000eOol01@00Oomoogoo000017oo00L007ooOomoo`00Ool00003Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?
Oomoo`0lOol00`0?Oomoo`0_Ool00`00Oomoo`0AOol10001Ool1Ool003Eoo`05001oogooOol00004
Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo03aoo`03
00moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo02moo`03001oogoo015oo`40
005oo`5oo`00=Woo0`001Woo0`000goo0`0027oo00<007ooOol01Goo00<007ooOol0?7oo00<03goo
Ool0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol0<7oo00<007ooOol047oo0@000Goo
0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?
Oomoo`0lOol00`0?Oomoo`0`Ool00`00Oomoo`0@Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03
001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo035oo`03
001oogoo00moo`40005oo`5oo`00D7oo0P001Woo00<007ooOol0?7oo00<03gooOol0>goo00<03goo
Ool0?7oo00<03gooOol0?7oo00<03gooOol0<Goo00<007ooOol03Woo0P000Woo001@Ool00`00Oomo
o`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomo
o`0bOol00`00Oomoo`0>Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300mo
ogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo03=oo`03001oogoo00eoo`40005o
o`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<0
3gooOol0?7oo00<03gooOol0<goo00<007ooOol03Goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool0
0`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`0dOol0
0`00Oomoo`0<Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]o
o`0300moogoo03aoo`0300moogoo03aoo`0300moogoo03Aoo`03001oogoo00aoo`40005oo`5oo`00
D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0
?7oo00<03gooOol0=Goo00<007ooOol02goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomo
o`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`0eOol00`00Oomo
o`0;Ool10001Ool1Ool0051oo`8000Ioo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03ao
o`0300moogoo03aoo`0300moogoo03Ioo`03001oogoo00Uoo`80009oo`00D7oo00<007ooOol01Goo
00<007ooOol0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol0=Woo
00<007ooOol02Woo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0k
Ool00`0?Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`0gOol00`00Oomoo`09Ool10001Ool1Ool0
051oo`03001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo
03aoo`0300moogoo03Moo`03001oogoo00Uoo`40005oo`5oo`00D7oo00<007ooOol01Goo00<007oo
Ool0?7oo00<03gooOol0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol0>7oo00<007oo
Ool027oo0@000Goo0Goo001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?
Oomoo`0lOol00`0?Oomoo`0lOol00`0?Oomoo`0iOol00`00Oomoo`07Ool10001Ool1Ool0051oo`03
001oogoo00Eoo`03001oogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`03
00moogoo03Uoo`03001oogoo00Moo`40005oo`5oo`00D7oo0P001Woo00<007ooOol0?7oo00<03goo
Ool0>goo00<03gooOol0?7oo00<03gooOol0?7oo00<03gooOol0>Woo00<007ooOol01Goo0P000Woo
001@Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0kOol00`0?Oomoo`0lOol00`0?Oomo
o`0lOol00`0?Oomoo`0jOol00`00Oomoo`06Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001o
ogoo03aoo`0300moogoo03]oo`0300moogoo03aoo`0300moogoo03aoo`0300moogoo03]oo`03001o
ogoo00Eoo`40005oo`5oo`00D7oo00<007ooOol01Goo00<007ooOol0?7oo00<03gooOol0>goo00<0
3gooOol0?7oo00<03gooOol0?7oo00<03gooOol0@goo0@000Goo0Goo001@Ool00`00Oomoo`05Ool0
0`00Oomoo`0lOol00`00Oomoo`0kOol00`00Oomoo`0lOol00`00Oomoo`0lOol00`00Oomoo`0kOol0
0`00Oomoo`05Ool10001Ool1Ool0051oo`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo00ao
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eo
o`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eo
o`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00ao
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00Eoo`40005oo`5oo`00
D7ooo`00B`000Woo003oOonMOol00?mooieoo`00ogooWGoo003oOonMOol00?mooieoo`00ogooWGoo
003oOonMOol00?mooieoo`00g7oo1P0047oo0`001Goo0`0000Aoo`00001oo`D00004Ool00000Ool2
002@Ool00=eoo`05001oogooOol00006Ool70002Ool01@00Oomoogoo00001Goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`00TGoo003MOol00`00Oomoo`0AOol01@00Oomoogoo00001Goo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00TGoo003NOol00`00Oomoo`0@Ool01@00
Oomoogoo00001Goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00TGoo003OOol00`00
Oomoo`06Ool70002Ool01@00Oomoogoo00001Goo0P0000Eoo`00001oo`00009oo`800005Ool00000
Ool0002AOol00>1oo`03001oogoo00ioo`05001oogooOol00004Ool200001Goo001oogoo00000Woo
0P0000Eoo`00Oomoo`00099oo`00g7oo00D007ooOomoo`00011oo`05001oogooOol0002VOol00=ao
o`H0011oo`<00:Moo`00ogooWGoo003oOonMOol00001\
\>"],
  ImageRangeCache->{{{0, 411}, {253.438, 0}} -> {-2.82854, -0.0552175, 
  0.0319332, 0.000655287}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnetization in the Iron ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Here are a few methods for plotting the magnetization in the iron. \
The first one plots a vector in the center of each subdivided element. The \
vector is oriented according to the local magnetization and its color is \
related to its absolute value. The other methods  makes  a contour plot of \
the  absolute value of the magnetization over a slice of material. This \
methods is more complicated to use and probably less usefull than the other  \
one. \
\>", "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(RadPlot3DOptions[]; \n\t
    ListPlotVectorField3D[radObjM[g]\n, VectorHeads -> True\n, 
      ColorFunction -> \ Hue\n, 
      PlotLabel -> "\<Magnetization in Element # \>"<>ToString[g]\n, 
      ViewPoint -> {3, 1\ , \ 0}\n, PlotRange -> {All, All, {20, 90}}\ \n, 
      ScaleFactor -> 8]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.5 1.0125 -79.1562 14 ]
[.5 1.0125 79.1562 28 ]
[.87609 .16723 -8 -14 ]
[.87609 .16723 8 0 ]
[.86848 .16115 -8 -14 ]
[.86848 .16115 8 0 ]
[.86059 .15484 -8 -14 ]
[.86059 .15484 8 0 ]
[.86788 .09817 -7.8125 -14 ]
[.86788 .09817 7.8125 0 ]
[.13684 .18167 -5 -14 ]
[.13684 .18167 5 0 ]
[.29784 .17424 -8 -14 ]
[.29784 .17424 8 0 ]
[.46685 .16644 -8 -14 ]
[.46685 .16644 8 0 ]
[.6445 .15824 -8 -14 ]
[.6445 .15824 8 0 ]
[.83146 .14961 -8 -14 ]
[.83146 .14961 8 0 ]
[.47286 .10366 -7.8125 -14 ]
[.47286 .10366 7.8125 0 ]
[.89168 .1922 0 -1.40305 ]
[.89168 .1922 16 12.5969 ]
[.89374 .36879 0 -4.60131 ]
[.89374 .36879 16 9.39869 ]
[.89433 .54367 0 -7.79956 ]
[.89433 .54367 16 6.20044 ]
[.89277 .71924 0 -10.9978 ]
[.89277 .71924 16 3.00218 ]
[.95691 .5 0 -7 ]
[.95691 .5 14.3125 7 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -140.156 10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Magnetization) show
135.125000 14.000000 moveto
(in) show
147.437500 14.000000 moveto
(Element) show
190.312500 14.000000 moveto
(#) show
199.312500 14.000000 moveto
(105) show
217.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
[ ] 0 setdash
.88191 .18439 m
.85281 .16113 L
s
.25 Mabswid
.87609 .17973 m
.87609 .18598 L
s
gsave
.87609 .16723 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.86848 .17365 m
.86848 .1799 L
s
gsave
.86848 .16115 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.86059 .16734 m
.86059 .17359 L
s
gsave
.86059 .15484 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.87459 .17854 m
.87459 .18229 L
s
.87308 .17733 m
.87308 .18108 L
s
.87156 .17611 m
.87156 .17986 L
s
.87003 .17489 m
.87003 .17864 L
s
.86693 .17241 m
.86693 .17616 L
s
.86536 .17116 m
.86536 .17491 L
s
.86378 .1699 m
.86378 .17365 L
s
.86219 .16862 m
.86219 .17237 L
s
.87758 .18092 m
.87758 .18467 L
s
.87905 .1821 m
.87905 .18585 L
s
.88052 .18327 m
.88052 .18702 L
s
.85897 .16605 m
.85897 .1698 L
s
.85734 .16475 m
.85734 .1685 L
s
.8557 .16343 m
.8557 .16718 L
s
.85405 .16211 m
.85405 .16586 L
s
gsave
.86788 .09817 -68.8125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.13028 .19447 m
.85281 .16113 L
s
.25 Mabswid
.13684 .19417 m
.13684 .20042 L
s
gsave
.13684 .18167 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.29784 .18674 m
.29784 .19299 L
s
gsave
.29784 .17424 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.46685 .17894 m
.46685 .18519 L
s
gsave
.46685 .16644 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.6445 .17074 m
.6445 .17699 L
s
gsave
.6445 .15824 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.83146 .16211 m
.83146 .16836 L
s
gsave
.83146 .14961 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(80) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.17637 .19235 m
.17637 .1961 L
s
.21637 .1905 m
.21637 .19425 L
s
.25686 .18863 m
.25686 .19238 L
s
.33931 .18482 m
.33931 .18857 L
s
.3813 .18289 m
.3813 .18664 L
s
.42381 .18093 m
.42381 .18468 L
s
.51043 .17693 m
.51043 .18068 L
s
.55455 .17489 m
.55455 .17864 L
s
.59924 .17283 m
.59924 .17658 L
s
.69034 .16862 m
.69034 .17237 L
s
.73677 .16648 m
.73677 .17023 L
s
.7838 .16431 m
.7838 .16806 L
s
gsave
.47286 .10366 -68.8125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.88191 .18439 m
.88191 .81561 L
s
.25 Mabswid
.88191 .18439 m
.87703 .18049 L
s
gsave
.89168 .1922 -61 -5.40305 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.88191 .36474 m
.876 .36271 L
s
gsave
.89374 .36879 -61 -8.60131 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.88191 .54509 m
.8757 .5458 L
s
gsave
.89433 .54367 -61 -11.7996 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.88191 .72543 m
.87649 .72853 L
s
gsave
.89277 .71924 -61 -14.9978 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(80) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.88191 .22948 m
.87882 .22736 L
s
.88191 .27457 m
.87866 .27271 L
s
.88191 .31965 m
.8785 .31809 L
s
.88191 .40983 m
.87826 .40899 L
s
.88191 .45491 m
.87819 .45449 L
s
.88191 .5 m
.87816 .5 L
s
.88191 .59017 m
.87826 .59101 L
s
.88191 .63526 m
.87837 .63648 L
s
.88191 .68035 m
.8785 .68191 L
s
.88191 .77052 m
.87882 .77264 L
s
gsave
.95691 .5 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.20173 .21351 m
.20173 .78649 L
s
.20173 .78649 m
.88191 .81561 L
s
.88191 .81561 m
.88191 .18439 L
s
.88191 .18439 m
.20173 .21351 L
s
.13028 .19447 m
.85281 .16113 L
s
.85281 .16113 m
.85281 .83887 L
s
.85281 .83887 m
.13028 .80553 L
s
.13028 .80553 m
.13028 .19447 L
s
.20173 .21351 m
.20173 .78649 L
s
.20173 .78649 m
.13028 .80553 L
s
.13028 .80553 m
.13028 .19447 L
s
.13028 .19447 m
.20173 .21351 L
s
.88191 .18439 m
.85281 .16113 L
s
.85281 .16113 m
.85281 .83887 L
s
.85281 .83887 m
.88191 .81561 L
s
.88191 .81561 m
.88191 .18439 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.2114 .69656 m
.2114 .69657 L
s
.2114 .69655 m
.2114 .69656 L
s
.2114 .69656 m
.21139 .69656 L
s
.21141 .69656 m
.2114 .69656 L
s
.21138 .69654 m
.2114 .69656 L
s
.2114 .69655 m
.21139 .69656 L
s
.21141 .69656 m
.2114 .69655 L
s
.21139 .69656 m
.2114 .69657 L
s
.2114 .69657 m
.21141 .69656 L
s
0 .369 1 r
.23037 .55735 m
.23662 .5575 L
s
.22515 .55756 m
.23037 .55735 L
s
.23037 .55735 m
.23089 .54952 L
s
0 .186 1 r
.22647 .62923 m
.23425 .62726 L
s
.23425 .62726 m
.23699 .62592 L
s
.23425 .62726 m
.22948 .61949 L
s
0 .484 1 r
.229 .48956 m
.23626 .48966 L
s
.22595 .48964 m
.229 .48956 L
s
.229 .48956 m
.23117 .48189 L
s
0 .728 1 r
.22911 .42283 m
.23602 .42298 L
s
.22666 .42279 m
.22911 .42283 L
s
.22911 .42283 m
.23147 .41566 L
s
0 1 .881 r
.22943 .35735 m
.23566 .35758 L
s
.2277 .35725 m
.22943 .35735 L
s
.22943 .35735 m
.23189 .35105 L
s
0 .484 1 r
.23626 .48966 m
.23324 .48974 L
s
.23117 .48189 m
.23626 .48966 L
s
0 .728 1 r
.23602 .42298 m
.2336 .42294 L
s
.23147 .41566 m
.23602 .42298 L
s
0 .186 1 r
.22919 .62789 m
.22647 .62923 L
s
.22948 .61949 m
.22647 .62923 L
s
.462 1 0 r
.23777 .2245 m
.24011 .22478 L
s
.23535 .22365 m
.23777 .2245 L
s
.23848 .22091 m
.23777 .2245 L
s
0 1 .881 r
.23566 .35758 m
.23395 .35748 L
s
.23189 .35105 m
.23566 .35758 L
s
0 .369 1 r
.23662 .5575 m
.23141 .55771 L
s
.23089 .54952 m
.23662 .5575 L
s
0 1 .286 r
.23044 .29354 m
.2354 .29398 L
s
.22917 .29359 m
.23044 .29354 L
s
.23044 .29354 m
.23264 .28873 L
s
0 .186 1 r
.23699 .62592 m
.22948 .61949 L
s
.22948 .61949 m
.22919 .62789 L
s
.24072 .65998 m
.22948 .61949 L
s
0 1 .286 r
.2354 .29398 m
.23414 .29402 L
s
.23264 .28873 m
.2354 .29398 L
s
0 1 .881 r
.23087 .38287 m
.23189 .35105 L
s
0 1 .286 r
.23087 .31398 m
.23264 .28873 L
s
0 .369 1 r
.23087 .58957 m
.23089 .54952 L
s
0 .484 1 r
.23087 .52067 m
.23117 .48189 L
s
0 .728 1 r
.23087 .45177 m
.23147 .41566 L
s
0 .369 1 r
.23089 .54952 m
.23141 .55771 L
s
.22515 .55756 m
.23089 .54952 L
s
0 .484 1 r
.23117 .48189 m
.23324 .48974 L
s
.22595 .48964 m
.23117 .48189 L
s
.462 1 0 r
.24011 .22478 m
.23768 .22393 L
s
.23848 .22091 m
.24011 .22478 L
s
.23535 .22365 m
.23848 .22091 L
s
.23768 .22393 m
.23848 .22091 L
s
.23471 .23745 m
.23848 .22091 L
s
0 .728 1 r
.23147 .41566 m
.2336 .42294 L
s
.22666 .42279 m
.23147 .41566 L
s
.462 1 0 r
.23768 .22393 m
.23535 .22365 L
s
0 .369 1 r
.23141 .55771 m
.22515 .55756 L
s
0 1 .881 r
.23189 .35105 m
.23395 .35748 L
s
.2277 .35725 m
.23189 .35105 L
s
0 .186 1 r
.23699 .62592 m
.22919 .62789 L
s
1 .005 0 r
.2375 .75344 m
.23749 .75347 L
s
.23748 .75344 m
.2375 .75344 L
s
.2375 .75344 m
.23747 .75345 L
s
.2375 .75345 m
.2375 .75344 L
s
.23743 .75349 m
.2375 .75344 L
s
.23747 .75345 m
.23749 .75347 L
s
.23748 .75344 m
.23747 .75345 L
s
.23749 .75347 m
.2375 .75345 L
s
.2375 .75345 m
.23748 .75344 L
s
0 1 .286 r
.23264 .28873 m
.23414 .29402 L
s
.22917 .29359 m
.23264 .28873 L
s
0 .484 1 r
.23324 .48974 m
.22595 .48964 L
s
0 .728 1 r
.2336 .42294 m
.22666 .42279 L
s
0 1 .881 r
.23395 .35748 m
.2277 .35725 L
s
0 1 .286 r
.23414 .29402 m
.22917 .29359 L
s
0 .526 1 r
.25638 .70608 m
.26112 .70092 L
s
.26112 .70092 m
.26132 .69665 L
s
.26112 .70092 m
.25271 .69742 L
s
.824 0 1 r
.26414 .65128 m
.27069 .64425 L
s
.27069 .64425 m
.27099 .6381 L
s
.27069 .64425 m
.25901 .63929 L
s
1 0 .748 r
.26293 .59853 m
.27365 .59587 L
s
.27365 .59587 m
.27746 .59384 L
s
.27365 .59587 m
.26705 .58502 L
s
0 .526 1 r
.25271 .69742 m
.25638 .70608 L
s
.26132 .69665 m
.25271 .69742 L
s
.25271 .69742 m
.25657 .70182 L
s
.28353 .71724 m
.25271 .69742 L
s
.25657 .70182 m
.25638 .70608 L
s
.824 0 1 r
.25901 .63929 m
.26414 .65128 L
s
.27099 .6381 m
.25901 .63929 L
s
.25901 .63929 m
.26441 .64515 L
s
.30197 .66644 m
.25901 .63929 L
s
0 .526 1 r
.26132 .69665 m
.25657 .70182 L
s
1 0 .748 r
.2667 .59652 m
.26293 .59853 L
s
.26705 .58502 m
.26293 .59853 L
s
.824 0 1 r
.26441 .64515 m
.26414 .65128 L
s
1 0 .748 r
.27746 .59384 m
.26705 .58502 L
s
.26705 .58502 m
.2667 .59652 L
s
.28277 .64097 m
.26705 .58502 L
s
.987 0 1 r
.28485 .54574 m
.29537 .5459 L
s
.2809 .54606 m
.28485 .54574 L
s
.28485 .54574 m
.2882 .53489 L
s
.824 0 1 r
.27099 .6381 m
.26441 .64515 L
s
.821 0 1 r
.28469 .47773 m
.29531 .47803 L
s
.28244 .47794 m
.28469 .47773 L
s
.28469 .47773 m
.28913 .46726 L
s
1 0 .748 r
.27746 .59384 m
.2667 .59652 L
s
.987 0 1 r
.29537 .5459 m
.29146 .54622 L
s
.2882 .53489 m
.29537 .5459 L
s
.821 0 1 r
.29531 .47803 m
.29311 .47825 L
s
.28913 .46726 m
.29531 .47803 L
s
.505 0 1 r
.28558 .41097 m
.29557 .41149 L
s
.2838 .41113 m
.28558 .41097 L
s
.28558 .41097 m
.29014 .40129 L
s
.29557 .41149 m
.29383 .41166 L
s
.29014 .40129 m
.29557 .41149 L
s
.021 0 1 r
.28691 .34565 m
.29586 .34647 L
s
.28563 .3459 m
.28691 .34565 L
s
.28691 .34565 m
.29147 .33724 L
s
.29586 .34647 m
.29462 .34671 L
s
.29147 .33724 m
.29586 .34647 L
s
0 1 .47 r
.28733 .25125 m
.29772 .22626 L
s
.021 0 1 r
.28791 .38188 m
.29147 .33724 L
s
0 .648 1 r
.28791 .3124 m
.29437 .27573 L
s
.987 0 1 r
.28791 .59033 m
.2882 .53489 L
s
.821 0 1 r
.28791 .52084 m
.28913 .46726 L
s
.505 0 1 r
.28791 .45136 m
.29014 .40129 L
s
.987 0 1 r
.2882 .53489 m
.29146 .54622 L
s
.2809 .54606 m
.2882 .53489 L
s
0 .648 1 r
.29704 .28345 m
.29655 .28413 L
s
.2896 .28204 m
.29704 .28345 L
s
.29437 .27573 m
.29704 .28345 L
s
.28909 .28272 m
.2896 .28204 L
s
.2896 .28204 m
.29437 .27573 L
s
.821 0 1 r
.28913 .46726 m
.29311 .47825 L
s
.28244 .47794 m
.28913 .46726 L
s
0 1 .47 r
.29807 .23165 m
.29837 .23293 L
s
.2929 .2296 m
.29807 .23165 L
s
.29772 .22626 m
.29807 .23165 L
s
.505 0 1 r
.29014 .40129 m
.29383 .41166 L
s
.2838 .41113 m
.29014 .40129 L
s
0 1 .47 r
.29319 .23089 m
.2929 .2296 L
s
.2929 .2296 m
.29772 .22626 L
s
.021 0 1 r
.29147 .33724 m
.29462 .34671 L
s
.28563 .3459 m
.29147 .33724 L
s
.987 0 1 r
.29146 .54622 m
.2809 .54606 L
s
.821 0 1 r
.29311 .47825 m
.28244 .47794 L
s
0 .648 1 r
.29437 .27573 m
.29655 .28413 L
s
.28909 .28272 m
.29437 .27573 L
s
0 1 .47 r
.29772 .22626 m
.29837 .23293 L
s
.29319 .23089 m
.29772 .22626 L
s
.505 0 1 r
.29383 .41166 m
.2838 .41113 L
s
0 1 .47 r
.29837 .23293 m
.29319 .23089 L
s
.021 0 1 r
.29462 .34671 m
.28563 .3459 L
s
0 .648 1 r
.29655 .28413 m
.28909 .28272 L
s
.225 0 1 r
.35296 .6708 m
.3555 .66357 L
s
.3555 .66357 m
.353 .65725 L
s
.3555 .66357 m
.34417 .66378 L
s
.34417 .66378 m
.35296 .6708 L
s
.353 .65725 m
.34417 .66378 L
s
.34417 .66378 m
.35044 .66448 L
s
.38845 .665 m
.34417 .66378 L
s
0 .969 1 r
.36297 .74503 m
.3648 .73968 L
s
.3648 .73968 m
.36301 .73529 L
s
.3648 .73968 m
.35666 .73991 L
s
.225 0 1 r
.35044 .66448 m
.35296 .6708 L
s
.353 .65725 m
.35044 .66448 L
s
0 .969 1 r
.35666 .73991 m
.36297 .74503 L
s
.36301 .73529 m
.35666 .73991 L
s
.35666 .73991 m
.36117 .74063 L
s
.38845 .74115 m
.35666 .73991 L
s
.36117 .74063 m
.36297 .74503 L
s
.36301 .73529 m
.36117 .74063 L
s
.231 0 1 r
.49942 .67489 m
.50155 .66749 L
s
.50155 .66749 m
.49932 .66103 L
s
.50155 .66749 m
.49017 .66781 L
s
.49017 .66781 m
.49942 .67489 L
s
.49932 .66103 m
.49017 .66781 L
s
.49017 .66781 m
.49717 .66843 L
s
.53638 .66855 m
.49017 .66781 L
s
0 .98 1 r
.50993 .75052 m
.51144 .74506 L
s
.51144 .74506 m
.50988 .7406 L
s
.51144 .74506 m
.50331 .74536 L
s
.231 0 1 r
.49932 .66103 m
.49717 .66843 L
s
.49717 .66843 m
.49942 .67489 L
s
0 .98 1 r
.50331 .74536 m
.50993 .75052 L
s
.50988 .7406 m
.50331 .74536 L
s
.50331 .74536 m
.50835 .74605 L
s
.53638 .74634 m
.50331 .74536 L
s
.50988 .7406 m
.50835 .74605 L
s
.50835 .74605 m
.50993 .75052 L
s
0 1 .224 r
.18598 .21064 m
.18991 .21099 L
s
.18263 .2094 m
.18598 .21064 L
s
.18725 .20516 m
.18598 .21064 L
s
.18991 .21099 m
.18657 .20975 L
s
.18725 .20516 m
.18991 .21099 L
s
.18263 .2094 m
.18725 .20516 L
s
.18657 .20975 m
.18725 .20516 L
s
.18234 .23035 m
.18725 .20516 L
s
1 .098 0 r
.15505 .7079 m
.15481 .7079 L
s
.15503 .70792 m
.15505 .7079 L
s
.15492 .70815 m
.15505 .7079 L
s
.15481 .7079 m
.15478 .70792 L
s
.15492 .70815 m
.15481 .7079 L
s
.15491 .70696 m
.15492 .70815 L
s
.15503 .70792 m
.15492 .70815 L
s
.15478 .70792 m
.15492 .70815 L
s
.361 0 1 r
.16812 .63167 m
.17756 .62922 L
s
.17756 .62922 m
.18066 .62753 L
s
.17756 .62922 m
.1716 .6199 L
s
1 .098 0 r
.15478 .70792 m
.15503 .70792 L
s
0 1 .224 r
.18657 .20975 m
.18263 .2094 L
s
.195 0 1 r
.17826 .55513 m
.18128 .55542 L
s
.1688 .55531 m
.17826 .55513 L
s
.17826 .55513 m
.17498 .54562 L
s
.114 0 1 r
.17594 .48337 m
.18193 .48356 L
s
.16825 .48356 m
.17594 .48337 L
s
.17594 .48337 m
.17505 .474 L
s
0 .106 1 r
.17545 .41286 m
.18167 .41303 L
s
.16863 .41299 m
.17545 .41286 L
s
.17545 .41286 m
.17513 .40395 L
s
0 .479 1 r
.17529 .34367 m
.18111 .34392 L
s
.16929 .34382 m
.17529 .34367 L
s
.17529 .34367 m
.17519 .33566 L
s
.361 0 1 r
.17119 .62999 m
.16812 .63167 L
s
.1716 .6199 m
.16812 .63167 L
s
.195 0 1 r
.17179 .55561 m
.1688 .55531 L
s
.1688 .55531 m
.17498 .54562 L
s
.361 0 1 r
.18066 .62753 m
.1716 .6199 L
s
.1716 .6199 m
.17119 .62999 L
s
.18554 .6685 m
.1716 .6199 L
s
0 1 .941 r
.17524 .27633 m
.18052 .2768 L
s
.17066 .27661 m
.17524 .27633 L
s
.17524 .27633 m
.17568 .26984 L
s
0 .479 1 r
.17525 .37665 m
.17519 .33566 L
s
0 1 .941 r
.17525 .30408 m
.17568 .26984 L
s
.195 0 1 r
.17525 .59433 m
.17498 .54562 L
s
.114 0 1 r
.17525 .52177 m
.17505 .474 L
s
0 .106 1 r
.17525 .44921 m
.17513 .40395 L
s
.195 0 1 r
.17498 .54562 m
.17179 .55561 L
s
.17498 .54562 m
.18128 .55542 L
s
.114 0 1 r
.18193 .48356 m
.17423 .48374 L
s
.17505 .474 m
.18193 .48356 L
s
.17423 .48374 m
.16825 .48356 L
s
.16825 .48356 m
.17505 .474 L
s
0 .106 1 r
.18167 .41303 m
.17486 .41316 L
s
.17513 .40395 m
.18167 .41303 L
s
.114 0 1 r
.17505 .474 m
.17423 .48374 L
s
.361 0 1 r
.18066 .62753 m
.17119 .62999 L
s
1 .036 0 r
.18249 .76705 m
.18247 .76712 L
s
.18249 .76699 m
.18249 .76705 L
s
.18257 .76707 m
.18249 .76705 L
s
.18211 .76699 m
.18257 .76707 L
s
.18247 .76712 m
.18246 .76706 L
s
.18257 .76707 m
.18247 .76712 L
s
.18246 .76706 m
.18249 .76699 L
s
.18249 .76699 m
.18257 .76707 L
s
.18246 .76706 m
.18257 .76707 L
s
0 .479 1 r
.18111 .34392 m
.17512 .34407 L
s
.17519 .33566 m
.18111 .34392 L
s
0 .106 1 r
.17513 .40395 m
.17486 .41316 L
s
.16863 .41299 m
.17513 .40395 L
s
.17486 .41316 m
.16863 .41299 L
s
.195 0 1 r
.18128 .55542 m
.17179 .55561 L
s
0 .066 1 r
.19816 .7156 m
.20392 .70942 L
s
.20392 .70942 m
.20397 .70435 L
s
.20392 .70942 m
.1938 .70528 L
s
1 0 .433 r
.20374 .6573 m
.2118 .64871 L
s
.2118 .64871 m
.2119 .64122 L
s
.2118 .64871 m
.19746 .64279 L
s
0 1 .941 r
.18052 .2768 m
.17595 .27708 L
s
.17568 .26984 m
.18052 .2768 L
s
1 0 0 r
.20521 .59783 m
.21823 .59448 L
s
.21823 .59448 m
.22241 .5919 L
s
.21823 .59448 m
.20989 .58149 L
s
0 .479 1 r
.17512 .34407 m
.16929 .34382 L
s
.16929 .34382 m
.17519 .33566 L
s
.17519 .33566 m
.17512 .34407 L
s
0 1 .941 r
.17595 .27708 m
.17066 .27661 L
s
.17066 .27661 m
.17568 .26984 L
s
.17568 .26984 m
.17595 .27708 L
s
0 .066 1 r
.1938 .70528 m
.19816 .7156 L
s
.20397 .70435 m
.1938 .70528 L
s
.1938 .70528 m
.19819 .71054 L
s
.23028 .72889 m
.1938 .70528 L
s
.19819 .71054 m
.19816 .7156 L
s
1 0 .433 r
.19746 .64279 m
.20374 .6573 L
s
.2119 .64122 m
.19746 .64279 L
s
.19746 .64279 m
.20381 .64984 L
s
.24956 .67539 m
.19746 .64279 L
s
0 .066 1 r
.20397 .70435 m
.19819 .71054 L
s
1 0 0 r
.20932 .59525 m
.20521 .59783 L
s
.20989 .58149 m
.20521 .59783 L
s
1 0 .433 r
.20381 .64984 m
.20374 .6573 L
s
1 0 0 r
.22241 .5919 m
.20989 .58149 L
s
.20989 .58149 m
.20932 .59525 L
s
.22948 .64853 m
.20989 .58149 L
s
1 0 .343 r
.2358 .54179 m
.24418 .5422 L
s
.22523 .54219 m
.2358 .54179 L
s
.2358 .54179 m
.23467 .52894 L
s
1 0 .433 r
.2119 .64122 m
.20381 .64984 L
s
.198 0 1 r
.65248 .67841 m
.65425 .67089 L
s
.65425 .67089 m
.65246 .66436 L
s
.65425 .67089 m
.64295 .67117 L
s
1 0 .551 r
.2344 .47045 m
.24431 .471 L
s
.22599 .47095 m
.2344 .47045 L
s
.2344 .47045 m
.23524 .45821 L
s
1 0 0 r
.22241 .5919 m
.20932 .59525 L
s
.198 0 1 r
.64295 .67117 m
.65248 .67841 L
s
.65246 .66436 m
.64295 .67117 L
s
.64295 .67117 m
.65068 .67188 L
s
.69082 .67225 m
.64295 .67117 L
s
1 0 .907 r
.23455 .40043 m
.24414 .40124 L
s
.22708 .40107 m
.23455 .40043 L
s
.23455 .40043 m
.23581 .38922 L
s
0 .998 1 r
.66334 .75584 m
.66459 .75029 L
s
.66459 .75029 m
.66333 .74577 L
s
.66459 .75029 m
.65649 .75057 L
s
.58 0 1 r
.23486 .37554 m
.23652 .32222 L
s
0 .103 1 r
.23486 .30233 m
.23879 .25793 L
s
1 0 .343 r
.23486 .59517 m
.23467 .52894 L
s
1 0 .551 r
.23486 .52196 m
.23524 .45821 L
s
1 0 .907 r
.23486 .44875 m
.23581 .38922 L
s
.198 0 1 r
.65246 .66436 m
.65068 .67188 L
s
.65068 .67188 m
.65248 .67841 L
s
0 .807 1 r
.23405 .24197 m
.24252 .20866 L
s
1 0 .343 r
.2336 .5426 m
.22523 .54219 L
s
.22523 .54219 m
.23467 .52894 L
s
.24418 .5422 m
.2336 .5426 L
s
.23467 .52894 m
.24418 .5422 L
s
.58 0 1 r
.23507 .33186 m
.24384 .33307 L
s
.22852 .33279 m
.23507 .33186 L
s
.23507 .33186 m
.23652 .32222 L
s
0 .998 1 r
.65649 .75057 m
.66334 .75584 L
s
.66333 .74577 m
.65649 .75057 L
s
.65649 .75057 m
.66207 .75132 L
s
.69082 .75176 m
.65649 .75057 L
s
1 0 .343 r
.23467 .52894 m
.2336 .5426 L
s
1 0 .551 r
.24431 .471 m
.23593 .47151 L
s
.23524 .45821 m
.24431 .471 L
s
0 .998 1 r
.66333 .74577 m
.66207 .75132 L
s
.66207 .75132 m
.66334 .75584 L
s
1 0 .907 r
.24414 .40124 m
.23669 .40189 L
s
.23581 .38922 m
.24414 .40124 L
s
1 0 .551 r
.23524 .45821 m
.23593 .47151 L
s
.22599 .47095 m
.23524 .45821 L
s
.23593 .47151 m
.22599 .47095 L
s
0 .103 1 r
.23647 .26518 m
.24438 .26709 L
s
.2316 .26662 m
.23647 .26518 L
s
.23647 .26518 m
.23879 .25793 L
s
.58 0 1 r
.24384 .33307 m
.23731 .334 L
s
.23652 .32222 m
.24384 .33307 L
s
1 0 .907 r
.23581 .38922 m
.23669 .40189 L
s
.22708 .40107 m
.23581 .38922 L
s
.23669 .40189 m
.22708 .40107 L
s
0 .103 1 r
.24438 .26709 m
.23954 .26854 L
s
.23879 .25793 m
.24438 .26709 L
s
.58 0 1 r
.23731 .334 m
.22852 .33279 L
s
.22852 .33279 m
.23652 .32222 L
s
.23652 .32222 m
.23731 .334 L
s
0 .807 1 r
.23902 .21283 m
.24577 .2157 L
s
.23585 .21504 m
.23902 .21283 L
s
.23902 .21283 m
.24252 .20866 L
s
.24577 .2157 m
.24262 .21791 L
s
.24252 .20866 m
.24577 .2157 L
s
.908 0 1 r
.29682 .68092 m
.30011 .67205 L
s
.30011 .67205 m
.29692 .66434 L
s
.30011 .67205 m
.28616 .67229 L
s
0 .103 1 r
.23954 .26854 m
.2316 .26662 L
s
.2316 .26662 m
.23879 .25793 L
s
.23879 .25793 m
.23954 .26854 L
s
0 .807 1 r
.24262 .21791 m
.23585 .21504 L
s
.23585 .21504 m
.24252 .20866 L
s
.908 0 1 r
.28616 .67229 m
.29682 .68092 L
s
.29692 .66434 m
.28616 .67229 L
s
.28616 .67229 m
.29361 .67322 L
s
.34005 .67399 m
.28616 .67229 L
s
0 .807 1 r
.24252 .20866 m
.24262 .21791 L
s
0 .599 1 r
.31017 .75877 m
.31247 .75242 L
s
.31247 .75242 m
.31022 .74726 L
s
.31247 .75242 m
.30277 .75269 L
s
.908 0 1 r
.29361 .67322 m
.29682 .68092 L
s
.29692 .66434 m
.29361 .67322 L
s
0 .599 1 r
.30277 .75269 m
.31017 .75877 L
s
.31022 .74726 m
.30277 .75269 L
s
.30277 .75269 m
.30791 .75361 L
s
.34005 .7543 m
.30277 .75269 L
s
.466 0 1 r
.75251 .70097 m
.75157 .69319 L
s
.75157 .69319 m
.7474 .6866 L
s
.75157 .69319 m
.74018 .69716 L
s
0 .599 1 r
.30791 .75361 m
.31017 .75877 L
s
.31022 .74726 m
.30791 .75361 L
s
.466 0 1 r
.74018 .69716 m
.75251 .70097 L
s
.7474 .6866 m
.74018 .69716 L
s
.74018 .69716 m
.74833 .69438 L
s
.78933 .68018 m
.74018 .69716 L
s
.7474 .6866 m
.74833 .69438 L
s
.74833 .69438 m
.75251 .70097 L
s
0 .83 1 r
.78625 .7524 m
.78558 .74669 L
s
.78558 .74669 m
.78276 .74206 L
s
.78558 .74669 m
.77745 .74946 L
s
.77745 .74946 m
.78625 .7524 L
s
.78276 .74206 m
.77745 .74946 L
s
.77745 .74946 m
.78342 .74778 L
s
.81287 .73827 m
.77745 .74946 L
s
.78276 .74206 m
.78342 .74778 L
s
.78342 .74778 m
.78625 .7524 L
s
.938 0 1 r
.4499 .68562 m
.45271 .67648 L
s
.45271 .67648 m
.4498 .66856 L
s
.45271 .67648 m
.43862 .67688 L
s
1 .498 0 r
.85706 .78325 m
.85721 .78228 L
s
.85721 .78228 m
.85706 .78152 L
s
.85721 .78228 m
.85585 .78234 L
s
.85585 .78234 m
.85706 .78325 L
s
.85706 .78152 m
.85585 .78234 L
s
.85585 .78234 m
.85691 .78248 L
s
.8619 .78256 m
.85585 .78234 L
s
.85706 .78152 m
.85691 .78248 L
s
.85691 .78248 m
.85706 .78325 L
s
.938 0 1 r
.43862 .67688 m
.4499 .68562 L
s
.4498 .66856 m
.43862 .67688 L
s
.43862 .67688 m
.44697 .67771 L
s
.49513 .67794 m
.43862 .67688 L
s
0 .626 1 r
.46413 .76491 m
.46603 .75845 L
s
.46603 .75845 m
.46408 .75323 L
s
.46603 .75845 m
.45639 .75882 L
s
.938 0 1 r
.4498 .66856 m
.44697 .67771 L
s
.44697 .67771 m
.4499 .68562 L
s
0 .626 1 r
.45639 .75882 m
.46413 .76491 L
s
.46408 .75323 m
.45639 .75882 L
s
.45639 .75882 m
.46217 .75969 L
s
.49513 .76007 m
.45639 .75882 L
s
.46408 .75323 m
.46217 .75969 L
s
.46217 .75969 m
.46413 .76491 L
s
.887 0 1 r
.61052 .68957 m
.61285 .6803 L
s
.61285 .6803 m
.6105 .67229 L
s
.61285 .6803 m
.59888 .68064 L
s
.59888 .68064 m
.61052 .68957 L
s
.6105 .67229 m
.59888 .68064 L
s
.59888 .68064 m
.60815 .68157 L
s
.65741 .68208 m
.59888 .68064 L
s
0 .651 1 r
.62519 .77085 m
.62676 .76428 L
s
.62676 .76428 m
.62519 .75898 L
s
.62676 .76428 m
.61718 .76462 L
s
.887 0 1 r
.6105 .67229 m
.60815 .68157 L
s
.60815 .68157 m
.61052 .68957 L
s
0 .651 1 r
.61718 .76462 m
.62519 .77085 L
s
.62519 .75898 m
.61718 .76462 L
s
.61718 .76462 m
.62361 .76556 L
s
.65741 .76611 m
.61718 .76462 L
s
.62519 .75898 m
.62361 .76556 L
s
.62361 .76556 m
.62519 .77085 L
s
1 0 .812 r
.71597 .7158 m
.71501 .70618 L
s
.71501 .70618 m
.70982 .69812 L
s
.71501 .70618 m
.70093 .71101 L
s
.70093 .71101 m
.71597 .7158 L
s
.70982 .69812 m
.70093 .71101 L
s
.70093 .71101 m
.71076 .70775 L
s
.76114 .69061 m
.70093 .71101 L
s
.70982 .69812 m
.71076 .70775 L
s
.71076 .70775 m
.71597 .7158 L
s
0 .479 1 r
.75461 .76829 m
.75399 .76152 L
s
.75399 .76152 m
.75066 .7561 L
s
.75399 .76152 m
.74435 .76471 L
s
.74435 .76471 m
.75461 .76829 L
s
.75066 .7561 m
.74435 .76471 L
s
.74435 .76471 m
.75127 .76288 L
s
.78594 .75211 m
.74435 .76471 L
s
.75066 .7561 m
.75127 .76288 L
s
.75127 .76288 m
.75461 .76829 L
s
1 .651 0 r
.831 .80001 m
.83121 .79867 L
s
.83121 .79867 m
.831 .79762 L
s
.83121 .79867 m
.82934 .79875 L
s
.82934 .79875 m
.831 .80001 L
s
.831 .79762 m
.82934 .79875 L
s
.82934 .79875 m
.83078 .79896 L
s
.83765 .79908 m
.82934 .79875 L
s
.831 .79762 m
.83078 .79896 L
s
.83078 .79896 m
.831 .80001 L
s
0 g
.001 w
[ .01 .01 ] 0 setdash
.13028 .19447 m
.85281 .16113 L
s
.85281 .16113 m
.85281 .83887 L
s
.85281 .83887 m
.13028 .80553 L
s
.13028 .80553 m
.13028 .19447 L
s
.88191 .18439 m
.85281 .16113 L
s
.85281 .16113 m
.85281 .83887 L
s
.85281 .83887 m
.88191 .81561 L
s
.88191 .81561 m
.88191 .18439 L
s
.003 w
[ ] 0 setdash
.88191 .18439 m
.85281 .16113 L
s
.25 Mabswid
.87609 .17973 m
.87609 .18598 L
s
gsave
.87609 .16723 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.86848 .17365 m
.86848 .1799 L
s
gsave
.86848 .16115 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.86059 .16734 m
.86059 .17359 L
s
gsave
.86059 .15484 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.87459 .17854 m
.87459 .18229 L
s
.87308 .17733 m
.87308 .18108 L
s
.87156 .17611 m
.87156 .17986 L
s
.87003 .17489 m
.87003 .17864 L
s
.86693 .17241 m
.86693 .17616 L
s
.86536 .17116 m
.86536 .17491 L
s
.86378 .1699 m
.86378 .17365 L
s
.86219 .16862 m
.86219 .17237 L
s
.87758 .18092 m
.87758 .18467 L
s
.87905 .1821 m
.87905 .18585 L
s
.88052 .18327 m
.88052 .18702 L
s
.85897 .16605 m
.85897 .1698 L
s
.85734 .16475 m
.85734 .1685 L
s
.8557 .16343 m
.8557 .16718 L
s
.85405 .16211 m
.85405 .16586 L
s
gsave
.86788 .09817 -68.8125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{350, 350},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005N0001GQ000`40O003h00OogooGgoo003oOomO
Ool00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00
ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomO
Ool00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomOOol00?mooaeoo`<0
009oo`<003Yoo`00XGoo0`00NWoo00@007ooOol003aoo`00XWoo00<007ooOol0NGoo00@007ooOol0
03aoo`00XWoo00<007ooOol0NWoo0P00?Goo002ROol00`00Oomoo`1jOol2000mOol00:5oo`03001o
o`0007Yoo`04001oogoo000lOol00:5oo`03001oo`0007Yoo`04001oogoo000lOol00:1oo`05001o
ogooOol0001gOol30002Ool3000jOol009moo`<00004Ool00000002hOol00?mooemoo`00ogooGgoo
003oOomOOol00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00ogoo4goo0`000goo0`00@goo
003oOolBOol01`00Oomoogoo001oo`0000=oo`03001oogoo041oo`00ogoo4Woo00L007ooOomoo`00
Ool00002Ool40003Ool3000jOol00=Ioo`<000=oo`<0039oo`07001oogooOol007oo00000Woo0P00
0Woo00<007oo00000goo00<007ooOol0=goo003EOol01`00Oomoogoo001oo`0000=oo`03001oogoo
031oo`<0009oo`05001oogooOol00002Ool300000goo00000002000hOol00:1oo`04001oogooOol3
000^Ool01`00Oomoogoo001oo`0000=oo`03001oogoo02moo`07001oogooOol007oo00000goo0P00
0Woo0P000goo00<007oo0000=goo002POol01000Oomoo`000goo00<007ooOol0:goo00L007ooOomo
o`00Ool00003Ool00`00Oomoo`0_Ool01`00Oomoogoo001oo`0000=oo`04001oo`00Ool6000017oo
00000000=Goo002MOol70003Ool00`00Oomoo`0[Ool40002Ool01@00Oomoogoo0000<Woo0`000goo
0`000Woo00L007oo000007oo001oo`030002Ool00`00Oomoo`0bOol006Qoo`@000=oo`<002]oo`04
001oogoo0002Ool01@00Oomoogoo0000;Woo00<007ooOol00Woo00D007ooOomoo`0003Yoo`05001o
ogoo001oo`0200000goo001oo`030002Ool00`00Oomoo`0bOol006Qoo`07001oogooOol007oo0000
0goo00<007ooOol0:Goo00<007oo00000Woo00D007ooOomoo`0002ioo`8000=oo`05001oogooOol0
000kOol20002Ool00`00Ool000040003Ool00`00Oomoo`0bOol003Uoo`<002eoo`03001oogoo009o
o`05001oogooOol0000/Ool20002Ool01@00Oomoogoo0000<7oo0P000Woo0`00@7oo00<007ooOol0
0P0000=oo`00Ool00Woo00<007ooOol0<Woo000hOol01@00Oomoogoo0000;Goo00D007ooOomoo`00
00=oo`03001oogoo02Yoo`80009oo`05001oogooOol0001fOol20002Ool50002Ool00`00Oomoo`0b
Ool003Qoo`05001oogooOol0000^Ool01000Oomoo`000goo00<007ooOol0:goo00@007ooOomoo`<0
07]oo`04001oogoo0003Ool00`00Oomoo`0bOol003Qoo`05001oogooOol0000^Ool01000Oomoo`00
0goo00<007ooOol0UWoo0`000Woo400000=oo`0000000goo0`00=Goo000hOol01@00Oomoogoo0000
:goo00@007ooOol0009oo`05001oogooOol00023Ool500000goo0000000E0004Ool00`00Oomoo`04
Ool3000mOol003Qoo`05001oogooOol0000/Ool20004Ool3001]Ool20002OolI000<Ool00`00Oomo
o`0<Ool00`00Oomoo`04Ool4000lOol003Qoo`05001oogooOol0002=OolK0005Ool00`00Oomoo`0a
Ool00`00Ool00003000jOol003Uoo`<007Moo`80009ooaL000eoo`03001oogoo049oo`D003Uoo`00
X7oo5`0027oo00<007ooOol06Goo00<007ooOol0A7oo1000>7oo0028OolH0003Ool00`00Oomoo`0;
Ool00`00Oomoo`1ZOol01000Oomoogoo1@00=goo001bOolG000=Ool00`00Oomoo`0:Ool00`00Oomo
o`1gOol40003Ool4000fOol005]ooaP000Qoo`03001oogoo00Yoo`03001oogoo07Uoo`@0009oo`@0
00=oo`@0009oo`@000=oo`03001oogoo00Eoo`8003Ioo`00A7oo60001Goo00<007ooOol02Woo00<0
07ooOol0O7oo0P000Woo10000Woo10000goo100077oo00<007ooOol01Woo00<007ooOol0=7oo000h
Ool<000017oo0000000037oo00<007ooOol05goo00<007ooOol0Igoo10000Woo10000Woo10000goo
0P00>Woo00<007ooOol0=7oo000hOol00`00Oomoo`02000:Ool00`00Oomoo`1dOol40003Ool40002
Ool40002Ool4001BOol00`00Oomoo`0dOol003Qoo`04001oogoo0003Ool3001UOol20002Ool40003
Ool40002Ool4001ROol00`00Oomoo`06Ool00`00Oomoo`0dOol003Qoo`03001oogoo00Moo`03001o
ogoo00<004Yoo`@0009oo`@000=oo`@0009oo`8007Moo`03001oogoo00Ioo`03001oogoo009oo`@0
00=oo`<002Qoo`00>7oo00<007ooOol03Goo00@007oo0nL3ibeoo`@0009oo`@0009oo`@000=oo`@0
08ioo`03001oogoo00Ioo`03001oogoo009oo`07001oogooOol007oo00000goo00<007ooOol09Goo
0019Ool30nL2000>Ool00`<oOomoo`02Ool20003Ool40002Ool40002Ool4002XOol00`00Oomoo`06
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo00009goo001;Ool00`?WOomoo`020003
Ool40002Ool200020cl2Ool20036Ool00`00Oomoo`04Ool01@00Oomoogoo00000goo00<007ooOol0
9Goo000hOol00`00Oomoo`0?Ool00`?WOomoo`02Ool00`00Oomoo`08Ool40co9Ool00`00Oomoo`05
Ool01000Oomoo`000goo00<007ooOol09Goo000hOol00`00Oomoo`0?Ool00`?WOomoo`02Ool00`00
Oomoo`09Ool20co:Ool00`00Oomoo`05Ool01000Oomoo`000goo00<007ooOol09Goo000hOol00`00
Oomoo`0?Ool00`?WOomoo`02Ool00`00Oomoo`08Ool00c_P0cmoo`31Ool00`00Oomoo`06Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00D007ooOomoo`0002Moo`00>7oo00<007ooOol03goo00<3igoo
Ool03Woo00<3?gooOol03goo0P?_[goo00<007ooOol01Woo00<007ooOol00goo0P0017oo0`00:7oo
0019Ool00`?WOomoo`0>Ool00`<o>n1oo`0?Ool30nn_Ool00`00Oomoo`05Ool2000fOol004Uoo`03
0nMoogoo00ioo`030cmoogoo00moo`<3kjmoo`03001oogoo00Ioo`03001oogoo03Aoo`00>7oo00<0
07ooOol057oo00<007ooOol027oo00<3?gooOol047oo00<3kgooOol0]goo00<007ooOol0=7oo000h
Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`<o>n1oo`0@Ool00`?_Oomoo`2hOol00`00Oomoo`0d
Ool003Qoo`03001oogoo01Aoo`03001oogoo00Moo`030cmoogoo011oo`030nmoogoo0:moo`03001o
ogoo00Ioo`03001oogoo03Aoo`00>7oo00<007ooOol057oo00<007ooOol06Goo00<3kgooOol0/7oo
00<007ooOol01Woo00<007ooOol0=7oo001[Ool00`?_Oomoo`2`Ool00`00Oomoo`06Ool00`00Oomo
o`0dOol006Yoo`030nmoogoo0;5oo`03001oogoo00Ioo`03001oogoo03Aoo`00Cgoo00<007ooOol0
eGoo00<007ooOol0=7oo000hOol00`00Oomoo`0DOol00`00Oomoo`09Ool00`1oOomoo`39Ool00`00
Oomoo`0dOol003Qoo`03001oogoo01Aoo`03001oogoo00Uoo`0307moogoo0<1oo`03001oogoo00Io
o`03001oogoo03Aoo`00>7oo00<007ooOol057oo00<007ooOol027oo0`1o`Goo00<007ooOol01Woo
00<007ooOol0=7oo000hOol00`00Oomoo`0NOol507o0Ool00`00Oomoo`06Ool00`00Oomoo`0dOol0
04Moo`030oioogoo015oo`0307moogoo0<1oo`03001oogoo00Ioo`03001oogoo03Aoo`00AWoo0P?n
1goo00<007ooOol02Goo00<0OgooOol0b7oo0P00=Woo000hOol00`00Oomoo`0:Ool40oh6Ool00`00
Oomoo`09Ool00`1oOomoo`0>Ool00`:OOomoo`2hOol00`00Oomoo`0dOol003Qoo`03001oogoo00ao
o`030oioogoo00Eoo`03001oogoo00Uoo`0307moogoo00ioo`030Ymoogoo0;Qoo`03001oogoo03Ao
o`00>7oo00<007ooOol037oo00<3oWooOol01Goo00<007ooOol027oo00<0OgooOol03Woo0`:O/7oo
00<007ooOol01Woo00<007ooOol0=7oo000hOol00`00Oomoo`0<Ool00`?nOomoo`0@Ool00`1oOomo
o`0?Ool20Yn`Ool00`00Oomoo`06Ool00`00Oomoo`0dOol004Moo`030oioogoo00moo`030nT0Ogoo
00moo`030Ymoogoo0;1oo`03001oogoo00Ioo`03001oogoo03Aoo`00Agoo00<3oWooOol03goo00<3
j@1oOol03goo00<2WgooOol0/7oo00<007ooOol01Woo00<007ooOol0=7oo000hOol00`00Oomoo`0<
Ool00`?nOomoo`05Ool00`00Oomoo`06Ool20nT00`1oOomoo`0>Ool00`:OOomoo`2iOol00`00Oomo
o`0dOol003Qoo`03001oogoo00aoo`030oioogoo00Eoo`03001oogoo00Moo`030nT0Ogoo00moo`03
0Ymoogoo0;Uoo`03001oogoo03Aoo`00>7oo00<007ooOol037oo00<3oWooOol01Goo00<007ooOol0
1goo00<3j@1oOol03goo00<2WgooOol0/7oo00<007ooOol01Woo00<007ooOol0=7oo000hOol00`00
Oomoo`0<Ool00`?nOomoo`05Ool00`00Oomoo`06Ool00`?YOomoo`0@Ool00`:OOomoo`2`Ool00`00
Oomoo`06Ool00`00Oomoo`0dOol005Qoo`030nUoogoo00moo`030Ymoogoo0;5oo`03001oogoo00Io
o`03001oogoo03Aoo`00F7oo00<3jGooOol03goo00<2WgooOol0/Goo00<007ooOol01Woo00<007oo
Ool0=7oo001?Ool00`00Oomoo`06Ool00`?YOomoo`0?Ool00`:OOomoo`2jOol00`00Oomoo`0dOol0
03Qoo`03001oogoo01Aoo`03001oogoo0=Aoo`8003Ioo`00>7oo00<007ooOol057oo00<007ooOol0
c7oo00<007ooOol01Woo00<007ooOol0=7oo000hOol00`00Oomoo`0DOol00`00Oomoo`08Ool00dPO
Oomoo`31Ool00`00Oomoo`06Ool00`00Oomoo`0dOol003Qoo`03001oogoo01moo`03B1moogoo0<5o
o`03001oogoo00Ioo`03001oogoo03Aoo`00FGoo0dPO`Woo00<007ooOol01Woo00<007ooOol0=7oo
001?Ool00`00Oomoo`06Ool5B1o1Ool00`00Oomoo`06Ool00`00Oomoo`0dOol003Qoo`03001oogoo
00aoo`030Omoogoo00Eoo`03001oogoo00Qoo`03B1moogoo00moo`0301moogoo0;Qoo`03001oogoo
03Aoo`00>7oo00<007ooOol037oo00<1ogooOol01Goo00<007ooOol027oo00=87gooOol03goo00<0
7gooOol0^7oo00<007ooOol0=7oo000hOol00`00Oomoo`0;Ool30Ol6Ool00`00Oomoo`08Ool00dPO
Oomoo`0>Ool301n`Ool00`00Oomoo`06Ool00`00Oomoo`0dOol003Qoo`03001oogoo00Yoo`D1oa1o
o`03B1moogoo00eoo`@07k1oo`03001oogoo00Ioo`03001oogoo03Aoo`00Agoo00<1ogooOol047oo
00=87gooOol03goo00<07gooOol0[goo00<007ooOol01Woo00<007ooOol0=7oo0017Ool00`7oOomo
o`0?Ool00`?lB1moo`0?Ool00`0OOomoo`2`Ool00`00Oomoo`06Ool00`00Oomoo`0dOol003Qoo`03
001oogoo00aoo`030Omoogoo00Eoo`03001oogoo00Ioo`83o003B1moogoo00ioo`0301moogoo0;Uo
o`03001oogoo03Aoo`00>7oo00<007ooOol037oo00<1ogooOol01Goo00<007ooOol01Goo0`?l00=8
7gooOol03Woo00<07gooOol0^Goo00<007ooOol0=7oo000hOol00`00Oomoo`0<Ool00`7oOomoo`05
Ool00`00Oomoo`07Ool00`?lB1moo`0?Ool00`0OOomoo`2`Ool00`00Oomoo`04Ool3000fOol003Qo
o`03001oogoo00aoo`030Omoogoo00Eoo`03001oogoo00Moo`030oa87goo00moo`0301moogoo0;1o
o`03001oogoo00Ioo`03001oogoo03Aoo`00Agoo00<1ogooOol03goo00<3o4POOol03goo00<07goo
Ool0/7oo00<007ooOol01Woo00<007ooOol0=7oo0017Ool00`7oOomoo`0>Ool00`?lOom87`0@Ool0
0`0OOomoo`2`Ool00`00Oomoo`06Ool00`00Oomoo`06Ool01000Oomoogoo0`009goo0017Ool00`7o
Oomoo`05Ool00`00Oomoo`06Ool00`?lOom87`0?Ool00`0OOomoo`2jOol00`00Oomoo`06Ool01000
Oomoo`000goo00<007ooOol097oo000hOol00`00Oomoo`0<Ool00`7oOomoo`05Ool00`00Oomoo`06
Ool00`?lOom87`0?Ool00`0OOomoo`2jOol00`00Oomoo`03Ool70003Ool00`00Oomoo`0TOol003Qo
o`03001oogoo01Aoo`03001oogoo00Ioo`030oaoogoo00moo`0301moogoo0;5oo`03001oogoo00Io
o`03001oogoo00=oo`04001oogoo0002Ool01@00Oomoogoo00009Woo000hOol00`00Oomoo`0DOol0
0`00Oomoo`06Ool00`?lOomoo`0?Ool00`0OOomoo`2aOol00`00Oomoo`06Ool00`00Oomoo`04Ool0
0`00Ool00002Ool01@00Oomoogoo00009Woo000hOol00`00Oomoo`3SOol00`00Oomoo`06Ool00`00
Oomoo`05Ool20002Ool01@00Oomoogoo00009Woo001JOol00g`MOomoo`31Ool00`00Oomoo`06Ool0
0`00Oomoo`05Ool20002Ool01@00Oomoogoo00009Woo001?Ool00`00Oomoo`08Ool00g`MOomoo`31
Ool00`00Oomoo`06Ool00`00Oomoo`06Ool01000Oomoogoo0`009goo000hOol00`00Oomoo`0DOol0
0`00Oomoo`07Ool3O1g;Ool00`00Oomoo`0dOol003Qoo`03001oogoo01Aoo`03001oogoo00Ioo`El
7LYoo`03001oogoo03Aoo`00>7oo00<007ooOol057oo00<007ooOol01Goo1g`M3Goo00=07gooOol0
/7oo00<007ooOol01Woo00<007ooOol0=7oo000hOol00`00Oomoo`0<Ool00`1oOomoo`0@Ool00g`M
Oomoo`0>Ool00d0OOomoo`2`Ool00`00Oomoo`06Ool00`00Oomoo`0dOol004Ioo`<0Oa5oo`03O1eo
ogoo00eoo`=07k5oo`03001oogoo00Eoo`8003Ioo`00AGoo1@1o47oo00=l7GooOol037oo1D0O/7oo
00<007ooOol01Woo00<007ooOol0=7oo000hOol00`00Oomoo`0<Ool00`1oOomoo`05Ool00`00Oomo
o`07Ool00`;oO1eoo`0?Ool00d0OOomoo`2iOol00`00Oomoo`0dOol003Qoo`03001oogoo00aoo`03
07moogoo00Eoo`03001oogoo00Moo`030_ml7Goo00moo`03@1moogoo0;Uoo`03001oogoo03Aoo`00
>7oo00<007ooOol037oo00<0OgooOol01Goo00<007ooOol01Woo0P;o00=l7GooOol03Woo00=07goo
Ool0/7oo00<007ooOol01Woo00<007ooOol0=7oo000hOol00`00Oomoo`0<Ool00`1oOomoo`05Ool0
0`00Oomoo`05Ool30_l00g`MOomoo`0>Ool00d0OOomoo`2`Ool00`00Oomoo`06Ool00`00Oomoo`0d
Ool004Moo`0307moogoo00moo`030_ml7Goo00moo`03@1moogoo0;1oo`03001oogoo00Ioo`03001o
ogoo03Aoo`00Agoo00<0OgooOol03goo00<2og`MOol03Woo00=07gooOol0/Goo00<007ooOol01Woo
00<007ooOol0=7oo0017Ool00`1oOomoo`05Ool00`00Oomoo`07Ool00`;oO1eoo`0>Ool00d0OOomo
o`2jOol00`00Oomoo`0dOol003Qoo`03001oogoo00aoo`0307moogoo00Eoo`03001oogoo00Ioo`03
0_moog`M00moo`03@1moogoo0;Yoo`03001oogoo03Aoo`00>7oo00<007ooOol037oo00<0OgooOol0
1Goo00<007ooOol01Woo00<2ogooO1d03goo00=07gooOol0/Goo00<007ooOol01Woo00<007ooOol0
=7oo000hOol00`00Oomoo`0<Ool00`1oOomoo`05Ool00`00Oomoo`06Ool00`;oOoml7@0?Ool00d0O
Oomoo`2aOol00`00Oomoo`06Ool00`00Oomoo`0dOol003Qoo`03001oogoo00aoo`0307moogoo00io
o`030_moog`M00moo`03@1moogoo0;5oo`03001oogoo00Ioo`03001oogoo03Aoo`00Agoo00<0Ogoo
Ool03Woo00<2ogooO1d03goo00=07gooOol0/Goo00<007ooOol01Woo00<007ooOol0=7oo001?Ool0
0`00Oomoo`06Ool00`;oOomoo`0?Ool00d0OOomoo`2aOol00`00Oomoo`06Ool00`00Oomoo`0dOol0
03Qoo`03001oogoo01Aoo`03001oogoo0=Aoo`8003Ioo`00>7oo00<007ooOol057oo00<007ooOol0
27oo00=l4GooOol0bWoo00<007ooOol0=7oo000hOol00`00Oomoo`0DOol00`00Oomoo`08Ool00g`A
Oomoo`31Ool00`00Oomoo`06Ool00`00Oomoo`0dOol003Qoo`03001oogoo01Aoo`03001oogoo00Mo
o`=l4L9oo`03001oogoo00Ioo`03001oogoo03Aoo`00F7oo0g`A00=oog`AOol03Goo00=X7gooOol0
/7oo00<007ooOol01Woo00<007ooOol0=7oo001GOol7O14=Ool00fPOOomoo`2`Ool00`00Oomoo`06
Ool00`00Oomoo`0dOol003Qoo`03001oogoo00aoo`0331moogoo00Eoo`03001oogoo00Qoo`03O15o
ogoo00eoo`=X7kYoo`03001oogoo03Aoo`00>7oo00<007ooOol037oo00<<7gooOol01Goo00<007oo
Ool027oo00=l4GooOol037oo1FPO^Goo00<007ooOol0=7oo000hOol00`00Oomoo`0;Ool331l6Ool0
0`00Oomoo`06Ool00`7oOoml4@0@Ool00fPOOomoo`2`Ool00`00Oomoo`06Ool00`00Oomoo`0dOol0
03Qoo`03001oogoo00Yoo`D<7`Eoo`03001oogoo00Ioo`030Omoog`A011oo`03J1moogoo0;1oo`03
001oogoo00Ioo`03001oogoo03Aoo`00Agoo00<<7gooOol03Goo0`7o00=l4GooOol03Woo00=X7goo
Ool0/7oo00<007ooOol01Woo00<007ooOol0=7oo0017Ool00``OOomoo`0=Ool30Ol00g`AOomoo`0>
Ool00fPOOomoo`2`Ool00`00Oomoo`06Ool00`00Oomoo`0dOol004Moo`0331moogoo00Eoo`03001o
ogoo00Ioo`030Omoog`A011oo`03J1moogoo0;Uoo`03001oogoo01Moo`H001Moo`00>7oo00<007oo
Ool037oo00<<7gooOol01Goo00<007ooOol01Woo00<1ogooO1403goo00=X7gooOol0^Woo00<007oo
Ool067oo00D007ooOomoo`0001Moo`00>7oo00<007ooOol037oo00<<7gooOol01Goo00<007ooOol0
1Woo00<1ogooO1403goo00=X7gooOol0/Goo00<007ooOol01Goo0P006Woo00<007ooOol06Goo000h
Ool00`00Oomoo`0<Ool00``OOomoo`05Ool00`00Oomoo`06Ool00`7oOoml4@0?Ool00fPOOomoo`2a
Ool00`00Oomoo`06Ool00`00Oomoo`0IOol00`00Oomoo`0HOol003Qoo`03001oogoo00aoo`0331mo
ogoo00ioo`030Omoog`A00moo`03J1moogoo0;5oo`03001oogoo00Ioo`03001oogoo01Yoo`03001o
ogoo01Moo`00Agoo00<<7gooOol03Woo00<1ogooO1403goo00=X7gooOol0/Goo00<007ooOol01Woo
00<007ooOol06goo00<007ooOol05Woo0017Ool00``OOomoo`05Ool00`00Oomoo`06Ool00`7oOoml
4@0?Ool00fPOOomoo`2aOol00`00Oomoo`06Ool00`00Oomoo`0GOol01@00Oomoogoo000067oo000h
Ool00`00Oomoo`0<Ool00``OOomoo`05Ool00`00Oomoo`06Ool00`7oOoml4@0?Ool00fPOOomoo`2j
Ool00`00Oomoo`0GOol6000GOol003Qoo`03001oogoo00aoo`0331moogoo00Eoo`03001oogoo00Io
o`030Omoog`A00moo`03J1moogoo0;Yoo`03001oogoo03Aoo`00>7oo00<007ooOol037oo00<<7goo
Ool01Goo00<007ooOol01Woo00<1ogooO1403goo00=X7gooOol0/Goo00<007ooOol01Woo00<007oo
Ool0=7oo000hOol00`00Oomoo`0DOol00`00Oomoo`3<Ool00`00Oomoo`06Ool00`00Oomoo`0dOol0
05Yoo`03O0Yoogoo0<5oo`03001oogoo00Ioo`03001oogoo03Aoo`00FWoo00=l2WooOol0`Goo00<0
07ooOol01Woo00<007ooOol0=7oo000hOol00`00Oomoo`0DOol00`00Oomoo`07Ool3O0X?Ool00g`O
Oomoo`2iOol00`00Oomoo`04Ool30003Ool3000WOol003Qoo`03001oogoo01Aoo`03001oogoo00Io
o`=l2P03Ooml2Woo00eoo`03O1moogoo0;Uoo`03001oogoo00=oo`07001oogooOol007oo00000goo
00<007ooOol097oo000hOol00`00Oomoo`0DOol00`00Oomoo`05Ool7O0X<Ool3O1naOol00`00Oomo
o`06Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`0000=oo`03001oogoo02Aoo`00>7oo00<007oo
Ool037oo00<H7gooOol01Goo00<007ooOol01goo0W`:3Woo17`O/Goo00<007ooOol01Goo0P001Goo
00L007ooOomoo`00Ool00003Ool00`00Oomoo`0TOol003Qoo`03001oogoo00aoo`0361moogoo011o
o`03O0Yoogoo00]oo`Il7k1oo`03001oogoo00Aoo`03001oo`0000Eoo`@0009oo`05001oogooOol0
000VOol004Ioo`<H7`moo`030Gmoog`:011oo`03O1moogoo0;1oo`03001oogoo00Ioo`03001oogoo
00Aoo`03001oogoo009oo`05001oogooOol0000VOol004Ioo`<H7`Ioo`03001oogoo00Ioo`81O`03
O0Yoogoo00ioo`03O1moogoo0;Uoo`03001oogoo00Aoo`8000=oo`05001oogooOol0000VOol003Qo
o`03001oogoo00Yoo`DH7`Eoo`03001oogoo00Eoo`<1O`03O0Yoogoo00ioo`03O1moogoo0;Uoo`03
001oogoo00Ioo`80009oo`<002Moo`00>7oo00<007ooOol037oo00<H7gooOol01Goo00<007ooOol0
1Woo00<1OgooO0X047oo00=l7gooOol0/7oo00<007ooOol01Woo00<007ooOol0=7oo000hOol00`00
Oomoo`0<Ool00aPOOomoo`05Ool00`00Oomoo`06Ool00`5oOoml2P0@Ool00g`OOomoo`2`Ool00`00
Oomoo`06Ool00`00Oomoo`0dOol003Qoo`03001oogoo00aoo`0361moogoo00ioo`030Gmoog`:00mo
o`03O1moogoo0;5oo`03001oogoo00Ioo`03001oogoo03Aoo`00Agoo00<H7gooOol03Woo00<1Ogoo
O0X03goo00=l7gooOol0/Goo00<007ooOol01Woo00<007ooOol0=7oo0017Ool00aPOOomoo`05Ool0
0`00Oomoo`06Ool00`5oOoml2P0?Ool00g`OOomoo`2aOol00`00Oomoo`06Ool00`00Oomoo`0dOol0
03Qoo`03001oogoo00aoo`0361moogoo00Eoo`03001oogoo00Ioo`030Gmoog`:00moo`03O1moogoo
0;Yoo`03001oogoo03Aoo`00>7oo00<007ooOol037oo00<H7gooOol01Goo00<007ooOol01Woo00<1
OgooO0X03goo00=l7gooOol0^Woo00<007ooOol0=7oo000hOol00`00Oomoo`0<Ool00aPOOomoo`05
Ool00`00Oomoo`02O004Ool00`5oOoml2P0?Ool00g`OOomoo`2aOol00`00Oomoo`06Ool00`00Oomo
o`0dOol003Qoo`03001oogoo00aoo`0361moogoo00Eoo`06001oogooO01oog`00goo00<1OgooO0X0
2Goo00=l5gooOol00goo00=l7gooOol0/Goo00<007ooOol01Woo00<007ooOol0=7oo0017Ool00aPO
Oomoo`07Ool3O0001gooO01oogoo0Gmoog`:00Uoo`9l5`Aoo`03O1moogoo0;5oo`03001oogoo00Io
o`03001oogoo03Aoo`00Agoo00<H7gooOol01goo1W`00goo00=l2WooOol01goo0g`G0goo00=l7goo
Ool0/Goo00<007ooOol01Goo0P00=Woo000hOol00`00Oomoo`0<Ool00aPOOomoo`05Ool00`00Ooml
0003O005Ool00g`:Oomoo`06Ool5O1NoOol00`00Oomoo`0dOol003Qoo`03001oogoo01Aoo`05001l
07`0Ooml000?Ool3O1O1Ool00`00Oomoo`0dOol003Qoo`03001oogoo01Aoo`03001oogoo009oo`03
O01oogoo00ioo`03O1Moogoo0;Ioo`03001oogoo00Ioo`03001oogoo03Aoo`00>7oo00<007ooOol0
57oo00<007ooOol00Woo00=l07ooOol03goo00=l5gooOol0]Goo00<007ooOol01Woo00<007ooOol0
=7oo000hOol00`00Oomoo`0IOol00g`0Oomoo`0?Ool00g`GOomoo`2eOol00`00Oomoo`06Ool00`00
Oomoo`0dOol005Aoo`03O01oogoo00moo`03O1Moogoo0;Eoo`03001oogoo00Ioo`03001oogoo03Ao
o`00Cgoo00<007ooOol00goo00=l07ooOol03Woo00=l5gooOol0_Woo00<007ooOol0=7oo000hOol0
0`00Oomoo`0DOol00`00Oomoo`03Ool00g`0Oomoo`0?Ool00g`GOomoo`2mOol00`00Oomoo`0dOol0
03Qoo`03001oogoo00]oo`03;1moogoo00Ioo`03001oogoo00=oo`04O01oogoo0;l>Ool00g`GOomo
o`2dOol00`00Oomoo`06Ool00`00Oomoo`0dOol003Qoo`03001oogoo00]oo`8/7`Moo`03001oogoo
00Aoo`04O01oo`2o0;l=Ool00g`GOomoo`2dOol00`00Oomoo`06Ool00`00Oomoo`0dOol003Qoo`03
001oogoo00Yoo`@/7`eoo`03O000_`2o0080_`aoo`03O1Moogoo0;Aoo`03001oogoo00Ioo`03001o
ogoo03Aoo`00AGoo0b`O3Woo00Al002o0;l0_`ioo`03O1Moogoo0;=oo`03001oogoo00Ioo`03001o
ogoo03Aoo`00A7oo0R`O00=oob`OOol01Woo00<007ooOol017oo00Al07ooOol0_`ioo`03O1Moogoo
0;=oo`03001oogoo00Ioo`03001oogoo03Aoo`00>7oo00<007ooOol037oo00</7gooOol01Goo00<0
07ooOol01Goo00=l07oo0;l03Woo00=l5gooOol0^goo0P00=Woo000hOol00`00Oomoo`0<Ool00b`O
Oomoo`05Ool00`00Oomoo`05Ool00g`0Ool0_`07Ool5J1l3Ool00g`GOomoo`2kOol00`00Oomoo`0d
Ool003Qoo`03001oogoo00eoo`03;1moogoo00=oo`El3@Aoo`04O01oogoo0;l6Ool5J1l3Ool00g`G
Oomoo`2bOol00`00Oomoo`06Ool00`00Oomoo`0dOol003Qoo`03001oogoo00eoo`03;1moogoo00=o
o`03O0d007`=009l3@Eoo`03O01oo`2o00Moo`AX7kQoo`03001oogoo00Ioo`03001oogoo03Aoo`00
B7oo00</7gooOol017oo00Al3GooO0el3@Eoo`03O01oo`2o00Moo`=X7`03OomX7goo0;Ioo`03001o
ogoo00Ioo`03001oogoo03Aoo`00BGoo00</7gooOol00goo0W`=00=oog`=O0d01Woo00<0_gooOol0
1Woo00AX7gooOomoo`9X7kEoo`03001oogoo00Ioo`03001oogoo03Aoo`00>7oo00<007ooOol03Woo
00</7gooOol00goo0g`=0Woo0W`=17oo00<0_gooOol037oo0VPO_7oo00<007ooOol0=7oo000hOol0
0`00Oomoo`0>Ool00b`OOomoo`03Ool00`00O0eoo`04Ool00g`=Oomoo`02Ool00`2oOomoo`0=Ool0
0fPOOomoo`0@Ool271nWOol00`00Oomoo`0dOol003Qoo`03001oogoo00ioo`03;1moogoo00=oo`03
001oogoo00Eoo`05O0eoogooOol0_`0@Ool2J1l?Ool00a`OOolL7`0]Ool00a`OOomoo`1^Ool00`00
Oomoo`06Ool00`00Oomoo`0dOol003Qoo`03001oogoo00moo`03;1moogoo009oo`03001oogoo00Io
o`9l3A=oo`03M1mX7goo00aoo`lL7b5oo`8L7bmoo`8H7cmoo`03001oogoo00Ioo`03001oogoo03Ao
o`00>7oo00<007ooOol03goo00</7gooOol03Goo00=l3GooOol03goo0W@O00=oofPOOol03Goo00<L
7goo71l077oo0WPO37oo3a`O8Woo00<H7goo61l0?goo00<007ooOol01Woo00<007ooOol0=7oo001K
Ool2O0d>Ool2M1l00gooM1moo`0?Ool00a`OOomoo`0JOol00gPOOomh7`0=Ool371l/Ool961ljOol0
0`00Oomoo`06Ool00`00Oomoo`0dOol004moo`03001oogoo00]oo`03O0eoogoo00Yooa9d7amoo`05
N1moogPOOomh7`0=Ool00a`OOomoo`0POol2L1l:Ool261l00goo61moo`03Ool761llOol00`00Oomo
o`0dOol003Qoo`03001oogoo01Aoo`03001oogoo00aoo`03O0eoogoo00]oo`03M1moog@O02]ooa=h
7b5oo`9`7`03Oom`7goo00Yoo`8H7dQoo`03001oogoo03Aoo`00>7oo00<007ooOol057oo00<007oo
Ool06goo00=d7gooOol0;7oo0WPO00=oogPOOol0;7oo2g0O1Woo00<H7gooOol09goo0SPO57oo00<0
07ooOol01Woo00<007ooOol0=7oo000hOol00`00Oomoo`0DOol00`00Oomoo`1;Ool2N1l`Ool3L1l6
Ool9L1lTOol3>1lFOol00`00Oomoo`05Ool2000fOol003Qoo`03001oogoo06=oo`03N1moogoo02mo
o`9`7bYoo`03>1moogoo00Aoo`8h7aUoo`03001oogoo00Ioo`03001oogoo03Aoo`00dGoo00=`7goo
Ool0:7oo00<h7gooOol00W`I0SPO6goo00<007ooOol01Woo00<007ooOol0=7oo001?Ool00`00Oomo
o`2YOol01CPOO1Ul6G`I>1l07Woo00<007ooOol01Woo00<007ooOol0=7oo000hOol00`00Oomoo`0D
Ool01000Oomoog`03Woo0P8OUWoo0g`I0SPO:Goo00<007ooOol0=7oo000hOol00`00Oomoo`0DOol0
0`00Oomoo`0=Ool40Qn=Ool00g`IOomoo`03Ool3O1T00goo>1lh7`03>1lXOol00`00Oomoo`0dOol0
03Qoo`03001oogoo01Aoo`03001oogoo00eoo`040Qmoo`8O0Qn=Ool2O1T2Ool2O1T7Ool2>1lOOol0
0`00Oomoo`06Ool00`00Oomoo`03Ool30003Ool3000XOol003Qoo`03001oogoo019oo`@0G`moo`04
0Qmoogoo0Qn;Ool5O1TZOol00`00Oomoo`06Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000=o
o`03001oogoo02Eoo`00@7oo00=lH7ooOol02Woo00@0Ggoo05l0Ga=oo`827hQoo`=l6@03Ooml6Goo
02Yoo`03001oogoo00Ioo`03001oogoo009oo`07001oogooOol007oo00000goo00<007ooOol09Goo
001>Ool305lEOol20Qn5Ool6O1T[Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01`00Oomoogoo001o
o`0000=oo`03001oogoo02Eoo`00>7oo00<007ooOol04goo00<0G`00Ool00P1O5Goo00<27gooOol0
QWoo0W`I=7oo00<007ooOol00goo0`000Woo00D007ooOomoo`0002Moo`00>7oo00<007ooOol057oo
00D007ooOomoo`1O01Eoo`030Qmoogoo0;]oo`03001oogoo009oo`07001oogooOol007oo00000goo
00<007ooOol09Goo000hOol00`00Oomoo`0DOol00`00Oomoo`02Ool205o8Ool00`00Oomoo`06Ool0
0`00Oomoo`02Ool01`00Oomoogoo001oo`0000=oo`03001oogoo02Eoo`00>7oo00<007ooOol057oo
00<007ooOol017oo00<0GgooOol0aGoo00<007ooOol01Goo0P001Goo0`000goo0`00:7oo000hOol0
0`00Oomoo`0LOol00`1OOomoo`34Ool00`00Oomoo`04Ool00`00Ool0000fOol005Qoo`0305moogoo
0<=oo`03001oogoo00Ioo`03001oogoo03Aoo`00Cgoo00<007ooOol0eGoo00<007ooOol0=7oo000h
Ool00`00Oomoo`0DOol00`00Oomoo`0_Ool20onTOol00`00Oomoo`0dOol003Qoo`03001oogoo01Ao
o`03001oogoo02ioo`/3obIoo`030omoogoo05]oo`<3GaEoo`03001oogoo03Aoo`00>7oo00<007oo
Ool057oo00<007ooOol0;goo0`?o;7oo0P?oEGoo00@3GgooOomoo`@3G`moo`03001oogoo00Ioo`03
001oogoo03Aoo`00>7oo00<007ooOol0=Woo0P9o3goo00<3ogooOol0:Woo2`?o9Woo0P?o9Goo10=O
4goo00<007ooOol01Woo00<007ooOol0=7oo001`Ool00`9oOol2O`0nOol00`?oOomoo`0[Ool70olP
Ool30elEOol00`00Oomoo`06Ool00`00Oomoo`0dOol004moo`03001oogoo00Qoo`9l01=oo`L2Obao
o`030Ymoogoo03]oo`<3o`=oo`D3oa]oo`<1oaEoo`03001oogoo00Ioo`03001oogoo03Aoo`00>7oo
00<007ooOol057oo00<007ooOol07Woo0`9o0goo1P9o9Goo0P:O?Woo00<3ogooOol06Goo00<1ogoo
Ool00goo0`7o8Goo00<007ooOol0=7oo000hOol00`00Oomoo`0DOol00`00Oomoo`0OOol00`9oOomo
o`0/Ool=0YlXOol00`:OOomoo`0UOol00`7oOomoo`030OlTOol00`00Oomoo`0dOol003Qoo`03001o
ogoo01Aoo`03001oogoo04moo`<2Wc1oo`82WbIoo`@1oaioo`03001oogoo00Ioo`03001oogoo03Ao
o`00>7oo00<007ooOol03Woo00=l87ooOol00goo00<007ooOol0D7oo00<2WgooOol0;Woo3P:O6Woo
107o7goo00<007ooOol01Woo00<007ooOol0=7oo0019Ool00g`POomoo`28Ool30YlWOol00`7oOomo
o`0MOol00`00Oomoo`06Ool00`00Oomoo`0dOol00=Eoo`030Ymoogoo04Ioo`03001oogoo00Eoo`80
03Ioo`00>7oo00<007ooOol057oo00<007ooOol0eGoo00<007ooOol0=7oo000hOol00`00Oomoo`0D
Ool00`00Oomoo`3EOol00`00Oomoo`0dOol003Qoo`03001oogoo01Aoo`03001oogoo0<aoo`03001m
h7oo00Ioo`03001oogoo03Aoo`00>7oo00<007ooOol057oo00<007ooOol0c7oo00<007gPON001Woo
00<007ooOol0=7oo000hOol00`00Oomoo`0COol50002Ool50002Ool3002oOol00`00Oomoo`06Ool0
0`00Oomoo`0dOol004aoo`80015oo`03001oogoo00@0009oo`D0009oo`@00:]oo`03001oogoo00Io
o`03001oogoo03Aoo`00AWoo1000:goo10000Woo1@000Woo10000Woo1000Vgoo00<007ooOol0=7oo
000hOol00`00Oomoo`07Ool2001:Ool50002Ool40002Ool40002Ool3001cOol00gj0Oomoo`0=Ool0
0`00Oomoo`0dOol003Qoo`03001oogoo00Eoo`80069oo`80009oo`@0009oo`@0009oo`D0009oo`<0
05Qoo`AnP0eoo`03001oogoo03Aoo`00>7oo00@007ooOomoo`80081oo`03001oogoo00@0009oo`D0
009oo`@004aoo`03001oogoo00Ioo`03001oogoo03Aoo`00>7oo100000=oo`0000000P000Woo0`00
SWoo10000Woo1@000Woo10000Woo0`00=7oo00<007ooOol01Woo00<007ooOol0=7oo0016Ool00`00
Oomoo`040003Ool40002Ool4002@Ool00`00Oomoo`050002Ool40002Ool40002Ool3000KOol00`00
Oomoo`06Ool00`00Oomoo`0dOol005aoo`@000=oo`@0009oo`@0009oo`<0095oo`80009oo`@0009o
o`@0009oo`D000Ioo`03001oogoo00Ioo`03001oogoo03Aoo`00LWoo00@007ooOomoo`@0009oo`@0
009oo`@009Aoo`@0009oo`@0009oo`8003Ioo`00RGoo10000Woo10000Woo1000aGoo002LOol40002
Ool40002Ool40003Ool3001/Ool00`00Oomoo`03Ool2000hOol00;9oo`03001oogoo00@0009oo`@0
00=oo`@005Qoo`03001oogoo009oo`03001oogoo03Qoo`00b7oo10000Woo10000goo10000Woo0`00
@7oo00D007ooOomoo`0003]oo`00gWoo00<007ooOol010000goo10000Woo1000;7oo00<007ooOol0
?Goo003dOol40003Ool40002Ool40002Ool3000EOol2000mOol00?moo`]oo`80009oo`@0009oo`@0
009oo`D003moo`00ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00
ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomO
Ool00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00
ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomO
Ool00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00
ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomO
Ool00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00
ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomO
Ool00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00
ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo001bOol4003XOol0075oo`03001oogoo009oo`03
001oogoo0>Eoo`00LGoo00<007ooOol00Woo00<007ooOol0iGoo001QOol30002Ool00`00Ool00002
0002Ool400000goo0000000200001Goo00000000Ool00P0000=oo`00000017oo00<007oo00001`00
00=oo`0000000P000goo100000Aoo`000000009oo`<00003Ool0000000=oo`H00003Ool0000000=o
o`H00004Ool000000002Ool20002Ool3000017oo000007oo0P0000=oo`0000000goo0`0000=oo`00
00000Woo00<007ooOol00Woo00<007oo00001goo0`000Woo0`000Woo1000IGoo001ROol00`00Oomo
o`020002Ool01000Oomoo`000Woo00<007oo00001Woo00H007ooOol007oo0002Ool01000Oomoo`00
0goo00@007ooOol0009oo`80009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`00
0Woo00<007ooOol00goo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo009oo`03001oo`00
009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007oo00000Woo00D007ooOomoo`00009oo`04
001oogoo0005Ool00`00Ool00008Ool01000Oomoo`000goo00<007ooOol00goo00<007ooOol0HWoo
001ROol02000Oomoo`00Ool007oo0002Ool01000Oomoo`000Woo0`000goo00H007ooOol007oo0005
Ool01@00Oomoogoo00000goo00@007ooOol0009oo`05001oogooOol00002Ool00`00Ool00003Ool0
1000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Ao
o`04001oogoo0005Ool01000Oomoo`000Woo00<007oo00001Woo00@007ooOol0009oo`03001oogoo
00=oo`03001oo`0000Qoo`04001oogoo0003Ool00`00Oomoo`03Ool00`00Oomoo`1ROol0069oo`03
001oo`00009oo`03001oo`0000=oo`<00003Ool007oo009oo`04001oogoo0002Ool00`00Ool00003
0002Ool01@00Oomoogoo00000goo00@007ooOomoo`<000=oo`06001oogoo001oo`000goo00@007oo
Ool0009oo`03001oogoo00=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000goo00<0
07ooOol010000Woo00@007ooOol0009oo`03001oo`0000<000=oo`04001oogoo0002Ool00`00Oomo
o`02Ool50007Ool01000Oomoo`000goo00<007ooOol00goo00<007ooOol0HWoo001ROol00`00Ool0
0002Ool00`00Ool00005Ool00`00Ool00003Ool00`00Oomoo`02000017oo001oo`000Woo00@007oo
Ool000=oo`03001oo`00009oo`03001oogoo009oo`05001oogooOol00002Ool00`00Ool00003Ool0
0`00Oomoo`0200000goo001oo`04Ool00`00Oomoo`0200000goo001oo`04Ool40003Ool01000Oomo
o`000Woo00<007ooOol00P0000Moo`00001oo`00Ool00002Ool01000Oomoogoo0P0000Eoo`00Oomo
o`0000Ioo`03001oo`0000Moo`04001oogoo0003Ool00`00Oomoo`03Ool00`00Oomoo`1ROol0069o
o`8000Aoo`80009oo`<000=oo`<0009oo`800003Ool007oo009oo`80009oo`<00004Ool00000Ool8
0003Ool50002Ool30002Ool200000goo001oo`04Ool200001Goo000007oo00001Woo00@007ooOol0
00=oo`04001oogooOol20002Ool200001Goo001oogoo00000goo0P000goo0P0000Aoo`00Oomoo`<0
00Aoo`D000Ioo`04001oogoo0003Ool00`00Ool00003001UOol0069oo`8000Aoo`8001Uoo`03001o
ogoo00moo`03001oogoo01ioo`05001oogooOol00002Ool00`00Oomoo`0KOol00`00Oomoo`04Ool0
0`00Ool00007Ool01000Oomoo`000goo00@007ooOol006Moo`00HGoo0P001Woo0P0067oo00D007oo
Oomoo`0000eoo`04001oogoo000AOol00`00Oomoo`08Ool600000goo0000000MOol00`00Oomoo`04
Ool00`00Ool00006Ool20003Ool30003Ool4001TOol00?mooemoo`00ogooGgoo0000\
\>"],
  ImageRangeCache->{{{0, 349}, {349, 0}} -> {-0.0493869, -5.06255*^-6, 
  0.00315424, 0.00315424}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RadPlot3DOptions[]; \n\t
    ListPlotVectorField3D[radObjM[t]\n, VectorHeads -> True\n, 
      ColorFunction -> \ Hue\n, 
      PlotLabel -> "\<Magnetization in Element # \>"<>ToString[t]\n, 
      ViewPoint -> {3, 2\ , \ 0}\n, PlotRange -> {All, All, All}\ \n, 
      ScaleFactor -> 8]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.5 1.0125 -79.1562 0 ]
[.5 1.0125 79.1562 14 ]
[.83552 .12334 -12.125 -14 ]
[.83552 .12334 12.125 0 ]
[.8091 .11601 -5 -14 ]
[.8091 .11601 5 0 ]
[.7816 .10838 -8 -14 ]
[.7816 .10838 8 0 ]
[.8091 .05351 -7.8125 -14 ]
[.8091 .05351 7.8125 0 ]
[.24103 .15718 -15.125 -14 ]
[.24103 .15718 15.125 0 ]
[.34707 .14702 -12.125 -14 ]
[.34707 .14702 12.125 0 ]
[.45983 .13623 -5 -14 ]
[.45983 .13623 5 0 ]
[.57997 .12473 -8 -14 ]
[.57997 .12473 8 0 ]
[.70825 .11244 -11 -14 ]
[.70825 .11244 11 0 ]
[.45983 .07373 -7.8125 -14 ]
[.45983 .07373 7.8125 0 ]
[.85495 .21126 0 -5.43755 ]
[.85495 .21126 30.25 8.56245 ]
[.85517 .35566 0 -6.21877 ]
[.85517 .35566 24.25 7.78123 ]
[.85525 .5 0 -7 ]
[.85525 .5 10 7 ]
[.85517 .64434 0 -7.78123 ]
[.85517 .64434 16 6.21877 ]
[.85495 .78874 0 -8.56245 ]
[.85495 .78874 22 5.43755 ]
[.91775 .5 0 -7 ]
[.91775 .5 14.3125 7 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -140.156 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Magnetization) show
135.125000 14.000000 moveto
(in) show
147.437500 14.000000 moveto
(Element) show
190.312500 14.000000 moveto
(#) show
199.312500 14.000000 moveto
(109) show
217.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
[ ] 0 setdash
.84275 .13784 m
.77367 .11868 L
s
.25 Mabswid
.83552 .13584 m
.83552 .14209 L
s
gsave
.83552 .12334 -73.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.8091 .12851 m
.8091 .13476 L
s
gsave
.8091 .11601 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7816 .12088 m
.7816 .12713 L
s
gsave
.7816 .10838 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.82901 .13403 m
.82901 .13778 L
s
.82244 .13221 m
.82244 .13596 L
s
.8158 .13037 m
.8158 .13412 L
s
.80233 .12663 m
.80233 .13038 L
s
.79549 .12473 m
.79549 .12848 L
s
.78858 .12282 m
.78858 .12657 L
s
.84196 .13762 m
.84196 .14137 L
s
.77454 .11892 m
.77454 .12267 L
s
gsave
.8091 .05351 -68.8125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.19183 .17439 m
.77367 .11868 L
s
.25 Mabswid
.24103 .16968 m
.24103 .17593 L
s
gsave
.24103 .15718 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.34707 .15952 m
.34707 .16577 L
s
gsave
.34707 .14702 -73.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.45983 .14873 m
.45983 .15498 L
s
gsave
.45983 .13623 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.57997 .13723 m
.57997 .14348 L
s
gsave
.57997 .12473 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.70825 .12494 m
.70825 .13119 L
s
gsave
.70825 .11244 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.26173 .16769 m
.26173 .17144 L
s
.28268 .16569 m
.28268 .16944 L
s
.30388 .16366 m
.30388 .16741 L
s
.32534 .1616 m
.32534 .16535 L
s
.36906 .15742 m
.36906 .16117 L
s
.39133 .15529 m
.39133 .15904 L
s
.41387 .15313 m
.41387 .15688 L
s
.43671 .15094 m
.43671 .15469 L
s
.48324 .14649 m
.48324 .15024 L
s
.50696 .14422 m
.50696 .14797 L
s
.53098 .14192 m
.53098 .14567 L
s
.55532 .13959 m
.55532 .14334 L
s
.60495 .13483 m
.60495 .13858 L
s
.63026 .13241 m
.63026 .13616 L
s
.65591 .12996 m
.65591 .13371 L
s
.68191 .12747 m
.68191 .13122 L
s
.22058 .17163 m
.22058 .17538 L
s
.20036 .17357 m
.20036 .17732 L
s
.73496 .12239 m
.73496 .12614 L
s
.76203 .1198 m
.76203 .12355 L
s
gsave
.45983 .07373 -68.8125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.84275 .13784 m
.84275 .86216 L
s
.25 Mabswid
.84275 .20854 m
.83665 .20718 L
s
gsave
.85495 .21126 -61 -9.43755 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.84275 .35427 m
.83654 .35358 L
s
gsave
.85517 .35566 -61 -10.2188 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.84275 .5 m
.8365 .5 L
s
gsave
.85525 .5 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.84275 .64573 m
.83654 .64642 L
s
gsave
.85517 .64434 -61 -11.7812 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.84275 .79146 m
.83665 .79282 L
s
gsave
.85495 .78874 -61 -12.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.84275 .23769 m
.83908 .23695 L
s
.84275 .26683 m
.83906 .26617 L
s
.84275 .29598 m
.83905 .2954 L
s
.84275 .32512 m
.83904 .32463 L
s
.84275 .38342 m
.83902 .38308 L
s
.84275 .41256 m
.83901 .41231 L
s
.84275 .44171 m
.83901 .44154 L
s
.84275 .47085 m
.839 .47077 L
s
.84275 .52915 m
.839 .52923 L
s
.84275 .55829 m
.83901 .55846 L
s
.84275 .58744 m
.83901 .58769 L
s
.84275 .61658 m
.83902 .61692 L
s
.84275 .67488 m
.83904 .67537 L
s
.84275 .70402 m
.83905 .7046 L
s
.84275 .73317 m
.83906 .73383 L
s
.84275 .76231 m
.83908 .76305 L
s
.84275 .17939 m
.83911 .1785 L
s
.84275 .15025 m
.83913 .14928 L
s
.84275 .82061 m
.83911 .8215 L
s
.84275 .84975 m
.83913 .85072 L
s
gsave
.91775 .5 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.27641 .18846 m
.27641 .81154 L
s
.27641 .81154 m
.84275 .86216 L
s
.84275 .86216 m
.84275 .13784 L
s
.84275 .13784 m
.27641 .18846 L
s
.19183 .17439 m
.77367 .11868 L
s
.77367 .11868 m
.77367 .88132 L
s
.77367 .88132 m
.19183 .82561 L
s
.19183 .82561 m
.19183 .17439 L
s
.27641 .18846 m
.27641 .81154 L
s
.27641 .81154 m
.19183 .82561 L
s
.19183 .82561 m
.19183 .17439 L
s
.19183 .17439 m
.27641 .18846 L
s
.84275 .13784 m
.77367 .11868 L
s
.77367 .11868 m
.77367 .88132 L
s
.77367 .88132 m
.84275 .86216 L
s
.84275 .86216 m
.84275 .13784 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .65 0 r
.5 Mabswid
[ ] 0 setdash
.28354 .49077 m
.28357 .49055 L
s
.28357 .49055 m
.2832 .49032 L
s
.28357 .49055 m
.28313 .49086 L
s
.28313 .49086 m
.28354 .49077 L
s
.2832 .49032 m
.28313 .49086 L
s
.28313 .49086 m
.28317 .49054 L
s
.28435 .4893 m
.28313 .49086 L
s
.2832 .49032 m
.28317 .49054 L
s
.28317 .49054 m
.28354 .49077 L
s
.28435 .5107 m
.28557 .51227 L
s
.28552 .51195 m
.28515 .51218 L
s
.2855 .51173 m
.28552 .51195 L
s
.28557 .51227 m
.28552 .51195 L
s
.28515 .51218 m
.28513 .51196 L
s
.28557 .51227 m
.28515 .51218 L
s
.28513 .51196 m
.2855 .51173 L
s
.2855 .51173 m
.28557 .51227 L
s
.28513 .51196 m
.28557 .51227 L
s
0 .479 1 r
.2965 .49718 m
.29637 .49643 L
s
.29637 .49643 m
.29411 .49567 L
s
.29637 .49643 m
.29447 .49855 L
s
.29411 .49567 m
.29425 .49642 L
s
.29411 .49567 m
.29447 .49855 L
s
.29447 .49855 m
.2965 .49718 L
s
.29447 .49855 m
.29425 .49642 L
s
.29865 .48791 m
.29447 .49855 L
s
.29425 .49642 m
.2965 .49718 L
s
.29865 .51209 m
.30284 .52276 L
s
.30306 .52061 m
.3008 .52138 L
s
.3032 .51987 m
.30306 .52061 L
s
.30284 .52276 m
.30306 .52061 L
s
.3008 .52138 m
.30094 .52064 L
s
.30284 .52276 m
.3008 .52138 L
s
.3032 .51987 m
.30284 .52276 L
s
.30094 .52064 m
.30284 .52276 L
s
.30094 .52064 m
.3032 .51987 L
s
1 0 .812 r
.30851 .5084 m
.30827 .50732 L
s
.30827 .50732 m
.30493 .50626 L
s
.30827 .50732 m
.30554 .5105 L
s
.30493 .50626 m
.30517 .50733 L
s
.30493 .50626 m
.30554 .5105 L
s
.30554 .5105 m
.30851 .5084 L
s
.30554 .5105 m
.30517 .50733 L
s
.31146 .49461 m
.30554 .5105 L
s
.30517 .50733 m
.30851 .5084 L
s
0 .652 1 r
.31143 .46682 m
.31152 .4657 L
s
.31152 .4657 m
.30961 .46454 L
s
.31152 .4657 m
.30925 .4673 L
s
.30925 .4673 m
.31143 .46682 L
s
.30961 .46454 m
.30925 .4673 L
s
.30925 .4673 m
.30952 .46566 L
s
.3156 .4592 m
.30925 .4673 L
s
.30961 .46454 m
.30952 .46566 L
s
.30952 .46566 m
.31143 .46682 L
s
1 0 .812 r
.31146 .50539 m
.3174 .52134 L
s
.31776 .51813 m
.31441 .51921 L
s
.31802 .51709 m
.31776 .51813 L
s
.3174 .52134 m
.31776 .51813 L
s
.31441 .51921 m
.31466 .51817 L
s
.3174 .52134 m
.31441 .51921 L
s
0 .652 1 r
.3156 .5408 m
.32196 .54893 L
s
1 0 .812 r
.31802 .51709 m
.3174 .52134 L
s
.31466 .51817 m
.3174 .52134 L
s
.31466 .51817 m
.31802 .51709 L
s
.887 0 1 r
.32234 .48644 m
.32247 .48478 L
s
.32247 .48478 m
.31968 .4831 L
s
.32247 .48478 m
.31915 .48713 L
s
0 .652 1 r
.32169 .54728 m
.31978 .54844 L
s
.3216 .54617 m
.32169 .54728 L
s
.32196 .54893 m
.32169 .54728 L
s
.887 0 1 r
.31915 .48713 m
.32234 .48644 L
s
.31968 .4831 m
.31915 .48713 L
s
.31915 .48713 m
.31954 .48476 L
s
.32845 .47531 m
.31915 .48713 L
s
.31968 .4831 m
.31954 .48476 L
s
0 .652 1 r
.31978 .54844 m
.31968 .54733 L
s
.32196 .54893 m
.31978 .54844 L
s
.31968 .54733 m
.3216 .54617 L
s
.3216 .54617 m
.32196 .54893 L
s
.31968 .54733 m
.32196 .54893 L
s
.887 0 1 r
.31954 .48476 m
.32234 .48644 L
s
1 .498 0 r
.25968 .4903 m
.2597 .49013 L
s
.2597 .49013 m
.25941 .48996 L
s
.2597 .49013 m
.25936 .49037 L
s
.887 0 1 r
.32845 .52469 m
.3378 .53658 L
s
1 .498 0 r
.25936 .49037 m
.25968 .4903 L
s
.25941 .48996 m
.25936 .49037 L
s
.25936 .49037 m
.25939 .49013 L
s
.2603 .48916 m
.25936 .49037 L
s
.25941 .48996 m
.25939 .49013 L
s
.25939 .49013 m
.25968 .4903 L
s
.2603 .51084 m
.26124 .51206 L
s
.26121 .51181 m
.26092 .51199 L
s
.26119 .51164 m
.26121 .51181 L
s
.26124 .51206 m
.26121 .51181 L
s
.26092 .51199 m
.2609 .51182 L
s
.26124 .51206 m
.26092 .51199 L
s
.2609 .51182 m
.26119 .51164 L
s
.26119 .51164 m
.26124 .51206 L
s
.2609 .51182 m
.26124 .51206 L
s
.887 0 1 r
.33738 .53417 m
.33459 .53586 L
s
.33727 .53252 m
.33738 .53417 L
s
.3378 .53658 m
.33738 .53417 L
s
.33459 .53586 m
.33447 .53422 L
s
.3378 .53658 m
.33459 .53586 L
s
0 .627 1 r
.33764 .43344 m
.33771 .43234 L
s
.33771 .43234 m
.33578 .43116 L
s
.33771 .43234 m
.33542 .43396 L
s
.33542 .43396 m
.33764 .43344 L
s
.33578 .43116 m
.33542 .43396 L
s
.33542 .43396 m
.33571 .43227 L
s
.34188 .42565 m
.33542 .43396 L
s
.33578 .43116 m
.33571 .43227 L
s
.887 0 1 r
.33447 .53422 m
.33727 .53252 L
s
.33727 .53252 m
.3378 .53658 L
s
0 .627 1 r
.33571 .43227 m
.33764 .43344 L
s
.887 0 1 r
.33447 .53422 m
.3378 .53658 L
s
0 .831 1 r
.27281 .49624 m
.2727 .49556 L
s
.2727 .49556 m
.27064 .49489 L
s
.2727 .49556 m
.27098 .49751 L
s
.27064 .49489 m
.27075 .49556 L
s
.27064 .49489 m
.27098 .49751 L
s
.27098 .49751 m
.27281 .49624 L
s
.27098 .49751 m
.27075 .49556 L
s
.27469 .48775 m
.27098 .49751 L
s
0 .627 1 r
.34188 .57435 m
.34837 .5827 L
s
0 .831 1 r
.27075 .49556 m
.27281 .49624 L
s
.27469 .51225 m
.2784 .52203 L
s
.938 0 1 r
.3487 .45319 m
.34879 .45155 L
s
.34879 .45155 m
.34596 .44983 L
s
.34879 .45155 m
.34543 .45394 L
s
0 .627 1 r
.34807 .58099 m
.34614 .58217 L
s
.34801 .57989 m
.34807 .58099 L
s
.34837 .5827 m
.34807 .58099 L
s
0 .831 1 r
.27864 .52006 m
.27657 .52075 L
s
.27875 .5194 m
.27864 .52006 L
s
.2784 .52203 m
.27864 .52006 L
s
.938 0 1 r
.34543 .45394 m
.3487 .45319 L
s
.34596 .44983 m
.34543 .45394 L
s
.34543 .45394 m
.34586 .45147 L
s
.35493 .44175 m
.34543 .45394 L
s
.34596 .44983 m
.34586 .45147 L
s
0 .831 1 r
.27657 .52075 m
.27668 .52008 L
s
.2784 .52203 m
.27657 .52075 L
s
0 .627 1 r
.34614 .58217 m
.34607 .58108 L
s
.34837 .5827 m
.34614 .58217 L
s
0 .831 1 r
.27875 .5194 m
.2784 .52203 L
s
.27668 .52008 m
.2784 .52203 L
s
0 .627 1 r
.34607 .58108 m
.34801 .57989 L
s
.34801 .57989 m
.34837 .5827 L
s
0 .831 1 r
.27668 .52008 m
.27875 .5194 L
s
0 .627 1 r
.34607 .58108 m
.34837 .5827 L
s
.938 0 1 r
.34586 .45147 m
.3487 .45319 L
s
.466 0 1 r
.28508 .50659 m
.2849 .50566 L
s
.2849 .50566 m
.28197 .50474 L
s
.2849 .50566 m
.28251 .50844 L
s
.28197 .50474 m
.28215 .50566 L
s
.28197 .50474 m
.28251 .50844 L
s
.28251 .50844 m
.28508 .50659 L
s
.28251 .50844 m
.28215 .50566 L
s
.28758 .49454 m
.28251 .50844 L
s
.28215 .50566 m
.28508 .50659 L
s
.938 0 1 r
.35493 .55825 m
.36448 .57049 L
s
0 .998 1 r
.28797 .46559 m
.28808 .46458 L
s
.28808 .46458 m
.28634 .46353 L
s
.28808 .46458 m
.28601 .46603 L
s
.28601 .46603 m
.28797 .46559 L
s
.28634 .46353 m
.28601 .46603 L
s
.28601 .46603 m
.28623 .46454 L
s
.29174 .45867 m
.28601 .46603 L
s
.28634 .46353 m
.28623 .46454 L
s
.466 0 1 r
.28758 .50546 m
.29265 .51941 L
s
0 .998 1 r
.28623 .46454 m
.28797 .46559 L
s
.466 0 1 r
.29301 .5166 m
.29007 .51753 L
s
.2932 .5157 m
.29301 .5166 L
s
.29265 .51941 m
.29301 .5166 L
s
.938 0 1 r
.36403 .56798 m
.36119 .56972 L
s
.36395 .56636 m
.36403 .56798 L
s
.36448 .57049 m
.36403 .56798 L
s
.466 0 1 r
.29007 .51753 m
.29027 .51663 L
s
.29265 .51941 m
.29007 .51753 L
s
.938 0 1 r
.36119 .56972 m
.36111 .5681 L
s
.36448 .57049 m
.36119 .56972 L
s
0 .6 1 r
.36418 .3995 m
.36425 .3984 L
s
.36425 .3984 m
.36231 .39718 L
s
.36425 .3984 m
.36192 .40003 L
s
0 .998 1 r
.29174 .54133 m
.29748 .54872 L
s
0 .6 1 r
.36192 .40003 m
.36418 .3995 L
s
.36231 .39718 m
.36192 .40003 L
s
.36192 .40003 m
.36223 .39828 L
s
.36857 .39159 m
.36192 .40003 L
s
.36231 .39718 m
.36223 .39828 L
s
.466 0 1 r
.2932 .5157 m
.29265 .51941 L
s
.29027 .51663 m
.29265 .51941 L
s
.29027 .51663 m
.2932 .5157 L
s
.938 0 1 r
.36111 .5681 m
.36395 .56636 L
s
.36395 .56636 m
.36448 .57049 L
s
0 .6 1 r
.36223 .39828 m
.36418 .3995 L
s
0 .998 1 r
.29725 .54722 m
.29551 .54827 L
s
.29715 .54621 m
.29725 .54722 L
s
.29748 .54872 m
.29725 .54722 L
s
.938 0 1 r
.36111 .5681 m
.36448 .57049 L
s
0 .998 1 r
.29551 .54827 m
.29541 .54727 L
s
.29748 .54872 m
.29551 .54827 L
s
.197 0 1 r
.29939 .48468 m
.29952 .48324 L
s
.29952 .48324 m
.29708 .48177 L
s
.29952 .48324 m
.29663 .48528 L
s
.29663 .48528 m
.29939 .48468 L
s
.29708 .48177 m
.29663 .48528 L
s
.29663 .48528 m
.29695 .48321 L
s
.30467 .47499 m
.29663 .48528 L
s
.29708 .48177 m
.29695 .48321 L
s
0 .998 1 r
.29541 .54727 m
.29715 .54621 L
s
.29715 .54621 m
.29748 .54872 L
s
.29541 .54727 m
.29748 .54872 L
s
0 .6 1 r
.36857 .60841 m
.37524 .61688 L
s
.197 0 1 r
.29695 .48321 m
.29939 .48468 L
s
.908 0 1 r
.37536 .4191 m
.37541 .41748 L
s
.37541 .41748 m
.37261 .41572 L
s
.37541 .41748 m
.37203 .41984 L
s
0 .6 1 r
.37491 .61512 m
.37296 .61634 L
s
.37485 .61402 m
.37491 .61512 L
s
.37524 .61688 m
.37491 .61512 L
s
.908 0 1 r
.37203 .41984 m
.37536 .4191 L
s
.37261 .41572 m
.37203 .41984 L
s
.37203 .41984 m
.37256 .41734 L
s
.38181 .40769 m
.37203 .41984 L
s
.37261 .41572 m
.37256 .41734 L
s
0 .6 1 r
.37296 .61634 m
.3729 .61525 L
s
.37524 .61688 m
.37296 .61634 L
s
1 .498 0 r
.235 .49018 m
.23503 .49 L
s
.23503 .49 m
.23473 .48983 L
s
.23503 .49 m
.23468 .49025 L
s
.23468 .49025 m
.235 .49018 L
s
.23473 .48983 m
.23468 .49025 L
s
.23468 .49025 m
.23471 .49 L
s
.23562 .48902 m
.23468 .49025 L
s
.197 0 1 r
.30467 .52501 m
.31276 .53535 L
s
1 .498 0 r
.23473 .48983 m
.23471 .49 L
s
0 .6 1 r
.3729 .61525 m
.37485 .61402 L
s
.37485 .61402 m
.37524 .61688 L
s
1 .498 0 r
.23471 .49 m
.235 .49018 L
s
0 .6 1 r
.3729 .61525 m
.37524 .61688 L
s
.908 0 1 r
.37256 .41734 m
.37536 .4191 L
s
1 .498 0 r
.23562 .51098 m
.23657 .51222 L
s
.23654 .51197 m
.23625 .51214 L
s
.23652 .5118 m
.23654 .51197 L
s
.23657 .51222 m
.23654 .51197 L
s
.23625 .51214 m
.23622 .51197 L
s
.23657 .51222 m
.23625 .51214 L
s
.23622 .51197 m
.23652 .5118 L
s
.23652 .5118 m
.23657 .51222 L
s
.23622 .51197 m
.23657 .51222 L
s
.197 0 1 r
.31242 .53326 m
.30998 .53474 L
s
.3123 .53183 m
.31242 .53326 L
s
.31276 .53535 m
.31242 .53326 L
s
.30998 .53474 m
.30985 .53331 L
s
.31276 .53535 m
.30998 .53474 L
s
0 .067 1 r
.38402 .37566 m
.38475 .37389 L
s
.38475 .37389 m
.38317 .37195 L
s
.38475 .37389 m
.38148 .37462 L
s
.38148 .37462 m
.38402 .37566 L
s
.38317 .37195 m
.38148 .37462 L
s
.38148 .37462 m
.38244 .37372 L
s
.39206 .37054 m
.38148 .37462 L
s
.908 0 1 r
.38181 .59231 m
.39165 .60451 L
s
0 .98 1 r
.31437 .43175 m
.31445 .43075 L
s
.31445 .43075 m
.31269 .42968 L
s
.31445 .43075 m
.31237 .43222 L
s
1 0 .433 r
.38624 .39339 m
.38724 .39086 L
s
.38724 .39086 m
.385 .38814 L
s
.38724 .39086 m
.38262 .39192 L
s
.197 0 1 r
.30985 .53331 m
.3123 .53183 L
s
.3123 .53183 m
.31276 .53535 L
s
0 .98 1 r
.31237 .43222 m
.31437 .43175 L
s
.31269 .42968 m
.31237 .43222 L
s
.31237 .43222 m
.31261 .43068 L
s
.31819 .42467 m
.31237 .43222 L
s
1 0 .433 r
.38262 .39192 m
.38624 .39339 L
s
.385 .38814 m
.38262 .39192 L
s
.38262 .39192 m
.38399 .39066 L
s
.39764 .38609 m
.38262 .39192 L
s
0 .98 1 r
.31269 .42968 m
.31261 .43068 L
s
.197 0 1 r
.30985 .53331 m
.31276 .53535 L
s
0 .067 1 r
.38317 .37195 m
.38244 .37372 L
s
.38244 .37372 m
.38402 .37566 L
s
0 .98 1 r
.31261 .43068 m
.31437 .43175 L
s
1 0 .433 r
.385 .38814 m
.38399 .39066 L
s
0 .831 1 r
.24821 .49619 m
.24812 .49551 L
s
.24812 .49551 m
.24602 .49482 L
s
.24812 .49551 m
.24637 .49748 L
s
1 0 .433 r
.38399 .39066 m
.38624 .39339 L
s
0 .831 1 r
.24602 .49482 m
.24611 .4955 L
s
.24602 .49482 m
.24637 .49748 L
s
.908 0 1 r
.39109 .60198 m
.38829 .60376 L
s
.39106 .60038 m
.39109 .60198 L
s
.39165 .60451 m
.39109 .60198 L
s
0 .831 1 r
.24637 .49748 m
.24821 .49619 L
s
.24637 .49748 m
.24611 .4955 L
s
.2501 .48759 m
.24637 .49748 L
s
.908 0 1 r
.38829 .60376 m
.38826 .60215 L
s
.39165 .60451 m
.38829 .60376 L
s
0 .98 1 r
.31819 .57533 m
.32403 .58291 L
s
0 .831 1 r
.24611 .4955 m
.24821 .49619 L
s
1 0 0 r
.39278 .38226 m
.39563 .37969 L
s
.39563 .37969 m
.39495 .37688 L
s
.39563 .37969 m
.39088 .37778 L
s
0 .831 1 r
.2501 .51241 m
.25384 .52232 L
s
1 0 0 r
.39088 .37778 m
.39278 .38226 L
s
.39495 .37688 m
.39088 .37778 L
s
.39088 .37778 m
.3921 .37945 L
s
.40586 .38675 m
.39088 .37778 L
s
.908 0 1 r
.38826 .60215 m
.39106 .60038 L
s
.39106 .60038 m
.39165 .60451 L
s
0 .98 1 r
.32378 .58135 m
.32202 .58242 L
s
.32371 .58036 m
.32378 .58135 L
s
.32403 .58291 m
.32378 .58135 L
s
.908 0 1 r
.38826 .60215 m
.39165 .60451 L
s
0 .831 1 r
.25409 .52033 m
.25199 .52102 L
s
.25419 .51966 m
.25409 .52033 L
s
.25384 .52232 m
.25409 .52033 L
s
0 .067 1 r
.39206 .62946 m
.4027 .63357 L
s
0 .98 1 r
.32202 .58242 m
.32194 .58143 L
s
.32403 .58291 m
.32202 .58242 L
s
.23 0 1 r
.32596 .45092 m
.32606 .4495 L
s
.32606 .4495 m
.32359 .44801 L
s
.32606 .4495 m
.32314 .45158 L
s
1 0 0 r
.3921 .37945 m
.39278 .38226 L
s
0 .831 1 r
.25199 .52102 m
.25209 .52035 L
s
.25384 .52232 m
.25199 .52102 L
s
.23 0 1 r
.32314 .45158 m
.32596 .45092 L
s
.32359 .44801 m
.32314 .45158 L
s
.32314 .45158 m
.32349 .44943 L
s
.33132 .44099 m
.32314 .45158 L
s
.32359 .44801 m
.32349 .44943 L
s
0 .98 1 r
.32194 .58143 m
.32371 .58036 L
s
.32371 .58036 m
.32403 .58291 L
s
1 .036 0 r
.39419 .64904 m
.39421 .64902 L
s
.39421 .64902 m
.39421 .649 L
s
.39421 .64902 m
.39418 .649 L
s
.39418 .649 m
.39419 .64904 L
s
.39421 .649 m
.39418 .649 L
s
.39418 .649 m
.39419 .64902 L
s
.39429 .64908 m
.39418 .649 L
s
.39419 .64902 m
.39419 .64904 L
s
.39421 .649 m
.39419 .64902 L
s
.39429 .35092 m
.3944 .35084 L
s
.39439 .35085 m
.39439 .35087 L
s
.39437 .35084 m
.39439 .35085 L
s
.3944 .35084 m
.39439 .35085 L
s
.39437 .35085 m
.39437 .35084 L
s
.39437 .35084 m
.3944 .35084 L
s
.39439 .35087 m
.39437 .35085 L
s
.3944 .35084 m
.39439 .35087 L
s
.39437 .35085 m
.3944 .35084 L
s
0 .98 1 r
.32194 .58143 m
.32403 .58291 L
s
0 .831 1 r
.25419 .51966 m
.25384 .52232 L
s
.25209 .52035 m
.25384 .52232 L
s
1 0 0 r
.39495 .37688 m
.3921 .37945 L
s
0 .831 1 r
.25209 .52035 m
.25419 .51966 L
s
.23 0 1 r
.32349 .44943 m
.32596 .45092 L
s
.466 0 1 r
.26056 .50667 m
.2604 .50573 L
s
.2604 .50573 m
.25743 .5048 L
s
.2604 .50573 m
.25797 .50855 L
s
1 0 .433 r
.39764 .61391 m
.41278 .61979 L
s
0 .067 1 r
.40172 .63266 m
.40014 .63461 L
s
.401 .63088 m
.40172 .63266 L
s
.4027 .63357 m
.40172 .63266 L
s
.466 0 1 r
.25743 .5048 m
.25758 .50574 L
s
.25743 .5048 m
.25797 .50855 L
s
.25797 .50855 m
.26056 .50667 L
s
.25797 .50855 m
.25758 .50574 L
s
.26306 .49446 m
.25797 .50855 L
s
.361 0 1 r
.40096 .36863 m
.40304 .36678 L
s
.40304 .36678 m
.40258 .36473 L
s
.40304 .36678 m
.39959 .36536 L
s
.39959 .36536 m
.40096 .36863 L
s
.40258 .36473 m
.39959 .36536 L
s
.39959 .36536 m
.4005 .36658 L
s
.41054 .37195 m
.39959 .36536 L
s
0 .067 1 r
.40014 .63461 m
.39942 .63283 L
s
.4027 .63357 m
.40014 .63461 L
s
.39942 .63283 m
.401 .63088 L
s
.401 .63088 m
.4027 .63357 L
s
.361 0 1 r
.4005 .36658 m
.40096 .36863 L
s
.466 0 1 r
.25758 .50574 m
.26056 .50667 L
s
.23 0 1 r
.33132 .55901 m
.33955 .56966 L
s
0 .998 1 r
.26346 .46514 m
.26359 .46411 L
s
.26359 .46411 m
.26182 .46305 L
s
.26359 .46411 m
.26149 .46558 L
s
1 0 .343 r
.40312 .39004 m
.40636 .38813 L
s
.40636 .38813 m
.40645 .38599 L
s
.40636 .38813 m
.40249 .38528 L
s
0 .998 1 r
.26149 .46558 m
.26346 .46514 L
s
.26182 .46305 m
.26149 .46558 L
s
.26149 .46558 m
.26169 .46408 L
s
.26725 .45812 m
.26149 .46558 L
s
.361 0 1 r
.40258 .36473 m
.4005 .36658 L
s
0 .067 1 r
.39942 .63283 m
.4027 .63357 L
s
0 .998 1 r
.26182 .46305 m
.26169 .46408 L
s
1 0 .343 r
.40249 .38528 m
.40312 .39004 L
s
.40645 .38599 m
.40249 .38528 L
s
.40249 .38528 m
.40321 .38791 L
s
.41398 .399 m
.40249 .38528 L
s
.40321 .38791 m
.40312 .39004 L
s
.466 0 1 r
.26306 .50554 m
.26817 .51966 L
s
0 .998 1 r
.26169 .46408 m
.26346 .46514 L
s
.466 0 1 r
.26855 .51682 m
.26558 .51776 L
s
.26872 .5159 m
.26855 .51682 L
s
.26817 .51966 m
.26855 .51682 L
s
1 0 0 r
.40586 .61325 m
.42096 .6042 L
s
.23 0 1 r
.33918 .56748 m
.3367 .56898 L
s
.33909 .56607 m
.33918 .56748 L
s
.33955 .56966 m
.33918 .56748 L
s
1 0 .433 r
.41135 .6185 m
.40912 .62125 L
s
.41037 .61597 m
.41135 .6185 L
s
.41278 .61979 m
.41135 .6185 L
s
.466 0 1 r
.26558 .51776 m
.26574 .51685 L
s
.26817 .51966 m
.26558 .51776 L
s
1 0 .343 r
.40645 .38599 m
.40321 .38791 L
s
.23 0 1 r
.3367 .56898 m
.33662 .56757 L
s
.33955 .56966 m
.3367 .56898 L
s
1 .036 0 r
.40804 .3334 m
.40806 .33338 L
s
.40805 .33336 m
.40804 .3334 L
s
.40804 .3334 m
.40803 .33337 L
s
.40807 .33337 m
.40804 .3334 L
s
.40809 .33328 m
.40804 .3334 L
s
.40805 .33336 m
.40803 .33337 L
s
.40807 .33337 m
.40805 .33336 L
s
.40806 .33338 m
.40807 .33337 L
s
.40803 .33337 m
.40806 .33338 L
s
.40809 .66672 m
.40813 .66684 L
s
.40811 .66683 m
.4081 .66681 L
s
.40814 .66681 m
.40811 .66683 L
s
.40813 .66684 m
.40811 .66683 L
s
.40813 .6668 m
.40814 .66681 L
s
.40813 .66684 m
.40814 .66681 L
s
.4081 .66681 m
.40813 .6668 L
s
.4081 .66681 m
.40813 .66684 L
s
.40813 .6668 m
.40813 .66684 L
s
0 .998 1 r
.26725 .54188 m
.27303 .54936 L
s
1 0 .433 r
.40912 .62125 m
.40813 .61872 L
s
.41278 .61979 m
.40912 .62125 L
s
0 .97 1 r
.34111 .39731 m
.34118 .39632 L
s
.34118 .39632 m
.33941 .39522 L
s
.34118 .39632 m
.33907 .39779 L
s
1 .098 0 r
.40947 .64379 m
.40947 .64375 L
s
.40947 .64375 m
.40941 .64372 L
s
.40947 .64375 m
.4094 .6438 L
s
.4094 .6438 m
.40947 .64379 L
s
.40941 .64372 m
.4094 .6438 L
s
.4094 .6438 m
.40941 .64376 L
s
.4096 .64356 m
.4094 .6438 L
s
.40941 .64372 m
.40941 .64376 L
s
.40941 .64376 m
.40947 .64379 L
s
.466 0 1 r
.26872 .5159 m
.26817 .51966 L
s
.26574 .51685 m
.26817 .51966 L
s
1 .098 0 r
.4096 .35644 m
.40981 .35668 L
s
.4098 .35663 m
.40974 .35667 L
s
.4098 .35659 m
.4098 .35663 L
s
.40981 .35668 m
.4098 .35663 L
s
0 .97 1 r
.33907 .39779 m
.34111 .39731 L
s
.33941 .39522 m
.33907 .39779 L
s
.33907 .39779 m
.33934 .39621 L
s
.34505 .39016 m
.33907 .39779 L
s
1 .098 0 r
.40974 .35667 m
.40974 .35663 L
s
.40981 .35668 m
.40974 .35667 L
s
.23 0 1 r
.33662 .56757 m
.33909 .56607 L
s
.33909 .56607 m
.33955 .56966 L
s
1 .098 0 r
.40974 .35663 m
.4098 .35659 L
s
.4098 .35659 m
.40981 .35668 L
s
.40974 .35663 m
.40981 .35668 L
s
0 .97 1 r
.33941 .39522 m
.33934 .39621 L
s
.466 0 1 r
.26574 .51685 m
.26872 .5159 L
s
.23 0 1 r
.33662 .56757 m
.33955 .56966 L
s
1 0 .433 r
.40813 .61872 m
.41037 .61597 L
s
.41037 .61597 m
.41278 .61979 L
s
.361 0 1 r
.41054 .62805 m
.42156 .62142 L
s
0 .998 1 r
.27282 .54784 m
.27105 .54891 L
s
.2727 .54682 m
.27282 .54784 L
s
.27303 .54936 m
.27282 .54784 L
s
0 .97 1 r
.33934 .39621 m
.34111 .39731 L
s
0 .998 1 r
.27105 .54891 m
.27093 .54789 L
s
.27303 .54936 m
.27105 .54891 L
s
1 0 .433 r
.40813 .61872 m
.41278 .61979 L
s
.197 0 1 r
.27494 .48448 m
.2751 .48302 L
s
.2751 .48302 m
.27263 .48153 L
s
.2751 .48302 m
.27217 .48509 L
s
1 .098 0 r
.41295 .64823 m
.41295 .64819 L
s
.41295 .64819 m
.41289 .64815 L
s
.41295 .64819 m
.41288 .64824 L
s
.41288 .64824 m
.41295 .64823 L
s
.41289 .64815 m
.41288 .64824 L
s
.41288 .64824 m
.41289 .64819 L
s
.41308 .64799 m
.41288 .64824 L
s
.41289 .64815 m
.41289 .64819 L
s
.41289 .64819 m
.41295 .64823 L
s
.41308 .35201 m
.41328 .35226 L
s
.41327 .35221 m
.41321 .35225 L
s
.41327 .35217 m
.41327 .35221 L
s
.41328 .35226 m
.41327 .35221 L
s
.41321 .35225 m
.41321 .35221 L
s
.41328 .35226 m
.41321 .35225 L
s
.41321 .35221 m
.41327 .35217 L
s
.41327 .35217 m
.41328 .35226 L
s
.41321 .35221 m
.41328 .35226 L
s
.197 0 1 r
.27217 .48509 m
.27494 .48448 L
s
.27263 .48153 m
.27217 .48509 L
s
.27217 .48509 m
.27246 .48299 L
s
.28027 .47466 m
.27217 .48509 L
s
1 0 .343 r
.41398 .601 m
.42554 .58719 L
s
.197 0 1 r
.27263 .48153 m
.27246 .48299 L
s
0 .998 1 r
.27093 .54789 m
.2727 .54682 L
s
.2727 .54682 m
.27303 .54936 L
s
1 0 0 r
.41968 .60591 m
.41903 .60872 L
s
.41683 .60332 m
.41968 .60591 L
s
.42096 .6042 m
.41968 .60591 L
s
0 .998 1 r
.27093 .54789 m
.27303 .54936 L
s
1 0 .551 r
.41585 .40507 m
.41894 .40327 L
s
.41894 .40327 m
.41928 .40128 L
s
.41894 .40327 m
.41532 .40045 L
s
0 .97 1 r
.34505 .60984 m
.35105 .6175 L
s
.195 0 1 r
.41724 .37821 m
.41964 .37677 L
s
.41964 .37677 m
.41967 .37516 L
s
.41964 .37677 m
.41675 .37467 L
s
.197 0 1 r
.27246 .48299 m
.27494 .48448 L
s
.361 0 1 r
.42061 .62266 m
.42017 .62471 L
s
.41853 .62079 m
.42061 .62266 L
s
.42156 .62142 m
.42061 .62266 L
s
1 0 0 r
.41617 .60612 m
.41683 .60332 L
s
.41683 .60332 m
.42096 .6042 L
s
.195 0 1 r
.41675 .37467 m
.41724 .37821 L
s
.41967 .37516 m
.41675 .37467 L
s
.41675 .37467 m
.41726 .3766 L
s
.4253 .38477 m
.41675 .37467 L
s
1 0 .551 r
.41532 .40045 m
.41585 .40507 L
s
.41928 .40128 m
.41532 .40045 L
s
.41532 .40045 m
.41618 .40308 L
s
.42656 .41413 m
.41532 .40045 L
s
.195 0 1 r
.41726 .3766 m
.41724 .37821 L
s
1 0 .551 r
.41618 .40308 m
.41585 .40507 L
s
.361 0 1 r
.41809 .62284 m
.41853 .62079 L
s
.41853 .62079 m
.42156 .62142 L
s
.4196 .34307 m
.42243 .34212 L
s
.42243 .34212 m
.42276 .34093 L
s
.42243 .34212 m
.42003 .33935 L
s
0 .97 1 r
.35076 .61591 m
.34899 .61701 L
s
.3507 .61492 m
.35076 .61591 L
s
.35105 .6175 m
.35076 .61591 L
s
1 0 .343 r
.42479 .58987 m
.4249 .59198 L
s
.42155 .58794 m
.42479 .58987 L
s
.42554 .58719 m
.42479 .58987 L
s
1 0 0 r
.41903 .60872 m
.41617 .60612 L
s
.42096 .6042 m
.41903 .60872 L
s
0 .067 1 r
.4201 .66 m
.42278 .65943 L
s
.42278 .65943 m
.42318 .65907 L
s
.42278 .65943 m
.42103 .65686 L
s
.361 0 1 r
.41992 .34189 m
.4196 .34307 L
s
.42003 .33935 m
.4196 .34307 L
s
0 .97 1 r
.34899 .61701 m
.34893 .61602 L
s
.35105 .6175 m
.34899 .61701 L
s
.195 0 1 r
.41967 .37516 m
.41726 .3766 L
s
.225 0 1 r
.35284 .41645 m
.35291 .41504 L
s
.35291 .41504 m
.35045 .41351 L
s
.35291 .41504 m
.34996 .4171 L
s
0 .067 1 r
.42049 .65964 m
.4201 .66 L
s
.42103 .65686 m
.4201 .66 L
s
.361 0 1 r
.42017 .62471 m
.41809 .62284 L
s
.42156 .62142 m
.42017 .62471 L
s
.42276 .34093 m
.42003 .33935 L
s
.42003 .33935 m
.41992 .34189 L
s
.42578 .35265 m
.42003 .33935 L
s
1 0 .551 r
.41928 .40128 m
.41618 .40308 L
s
.225 0 1 r
.34996 .4171 m
.35284 .41645 L
s
.35045 .41351 m
.34996 .4171 L
s
.34996 .4171 m
.35037 .41491 L
s
.35838 .40647 m
.34996 .4171 L
s
1 0 .343 r
.42166 .59005 m
.42155 .58794 L
s
.42155 .58794 m
.42554 .58719 L
s
0 .067 1 r
.42318 .65907 m
.42103 .65686 L
s
.42103 .65686 m
.42049 .65964 L
s
.42407 .67024 m
.42103 .65686 L
s
1 0 0 r
.41617 .60612 m
.42096 .6042 L
s
.225 0 1 r
.35045 .41351 m
.35037 .41491 L
s
.361 0 1 r
.41809 .62284 m
.42156 .62142 L
s
0 .97 1 r
.34893 .61602 m
.3507 .61492 L
s
.3507 .61492 m
.35105 .6175 L
s
1 .65 0 r
.20948 .4904 m
.20952 .49017 L
s
.20952 .49017 m
.20913 .48994 L
s
.20952 .49017 m
.20906 .49049 L
s
.20906 .49049 m
.20948 .4904 L
s
.20913 .48994 m
.20906 .49049 L
s
.20906 .49049 m
.20909 .49017 L
s
.2103 .48887 m
.20906 .49049 L
s
.20913 .48994 m
.20909 .49017 L
s
0 .97 1 r
.34893 .61602 m
.35105 .6175 L
s
.197 0 1 r
.28027 .52534 m
.2884 .53582 L
s
1 .65 0 r
.20909 .49017 m
.20948 .4904 L
s
.361 0 1 r
.42276 .34093 m
.41992 .34189 L
s
1 .65 0 r
.2103 .51113 m
.21154 .51275 L
s
0 .067 1 r
.42318 .65907 m
.42049 .65964 L
s
1 .65 0 r
.2115 .51243 m
.21111 .51266 L
s
.21147 .5122 m
.2115 .51243 L
s
.21154 .51275 m
.2115 .51243 L
s
.225 0 1 r
.35037 .41491 m
.35284 .41645 L
s
1 .65 0 r
.21111 .51266 m
.21107 .51243 L
s
.21154 .51275 m
.21111 .51266 L
s
0 .067 1 r
.42407 .32976 m
.42713 .31636 L
s
1 0 .343 r
.4249 .59198 m
.42166 .59005 L
s
.42554 .58719 m
.4249 .59198 L
s
0 .067 1 r
.42766 .31916 m
.42806 .3195 L
s
.42497 .31858 m
.42766 .31916 L
s
.42713 .31636 m
.42766 .31916 L
s
1 .65 0 r
.21107 .51243 m
.21147 .5122 L
s
.21147 .5122 m
.21154 .51275 L
s
.21107 .51243 m
.21154 .51275 L
s
1 0 .343 r
.42166 .59005 m
.42554 .58719 L
s
0 .067 1 r
.42537 .31892 m
.42497 .31858 L
s
.42497 .31858 m
.42713 .31636 L
s
.195 0 1 r
.4253 .61523 m
.43389 .60509 L
s
.361 0 1 r
.42578 .64735 m
.43154 .634 L
s
.197 0 1 r
.28809 .5337 m
.28561 .5352 L
s
.28794 .53225 m
.28809 .5337 L
s
.2884 .53582 m
.28809 .5337 L
s
1 0 .551 r
.42656 .58587 m
.43786 .57213 L
s
0 .067 1 r
.42713 .31636 m
.42806 .3195 L
s
.42537 .31892 m
.42713 .31636 L
s
.195 0 1 r
.42857 .36389 m
.43099 .36246 L
s
.43099 .36246 m
.43103 .36083 L
s
.43099 .36246 m
.42808 .36034 L
s
.361 0 1 r
.43164 .63657 m
.43197 .63774 L
s
.4288 .63561 m
.43164 .63657 L
s
.43154 .634 m
.43164 .63657 L
s
.197 0 1 r
.28561 .5352 m
.28546 .53375 L
s
.2884 .53582 m
.28561 .5352 L
s
1 0 0 r
.42943 .33308 m
.43336 .33179 L
s
.43336 .33179 m
.43378 .33015 L
s
.43336 .33179 m
.43006 .32794 L
s
0 .067 1 r
.42806 .3195 m
.42537 .31892 L
s
.195 0 1 r
.42808 .36034 m
.42857 .36389 L
s
.43103 .36083 m
.42808 .36034 L
s
.42808 .36034 m
.42861 .36226 L
s
.43668 .37044 m
.42808 .36034 L
s
.361 0 1 r
.42913 .63677 m
.4288 .63561 L
s
.4288 .63561 m
.43154 .634 L
s
.195 0 1 r
.42861 .36226 m
.42857 .36389 L
s
.113 0 1 r
.4299 .39328 m
.43225 .39188 L
s
.43225 .39188 m
.43238 .39033 L
s
.43225 .39188 m
.42944 .38979 L
s
1 0 0 r
.42984 .33145 m
.42943 .33308 L
s
.43006 .32794 m
.42943 .33308 L
s
.195 0 1 r
.43335 .60705 m
.4334 .60865 L
s
.43094 .6056 m
.43335 .60705 L
s
.43389 .60509 m
.43335 .60705 L
s
.225 0 1 r
.35838 .59353 m
.36684 .60421 L
s
0 .98 1 r
.29003 .43084 m
.29013 .42983 L
s
.29013 .42983 m
.28834 .42875 L
s
.29013 .42983 m
.28802 .43133 L
s
1 0 0 r
.43378 .33015 m
.43006 .32794 L
s
.43006 .32794 m
.42984 .33145 L
s
.43781 .34634 m
.43006 .32794 L
s
1 0 .433 r
.43137 .64938 m
.43518 .64856 L
s
.43518 .64856 m
.4357 .64801 L
s
.43518 .64856 m
.43266 .64491 L
s
1 0 .907 r
.42898 .42048 m
.43181 .41884 L
s
.43181 .41884 m
.43241 .41704 L
s
.43181 .41884 m
.42857 .41612 L
s
.197 0 1 r
.28546 .53375 m
.28794 .53225 L
s
.28794 .53225 m
.2884 .53582 L
s
0 .526 1 r
.36153 .37339 m
.3622 .3718 L
s
.3622 .3718 m
.36078 .37006 L
s
.3622 .3718 m
.35928 .37245 L
s
0 .98 1 r
.28802 .43133 m
.29003 .43084 L
s
.28834 .42875 m
.28802 .43133 L
s
.28802 .43133 m
.28824 .42976 L
s
.29387 .42367 m
.28802 .43133 L
s
.113 0 1 r
.42944 .38979 m
.4299 .39328 L
s
.43238 .39033 m
.42944 .38979 L
s
.42944 .38979 m
.43003 .39173 L
s
.43795 .39989 m
.42944 .38979 L
s
0 .526 1 r
.35928 .37245 m
.36153 .37339 L
s
.36078 .37006 m
.35928 .37245 L
s
.35928 .37245 m
.36011 .37165 L
s
.3687 .36882 m
.35928 .37245 L
s
1 0 .551 r
.43696 .57481 m
.43732 .57678 L
s
.43387 .57299 m
.43696 .57481 L
s
.43786 .57213 m
.43696 .57481 L
s
0 .98 1 r
.28834 .42875 m
.28824 .42976 L
s
.197 0 1 r
.28546 .53375 m
.2884 .53582 L
s
.113 0 1 r
.43003 .39173 m
.4299 .39328 L
s
.195 0 1 r
.43098 .6072 m
.43094 .6056 L
s
.43094 .6056 m
.43389 .60509 L
s
1 0 .433 r
.43189 .64884 m
.43137 .64938 L
s
.43266 .64491 m
.43137 .64938 L
s
.195 0 1 r
.43103 .36083 m
.42861 .36226 L
s
.361 0 1 r
.43154 .634 m
.43197 .63774 L
s
.42913 .63677 m
.43154 .634 L
s
.43197 .63774 m
.42913 .63677 L
s
0 .526 1 r
.36078 .37006 m
.36011 .37165 L
s
1 0 .907 r
.42857 .41612 m
.42898 .42048 L
s
.43241 .41704 m
.42857 .41612 L
s
.42857 .41612 m
.42957 .41868 L
s
.43922 .42935 m
.42857 .41612 L
s
.824 0 1 r
.36436 .3909 m
.36529 .38868 L
s
.36529 .38868 m
.36331 .38628 L
s
.36529 .38868 m
.36123 .38959 L
s
0 .98 1 r
.28824 .42976 m
.29003 .43084 L
s
1 0 .907 r
.42957 .41868 m
.42898 .42048 L
s
.824 0 1 r
.36123 .38959 m
.36436 .3909 L
s
.36331 .38628 m
.36123 .38959 L
s
.36123 .38959 m
.36238 .3885 L
s
.37431 .38457 m
.36123 .38959 L
s
1 0 .433 r
.4357 .64801 m
.43266 .64491 L
s
.43266 .64491 m
.43189 .64884 L
s
.43705 .66387 m
.43266 .64491 L
s
1 0 .551 r
.43422 .57495 m
.43387 .57299 L
s
.43387 .57299 m
.43786 .57213 L
s
0 .526 1 r
.36011 .37165 m
.36153 .37339 L
s
0 .479 1 r
.22267 .49707 m
.22259 .49629 L
s
.22259 .49629 m
.22023 .4955 L
s
.22259 .49629 m
.2206 .4985 L
s
.113 0 1 r
.43238 .39033 m
.43003 .39173 L
s
.195 0 1 r
.4334 .60865 m
.43098 .6072 L
s
.43389 .60509 m
.4334 .60865 L
s
0 .6 1 r
.43436 .69476 m
.43633 .6935 L
s
.43633 .6935 m
.43635 .69246 L
s
.43633 .6935 m
.43398 .69184 L
s
.195 0 1 r
.43098 .6072 m
.43389 .60509 L
s
.225 0 1 r
.36641 .602 m
.36394 .60354 L
s
.36634 .6006 m
.36641 .602 L
s
.36684 .60421 m
.36641 .602 L
s
0 .479 1 r
.22023 .4955 m
.2203 .49628 L
s
.22023 .4955 m
.2206 .4985 L
s
1 0 0 r
.43378 .33015 m
.42984 .33145 L
s
0 .6 1 r
.43398 .69184 m
.43436 .69476 L
s
.43635 .69246 m
.43398 .69184 L
s
.43398 .69184 m
.43438 .69372 L
s
.44088 .7007 m
.43398 .69184 L
s
0 .479 1 r
.2206 .4985 m
.22267 .49707 L
s
.2206 .4985 m
.2203 .49628 L
s
.22486 .48743 m
.2206 .4985 L
s
0 .6 1 r
.43438 .69372 m
.43436 .69476 L
s
.824 0 1 r
.36331 .38628 m
.36238 .3885 L
s
1 0 .907 r
.43241 .41704 m
.42957 .41868 L
s
.225 0 1 r
.36394 .60354 m
.36388 .60214 L
s
.36684 .60421 m
.36394 .60354 L
s
1 0 .551 r
.43732 .57678 m
.43422 .57495 L
s
.43786 .57213 m
.43732 .57678 L
s
.824 0 1 r
.36238 .3885 m
.36436 .3909 L
s
1 0 .433 r
.4357 .64801 m
.43189 .64884 L
s
1 0 .551 r
.43422 .57495 m
.43786 .57213 L
s
1 0 .343 r
.43697 .34731 m
.44019 .34537 L
s
.44019 .34537 m
.4403 .34313 L
s
.44019 .34537 m
.43626 .34253 L
s
0 .479 1 r
.2203 .49628 m
.22267 .49707 L
s
0 .98 1 r
.29387 .57633 m
.29974 .58401 L
s
0 .6 1 r
.43635 .69246 m
.43438 .69372 L
s
.195 0 1 r
.43668 .62956 m
.44532 .61941 L
s
1 0 .433 r
.43705 .33613 m
.44146 .31713 L
s
1 0 .343 r
.43626 .34253 m
.43697 .34731 L
s
.4403 .34313 m
.43626 .34253 L
s
.43626 .34253 m
.43707 .34507 L
s
.44814 .35603 m
.43626 .34253 L
s
1 0 .433 r
.44222 .3211 m
.44275 .3216 L
s
.43841 .32027 m
.44222 .3211 L
s
.44146 .31713 m
.44222 .3211 L
s
.225 0 1 r
.36388 .60214 m
.36634 .6006 L
s
.36634 .6006 m
.36684 .60421 L
s
1 0 .343 r
.43707 .34507 m
.43697 .34731 L
s
1 0 0 r
.43781 .65366 m
.44561 .63518 L
s
.113 0 1 r
.43795 .60011 m
.4465 .58998 L
s
.225 0 1 r
.36388 .60214 m
.36684 .60421 L
s
1 0 .433 r
.43893 .32077 m
.43841 .32027 L
s
.43841 .32027 m
.44146 .31713 L
s
0 .479 1 r
.22486 .51257 m
.22913 .52367 L
s
1 0 .907 r
.43922 .57065 m
.44992 .55736 L
s
0 .98 1 r
.29951 .58243 m
.29772 .58352 L
s
.29941 .58143 m
.29951 .58243 L
s
.29974 .58401 m
.29951 .58243 L
s
0 .526 1 r
.3687 .63118 m
.37816 .63484 L
s
0 .479 1 r
.22941 .52144 m
.22705 .52223 L
s
.22949 .52067 m
.22941 .52144 L
s
.22913 .52367 m
.22941 .52144 L
s
1 0 .749 r
.37109 .38104 m
.37366 .37878 L
s
.37366 .37878 m
.37307 .37631 L
s
.37366 .37878 m
.36946 .37704 L
s
0 .98 1 r
.29772 .58352 m
.29762 .58252 L
s
.29974 .58401 m
.29772 .58352 L
s
.113 0 1 r
.4412 .37918 m
.44353 .37775 L
s
.44353 .37775 m
.44364 .37615 L
s
.44353 .37775 m
.44067 .3757 L
s
1 0 0 r
.4458 .63874 m
.44623 .64033 L
s
.44186 .63743 m
.4458 .63874 L
s
.44561 .63518 m
.4458 .63874 L
s
.23 0 1 r
.30169 .45027 m
.30182 .44883 L
s
.30182 .44883 m
.29931 .44732 L
s
.30182 .44883 m
.29885 .45094 L
s
1 0 .749 r
.36946 .37704 m
.37109 .38104 L
s
.37307 .37631 m
.36946 .37704 L
s
.36946 .37704 m
.3705 .37857 L
s
.38259 .38524 m
.36946 .37704 L
s
.195 0 1 r
.44477 .62136 m
.44483 .62298 L
s
.44236 .61992 m
.44477 .62136 L
s
.44532 .61941 m
.44477 .62136 L
s
1 0 .343 r
.4403 .34313 m
.43707 .34507 L
s
0 .6 1 r
.44088 .2993 m
.4478 .29041 L
s
0 .479 1 r
.22705 .52223 m
.22713 .52146 L
s
.22913 .52367 m
.22705 .52223 L
s
.23 0 1 r
.29885 .45094 m
.30169 .45027 L
s
.29931 .44732 m
.29885 .45094 L
s
.29885 .45094 m
.29917 .44876 L
s
.30708 .4402 m
.29885 .45094 L
s
.113 0 1 r
.44067 .3757 m
.4412 .37918 L
s
.44364 .37615 m
.44067 .3757 L
s
.44067 .3757 m
.44131 .37758 L
s
.44942 .38556 m
.44067 .3757 L
s
.44589 .59194 m
.44604 .59348 L
s
.44354 .59053 m
.44589 .59194 L
s
.4465 .58998 m
.44589 .59194 L
s
1 0 .907 r
.44889 .55997 m
.44951 .56174 L
s
.44605 .55831 m
.44889 .55997 L
s
.44992 .55736 m
.44889 .55997 L
s
1 0 .433 r
.44146 .31713 m
.44275 .3216 L
s
.43893 .32077 m
.44146 .31713 L
s
.23 0 1 r
.29931 .44732 m
.29917 .44876 L
s
1 0 0 r
.44229 .63902 m
.44186 .63743 L
s
.44186 .63743 m
.44561 .63518 L
s
.113 0 1 r
.44131 .37758 m
.4412 .37918 L
s
0 .98 1 r
.29762 .58252 m
.29941 .58143 L
s
.29941 .58143 m
.29974 .58401 L
s
.195 0 1 r
.44241 .62153 m
.44236 .61992 L
s
.44236 .61992 m
.44532 .61941 L
s
1 .005 0 r
.37096 .34892 m
.37096 .34892 L
s
.37095 .34892 m
.37096 .34892 L
s
.37096 .34892 m
.37095 .34892 L
s
.37096 .34892 m
.37096 .34892 L
s
.37094 .34893 m
.37096 .34892 L
s
.37095 .34892 m
.37096 .34892 L
s
.37095 .34892 m
.37095 .34892 L
s
.37096 .34892 m
.37096 .34892 L
s
.37096 .34892 m
.37095 .34892 L
s
.37094 .65107 m
.37092 .65105 L
s
.37093 .65106 m
.37092 .65106 L
s
.37092 .65106 m
.37093 .65105 L
s
.37092 .65106 m
.37092 .65105 L
s
.37093 .65105 m
.37093 .65106 L
s
.37093 .65105 m
.37092 .65105 L
s
.37093 .65106 m
.37093 .65106 L
s
.37092 .65105 m
.37093 .65106 L
s
.37092 .65105 m
.37093 .65106 L
s
1 0 .749 r
.3705 .37857 m
.37109 .38104 L
s
0 .98 1 r
.29762 .58252 m
.29974 .58401 L
s
0 .107 1 r
.44293 .40869 m
.44514 .40738 L
s
.44514 .40738 m
.44537 .40593 L
s
.44514 .40738 m
.44252 .40537 L
s
1 0 .433 r
.44275 .3216 m
.43893 .32077 L
s
.113 0 1 r
.44368 .59207 m
.44354 .59053 L
s
.44354 .59053 m
.4465 .58998 L
s
0 .479 1 r
.22949 .52067 m
.22913 .52367 L
s
.22713 .52146 m
.22913 .52367 L
s
.22713 .52146 m
.22949 .52067 L
s
.908 0 1 r
.44531 .67604 m
.44817 .67423 L
s
.44817 .67423 m
.44817 .6727 L
s
.44817 .67423 m
.44476 .67182 L
s
1 0 .907 r
.44667 .56008 m
.44605 .55831 L
s
.44605 .55831 m
.44992 .55736 L
s
0 .107 1 r
.44252 .40537 m
.44293 .40869 L
s
.44537 .40593 m
.44252 .40537 L
s
.44252 .40537 m
.44316 .40725 L
s
.4507 .41511 m
.44252 .40537 L
s
1 0 .812 r
.23491 .50874 m
.23478 .50761 L
s
.23478 .50761 m
.23127 .50651 L
s
.23478 .50761 m
.23189 .51092 L
s
.113 0 1 r
.44364 .37615 m
.44131 .37758 L
s
0 .107 1 r
.44316 .40725 m
.44293 .40869 L
s
0 .6 1 r
.44739 .29231 m
.44741 .29334 L
s
.44541 .29104 m
.44739 .29231 L
s
.4478 .29041 m
.44739 .29231 L
s
1 0 .749 r
.37307 .37631 m
.3705 .37857 L
s
.23 0 1 r
.29917 .44876 m
.30169 .45027 L
s
.195 0 1 r
.44483 .62298 m
.44241 .62153 L
s
.44532 .61941 m
.44483 .62298 L
s
.908 0 1 r
.44476 .67182 m
.44531 .67604 L
s
.44817 .6727 m
.44476 .67182 L
s
.44476 .67182 m
.4453 .67451 L
s
.45466 .68462 m
.44476 .67182 L
s
.195 0 1 r
.44241 .62153 m
.44532 .61941 L
s
.58 0 1 r
.44254 .43625 m
.44498 .43483 L
s
.44498 .43483 m
.44591 .43329 L
s
.44498 .43483 m
.44229 .4323 L
s
.908 0 1 r
.4453 .67451 m
.44531 .67604 L
s
.113 0 1 r
.44604 .59348 m
.44368 .59207 L
s
.4465 .58998 m
.44604 .59348 L
s
1 0 .812 r
.23127 .50651 m
.2314 .50763 L
s
.23127 .50651 m
.23189 .51092 L
s
0 .6 1 r
.44544 .29207 m
.44541 .29104 L
s
.44541 .29104 m
.4478 .29041 L
s
0 .526 1 r
.37731 .63403 m
.37589 .63577 L
s
.37665 .63244 m
.37731 .63403 L
s
.37816 .63484 m
.37731 .63403 L
s
.113 0 1 r
.44368 .59207 m
.4465 .58998 L
s
.824 0 1 r
.37431 .61543 m
.3875 .62048 L
s
1 0 0 r
.44561 .63518 m
.44623 .64033 L
s
.44229 .63902 m
.44561 .63518 L
s
1 0 .812 r
.23189 .51092 m
.23491 .50874 L
s
.23189 .51092 m
.2314 .50763 L
s
.2379 .49439 m
.23189 .51092 L
s
1 0 .907 r
.44951 .56174 m
.44667 .56008 L
s
.44992 .55736 m
.44951 .56174 L
s
0 .107 1 r
.44537 .40593 m
.44316 .40725 L
s
1 0 0 r
.44623 .64033 m
.44229 .63902 L
s
1 0 .907 r
.44667 .56008 m
.44992 .55736 L
s
0 .526 1 r
.37589 .63577 m
.37522 .63418 L
s
.37816 .63484 m
.37589 .63577 L
s
.58 0 1 r
.44229 .4323 m
.44254 .43625 L
s
.44591 .43329 m
.44229 .4323 L
s
.44229 .4323 m
.44347 .43471 L
s
.45197 .44469 m
.44229 .4323 L
s
0 .6 1 r
.44741 .29334 m
.44544 .29207 L
s
.4478 .29041 m
.44741 .29334 L
s
.58 0 1 r
.44347 .43471 m
.44254 .43625 L
s
0 .6 1 r
.44544 .29207 m
.4478 .29041 L
s
.908 0 1 r
.44817 .6727 m
.4453 .67451 L
s
0 .526 1 r
.37522 .63418 m
.37665 .63244 L
s
.37665 .63244 m
.37816 .63484 L
s
1 0 .343 r
.44814 .64397 m
.46009 .63039 L
s
0 .186 1 r
.3789 .36718 m
.38077 .36555 L
s
.38077 .36555 m
.38036 .36374 L
s
.38077 .36555 m
.37772 .36427 L
s
.58 0 1 r
.44591 .43329 m
.44347 .43471 L
s
0 .186 1 r
.37772 .36427 m
.3789 .36718 L
s
.38036 .36374 m
.37772 .36427 L
s
.37772 .36427 m
.37849 .36537 L
s
.3873 .37024 m
.37772 .36427 L
s
1 0 .812 r
.2314 .50763 m
.23491 .50874 L
s
1 0 .551 r
.44956 .36302 m
.45255 .36109 L
s
.45255 .36109 m
.4528 .3589 L
s
.45255 .36109 m
.44874 .35842 L
s
0 .652 1 r
.23786 .46549 m
.23802 .46433 L
s
.23802 .46433 m
.23601 .46312 L
s
.23802 .46433 m
.23564 .46599 L
s
.113 0 1 r
.44942 .61444 m
.4582 .60454 L
s
0 .526 1 r
.37522 .63418 m
.37816 .63484 L
s
.23 0 1 r
.30708 .5598 m
.31535 .57059 L
s
0 .652 1 r
.23564 .46599 m
.23786 .46549 L
s
.23601 .46312 m
.23564 .46599 L
s
.23564 .46599 m
.23585 .46429 L
s
.24211 .45756 m
.23564 .46599 L
s
0 .186 1 r
.37849 .36537 m
.3789 .36718 L
s
0 .652 1 r
.23601 .46312 m
.23585 .46429 L
s
0 .107 1 r
.4507 .58489 m
.4589 .5751 L
s
1 0 .551 r
.44874 .35842 m
.44956 .36302 L
s
.4528 .3589 m
.44874 .35842 L
s
.44874 .35842 m
.4498 .36082 L
s
.46095 .37114 m
.44874 .35842 L
s
.987 0 1 r
.38128 .38963 m
.3842 .38792 L
s
.3842 .38792 m
.3842 .38602 L
s
.3842 .38792 m
.38073 .38538 L
s
1 0 .551 r
.4498 .36082 m
.44956 .36302 L
s
0 .186 1 r
.38036 .36374 m
.37849 .36537 L
s
.58 0 1 r
.45197 .55531 m
.46169 .54289 L
s
0 .652 1 r
.23585 .46429 m
.23786 .46549 L
s
1 0 .812 r
.2379 .50561 m
.24393 .5222 L
s
.58 0 1 r
.46049 .54534 m
.46143 .54686 L
s
.45805 .5439 m
.46049 .54534 L
s
.46169 .54289 m
.46049 .54534 L
s
.987 0 1 r
.38073 .38538 m
.38128 .38963 L
s
.3842 .38602 m
.38073 .38538 L
s
.38073 .38538 m
.38127 .38773 L
s
.39077 .39765 m
.38073 .38538 L
s
.38127 .38773 m
.38128 .38963 L
s
.113 0 1 r
.45755 .60644 m
.45767 .60804 L
s
.45522 .60501 m
.45755 .60644 L
s
.4582 .60454 m
.45755 .60644 L
s
1 0 .343 r
.45924 .63299 m
.45938 .63521 L
s
.45601 .63103 m
.45924 .63299 L
s
.46009 .63039 m
.45924 .63299 L
s
.824 0 1 r
.3863 .61937 m
.38432 .62179 L
s
.38539 .61714 m
.3863 .61937 L
s
.3875 .62048 m
.3863 .61937 L
s
0 .107 1 r
.45825 .57701 m
.45849 .57844 L
s
.45603 .57569 m
.45825 .57701 L
s
.4589 .5751 m
.45825 .57701 L
s
.45418 .39481 m
.45634 .39344 L
s
.45634 .39344 m
.45652 .39191 L
s
.45634 .39344 m
.45363 .39151 L
s
1 0 .749 r
.38259 .61476 m
.3958 .6065 L
s
1 0 .551 r
.4528 .3589 m
.4498 .36082 L
s
.23 0 1 r
.31501 .56838 m
.3125 .5699 L
s
.3149 .56695 m
.31501 .56838 L
s
.31535 .57059 m
.31501 .56838 L
s
1 0 .812 r
.2444 .51886 m
.24089 .51998 L
s
.24455 .51777 m
.2444 .51886 L
s
.24393 .5222 m
.2444 .51886 L
s
.113 0 1 r
.45534 .6066 m
.45522 .60501 L
s
.45522 .60501 m
.4582 .60454 L
s
.908 0 1 r
.45466 .31538 m
.46462 .30251 L
s
.58 0 1 r
.459 .54542 m
.45805 .5439 L
s
.45805 .5439 m
.46169 .54289 L
s
0 .107 1 r
.45363 .39151 m
.45418 .39481 L
s
.45652 .39191 m
.45363 .39151 L
s
.45363 .39151 m
.45436 .39329 L
s
.46224 .40078 m
.45363 .39151 L
s
.45627 .57712 m
.45603 .57569 L
s
.45603 .57569 m
.4589 .5751 L
s
.45436 .39329 m
.45418 .39481 L
s
1 0 .343 r
.45615 .63325 m
.45601 .63103 L
s
.45601 .63103 m
.46009 .63039 L
s
1 0 .812 r
.24089 .51998 m
.24103 .51889 L
s
.24393 .5222 m
.24089 .51998 L
s
.23 0 1 r
.3125 .5699 m
.31238 .56848 L
s
.31535 .57059 m
.3125 .5699 L
s
.824 0 1 r
.38432 .62179 m
.38341 .61957 L
s
.3875 .62048 m
.38432 .62179 L
s
.987 0 1 r
.3842 .38602 m
.38127 .38773 L
s
1 .005 0 r
.38484 .33105 m
.38483 .33106 L
s
.38483 .33105 m
.38484 .33105 L
s
.38484 .33105 m
.38483 .33105 L
s
.38484 .33105 m
.38484 .33105 L
s
.38483 .33105 m
.38484 .33105 L
s
.38483 .33105 m
.38483 .33106 L
s
.38483 .33105 m
.38483 .33105 L
s
.38483 .33106 m
.38484 .33105 L
s
.38484 .33105 m
.38483 .33105 L
s
.38483 .66895 m
.38482 .66895 L
s
.38483 .66895 m
.38482 .66895 L
s
.38482 .66895 m
.38483 .66894 L
s
.38482 .66895 m
.38482 .66895 L
s
.38483 .66894 m
.38483 .66895 L
s
.38483 .66894 m
.38482 .66895 L
s
.38483 .66895 m
.38483 .66895 L
s
.38482 .66895 m
.38483 .66895 L
s
.38482 .66895 m
.38483 .66895 L
s
.58 0 1 r
.46143 .54686 m
.459 .54542 L
s
.46169 .54289 m
.46143 .54686 L
s
.459 .54542 m
.46169 .54289 L
s
0 .479 1 r
.45634 .42445 m
.45831 .42327 L
s
.45831 .42327 m
.45866 .422 L
s
.45831 .42327 m
.45599 .42142 L
s
.113 0 1 r
.45767 .60804 m
.45534 .6066 L
s
.4582 .60454 m
.45767 .60804 L
s
0 .652 1 r
.24211 .54244 m
.2486 .5509 L
s
.824 0 1 r
.38341 .61957 m
.38539 .61714 L
s
.38539 .61714 m
.3875 .62048 L
s
0 .107 1 r
.45849 .57844 m
.45627 .57712 L
s
.4589 .5751 m
.45849 .57844 L
s
.113 0 1 r
.45534 .6066 m
.4582 .60454 L
s
0 .107 1 r
.45652 .39191 m
.45436 .39329 L
s
0 .97 1 r
.31693 .39594 m
.31702 .39493 L
s
.31702 .39493 m
.31522 .39382 L
s
.31702 .39493 m
.31487 .39642 L
s
0 .107 1 r
.45627 .57712 m
.4589 .5751 L
s
1 0 0 r
.38637 .35452 m
.38637 .35452 L
s
.38637 .35452 m
.38637 .35452 L
s
.38637 .35452 m
.38637 .35452 L
s
.38637 .35452 m
.38637 .35452 L
s
.38637 .35452 m
.38637 .35452 L
s
.38637 .35452 m
.38637 .35452 L
s
.38636 .35452 m
.38637 .35452 L
s
.38637 .35452 m
.38637 .35452 L
s
.38637 .35452 m
.38637 .35452 L
s
.38636 .64548 m
.38634 .64549 L
s
.38635 .64549 m
.38635 .64549 L
s
.38635 .64549 m
.38635 .64549 L
s
.38635 .64549 m
.38634 .64549 L
s
.38635 .64549 m
.38635 .64549 L
s
.38634 .64549 m
.38635 .64549 L
s
.38635 .64549 m
.38635 .64549 L
s
.38635 .64549 m
.38634 .64549 L
s
.38634 .64549 m
.38635 .64549 L
s
0 .479 1 r
.45599 .42142 m
.45634 .42445 L
s
.45866 .422 m
.45599 .42142 L
s
.45599 .42142 m
.45669 .42317 L
s
.46353 .43045 m
.45599 .42142 L
s
0 .97 1 r
.31487 .39642 m
.31693 .39594 L
s
.31522 .39382 m
.31487 .39642 L
s
.31487 .39642 m
.31513 .39482 L
s
.3209 .38869 m
.31487 .39642 L
s
.23 0 1 r
.31238 .56848 m
.3149 .56695 L
s
.3149 .56695 m
.31535 .57059 L
s
0 .479 1 r
.45669 .42317 m
.45634 .42445 L
s
0 .97 1 r
.31522 .39382 m
.31513 .39482 L
s
1 0 .343 r
.45938 .63521 m
.45615 .63325 L
s
.46009 .63039 m
.45938 .63521 L
s
.23 0 1 r
.31238 .56848 m
.31535 .57059 L
s
1 0 .812 r
.24455 .51777 m
.24393 .5222 L
s
.24103 .51889 m
.24393 .5222 L
s
0 .186 1 r
.3873 .62976 m
.39694 .62375 L
s
.824 0 1 r
.38341 .61957 m
.3875 .62048 L
s
1 0 .343 r
.45615 .63325 m
.46009 .63039 L
s
1 0 .812 r
.24103 .51889 m
.24455 .51777 L
s
.887 0 1 r
.24896 .4859 m
.24918 .48417 L
s
.24918 .48417 m
.24625 .48242 L
s
.24918 .48417 m
.24571 .48661 L
s
.908 0 1 r
.46405 .30525 m
.46407 .30676 L
s
.46118 .30343 m
.46405 .30525 L
s
.46462 .30251 m
.46405 .30525 L
s
0 .479 1 r
.45866 .422 m
.45669 .42317 L
s
0 .97 1 r
.31513 .39482 m
.31693 .39594 L
s
0 .652 1 r
.24838 .54917 m
.24637 .55039 L
s
.24823 .54802 m
.24838 .54917 L
s
.2486 .5509 m
.24838 .54917 L
s
.887 0 1 r
.24571 .48661 m
.24896 .4859 L
s
.24625 .48242 m
.24571 .48661 L
s
.24571 .48661 m
.24603 .48415 L
s
.2552 .47432 m
.24571 .48661 L
s
0 .103 1 r
.45691 .45225 m
.45875 .45116 L
s
.45875 .45116 m
.46011 .44998 L
s
.45875 .45116 m
.45694 .44887 L
s
1 0 .551 r
.46095 .62886 m
.47324 .61607 L
s
.887 0 1 r
.24625 .48242 m
.24603 .48415 L
s
.908 0 1 r
.46119 .30493 m
.46118 .30343 L
s
.46118 .30343 m
.46462 .30251 L
s
0 .627 1 r
.46249 .73075 m
.46445 .72947 L
s
.46445 .72947 m
.46447 .72845 L
s
.46445 .72947 m
.46209 .72784 L
s
0 .652 1 r
.24637 .55039 m
.24622 .54923 L
s
.2486 .5509 m
.24637 .55039 L
s
1 0 0 r
.38987 .35004 m
.38987 .35004 L
s
.38987 .35003 m
.38987 .35004 L
s
.38988 .35004 m
.38987 .35004 L
s
.38988 .35004 m
.38987 .35004 L
s
.38987 .35003 m
.38988 .35004 L
s
.38987 .35004 m
.38988 .35004 L
s
.38986 .35003 m
.38988 .35004 L
s
.38987 .35004 m
.38987 .35003 L
s
.38987 .35004 m
.38987 .35004 L
s
.38986 .64997 m
.38985 .64998 L
s
.38985 .64998 m
.38985 .64998 L
s
.38985 .64998 m
.38985 .64997 L
s
.38985 .64998 m
.38985 .64998 L
s
.38985 .64998 m
.38985 .64998 L
s
.38985 .64998 m
.38985 .64998 L
s
.38985 .64997 m
.38985 .64998 L
s
.38985 .64997 m
.38985 .64998 L
s
.38985 .64998 m
.38985 .64998 L
s
1 0 .749 r
.39472 .60806 m
.39415 .61053 L
s
.39215 .60578 m
.39472 .60806 L
s
.3958 .6065 m
.39472 .60806 L
s
0 .627 1 r
.46209 .72784 m
.46249 .73075 L
s
.46447 .72845 m
.46209 .72784 L
s
.46209 .72784 m
.46251 .72974 L
s
.46907 .73669 m
.46209 .72784 L
s
0 .107 1 r
.46224 .59922 m
.47088 .58991 L
s
0 .627 1 r
.46251 .72974 m
.46249 .73075 L
s
.987 0 1 r
.39077 .60235 m
.40086 .59001 L
s
0 .103 1 r
.47135 .53083 m
.47272 .53199 L
s
.46952 .52972 m
.47135 .53083 L
s
.4727 .5286 m
.47135 .53083 L
s
1 0 .907 r
.46256 .37913 m
.46521 .37726 L
s
.46521 .37726 m
.46558 .37516 L
s
.46521 .37726 m
.46162 .37485 L
s
0 .652 1 r
.24622 .54923 m
.24823 .54802 L
s
.24823 .54802 m
.2486 .5509 L
s
0 .479 1 r
.46353 .56955 m
.47109 .5605 L
s
0 .103 1 r
.45827 .45108 m
.45691 .45225 L
s
.45694 .44887 m
.45691 .45225 L
s
.46011 .44998 m
.45694 .44887 L
s
.45694 .44887 m
.45827 .45108 L
s
.46482 .46013 m
.45694 .44887 L
s
0 .652 1 r
.24622 .54923 m
.2486 .5509 L
s
1 0 .749 r
.39158 .60825 m
.39215 .60578 L
s
.39215 .60578 m
.3958 .6065 L
s
0 .103 1 r
.46011 .44998 m
.45827 .45108 L
s
.887 0 1 r
.24603 .48415 m
.24896 .4859 L
s
.908 0 1 r
.46407 .30676 m
.46119 .30493 L
s
.46462 .30251 m
.46407 .30676 L
s
0 .186 1 r
.39614 .62487 m
.39574 .62668 L
s
.39427 .62323 m
.39614 .62487 L
s
.39694 .62375 m
.39614 .62487 L
s
0 .97 1 r
.3209 .61131 m
.32694 .61907 L
s
0 .627 1 r
.46447 .72845 m
.46251 .72974 L
s
0 .103 1 r
.46482 .53987 m
.4727 .5286 L
s
.908 0 1 r
.46119 .30493 m
.46462 .30251 L
s
.82 0 1 r
.39423 .40486 m
.39707 .40324 L
s
.39707 .40324 m
.39718 .40146 L
s
.39707 .40324 m
.39377 .40071 L
s
1 0 .907 r
.46162 .37485 m
.46256 .37913 L
s
.46558 .37516 m
.46162 .37485 L
s
.46162 .37485 m
.46292 .37703 L
s
.47386 .38636 m
.46162 .37485 L
s
1 0 .551 r
.47213 .61852 m
.47241 .6207 L
s
.46914 .61657 m
.47213 .61852 L
s
.47324 .61607 m
.47213 .61852 L
s
0 .107 1 r
.47014 .59171 m
.47033 .59323 L
s
.46798 .59032 m
.47014 .59171 L
s
.47088 .58991 m
.47014 .59171 L
s
0 .103 1 r
.47089 .53088 m
.46952 .52972 L
s
.46952 .52972 m
.4727 .5286 L
s
0 .479 1 r
.47037 .56227 m
.47074 .56354 L
s
.4684 .56109 m
.47037 .56227 L
s
.47109 .5605 m
.47037 .56227 L
s
1 0 .907 r
.46292 .37703 m
.46256 .37913 L
s
0 .369 1 r
.39519 .37743 m
.39732 .37618 L
s
.39732 .37618 m
.39731 .37477 L
s
.39732 .37618 m
.39478 .37433 L
s
1 0 .749 r
.39415 .61053 m
.39158 .60825 L
s
.3958 .6065 m
.39415 .61053 L
s
0 .186 1 r
.39387 .62504 m
.39427 .62323 L
s
.39427 .62323 m
.39694 .62375 L
s
0 .103 1 r
.4727 .5286 m
.47272 .53199 L
s
.47089 .53088 m
.4727 .5286 L
s
.47272 .53199 m
.47089 .53088 L
s
.82 0 1 r
.39377 .40071 m
.39423 .40486 L
s
.39718 .40146 m
.39377 .40071 L
s
.39377 .40071 m
.39433 .40308 L
s
.40343 .41297 m
.39377 .40071 L
s
.39433 .40308 m
.39423 .40486 L
s
0 .369 1 r
.39478 .37433 m
.39519 .37743 L
s
.39731 .37477 m
.39478 .37433 L
s
.39478 .37433 m
.39518 .37603 L
s
.40216 .38322 m
.39478 .37433 L
s
0 .107 1 r
.46816 .59184 m
.46798 .59032 L
s
.46798 .59032 m
.47088 .58991 L
s
0 .479 1 r
.46877 .56235 m
.4684 .56109 L
s
.4684 .56109 m
.47109 .5605 L
s
0 .369 1 r
.39518 .37603 m
.39519 .37743 L
s
.987 0 1 r
.4003 .5924 m
.40031 .59429 L
s
.39736 .59068 m
.4003 .5924 L
s
.40086 .59001 m
.4003 .5924 L
s
0 .97 1 r
.32667 .61746 m
.32487 .61858 L
s
.32659 .61646 m
.32667 .61746 L
s
.32694 .61907 m
.32667 .61746 L
s
0 .186 1 r
.39574 .62668 m
.39387 .62504 L
s
.39694 .62375 m
.39574 .62668 L
s
1 0 .749 r
.39158 .60825 m
.3958 .6065 L
s
1 0 .551 r
.46941 .61875 m
.46914 .61657 L
s
.46914 .61657 m
.47324 .61607 L
s
0 .479 1 r
.46752 .41084 m
.46941 .40956 L
s
.46941 .40956 m
.46965 .40817 L
s
.46941 .40956 m
.46695 .40786 L
s
1 0 .907 r
.46558 .37516 m
.46292 .37703 L
s
0 .186 1 r
.39713 .34227 m
.39964 .3414 L
s
.39964 .3414 m
.3999 .34033 L
s
.39964 .3414 m
.39748 .33896 L
s
0 .526 1 r
.39741 .66335 m
.39982 .66284 L
s
.39982 .66284 m
.40015 .66252 L
s
.39982 .66284 m
.39824 .66054 L
s
0 .97 1 r
.32487 .61858 m
.32479 .61758 L
s
.32694 .61907 m
.32487 .61858 L
s
.225 0 1 r
.32877 .41533 m
.3289 .4139 L
s
.3289 .4139 m
.32639 .41235 L
s
.3289 .4139 m
.3259 .41599 L
s
0 .186 1 r
.39387 .62504 m
.39694 .62375 L
s
0 .479 1 r
.47074 .56354 m
.46877 .56235 L
s
.47109 .5605 m
.47074 .56354 L
s
.46695 .40786 m
.46752 .41084 L
s
.46965 .40817 m
.46695 .40786 L
s
.46695 .40786 m
.46777 .40945 L
s
.47515 .41611 m
.46695 .40786 L
s
0 .186 1 r
.39738 .34119 m
.39713 .34227 L
s
.39748 .33896 m
.39713 .34227 L
s
.987 0 1 r
.39737 .59256 m
.39736 .59068 L
s
.39736 .59068 m
.40086 .59001 L
s
0 .479 1 r
.46877 .56235 m
.47109 .5605 L
s
0 .107 1 r
.47033 .59323 m
.46816 .59184 L
s
.47088 .58991 m
.47033 .59323 L
s
0 .627 1 r
.46907 .26331 m
.47609 .25443 L
s
0 .526 1 r
.39774 .66303 m
.39741 .66335 L
s
.39824 .66054 m
.39741 .66335 L
s
0 .369 1 r
.39731 .37477 m
.39518 .37603 L
s
0 .186 1 r
.3999 .34033 m
.39748 .33896 L
s
.39748 .33896 m
.39738 .34119 L
s
.40264 .35067 m
.39748 .33896 L
s
0 .479 1 r
.46777 .40945 m
.46752 .41084 L
s
.82 0 1 r
.39718 .40146 m
.39433 .40308 L
s
.225 0 1 r
.3259 .41599 m
.32877 .41533 L
s
.32639 .41235 m
.3259 .41599 L
s
.3259 .41599 m
.32626 .41377 L
s
.33432 .40521 m
.3259 .41599 L
s
0 .107 1 r
.46816 .59184 m
.47088 .58991 L
s
.225 0 1 r
.32639 .41235 m
.32626 .41377 L
s
0 .526 1 r
.40015 .66252 m
.39824 .66054 L
s
.39824 .66054 m
.39774 .66303 L
s
.40093 .67253 m
.39824 .66054 L
s
0 .97 1 r
.32479 .61758 m
.32659 .61646 L
s
.32659 .61646 m
.32694 .61907 L
s
1 0 .551 r
.47241 .6207 m
.46941 .61875 L
s
.47324 .61607 m
.47241 .6207 L
s
0 .97 1 r
.32479 .61758 m
.32694 .61907 L
s
.887 0 1 r
.2552 .52568 m
.26475 .53805 L
s
0 .479 1 r
.46965 .40817 m
.46777 .40945 L
s
0 .807 1 r
.47925 .51917 m
.4811 .51994 L
s
.47838 .51842 m
.47925 .51917 L
s
.48076 .51718 m
.47925 .51917 L
s
1 0 .551 r
.46941 .61875 m
.47324 .61607 L
s
0 1 .941 r
.47032 .44058 m
.47192 .43964 L
s
.47192 .43964 m
.47243 .43862 L
s
.47192 .43964 m
.47011 .43803 L
s
.938 0 1 r
.47336 .71197 m
.47623 .7101 L
s
.47623 .7101 m
.47627 .70858 L
s
.47623 .7101 m
.47276 .7077 L
s
0 .186 1 r
.3999 .34033 m
.39738 .34119 L
s
.987 0 1 r
.40031 .59429 m
.39737 .59256 L
s
.40086 .59001 m
.40031 .59429 L
s
0 .526 1 r
.40015 .66252 m
.39774 .66303 L
s
.987 0 1 r
.39737 .59256 m
.40086 .59001 L
s
.225 0 1 r
.32626 .41377 m
.32877 .41533 L
s
0 .627 1 r
.47565 .25635 m
.47568 .25736 L
s
.47369 .25506 m
.47565 .25635 L
s
.47609 .25443 m
.47565 .25635 L
s
0 .807 1 r
.4811 .51994 m
.48024 .51919 L
s
.48076 .51718 m
.4811 .51994 L
s
.938 0 1 r
.47276 .7077 m
.47336 .71197 L
s
.47627 .70858 m
.47276 .7077 L
s
.47276 .7077 m
.47341 .71045 L
s
.48308 .72062 m
.47276 .7077 L
s
0 .807 1 r
.47838 .51842 m
.48076 .51718 L
s
.48024 .51919 m
.48076 .51718 L
s
.47568 .52719 m
.48076 .51718 L
s
0 .526 1 r
.40093 .32747 m
.40362 .31547 L
s
0 1 .941 r
.47011 .43803 m
.47032 .44058 L
s
.47243 .43862 m
.47011 .43803 L
s
.47011 .43803 m
.47083 .43957 L
s
.47645 .44589 m
.47011 .43803 L
s
0 .526 1 r
.40412 .31798 m
.40446 .31828 L
s
.40171 .31747 m
.40412 .31798 L
s
.40362 .31547 m
.40412 .31798 L
s
0 1 .941 r
.47083 .43957 m
.47032 .44058 L
s
.938 0 1 r
.47341 .71045 m
.47336 .71197 L
s
0 .526 1 r
.40204 .31776 m
.40171 .31747 L
s
.40171 .31747 m
.40362 .31547 L
s
0 .627 1 r
.47372 .25607 m
.47369 .25506 L
s
.47369 .25506 m
.47609 .25443 L
s
1 0 .907 r
.47386 .61364 m
.48615 .60207 L
s
0 .807 1 r
.48024 .51919 m
.47838 .51842 L
s
0 .369 1 r
.40216 .61678 m
.40958 .60785 L
s
0 1 .941 r
.47243 .43862 m
.47083 .43957 L
s
0 .186 1 r
.40264 .64933 m
.40782 .63758 L
s
0 .807 1 r
.47024 .46555 m
.47111 .46481 L
s
.47111 .46481 m
.47297 .46403 L
s
.47111 .46481 m
.47059 .46278 L
s
0 .479 1 r
.47515 .58389 m
.48339 .5756 L
s
0 .807 1 r
.47568 .47281 m
.47059 .46278 L
s
.82 0 1 r
.40343 .58703 m
.41314 .57471 L
s
0 .526 1 r
.40362 .31547 m
.40446 .31828 L
s
.40204 .31776 m
.40362 .31547 L
s
0 .627 1 r
.47568 .25736 m
.47372 .25607 L
s
.47609 .25443 m
.47568 .25736 L
s
.887 0 1 r
.26441 .53554 m
.26147 .53731 L
s
.26421 .53383 m
.26441 .53554 L
s
.26475 .53805 m
.26441 .53554 L
s
0 .627 1 r
.47372 .25607 m
.47609 .25443 L
s
.938 0 1 r
.47627 .70858 m
.47341 .71045 L
s
0 .186 1 r
.40791 .63984 m
.40817 .64089 L
s
.40539 .63897 m
.40791 .63984 L
s
.40782 .63758 m
.40791 .63984 L
s
0 1 .941 r
.47645 .55411 m
.48281 .54624 L
s
0 .526 1 r
.40446 .31828 m
.40204 .31776 L
s
0 .807 1 r
.47297 .46403 m
.4721 .46477 L
s
.47297 .46403 m
.47059 .46278 L
s
0 1 .941 r
.48208 .54779 m
.48259 .5488 L
s
.48048 .54684 m
.48208 .54779 L
s
.48281 .54624 m
.48208 .54779 L
s
0 .186 1 r
.40565 .64002 m
.40539 .63897 L
s
.40539 .63897 m
.40782 .63758 L
s
1 0 .907 r
.48482 .60429 m
.48521 .60637 L
s
.48217 .6024 m
.48482 .60429 L
s
.48615 .60207 m
.48482 .60429 L
s
.887 0 1 r
.26147 .53731 m
.26127 .5356 L
s
.26475 .53805 m
.26147 .53731 L
s
0 .369 1 r
.40658 .36298 m
.4087 .36172 L
s
.4087 .36172 m
.4087 .36029 L
s
.4087 .36172 m
.40614 .35987 L
s
0 .627 1 r
.26458 .43076 m
.26472 .42961 L
s
.26472 .42961 m
.26268 .42839 L
s
.26472 .42961 m
.26231 .4313 L
s
0 .479 1 r
.48255 .57721 m
.48281 .5786 L
s
.48067 .57592 m
.48255 .57721 L
s
.48339 .5756 m
.48255 .57721 L
s
0 .369 1 r
.40916 .60957 m
.40916 .61097 L
s
.40702 .60831 m
.40916 .60957 L
s
.40958 .60785 m
.40916 .60957 L
s
0 .807 1 r
.47059 .46278 m
.47024 .46555 L
s
.47059 .46278 m
.4721 .46477 L
s
1 0 .749 r
.40722 .33265 m
.41069 .33147 L
s
.41069 .33147 m
.41103 .32998 L
s
.41069 .33147 m
.40771 .32808 L
s
0 .807 1 r
.4721 .46477 m
.47024 .46555 L
s
.58 0 1 r
.47593 .39574 m
.47811 .39397 L
s
.47811 .39397 m
.47857 .39202 L
s
.47811 .39397 m
.47486 .39193 L
s
0 .369 1 r
.40614 .35987 m
.40658 .36298 L
s
.4087 .36029 m
.40614 .35987 L
s
.40614 .35987 m
.40657 .36155 L
s
.41363 .3687 m
.40614 .35987 L
s
0 .627 1 r
.26231 .4313 m
.26458 .43076 L
s
.26268 .42839 m
.26231 .4313 L
s
.26231 .4313 m
.26254 .42953 L
s
.26889 .42264 m
.26231 .4313 L
s
.225 0 1 r
.33432 .59479 m
.34277 .60562 L
s
0 .369 1 r
.40657 .36155 m
.40658 .36298 L
s
0 1 .941 r
.48099 .54785 m
.48048 .54684 L
s
.48048 .54684 m
.48281 .54624 L
s
0 .627 1 r
.26268 .42839 m
.26254 .42953 L
s
0 .369 1 r
.40702 .60971 m
.40702 .60831 L
s
.40702 .60831 m
.40958 .60785 L
s
0 .526 1 r
.3375 .37169 m
.33819 .37008 L
s
.33819 .37008 m
.33674 .36832 L
s
.33819 .37008 m
.33523 .37074 L
s
.505 0 1 r
.40757 .42043 m
.41025 .41896 L
s
.41025 .41896 m
.41048 .41735 L
s
.41025 .41896 m
.40724 .41652 L
s
1 0 .749 r
.40755 .33117 m
.40722 .33265 L
s
.40771 .32808 m
.40722 .33265 L
s
0 .484 1 r
.40811 .39279 m
.41018 .39158 L
s
.41018 .39158 m
.41022 .39024 L
s
.41018 .39158 m
.40773 .38976 L
s
0 .526 1 r
.33523 .37074 m
.3375 .37169 L
s
.33674 .36832 m
.33523 .37074 L
s
.33523 .37074 m
.33604 .36992 L
s
.3447 .36705 m
.33523 .37074 L
s
0 .479 1 r
.48092 .57731 m
.48067 .57592 L
s
.48067 .57592 m
.48339 .5756 L
s
.82 0 1 r
.41256 .57711 m
.41268 .57888 L
s
.40971 .57548 m
.41256 .57711 L
s
.41314 .57471 m
.41256 .57711 L
s
1 0 .749 r
.41103 .32998 m
.40771 .32808 L
s
.40771 .32808 m
.40755 .33117 L
s
.41476 .34427 m
.40771 .32808 L
s
1 0 .907 r
.48256 .60448 m
.48217 .6024 L
s
.48217 .6024 m
.48615 .60207 L
s
0 .186 1 r
.40782 .63758 m
.40817 .64089 L
s
.40565 .64002 m
.40782 .63758 L
s
.58 0 1 r
.47486 .39193 m
.47593 .39574 L
s
.47857 .39202 m
.47486 .39193 L
s
.47486 .39193 m
.4764 .39379 L
s
.48685 .40169 m
.47486 .39193 L
s
0 1 .941 r
.48259 .5488 m
.48099 .54785 L
s
.48281 .54624 m
.48259 .5488 L
s
.824 0 1 r
.40905 .65331 m
.4124 .6526 L
s
.4124 .6526 m
.41288 .65214 L
s
.4124 .6526 m
.41021 .64939 L
s
0 1 .941 r
.48099 .54785 m
.48281 .54624 L
s
0 .484 1 r
.40773 .38976 m
.40811 .39279 L
s
.41022 .39024 m
.40773 .38976 L
s
.40773 .38976 m
.40815 .39145 L
s
.4149 .39854 m
.40773 .38976 L
s
0 .186 1 r
.40817 .64089 m
.40565 .64002 L
s
.887 0 1 r
.26127 .5356 m
.26421 .53383 L
s
.26421 .53383 m
.26475 .53805 L
s
.505 0 1 r
.40724 .41652 m
.40757 .42043 L
s
.41048 .41735 m
.40724 .41652 L
s
.40724 .41652 m
.4078 .41883 L
s
.41618 .4284 m
.40724 .41652 L
s
0 .484 1 r
.40815 .39145 m
.40811 .39279 L
s
.58 0 1 r
.4764 .39379 m
.47593 .39574 L
s
.505 0 1 r
.4078 .41883 m
.40757 .42043 L
s
0 .627 1 r
.26254 .42953 m
.26458 .43076 L
s
0 .369 1 r
.4087 .36029 m
.40657 .36155 L
s
0 .526 1 r
.33674 .36832 m
.33604 .36992 L
s
0 .479 1 r
.48281 .5786 m
.48092 .57731 L
s
.48339 .5756 m
.48281 .5786 L
s
.887 0 1 r
.26127 .5356 m
.26475 .53805 L
s
.824 0 1 r
.34033 .38943 m
.34129 .38718 L
s
.34129 .38718 m
.33927 .38475 L
s
.34129 .38718 m
.33718 .3881 L
s
0 .369 1 r
.40916 .61097 m
.40702 .60971 L
s
.40958 .60785 m
.40916 .61097 L
s
.824 0 1 r
.40953 .65285 m
.40905 .65331 L
s
.41021 .64939 m
.40905 .65331 L
s
.82 0 1 r
.40983 .57724 m
.40971 .57548 L
s
.40971 .57548 m
.41314 .57471 L
s
.824 0 1 r
.33718 .3881 m
.34033 .38943 L
s
.33927 .38475 m
.33718 .3881 L
s
.33718 .3881 m
.33831 .38699 L
s
.35036 .38301 m
.33718 .3881 L
s
0 .479 1 r
.48092 .57731 m
.48339 .5756 L
s
0 .369 1 r
.40702 .60971 m
.40958 .60785 L
s
0 .526 1 r
.33604 .36992 m
.3375 .37169 L
s
1 0 .907 r
.48521 .60637 m
.48256 .60448 L
s
.48615 .60207 m
.48521 .60637 L
s
.58 0 1 r
.47857 .39202 m
.4764 .39379 L
s
.824 0 1 r
.41288 .65214 m
.41021 .64939 L
s
.41021 .64939 m
.40953 .65285 L
s
.414 .66607 m
.41021 .64939 L
s
0 1 .941 r
.48134 .42746 m
.4828 .42634 L
s
.4828 .42634 m
.48309 .42513 L
s
.4828 .42634 m
.48073 .42498 L
s
0 .484 1 r
.41022 .39024 m
.40815 .39145 L
s
1 0 .907 r
.48256 .60448 m
.48615 .60207 L
s
.225 0 1 r
.34239 .60337 m
.33988 .60493 L
s
.34228 .60196 m
.34239 .60337 L
s
.34277 .60562 m
.34239 .60337 L
s
.938 0 1 r
.48308 .27938 m
.49345 .26639 L
s
1 0 .749 r
.41103 .32998 m
.40755 .33117 L
s
0 .97 1 r
.41201 .69804 m
.4138 .6969 L
s
.4138 .6969 m
.41379 .69596 L
s
.4138 .6969 m
.41166 .6954 L
s
.505 0 1 r
.41048 .41735 m
.4078 .41883 L
s
0 1 .941 r
.48073 .42498 m
.48134 .42746 L
s
.48309 .42513 m
.48073 .42498 L
s
.48073 .42498 m
.48162 .42625 L
s
.48816 .43155 m
.48073 .42498 L
s
.824 0 1 r
.33927 .38475 m
.33831 .38699 L
s
0 .97 1 r
.41166 .6954 m
.41201 .69804 L
s
.41379 .69596 m
.41166 .6954 L
s
.41166 .6954 m
.412 .6971 L
s
.41785 .7034 m
.41166 .6954 L
s
0 1 .941 r
.48162 .42625 m
.48134 .42746 L
s
.82 0 1 r
.41268 .57888 m
.40983 .57724 L
s
.41314 .57471 m
.41268 .57888 L
s
0 .97 1 r
.412 .6971 m
.41201 .69804 L
s
.225 0 1 r
.33988 .60493 m
.33977 .60352 L
s
.34277 .60562 m
.33988 .60493 L
s
.82 0 1 r
.40983 .57724 m
.41314 .57471 L
s
.824 0 1 r
.33831 .38699 m
.34033 .38943 L
s
0 1 .941 r
.48309 .42513 m
.48162 .42625 L
s
.824 0 1 r
.41288 .65214 m
.40953 .65285 L
s
0 .627 1 r
.26889 .57736 m
.27549 .58605 L
s
0 .369 1 r
.41363 .6313 m
.42114 .62244 L
s
0 .97 1 r
.41379 .69596 m
.412 .6971 L
s
.987 0 1 r
.41537 .34633 m
.41828 .34459 L
s
.41828 .34459 m
.41828 .34258 L
s
.41828 .34459 m
.41475 .34205 L
s
.824 0 1 r
.414 .33393 m
.41779 .31721 L
s
.41846 .32071 m
.41896 .32113 L
s
.41511 .31999 m
.41846 .32071 L
s
.41779 .31721 m
.41846 .32071 L
s
.225 0 1 r
.33977 .60352 m
.34228 .60196 L
s
.34228 .60196 m
.34277 .60562 L
s
.58 0 1 r
.48685 .59831 m
.4989 .58851 L
s
1 0 .749 r
.41476 .65573 m
.42185 .63947 L
s
0 1 .224 r
.48437 .45825 m
.48582 .45759 L
s
.48582 .45759 m
.4857 .4569 L
s
.48582 .45759 m
.48436 .4563 L
s
0 .484 1 r
.4149 .60146 m
.42211 .59265 L
s
.987 0 1 r
.41475 .34205 m
.41537 .34633 L
s
.41828 .34258 m
.41475 .34205 L
s
.41475 .34205 m
.41537 .34432 L
s
.42516 .35408 m
.41475 .34205 L
s
.225 0 1 r
.33977 .60352 m
.34277 .60562 L
s
.824 0 1 r
.4156 .32041 m
.41511 .31999 L
s
.41511 .31999 m
.41779 .31721 L
s
0 1 .224 r
.48436 .4563 m
.48437 .45825 L
s
.4857 .4569 m
.48436 .4563 L
s
.48436 .4563 m
.48426 .45756 L
s
.48774 .46267 m
.48436 .4563 L
s
.48426 .45756 m
.48437 .45825 L
s
.987 0 1 r
.41537 .34432 m
.41537 .34633 L
s
.938 0 1 r
.27584 .45129 m
.27603 .44959 L
s
.27603 .44959 m
.27305 .4478 L
s
.27603 .44959 m
.27251 .45208 L
s
0 1 .941 r
.48816 .56845 m
.49561 .56186 L
s
.938 0 1 r
.49277 .26919 m
.49284 .27069 L
s
.48991 .2673 m
.49277 .26919 L
s
.49345 .26639 m
.49277 .26919 L
s
.505 0 1 r
.41618 .5716 m
.42517 .55967 L
s
0 .627 1 r
.27525 .58426 m
.27322 .5855 L
s
.27512 .58312 m
.27525 .58426 L
s
.27549 .58605 m
.27525 .58426 L
s
.58 0 1 r
.49733 .5904 m
.49781 .59234 L
s
.49516 .58861 m
.49733 .5904 L
s
.4989 .58851 m
.49733 .5904 L
s
0 .526 1 r
.3447 .63295 m
.35422 .63666 L
s
.938 0 1 r
.27251 .45208 m
.27584 .45129 L
s
.27305 .4478 m
.27251 .45208 L
s
.27251 .45208 m
.27286 .4495 L
s
.28219 .43939 m
.27251 .45208 L
s
0 1 .224 r
.4857 .4569 m
.48426 .45756 L
s
1 0 .749 r
.34706 .37943 m
.34967 .37715 L
s
.34967 .37715 m
.34906 .37464 L
s
.34967 .37715 m
.34541 .37538 L
s
.42199 .6426 m
.42235 .64406 L
s
.41851 .6414 m
.42199 .6426 L
s
.42185 .63947 m
.42199 .6426 L
s
0 .369 1 r
.4207 .62414 m
.4207 .62557 L
s
.41857 .62287 m
.4207 .62414 L
s
.42114 .62244 m
.4207 .62414 L
s
.938 0 1 r
.27305 .4478 m
.27286 .4495 L
s
0 1 .941 r
.4947 .56314 m
.49499 .56435 L
s
.49324 .56201 m
.4947 .56314 L
s
.49561 .56186 m
.4947 .56314 L
s
.938 0 1 r
.48997 .2688 m
.48991 .2673 L
s
.48991 .2673 m
.49345 .26639 L
s
0 .627 1 r
.27322 .5855 m
.27308 .58436 L
s
.27549 .58605 m
.27322 .5855 L
s
0 .652 1 r
.49109 .7672 m
.49304 .76592 L
s
.49304 .76592 m
.49309 .76493 L
s
.49304 .76592 m
.49069 .76428 L
s
1 0 .749 r
.34541 .37538 m
.34706 .37943 L
s
.34906 .37464 m
.34541 .37538 L
s
.34541 .37538 m
.34644 .37693 L
s
.35868 .38369 m
.34541 .37538 L
s
.824 0 1 r
.41779 .31721 m
.41896 .32113 L
s
.4156 .32041 m
.41779 .31721 L
s
0 .97 1 r
.41785 .2966 m
.42405 .28857 L
s
0 .484 1 r
.42168 .59436 m
.42173 .59569 L
s
.4196 .59314 m
.42168 .59436 L
s
.42211 .59265 m
.42168 .59436 L
s
0 .652 1 r
.49069 .76428 m
.49109 .7672 L
s
.49309 .76493 m
.49069 .76428 L
s
.49069 .76428 m
.49114 .76622 L
s
.49771 .77324 m
.49069 .76428 L
s
.987 0 1 r
.41828 .34258 m
.41537 .34432 L
s
0 .369 1 r
.41857 .6243 m
.41857 .62287 L
s
.41857 .62287 m
.42114 .62244 L
s
0 .484 1 r
.41947 .37853 m
.42151 .37728 L
s
.42151 .37728 m
.42153 .37589 L
s
.42151 .37728 m
.41901 .37551 L
s
1 0 .749 r
.41886 .64286 m
.41851 .6414 L
s
.41851 .6414 m
.42185 .63947 L
s
0 .652 1 r
.49114 .76622 m
.49109 .7672 L
s
.824 0 1 r
.41896 .32113 m
.4156 .32041 L
s
0 1 .941 r
.49353 .56321 m
.49324 .56201 L
s
.49324 .56201 m
.49561 .56186 L
s
1 .005 0 r
.34698 .65309 m
.34698 .6531 L
s
.34698 .65309 m
.34698 .65309 L
s
.34698 .65309 m
.34697 .65309 L
s
.34698 .65309 m
.34698 .65309 L
s
.34696 .65311 m
.34698 .65309 L
s
.34697 .65309 m
.34698 .6531 L
s
.34698 .65309 m
.34697 .65309 L
s
.34698 .6531 m
.34698 .65309 L
s
.34698 .65309 m
.34698 .65309 L
s
.34696 .34689 m
.34694 .34688 L
s
.34694 .34688 m
.34694 .34688 L
s
.34694 .34688 m
.34695 .34688 L
s
.34694 .34688 m
.34694 .34688 L
s
.34695 .34688 m
.34695 .34688 L
s
.34695 .34688 m
.34694 .34688 L
s
.34695 .34688 m
.34694 .34688 L
s
.34694 .34688 m
.34694 .34688 L
s
.34694 .34688 m
.34695 .34688 L
s
0 .484 1 r
.41901 .37551 m
.41947 .37853 L
s
.42153 .37589 m
.41901 .37551 L
s
.41901 .37551 m
.41948 .37713 L
s
.42645 .38401 m
.41901 .37551 L
s
.58 0 1 r
.49564 .59056 m
.49516 .58861 L
s
.49516 .58861 m
.4989 .58851 L
s
0 .484 1 r
.41965 .59448 m
.4196 .59314 L
s
.4196 .59314 m
.42211 .59265 L
s
1 0 .749 r
.34644 .37693 m
.34706 .37943 L
s
.505 0 1 r
.42459 .56201 m
.42483 .5636 L
s
.42191 .56052 m
.42459 .56201 L
s
.42517 .55967 m
.42459 .56201 L
s
0 .627 1 r
.27308 .58436 m
.27512 .58312 L
s
.27512 .58312 m
.27549 .58605 L
s
0 .484 1 r
.41948 .37713 m
.41947 .37853 L
s
0 1 .224 r
.48774 .53733 m
.49113 .53094 L
s
0 .627 1 r
.27308 .58436 m
.27549 .58605 L
s
0 1 .941 r
.49499 .56435 m
.49353 .56321 L
s
.49561 .56186 m
.49499 .56435 L
s
.938 0 1 r
.27286 .4495 m
.27584 .45129 L
s
.49284 .27069 m
.48997 .2688 L
s
.49345 .26639 m
.49284 .27069 L
s
0 1 .941 r
.49353 .56321 m
.49561 .56186 L
s
0 .369 1 r
.4207 .62557 m
.41857 .6243 L
s
.42114 .62244 m
.4207 .62557 L
s
0 .728 1 r
.42137 .40845 m
.4233 .40734 L
s
.4233 .40734 m
.42339 .40612 L
s
.4233 .40734 m
.42104 .40562 L
s
0 .652 1 r
.49309 .76493 m
.49114 .76622 L
s
.58 0 1 r
.49781 .59234 m
.49564 .59056 L
s
.4989 .58851 m
.49781 .59234 L
s
0 .103 1 r
.48975 .41326 m
.49126 .41161 L
s
.49126 .41161 m
.4917 .40982 L
s
.49126 .41161 m
.48842 .41015 L
s
0 .97 1 r
.42371 .29028 m
.4237 .29121 L
s
.42192 .28914 m
.42371 .29028 L
s
.42405 .28857 m
.42371 .29028 L
s
0 .369 1 r
.41857 .6243 m
.42114 .62244 L
s
.938 0 1 r
.48997 .2688 m
.49345 .26639 L
s
.505 0 1 r
.42215 .56211 m
.42191 .56052 L
s
.42191 .56052 m
.42517 .55967 L
s
0 .484 1 r
.42173 .59569 m
.41965 .59448 L
s
.42211 .59265 m
.42173 .59569 L
s
1 0 .749 r
.34906 .37464 m
.34644 .37693 L
s
.021 0 1 r
.4214 .43633 m
.4238 .43508 L
s
.4238 .43508 m
.42419 .43374 L
s
.4238 .43508 m
.42123 .43281 L
s
.58 0 1 r
.49564 .59056 m
.4989 .58851 L
s
0 .728 1 r
.42104 .40562 m
.42137 .40845 L
s
.42339 .40612 m
.42104 .40562 L
s
.42104 .40562 m
.42146 .40723 L
s
.42774 .41396 m
.42104 .40562 L
s
0 .484 1 r
.42153 .37589 m
.41948 .37713 L
s
.41965 .59448 m
.42211 .59265 L
s
0 .728 1 r
.42146 .40723 m
.42137 .40845 L
s
0 .97 1 r
.42191 .29007 m
.42192 .28914 L
s
.42192 .28914 m
.42405 .28857 L
s
1 0 .749 r
.42185 .63947 m
.42235 .64406 L
s
.41886 .64286 m
.42185 .63947 L
s
.225 0 1 r
.42357 .67965 m
.42607 .67806 L
s
.42607 .67806 m
.42606 .67674 L
s
.42607 .67806 m
.42309 .67597 L
s
0 1 .224 r
.49123 .53221 m
.49112 .53289 L
s
.48978 .53154 m
.49123 .53221 L
s
.49113 .53094 m
.49123 .53221 L
s
1 0 .749 r
.42235 .64406 m
.41886 .64286 L
s
0 .526 1 r
.35339 .63584 m
.35193 .63761 L
s
.3527 .63423 m
.35339 .63584 L
s
.35422 .63666 m
.35339 .63584 L
s
0 1 .224 r
.48967 .53223 m
.48978 .53154 L
s
.48978 .53154 m
.49113 .53094 L
s
.824 0 1 r
.35036 .61699 m
.36364 .62211 L
s
0 .103 1 r
.48842 .41015 m
.48975 .41326 L
s
.4917 .40982 m
.48842 .41015 L
s
.48842 .41015 m
.49018 .41147 L
s
.49994 .41713 m
.48842 .41015 L
s
.021 0 1 r
.42123 .43281 m
.4214 .43633 L
s
.42419 .43374 m
.42123 .43281 L
s
.42123 .43281 m
.42178 .43499 L
s
.42903 .44394 m
.42123 .43281 L
s
.225 0 1 r
.42309 .67597 m
.42357 .67965 L
s
.42606 .67674 m
.42309 .67597 L
s
.42309 .67597 m
.42355 .67832 L
s
.43174 .68712 m
.42309 .67597 L
s
.021 0 1 r
.42178 .43499 m
.4214 .43633 L
s
0 .103 1 r
.49018 .41147 m
.48975 .41326 L
s
.225 0 1 r
.42355 .67832 m
.42357 .67965 L
s
0 .97 1 r
.4237 .29121 m
.42191 .29007 L
s
.42405 .28857 m
.4237 .29121 L
s
.505 0 1 r
.42483 .5636 m
.42215 .56211 L
s
.42517 .55967 m
.42483 .5636 L
s
0 .728 1 r
.42339 .40612 m
.42146 .40723 L
s
.505 0 1 r
.42215 .56211 m
.42517 .55967 L
s
0 .97 1 r
.42191 .29007 m
.42405 .28857 L
s
0 .103 1 r
.4917 .40982 m
.49018 .41147 L
s
0 .526 1 r
.35193 .63761 m
.35124 .636 L
s
.35422 .63666 m
.35193 .63761 L
s
0 1 .224 r
.49112 .53289 m
.48967 .53223 L
s
.49113 .53094 m
.49112 .53289 L
s
.48967 .53223 m
.49113 .53094 L
s
0 .526 1 r
.35124 .636 m
.3527 .63423 L
s
.3527 .63423 m
.35422 .63666 L
s
.987 0 1 r
.42516 .64592 m
.43564 .63383 L
s
.021 0 1 r
.42419 .43374 m
.42178 .43499 L
s
0 .652 1 r
.49771 .22676 m
.50476 .21777 L
s
0 .186 1 r
.355 .36539 m
.35691 .36373 L
s
.35691 .36373 m
.35646 .36189 L
s
.35691 .36373 m
.35381 .36243 L
s
.225 0 1 r
.42606 .67674 m
.42355 .67832 L
s
0 .186 1 r
.35381 .36243 m
.355 .36539 L
s
.35646 .36189 m
.35381 .36243 L
s
.35381 .36243 m
.35455 .36355 L
s
.36343 .36848 m
.35381 .36243 L
s
0 .484 1 r
.42645 .61599 m
.43392 .60745 L
s
0 1 .224 r
.49652 .44392 m
.49776 .443 L
s
.49776 .443 m
.49752 .44205 L
s
.49776 .443 m
.49603 .44208 L
s
.49603 .44208 m
.49652 .44392 L
s
.49752 .44205 m
.49603 .44208 L
s
.49603 .44208 m
.49628 .44296 L
s
.50096 .4466 m
.49603 .44208 L
s
0 .526 1 r
.35124 .636 m
.35422 .63666 L
s
.938 0 1 r
.28219 .56061 m
.29192 .57336 L
s
.82 0 1 r
.42825 .36212 m
.43101 .36039 L
s
.43101 .36039 m
.43105 .35842 L
s
.43101 .36039 m
.42754 .358 L
s
0 1 .224 r
.49628 .44296 m
.49652 .44392 L
s
0 .186 1 r
.35455 .36355 m
.355 .36539 L
s
0 .103 1 r
.49994 .58287 m
.5115 .57587 L
s
0 .728 1 r
.42774 .58604 m
.43446 .57766 L
s
.887 0 1 r
.50219 .7484 m
.50504 .74653 L
s
.50504 .74653 m
.50513 .74506 L
s
.50504 .74653 m
.5016 .74413 L
s
.987 0 1 r
.35754 .38815 m
.36054 .38641 L
s
.36054 .38641 m
.36042 .38448 L
s
.36054 .38641 m
.357 .38384 L
s
.82 0 1 r
.42754 .358 m
.42825 .36212 L
s
.43105 .35842 m
.42754 .358 L
s
.42754 .358 m
.42828 .36015 L
s
.43807 .36939 m
.42754 .358 L
s
0 1 .224 r
.49752 .44205 m
.49628 .44296 L
s
0 .103 1 r
.50971 .57721 m
.51016 .579 L
s
.5082 .57555 m
.50971 .57721 L
s
.5115 .57587 m
.50971 .57721 L
s
0 .652 1 r
.50429 .21974 m
.50436 .22071 L
s
.50234 .21844 m
.50429 .21974 L
s
.50476 .21777 m
.50429 .21974 L
s
0 .186 1 r
.35646 .36189 m
.35455 .36355 L
s
.82 0 1 r
.42828 .36015 m
.42825 .36212 L
s
.021 0 1 r
.42903 .55606 m
.43685 .5449 L
s
.887 0 1 r
.5016 .74413 m
.50219 .7484 L
s
.50513 .74506 m
.5016 .74413 L
s
.5016 .74413 m
.50228 .74694 L
s
.51193 .75718 m
.5016 .74413 L
s
.987 0 1 r
.357 .38384 m
.35754 .38815 L
s
.36042 .38448 m
.357 .38384 L
s
.357 .38384 m
.35742 .38622 L
s
.36692 .39626 m
.357 .38384 L
s
.887 0 1 r
.50228 .74694 m
.50219 .7484 L
s
.987 0 1 r
.35742 .38622 m
.35754 .38815 L
s
0 .652 1 r
.5024 .21941 m
.50234 .21844 L
s
.50234 .21844 m
.50476 .21777 L
s
0 .484 1 r
.43343 .6091 m
.43346 .61048 L
s
.43139 .60784 m
.43343 .6091 L
s
.43392 .60745 m
.43343 .6091 L
s
.987 0 1 r
.43499 .63613 m
.43501 .63812 L
s
.43207 .63438 m
.43499 .63613 L
s
.43564 .63383 m
.43499 .63613 L
s
.824 0 1 r
.36245 .62099 m
.36044 .62344 L
s
.36151 .61873 m
.36245 .62099 L
s
.36364 .62211 m
.36245 .62099 L
s
0 .728 1 r
.43403 .57929 m
.43413 .58051 L
s
.43209 .57817 m
.43403 .57929 L
s
.43446 .57766 m
.43403 .57929 L
s
0 .103 1 r
.50865 .57733 m
.5082 .57555 L
s
.5082 .57555 m
.5115 .57587 L
s
0 .484 1 r
.43141 .60923 m
.43139 .60784 L
s
.43139 .60784 m
.43392 .60745 L
s
1 0 .749 r
.35868 .61631 m
.37205 .60794 L
s
.021 0 1 r
.43629 .5471 m
.43668 .54843 L
s
.43388 .54584 m
.43629 .5471 L
s
.43685 .5449 m
.43629 .5471 L
s
.82 0 1 r
.43105 .35842 m
.42828 .36015 L
s
0 .103 1 r
.51016 .579 m
.50865 .57733 L
s
.5115 .57587 m
.51016 .579 L
s
.225 0 1 r
.43174 .31288 m
.44043 .30168 L
s
0 .728 1 r
.43219 .57938 m
.43209 .57817 L
s
.43209 .57817 m
.43446 .57766 L
s
0 .652 1 r
.50436 .22071 m
.5024 .21941 L
s
.50476 .21777 m
.50436 .22071 L
s
.987 0 1 r
.43209 .63637 m
.43207 .63438 L
s
.43207 .63438 m
.43564 .63383 L
s
0 .728 1 r
.4327 .3944 m
.43457 .39322 L
s
.43457 .39322 m
.43462 .39191 L
s
.43457 .39322 m
.43223 .39159 L
s
.938 0 1 r
.29155 .57075 m
.28856 .57255 L
s
.29138 .56906 m
.29155 .57075 L
s
.29192 .57336 m
.29155 .57075 L
s
0 .652 1 r
.5024 .21941 m
.50476 .21777 L
s
0 .103 1 r
.50865 .57733 m
.5115 .57587 L
s
.887 0 1 r
.50513 .74506 m
.50228 .74694 L
s
0 .728 1 r
.43223 .39159 m
.4327 .3944 L
s
.43462 .39191 m
.43223 .39159 L
s
.43223 .39159 m
.43274 .39309 L
s
.43937 .39944 m
.43223 .39159 L
s
.987 0 1 r
.36042 .38448 m
.35742 .38622 L
s
0 1 .224 r
.50096 .5534 m
.50591 .54887 L
s
.021 0 1 r
.43427 .54717 m
.43388 .54584 L
s
.43388 .54584 m
.43685 .5449 L
s
.824 0 1 r
.36044 .62344 m
.35949 .62119 L
s
.36364 .62211 m
.36044 .62344 L
s
0 .807 1 r
.50173 .42902 m
.5025 .4275 L
s
.5025 .4275 m
.50266 .42589 L
s
.5025 .4275 m
.50004 .4268 L
s
0 .484 1 r
.43346 .61048 m
.43141 .60923 L
s
.43392 .60745 m
.43346 .61048 L
s
0 .728 1 r
.43274 .39309 m
.4327 .3944 L
s
1 .005 0 r
.36097 .67123 m
.36097 .67124 L
s
.36097 .67123 m
.36097 .67123 L
s
.36098 .67123 m
.36097 .67123 L
s
.36098 .67123 m
.36097 .67124 L
s
.36097 .67123 m
.36098 .67123 L
s
.36097 .67123 m
.36098 .67123 L
s
.36094 .67124 m
.36098 .67123 L
s
.36097 .67124 m
.36097 .67123 L
s
.36097 .67123 m
.36097 .67123 L
s
.36094 .32876 m
.36091 .32876 L
s
.36092 .32877 m
.36092 .32876 L
s
.36092 .32876 m
.36092 .32876 L
s
.36092 .32876 m
.36091 .32876 L
s
.36092 .32876 m
.36092 .32876 L
s
.36092 .32876 m
.36091 .32876 L
s
.36092 .32876 m
.36092 .32877 L
s
.36091 .32876 m
.36092 .32877 L
s
.36091 .32876 m
.36092 .32876 L
s
0 .484 1 r
.43141 .60923 m
.43392 .60745 L
s
0 .728 1 r
.43413 .58051 m
.43219 .57938 L
s
.43446 .57766 m
.43413 .58051 L
s
.938 0 1 r
.28856 .57255 m
.28839 .57087 L
s
.29192 .57336 m
.28856 .57255 L
s
0 .6 1 r
.29159 .39541 m
.29171 .39427 L
s
.29171 .39427 m
.28966 .393 L
s
.29171 .39427 m
.28926 .39596 L
s
0 .728 1 r
.43219 .57938 m
.43446 .57766 L
s
.824 0 1 r
.35949 .62119 m
.36151 .61873 L
s
.36151 .61873 m
.36364 .62211 L
s
0 .6 1 r
.28926 .39596 m
.29159 .39541 L
s
.28966 .393 m
.28926 .39596 L
s
.28926 .39596 m
.28954 .39414 L
s
.29609 .38718 m
.28926 .39596 L
s
0 1 .881 r
.43504 .42445 m
.43675 .42348 L
s
.43675 .42348 m
.4369 .42244 L
s
.43675 .42348 m
.43479 .42193 L
s
0 .807 1 r
.50004 .4268 m
.50173 .42902 L
s
.50266 .42589 m
.50004 .4268 L
s
.50004 .4268 m
.50188 .4274 L
s
.5108 .43006 m
.50004 .4268 L
s
.987 0 1 r
.43501 .63812 m
.43209 .63637 L
s
.43564 .63383 m
.43501 .63812 L
s
0 .6 1 r
.28966 .393 m
.28954 .39414 L
s
0 .728 1 r
.43462 .39191 m
.43274 .39309 L
s
1 0 0 r
.36249 .64746 m
.36248 .64746 L
s
.36248 .64746 m
.36249 .64746 L
s
.36249 .64746 m
.36248 .64746 L
s
.36249 .64746 m
.36249 .64746 L
s
.36248 .64745 m
.36249 .64746 L
s
.36248 .64746 m
.36248 .64746 L
s
.36249 .64746 m
.36248 .64746 L
s
.36248 .64746 m
.36248 .64746 L
s
.36248 .64746 m
.36249 .64746 L
s
.021 0 1 r
.43668 .54843 m
.43427 .54717 L
s
.43685 .5449 m
.43668 .54843 L
s
1 0 0 r
.36248 .35255 m
.36248 .35255 L
s
.36248 .35255 m
.36248 .35255 L
s
.36248 .35255 m
.36248 .35255 L
s
.36248 .35255 m
.36248 .35255 L
s
.36248 .35255 m
.36248 .35255 L
s
.36248 .35255 m
.36248 .35255 L
s
.36248 .35255 m
.36248 .35255 L
s
.36248 .35255 m
.36248 .35255 L
s
.36248 .35255 m
.36248 .35255 L
s
.021 0 1 r
.43427 .54717 m
.43685 .5449 L
s
0 .807 1 r
.50188 .4274 m
.50173 .42902 L
s
.987 0 1 r
.43209 .63637 m
.43564 .63383 L
s
0 1 .881 r
.43479 .42193 m
.43504 .42445 L
s
.4369 .42244 m
.43479 .42193 L
s
.43479 .42193 m
.43518 .42341 L
s
.44066 .4295 m
.43479 .42193 L
s
0 .807 1 r
.50266 .42589 m
.50188 .4274 L
s
0 1 .881 r
.43518 .42341 m
.43504 .42445 L
s
0 .186 1 r
.36343 .63152 m
.37311 .62543 L
s
.225 0 1 r
.43994 .30407 m
.43994 .30539 L
s
.43743 .30247 m
.43994 .30407 L
s
.44043 .30168 m
.43994 .30407 L
s
.824 0 1 r
.35949 .62119 m
.36364 .62211 L
s
0 1 .224 r
.50566 .54976 m
.50543 .55072 L
s
.50442 .54884 m
.50566 .54976 L
s
.50591 .54887 m
.50566 .54976 L
s
.938 0 1 r
.28839 .57087 m
.29138 .56906 L
s
.29138 .56906 m
.29192 .57336 L
s
0 .648 1 r
.43596 .45238 m
.43798 .45149 L
s
.43798 .45149 m
.43863 .45054 L
s
.43798 .45149 m
.43613 .44943 L
s
0 .6 1 r
.28954 .39414 m
.29159 .39541 L
s
0 1 .224 r
.50418 .5498 m
.50442 .54884 L
s
.50442 .54884 m
.50591 .54887 L
s
.938 0 1 r
.28839 .57087 m
.29192 .57336 L
s
0 1 .881 r
.4369 .42244 m
.43518 .42341 L
s
.225 0 1 r
.43743 .30379 m
.43743 .30247 L
s
.43743 .30247 m
.44043 .30168 L
s
0 .807 1 r
.5108 .56994 m
.52157 .56667 L
s
.51971 .56728 m
.51988 .5689 L
s
.51895 .56576 m
.51971 .56728 L
s
.52157 .56667 m
.51971 .56728 L
s
.82 0 1 r
.43807 .63061 m
.44865 .61915 L
s
0 .648 1 r
.43661 .45143 m
.43596 .45238 L
s
.43613 .44943 m
.43596 .45238 L
s
0 1 .224 r
.50543 .55072 m
.50418 .5498 L
s
.50591 .54887 m
.50543 .55072 L
s
0 .648 1 r
.43863 .45054 m
.43613 .44943 L
s
.43613 .44943 m
.43661 .45143 L
s
.44196 .45959 m
.43613 .44943 L
s
1 0 0 r
.36601 .65201 m
.36601 .65201 L
s
.36601 .65201 m
.36601 .65201 L
s
.36601 .65201 m
.36601 .65201 L
s
.36602 .65201 m
.36601 .65201 L
s
.36601 .652 m
.36601 .65201 L
s
.36601 .65201 m
.36601 .65201 L
s
.36602 .65201 m
.36601 .65201 L
s
.36601 .65201 m
.36601 .65201 L
s
.36601 .65201 m
.36602 .65201 L
s
.36601 .348 m
.36601 .348 L
s
.36601 .348 m
.36601 .348 L
s
.36601 .348 m
.36601 .348 L
s
.36601 .348 m
.36601 .348 L
s
.36601 .348 m
.36601 .348 L
s
.36601 .348 m
.36601 .348 L
s
.36601 .348 m
.36601 .348 L
s
.36601 .348 m
.36601 .348 L
s
.36601 .348 m
.36601 .348 L
s
1 0 .749 r
.37097 .60952 m
.37038 .61203 L
s
.36836 .60721 m
.37097 .60952 L
s
.37205 .60794 m
.37097 .60952 L
s
0 1 .224 r
.50418 .5498 m
.50591 .54887 L
s
.887 0 1 r
.51193 .24282 m
.52232 .2297 L
s
0 .98 1 r
.44031 .73452 m
.44209 .73335 L
s
.44209 .73335 m
.44209 .73243 L
s
.44209 .73335 m
.43994 .73187 L
s
0 .728 1 r
.43937 .60056 m
.44653 .59269 L
s
.987 0 1 r
.36692 .60374 m
.3769 .59124 L
s
0 .98 1 r
.43994 .73187 m
.44031 .73452 L
s
.44209 .73243 m
.43994 .73187 L
s
.43994 .73187 m
.44031 .73359 L
s
.44625 .7399 m
.43994 .73187 L
s
0 .648 1 r
.43863 .45054 m
.43661 .45143 L
s
.225 0 1 r
.43994 .30539 m
.43743 .30379 L
s
.44043 .30168 m
.43994 .30539 L
s
0 .807 1 r
.51912 .56737 m
.51895 .56576 L
s
.51895 .56576 m
.52157 .56667 L
s
0 .98 1 r
.44031 .73359 m
.44031 .73452 L
s
0 .807 1 r
.51988 .5689 m
.51912 .56737 L
s
.52157 .56667 m
.51988 .5689 L
s
0 .479 1 r
.51469 .79433 m
.51636 .7926 L
s
.51636 .7926 m
.51604 .79121 L
s
.51636 .7926 m
.51348 .7915 L
s
.225 0 1 r
.43743 .30379 m
.44043 .30168 L
s
0 1 .881 r
.44066 .5705 m
.44655 .56291 L
s
0 .479 1 r
.51348 .7915 m
.51469 .79433 L
s
.51604 .79121 m
.51348 .7915 L
s
.51348 .7915 m
.51437 .79295 L
s
.52294 .7979 m
.51348 .7915 L
s
.505 0 1 r
.4415 .37831 m
.44401 .37663 L
s
.44401 .37663 m
.44408 .37475 L
s
.44401 .37663 m
.44073 .37446 L
s
0 .807 1 r
.51912 .56737 m
.52157 .56667 L
s
1 0 .749 r
.36777 .60972 m
.36836 .60721 L
s
.36836 .60721 m
.37205 .60794 L
s
.82 0 1 r
.37085 .40359 m
.3738 .40194 L
s
.3738 .40194 m
.37368 .40014 L
s
.3738 .40194 m
.37041 .39939 L
s
0 .6 1 r
.29609 .61282 m
.30294 .62164 L
s
1 0 .812 r
.51669 .77623 m
.5191 .77365 L
s
.5191 .77365 m
.51859 .77155 L
s
.5191 .77365 m
.51483 .7721 L
s
0 .186 1 r
.37234 .62657 m
.37191 .62841 L
s
.37043 .6249 m
.37234 .62657 L
s
.37311 .62543 m
.37234 .62657 L
s
.505 0 1 r
.44073 .37446 m
.4415 .37831 L
s
.44408 .37475 m
.44073 .37446 L
s
.44073 .37446 m
.44157 .37643 L
s
.45107 .38482 m
.44073 .37446 L
s
0 .648 1 r
.44196 .54041 m
.4478 .53023 L
s
0 .479 1 r
.51437 .79295 m
.51469 .79433 L
s
1 0 .812 r
.51483 .7721 m
.51669 .77623 L
s
.51859 .77155 m
.51483 .7721 L
s
.51483 .7721 m
.51617 .77414 L
s
.52893 .78109 m
.51483 .7721 L
s
0 .98 1 r
.44209 .73243 m
.44031 .73359 L
s
0 .648 1 r
.44731 .53225 m
.44797 .53319 L
s
.44529 .53135 m
.44731 .53225 L
s
.4478 .53023 m
.44731 .53225 L
s
.82 0 1 r
.37041 .39939 m
.37085 .40359 L
s
.37368 .40014 m
.37041 .39939 L
s
.37041 .39939 m
.37072 .40179 L
s
.37967 .41179 m
.37041 .39939 L
s
0 .728 1 r
.44601 .59421 m
.44606 .59551 L
s
.44413 .59302 m
.44601 .59421 L
s
.44653 .59269 m
.44601 .59421 L
s
.505 0 1 r
.44157 .37643 m
.4415 .37831 L
s
.82 0 1 r
.44788 .62134 m
.44795 .6233 L
s
.44512 .6196 m
.44788 .62134 L
s
.44865 .61915 m
.44788 .62134 L
s
0 .369 1 r
.37146 .37578 m
.37364 .3745 L
s
.37364 .3745 m
.37357 .37308 L
s
.37364 .3745 m
.37105 .37263 L
s
.82 0 1 r
.37072 .40179 m
.37085 .40359 L
s
0 1 .881 r
.44615 .5644 m
.44631 .56543 L
s
.44444 .56343 m
.44615 .5644 L
s
.44655 .56291 m
.44615 .5644 L
s
1 0 .749 r
.37038 .61203 m
.36777 .60972 L
s
.37205 .60794 m
.37038 .61203 L
s
0 .186 1 r
.37 .62674 m
.37043 .6249 L
s
.37043 .6249 m
.37311 .62543 L
s
0 .479 1 r
.51604 .79121 m
.51437 .79295 L
s
0 .369 1 r
.37105 .37263 m
.37146 .37578 L
s
.37357 .37308 m
.37105 .37263 L
s
.37105 .37263 m
.37139 .37435 L
s
.37839 .38163 m
.37105 .37263 L
s
0 .728 1 r
.44418 .59432 m
.44413 .59302 L
s
.44413 .59302 m
.44653 .59269 L
s
1 0 .812 r
.51617 .77414 m
.51669 .77623 L
s
0 .648 1 r
.44595 .53229 m
.44529 .53135 L
s
.44529 .53135 m
.4478 .53023 L
s
0 1 .881 r
.44459 .56446 m
.44444 .56343 L
s
.44444 .56343 m
.44655 .56291 L
s
0 .369 1 r
.37139 .37435 m
.37146 .37578 L
s
.908 0 1 r
.30313 .41581 m
.30333 .41412 L
s
.30333 .41412 m
.30036 .41229 L
s
.30333 .41412 m
.29979 .41658 L
s
.887 0 1 r
.52161 .23255 m
.52172 .234 L
s
.51876 .23066 m
.52161 .23255 L
s
.52232 .2297 m
.52161 .23255 L
s
.82 0 1 r
.44518 .62155 m
.44512 .6196 L
s
.44512 .6196 m
.44865 .61915 L
s
0 .186 1 r
.37191 .62841 m
.37 .62674 L
s
.37311 .62543 m
.37191 .62841 L
s
1 0 .749 r
.36777 .60972 m
.37205 .60794 L
s
.987 0 1 r
.37645 .59367 m
.37636 .59558 L
s
.37345 .59192 m
.37645 .59367 L
s
.3769 .59124 m
.37645 .59367 L
s
.505 0 1 r
.44408 .37475 m
.44157 .37643 L
s
0 .6 1 r
.30265 .61981 m
.3006 .62108 L
s
.30254 .61867 m
.30265 .61981 L
s
.30294 .62164 m
.30265 .61981 L
s
.908 0 1 r
.29979 .41658 m
.30313 .41581 L
s
.30036 .41229 m
.29979 .41658 L
s
.29979 .41658 m
.30016 .41398 L
s
.3096 .40392 m
.29979 .41658 L
s
0 .186 1 r
.37336 .34012 m
.37591 .33925 L
s
.37591 .33925 m
.37613 .33816 L
s
.37591 .33925 m
.37371 .33677 L
s
0 .648 1 r
.4478 .53023 m
.44797 .53319 L
s
.44595 .53229 m
.4478 .53023 L
s
0 .728 1 r
.44606 .59551 m
.44418 .59432 L
s
.44653 .59269 m
.44606 .59551 L
s
0 .648 1 r
.44797 .53319 m
.44595 .53229 L
s
0 1 .881 r
.44631 .56543 m
.44459 .56446 L
s
.44655 .56291 m
.44631 .56543 L
s
0 .526 1 r
.3736 .66557 m
.37604 .66505 L
s
.37604 .66505 m
.37636 .66473 L
s
.37604 .66505 m
.37444 .66272 L
s
.908 0 1 r
.30036 .41229 m
.30016 .41398 L
s
1 0 .812 r
.51859 .77155 m
.51617 .77414 L
s
0 1 .881 r
.4463 .41066 m
.44793 .40959 L
s
.44793 .40959 m
.44798 .40842 L
s
.44793 .40959 m
.44584 .40819 L
s
.44459 .56446 m
.44655 .56291 L
s
.887 0 1 r
.51887 .2321 m
.51876 .23066 L
s
.51876 .23066 m
.52232 .2297 L
s
0 .186 1 r
.37 .62674 m
.37311 .62543 L
s
0 .728 1 r
.44418 .59432 m
.44653 .59269 L
s
.82 0 1 r
.37368 .40014 m
.37072 .40179 L
s
0 .186 1 r
.37357 .33904 m
.37336 .34012 L
s
.37371 .33677 m
.37336 .34012 L
s
0 .6 1 r
.3006 .62108 m
.30049 .61995 L
s
.30294 .62164 m
.3006 .62108 L
s
0 .98 1 r
.44625 .2601 m
.45258 .25203 L
s
0 .369 1 r
.37357 .37308 m
.37139 .37435 L
s
0 .526 1 r
.37392 .66525 m
.3736 .66557 L
s
.37444 .66272 m
.3736 .66557 L
s
.987 0 1 r
.37335 .59383 m
.37345 .59192 L
s
.37345 .59192 m
.3769 .59124 L
s
0 .186 1 r
.37613 .33816 m
.37371 .33677 L
s
.37371 .33677 m
.37357 .33904 L
s
.37888 .34864 m
.37371 .33677 L
s
0 1 .881 r
.44584 .40819 m
.4463 .41066 L
s
.44798 .40842 m
.44584 .40819 L
s
.44584 .40819 m
.44636 .4095 L
s
.45237 .41497 m
.44584 .40819 L
s
.44636 .4095 m
.4463 .41066 L
s
0 .526 1 r
.37636 .66473 m
.37444 .66272 L
s
.37444 .66272 m
.37392 .66525 L
s
.37715 .67487 m
.37444 .66272 L
s
.82 0 1 r
.44795 .6233 m
.44518 .62155 L
s
.44865 .61915 m
.44795 .6233 L
s
.44518 .62155 m
.44865 .61915 L
s
0 .6 1 r
.30049 .61995 m
.30254 .61867 L
s
.30254 .61867 m
.30294 .62164 L
s
0 1 .881 r
.44798 .40842 m
.44636 .4095 L
s
0 .6 1 r
.30049 .61995 m
.30294 .62164 L
s
.908 0 1 r
.30016 .41398 m
.30313 .41581 L
s
.887 0 1 r
.52172 .234 m
.51887 .2321 L
s
.52232 .2297 m
.52172 .234 L
s
0 .186 1 r
.37613 .33816 m
.37357 .33904 L
s
0 .526 1 r
.37636 .66473 m
.37392 .66525 L
s
0 1 .286 r
.44922 .4408 m
.45058 .44008 L
s
.45058 .44008 m
.45085 .43931 L
s
.45058 .44008 m
.44912 .43878 L
s
0 .98 1 r
.4522 .25378 m
.45221 .25469 L
s
.45042 .25261 m
.4522 .25378 L
s
.45258 .25203 m
.4522 .25378 L
s
.887 0 1 r
.51887 .2321 m
.52232 .2297 L
s
.987 0 1 r
.37636 .59558 m
.37335 .59383 L
s
.3769 .59124 m
.37636 .59558 L
s
1 .65 0 r
.52282 .81621 m
.5232 .81596 L
s
.5232 .81596 m
.52322 .81577 L
s
.5232 .81596 m
.52274 .81564 L
s
.52274 .81564 m
.52282 .81621 L
s
.52322 .81577 m
.52274 .81564 L
s
.52274 .81564 m
.52284 .81603 L
s
.52413 .81742 m
.52274 .81564 L
s
.52284 .81603 m
.52282 .81621 L
s
0 .526 1 r
.37715 .32513 m
.37987 .31296 L
s
0 .479 1 r
.52294 .2021 m
.53244 .19567 L
s
0 .526 1 r
.38039 .3155 m
.38072 .3158 L
s
.37794 .31498 m
.38039 .3155 L
s
.37987 .31296 m
.38039 .3155 L
s
.987 0 1 r
.37335 .59383 m
.3769 .59124 L
s
0 1 .286 r
.44912 .43878 m
.44922 .4408 L
s
.45085 .43931 m
.44912 .43878 L
s
.44912 .43878 m
.44949 .44003 L
s
.45368 .44515 m
.44912 .43878 L
s
1 .65 0 r
.52322 .81577 m
.52284 .81603 L
s
0 1 .286 r
.44949 .44003 m
.44922 .4408 L
s
0 .98 1 r
.45042 .25352 m
.45042 .25261 L
s
.45042 .25261 m
.45258 .25203 L
s
.23 0 1 r
.45196 .71612 m
.45446 .71449 L
s
.45446 .71449 m
.45447 .71317 L
s
.45446 .71449 m
.45143 .71241 L
s
0 .526 1 r
.37827 .31528 m
.37794 .31498 L
s
.37794 .31498 m
.37987 .31296 L
s
1 0 .812 r
.52814 .78982 m
.52864 .78707 L
s
.52864 .78707 m
.52624 .78484 L
s
.52864 .78707 m
.52436 .7887 L
s
0 1 .47 r
.45015 .46698 m
.45161 .46659 L
s
.45161 .46659 m
.45251 .46616 L
s
.45161 .46659 m
.45078 .46488 L
s
.505 0 1 r
.45107 .61518 m
.46146 .60478 L
s
1 .65 0 r
.52413 .18258 m
.52553 .1808 L
s
0 .369 1 r
.37839 .61837 m
.38577 .60933 L
s
.23 0 1 r
.45143 .71241 m
.45196 .71612 L
s
.45447 .71317 m
.45143 .71241 L
s
.45143 .71241 m
.45197 .7148 L
s
.46035 .72363 m
.45143 .71241 L
s
1 0 .812 r
.52436 .7887 m
.52814 .78982 L
s
.52624 .78484 m
.52436 .7887 L
s
.52436 .7887 m
.52574 .78759 L
s
.53856 .78182 m
.52436 .7887 L
s
0 1 .286 r
.45085 .43931 m
.44949 .44003 L
s
0 .186 1 r
.37888 .65136 m
.38407 .63945 L
s
1 .65 0 r
.52543 .18119 m
.52545 .18138 L
s
.52505 .18094 m
.52543 .18119 L
s
.52553 .1808 m
.52543 .18119 L
s
.23 0 1 r
.45197 .7148 m
.45196 .71612 L
s
1 .65 0 r
.52506 .18112 m
.52505 .18094 L
s
.52505 .18094 m
.52553 .1808 L
s
0 .98 1 r
.45221 .25469 m
.45042 .25352 L
s
.45258 .25203 m
.45221 .25469 L
s
0 1 .47 r
.45603 .51993 m
.45693 .52035 L
s
.45458 .51954 m
.45603 .51993 L
s
.45631 .51826 m
.45603 .51993 L
s
0 1 .881 r
.45237 .58503 m
.45893 .57822 L
s
1 .65 0 r
.52545 .18138 m
.52506 .18112 L
s
.52553 .1808 m
.52545 .18138 L
s
0 1 .47 r
.45106 .46655 m
.45015 .46698 L
s
.45078 .46488 m
.45015 .46698 L
s
1 .65 0 r
.52506 .18112 m
.52553 .1808 L
s
0 .98 1 r
.45042 .25352 m
.45258 .25203 L
s
.82 0 1 r
.37967 .58821 m
.38899 .57575 L
s
0 1 .47 r
.45251 .46616 m
.45078 .46488 L
s
.45078 .46488 m
.45106 .46655 L
s
.45354 .47331 m
.45078 .46488 L
s
0 .526 1 r
.37987 .31296 m
.38072 .3158 L
s
.37827 .31528 m
.37987 .31296 L
s
0 1 .47 r
.45251 .46616 m
.45106 .46655 L
s
1 0 .812 r
.52624 .78484 m
.52574 .78759 L
s
0 1 .47 r
.45354 .52669 m
.45631 .51826 L
s
0 .186 1 r
.3842 .64174 m
.38442 .64282 L
s
.38164 .64086 m
.3842 .64174 L
s
.38407 .63945 m
.3842 .64174 L
s
0 .526 1 r
.38072 .3158 m
.37827 .31528 L
s
0 1 .286 r
.45368 .55485 m
.45824 .54847 L
s
0 1 .47 r
.45548 .51995 m
.45458 .51954 L
s
.45458 .51954 m
.45631 .51826 L
s
.45631 .51826 m
.45693 .52035 L
s
.45548 .51995 m
.45631 .51826 L
s
.23 0 1 r
.45447 .71317 m
.45197 .7148 L
s
0 1 .47 r
.45693 .52035 m
.45548 .51995 L
s
0 .369 1 r
.38293 .36112 m
.3851 .35984 L
s
.3851 .35984 m
.38504 .35839 L
s
.3851 .35984 m
.3825 .35797 L
s
0 .186 1 r
.38185 .64193 m
.38164 .64086 L
s
.38164 .64086 m
.38407 .63945 L
s
0 1 .286 r
.45788 .54973 m
.45814 .55049 L
s
.45652 .549 m
.45788 .54973 L
s
.45824 .54847 m
.45788 .54973 L
s
.021 0 1 r
.45516 .39499 m
.45731 .39342 L
s
.45731 .39342 m
.45739 .39169 L
s
.45731 .39342 m
.45431 .39159 L
s
0 .067 1 r
.31185 .37058 m
.31267 .36873 L
s
.31267 .36873 m
.31098 .36671 L
s
.31267 .36873 m
.30926 .36949 L
s
1 0 .749 r
.38342 .33036 m
.38694 .32917 L
s
.38694 .32917 m
.38729 .32766 L
s
.38694 .32917 m
.38392 .32573 L
s
0 .369 1 r
.38541 .61107 m
.38536 .61249 L
s
.38323 .60979 m
.38541 .61107 L
s
.38577 .60933 m
.38541 .61107 L
s
0 1 .881 r
.4584 .57954 m
.45846 .58071 L
s
.45678 .57847 m
.4584 .57954 L
s
.45893 .57822 m
.4584 .57954 L
s
1 0 .812 r
.52574 .78759 m
.52814 .78982 L
s
0 .067 1 r
.30926 .36949 m
.31185 .37058 L
s
.31098 .36671 m
.30926 .36949 L
s
.30926 .36949 m
.31016 .36855 L
s
.32005 .36523 m
.30926 .36949 L
s
0 .479 1 r
.53152 .19714 m
.53122 .19853 L
s
.52986 .19539 m
.53152 .19714 L
s
.53244 .19567 m
.53152 .19714 L
s
.505 0 1 r
.38458 .41938 m
.3874 .41788 L
s
.3874 .41788 m
.38726 .41625 L
s
.3874 .41788 m
.38427 .41542 L
s
0 .369 1 r
.3825 .35797 m
.38293 .36112 L
s
.38504 .35839 m
.3825 .35797 L
s
.3825 .35797 m
.38286 .35967 L
s
.38994 .3669 m
.3825 .35797 L
s
.505 0 1 r
.46059 .60678 m
.46068 .60865 L
s
.45808 .60509 m
.46059 .60678 L
s
.46146 .60478 m
.46059 .60678 L
s
.908 0 1 r
.3096 .59608 m
.31947 .60881 L
s
0 .369 1 r
.38286 .35967 m
.38293 .36112 L
s
0 1 .286 r
.45678 .54977 m
.45652 .549 L
s
.45652 .549 m
.45824 .54847 L
s
1 0 .812 r
.52893 .21891 m
.54314 .20985 L
s
.021 0 1 r
.45431 .39159 m
.45516 .39499 L
s
.45739 .39169 m
.45431 .39159 L
s
.45431 .39159 m
.45524 .39326 L
s
.46416 .40035 m
.45431 .39159 L
s
1 0 .433 r
.3142 .38903 m
.31535 .3864 L
s
.31535 .3864 m
.31294 .38356 L
s
.31535 .3864 m
.31054 .38751 L
s
.505 0 1 r
.38427 .41542 m
.38458 .41938 L
s
.38726 .41625 m
.38427 .41542 L
s
.38427 .41542 m
.38443 .41775 L
s
.39252 .42742 m
.38427 .41542 L
s
0 .484 1 r
.38458 .39134 m
.38671 .39011 L
s
.38671 .39011 m
.38664 .38875 L
s
.38671 .39011 m
.38421 .38827 L
s
0 1 .881 r
.45684 .57963 m
.45678 .57847 L
s
.45678 .57847 m
.45893 .57822 L
s
0 .369 1 r
.38317 .61121 m
.38323 .60979 L
s
.38323 .60979 m
.38577 .60933 L
s
1 0 .433 r
.31054 .38751 m
.3142 .38903 L
s
.31294 .38356 m
.31054 .38751 L
s
.31054 .38751 m
.31179 .38619 L
s
.32574 .38141 m
.31054 .38751 L
s
.505 0 1 r
.38443 .41775 m
.38458 .41938 L
s
1 0 .749 r
.38376 .32886 m
.38342 .33036 L
s
.38392 .32573 m
.38342 .33036 L
s
.021 0 1 r
.45524 .39326 m
.45516 .39499 L
s
0 .479 1 r
.52955 .19678 m
.52986 .19539 L
s
.52986 .19539 m
.53244 .19567 L
s
0 .484 1 r
.38421 .38827 m
.38458 .39134 L
s
.38664 .38875 m
.38421 .38827 L
s
.38421 .38827 m
.38451 .38998 L
s
.39123 .39715 m
.38421 .38827 L
s
0 .067 1 r
.31098 .36671 m
.31016 .36855 L
s
0 1 .286 r
.45814 .55049 m
.45678 .54977 L
s
.45824 .54847 m
.45814 .55049 L
s
1 0 .749 r
.38729 .32766 m
.38392 .32573 L
s
.38392 .32573 m
.38376 .32886 L
s
.39109 .34215 m
.38392 .32573 L
s
0 1 .286 r
.45678 .54977 m
.45824 .54847 L
s
0 .186 1 r
.38407 .63945 m
.38442 .64282 L
s
.38185 .64193 m
.38407 .63945 L
s
.505 0 1 r
.45816 .60695 m
.45808 .60509 L
s
.45808 .60509 m
.46146 .60478 L
s
.824 0 1 r
.38534 .6554 m
.38874 .65468 L
s
.38874 .65468 m
.38919 .65422 L
s
.38874 .65468 m
.3865 .65143 L
s
0 .484 1 r
.38451 .38998 m
.38458 .39134 L
s
0 .186 1 r
.38442 .64282 m
.38185 .64193 L
s
.82 0 1 r
.38865 .57818 m
.38855 .57998 L
s
.38569 .57652 m
.38865 .57818 L
s
.38899 .57575 m
.38865 .57818 L
s
0 1 .881 r
.45846 .58071 m
.45684 .57963 L
s
.45893 .57822 m
.45846 .58071 L
s
0 .067 1 r
.31016 .36855 m
.31185 .37058 L
s
0 .369 1 r
.38504 .35839 m
.38286 .35967 L
s
0 .479 1 r
.53122 .19853 m
.52955 .19678 L
s
.53244 .19567 m
.53122 .19853 L
s
0 1 .881 r
.45684 .57963 m
.45893 .57822 L
s
.824 0 1 r
.38579 .65494 m
.38534 .6554 L
s
.3865 .65143 m
.38534 .6554 L
s
.021 0 1 r
.45739 .39169 m
.45524 .39326 L
s
0 .369 1 r
.38536 .61249 m
.38317 .61121 L
s
.38577 .60933 m
.38536 .61249 L
s
1 0 .433 r
.31294 .38356 m
.31179 .38619 L
s
0 .369 1 r
.38317 .61121 m
.38577 .60933 L
s
.82 0 1 r
.38558 .57831 m
.38569 .57652 L
s
.38569 .57652 m
.38899 .57575 L
s
0 .479 1 r
.52955 .19678 m
.53244 .19567 L
s
0 .484 1 r
.38664 .38875 m
.38451 .38998 L
s
.824 0 1 r
.38919 .65422 m
.3865 .65143 L
s
.3865 .65143 m
.38579 .65494 L
s
.39031 .66834 m
.3865 .65143 L
s
.505 0 1 r
.38726 .41625 m
.38443 .41775 L
s
.46068 .60865 m
.45816 .60695 L
s
.46146 .60478 m
.46068 .60865 L
s
1 0 .433 r
.31179 .38619 m
.3142 .38903 L
s
.505 0 1 r
.45816 .60695 m
.46146 .60478 L
s
0 1 .286 r
.4603 .42752 m
.46151 .42662 L
s
.46151 .42662 m
.46158 .42565 L
s
.46151 .42662 m
.45981 .42558 L
s
.23 0 1 r
.46035 .27637 m
.46932 .2651 L
s
0 .97 1 r
.38832 .70074 m
.39014 .69958 L
s
.39014 .69958 m
.39011 .69864 L
s
.39014 .69958 m
.38797 .69807 L
s
1 0 .749 r
.38729 .32766 m
.38376 .32886 L
s
.908 0 1 r
.31907 .60617 m
.31609 .60801 L
s
.31888 .6045 m
.31907 .60617 L
s
.31947 .60881 m
.31907 .60617 L
s
0 1 .286 r
.45981 .42558 m
.4603 .42752 L
s
.46158 .42565 m
.45981 .42558 L
s
.45981 .42558 m
.46037 .42656 L
s
.46548 .43062 m
.45981 .42558 L
s
0 .97 1 r
.38797 .69807 m
.38832 .70074 L
s
.39011 .69864 m
.38797 .69807 L
s
.38797 .69807 m
.38829 .69979 L
s
.39419 .70618 m
.38797 .69807 L
s
0 1 .286 r
.46037 .42656 m
.4603 .42752 L
s
0 .97 1 r
.38829 .69979 m
.38832 .70074 L
s
0 .479 1 r
.53763 .80524 m
.53793 .80337 L
s
.53793 .80337 m
.53627 .80188 L
s
.53793 .80337 m
.53504 .80454 L
s
.53504 .80454 m
.53763 .80524 L
s
.53627 .80188 m
.53504 .80454 L
s
.53504 .80454 m
.53596 .80374 L
s
.5446 .79963 m
.53504 .80454 L
s
.824 0 1 r
.38919 .65422 m
.38579 .65494 L
s
.82 0 1 r
.38855 .57998 m
.38558 .57831 L
s
.38899 .57575 m
.38855 .57998 L
s
0 1 .286 r
.46158 .42565 m
.46037 .42656 L
s
.908 0 1 r
.31609 .60801 m
.31591 .60635 L
s
.31947 .60881 m
.31609 .60801 L
s
.82 0 1 r
.38558 .57831 m
.38899 .57575 L
s
0 .369 1 r
.38994 .6331 m
.39742 .62413 L
s
0 .479 1 r
.53627 .80188 m
.53596 .80374 L
s
.987 0 1 r
.39186 .34424 m
.39485 .34248 L
s
.39485 .34248 m
.39475 .34044 L
s
.39485 .34248 m
.39125 .33991 L
s
0 .97 1 r
.39011 .69864 m
.38829 .69979 L
s
.824 0 1 r
.39031 .33166 m
.39413 .31471 L
s
.39484 .31826 m
.3953 .31868 L
s
.39143 .31753 m
.39484 .31826 L
s
.39413 .31471 m
.39484 .31826 L
s
1 0 .812 r
.54174 .21192 m
.54125 .21401 L
s
.53933 .20932 m
.54174 .21192 L
s
.54314 .20985 m
.54174 .21192 L
s
.463 1 0 r
.46516 .46038 m
.46618 .45994 L
s
.46618 .45994 m
.46611 .45948 L
s
.46618 .45994 m
.46519 .45901 L
s
.987 0 1 r
.39125 .33991 m
.39186 .34424 L
s
.39475 .34044 m
.39125 .33991 L
s
.39125 .33991 m
.39176 .34221 L
s
.40156 .35208 m
.39125 .33991 L
s
.021 0 1 r
.46416 .59965 m
.47406 .59086 L
s
.463 1 0 r
.46508 .45992 m
.46516 .46038 L
s
.46519 .45901 m
.46516 .46038 L
s
1 0 .749 r
.39109 .65785 m
.39828 .64138 L
s
.463 1 0 r
.46611 .45948 m
.46519 .45901 L
s
.46519 .45901 m
.46508 .45992 L
s
.46742 .46361 m
.46519 .45901 L
s
0 .484 1 r
.39123 .60285 m
.39827 .59393 L
s
0 .479 1 r
.53596 .80374 m
.53763 .80524 L
s
1 0 0 r
.32069 .37742 m
.32369 .37476 L
s
.32369 .37476 m
.32292 .37183 L
s
.32369 .37476 m
.31874 .37277 L
s
.824 0 1 r
.39189 .31795 m
.39143 .31753 L
s
.39143 .31753 m
.39413 .31471 L
s
.987 0 1 r
.39176 .34221 m
.39186 .34424 L
s
.23 0 1 r
.46876 .26753 m
.46879 .26883 L
s
.46626 .26588 m
.46876 .26753 L
s
.46932 .2651 m
.46876 .26753 L
s
1 0 0 r
.31874 .37277 m
.32069 .37742 L
s
.32292 .37183 m
.31874 .37277 L
s
.31874 .37277 m
.31991 .37449 L
s
.33413 .38209 m
.31874 .37277 L
s
1 0 .812 r
.53856 .21818 m
.55287 .22512 L
s
0 1 .286 r
.46548 .56938 m
.47115 .56433 L
s
.908 0 1 r
.31591 .60635 m
.31888 .6045 L
s
.31888 .6045 m
.31947 .60881 L
s
.463 1 0 r
.46611 .45948 m
.46508 .45992 L
s
.505 0 1 r
.39252 .57258 m
.4008 .56051 L
s
.908 0 1 r
.31591 .60635 m
.31947 .60881 L
s
1 0 .812 r
.53884 .2114 m
.53933 .20932 L
s
.53933 .20932 m
.54314 .20985 L
s
.23 0 1 r
.46629 .26719 m
.46626 .26588 L
s
.46626 .26588 m
.46932 .2651 L
s
0 .067 1 r
.32005 .63477 m
.3309 .63906 L
s
1 0 .749 r
.39842 .64455 m
.39879 .64602 L
s
.39489 .64333 m
.39842 .64455 L
s
.39828 .64138 m
.39842 .64455 L
s
0 .369 1 r
.39704 .62584 m
.39698 .62729 L
s
.39486 .62456 m
.39704 .62584 L
s
.39742 .62413 m
.39704 .62584 L
s
1 0 0 r
.31991 .37449 m
.32069 .37742 L
s
.824 0 1 r
.39413 .31471 m
.3953 .31868 L
s
.39189 .31795 m
.39413 .31471 L
s
.463 1 0 r
.46742 .53639 m
.46965 .53179 L
s
0 .97 1 r
.39419 .29382 m
.40044 .28567 L
s
0 1 .286 r
.47059 .56532 m
.47066 .56628 L
s
.46937 .56441 m
.47059 .56532 L
s
.47115 .56433 m
.47059 .56532 L
s
.987 0 1 r
.39475 .34044 m
.39176 .34221 L
s
0 .484 1 r
.39602 .37688 m
.39812 .37561 L
s
.39812 .37561 m
.39803 .3742 L
s
.39812 .37561 m
.39557 .37382 L
s
1 0 .812 r
.54125 .21401 m
.53884 .2114 L
s
.54314 .20985 m
.54125 .21401 L
s
.021 0 1 r
.4731 .59255 m
.47319 .59427 L
s
.47096 .59097 m
.4731 .59255 L
s
.47406 .59086 m
.4731 .59255 L
s
1 0 .749 r
.39525 .64481 m
.39489 .64333 L
s
.39489 .64333 m
.39828 .64138 L
s
0 .998 1 r
.46912 .77149 m
.4709 .77032 L
s
.4709 .77032 m
.47093 .76943 L
s
.4709 .77032 m
.46875 .76883 L
s
0 .484 1 r
.39796 .59566 m
.3979 .59701 L
s
.39582 .59443 m
.39796 .59566 L
s
.39827 .59393 m
.39796 .59566 L
s
0 .369 1 r
.3948 .626 m
.39486 .62456 L
s
.39486 .62456 m
.39742 .62413 L
s
0 .484 1 r
.39557 .37382 m
.39602 .37688 L
s
.39803 .3742 m
.39557 .37382 L
s
.39557 .37382 m
.39593 .37546 L
s
.40285 .38242 m
.39557 .37382 L
s
.824 0 1 r
.3953 .31868 m
.39189 .31795 L
s
1 .65 0 r
.54247 .82055 m
.54245 .82026 L
s
.54245 .82026 m
.54206 .82004 L
s
.54245 .82026 m
.54198 .82061 L
s
0 1 .286 r
.46945 .56537 m
.46937 .56441 L
s
.46937 .56441 m
.47115 .56433 L
s
1 .036 0 r
.32226 .65511 m
.32227 .65515 L
s
.32228 .65511 m
.32226 .65511 L
s
.32226 .65511 m
.32225 .65513 L
s
.32229 .65513 m
.32226 .65511 L
s
.32233 .6552 m
.32226 .65511 L
s
.32227 .65515 m
.32229 .65513 L
s
.32229 .65513 m
.32228 .65511 L
s
.32225 .65513 m
.32227 .65515 L
s
1 .65 0 r
.54198 .82061 m
.54247 .82055 L
s
.54206 .82004 m
.54198 .82061 L
s
.54198 .82061 m
.54208 .82033 L
s
.54339 .81906 m
.54198 .82061 L
s
1 .036 0 r
.32228 .65511 m
.32225 .65513 L
s
0 .998 1 r
.46875 .76883 m
.46912 .77149 L
s
.47093 .76943 m
.46875 .76883 L
s
.46875 .76883 m
.46914 .7706 L
s
.4751 .77698 m
.46875 .76883 L
s
.23 0 1 r
.46879 .26883 m
.46629 .26719 L
s
.46932 .2651 m
.46879 .26883 L
s
1 .65 0 r
.54206 .82004 m
.54208 .82033 L
s
1 .036 0 r
.32233 .3448 m
.32239 .34471 L
s
.3224 .34473 m
.32239 .34475 L
s
.32237 .34471 m
.3224 .34473 L
s
.32239 .34471 m
.3224 .34473 L
s
.32236 .34473 m
.32237 .34471 L
s
.32237 .34471 m
.32239 .34471 L
s
.32239 .34475 m
.32236 .34473 L
s
.32239 .34471 m
.32239 .34475 L
s
0 .484 1 r
.39593 .37546 m
.39602 .37688 L
s
1 .036 0 r
.32236 .34473 m
.32239 .34471 L
s
.463 1 0 r
.46975 .5327 m
.46968 .53315 L
s
.46872 .53226 m
.46975 .5327 L
s
.46965 .53179 m
.46975 .5327 L
s
0 .998 1 r
.46914 .7706 m
.46912 .77149 L
s
1 .65 0 r
.54208 .82033 m
.54247 .82055 L
s
.463 1 0 r
.46865 .53271 m
.46872 .53226 L
s
.46872 .53226 m
.46965 .53179 L
s
0 .484 1 r
.39576 .59578 m
.39582 .59443 L
s
.39582 .59443 m
.39827 .59393 L
s
.23 0 1 r
.46629 .26719 m
.46932 .2651 L
s
0 .648 1 r
.46916 .41259 m
.47075 .41115 L
s
.47075 .41115 m
.47076 .4096 L
s
.47075 .41115 m
.46811 .40987 L
s
0 .807 1 r
.55087 .4328 m
.5524 .43365 L
s
.55186 .43051 m
.55087 .4328 L
s
.55087 .4328 m
.55077 .43206 L
s
.55349 .43211 m
.55087 .4328 L
s
.55718 .42919 m
.55087 .4328 L
s
1 0 0 r
.32292 .37183 m
.31991 .37449 L
s
0 1 .286 r
.47066 .56628 m
.46945 .56537 L
s
.47115 .56433 m
.47066 .56628 L
s
.021 0 1 r
.39882 .4355 m
.40142 .43422 L
s
.40142 .43422 m
.40125 .43286 L
s
.40142 .43422 m
.39868 .43194 L
s
.47105 .59269 m
.47096 .59097 L
s
.47096 .59097 m
.47406 .59086 L
s
0 .728 1 r
.39805 .40722 m
.40007 .40608 L
s
.40007 .40608 m
.39999 .40484 L
s
.40007 .40608 m
.39774 .40434 L
s
1 0 .812 r
.53884 .2114 m
.54314 .20985 L
s
0 1 .286 r
.46945 .56537 m
.47115 .56433 L
s
1 .65 0 r
.54339 .18094 m
.5448 .1825 L
s
.021 0 1 r
.39868 .43194 m
.39882 .4355 L
s
.40125 .43286 m
.39868 .43194 L
s
.39868 .43194 m
.39865 .43414 L
s
.40545 .44317 m
.39868 .43194 L
s
0 .369 1 r
.39698 .62729 m
.3948 .626 L
s
.39742 .62413 m
.39698 .62729 L
s
0 .648 1 r
.46811 .40987 m
.46916 .41259 L
s
.47076 .4096 m
.46811 .40987 L
s
.46811 .40987 m
.46916 .41104 L
s
.47735 .41599 m
.46811 .40987 L
s
.021 0 1 r
.39865 .43414 m
.39882 .4355 L
s
0 .728 1 r
.39774 .40434 m
.39805 .40722 L
s
.39999 .40484 m
.39774 .40434 L
s
.39774 .40434 m
.39798 .40598 L
s
.40415 .41279 m
.39774 .40434 L
s
.463 1 0 r
.46965 .53179 m
.46968 .53315 L
s
.46865 .53271 m
.46965 .53179 L
s
.46968 .53315 m
.46865 .53271 L
s
0 .97 1 r
.40011 .28741 m
.40009 .28835 L
s
.39829 .28625 m
.40011 .28741 L
s
.40044 .28567 m
.40011 .28741 L
s
.505 0 1 r
.40062 .56288 m
.4005 .56449 L
s
.39779 .56137 m
.40062 .56288 L
s
.4008 .56051 m
.40062 .56288 L
s
1 .65 0 r
.5447 .18222 m
.54432 .18244 L
s
.54472 .18193 m
.5447 .18222 L
s
.5448 .1825 m
.5447 .18222 L
s
.887 0 1 r
.54886 .77152 m
.54872 .76939 L
s
.54872 .76939 m
.54585 .76772 L
s
.54872 .76939 m
.54525 .77197 L
s
0 .369 1 r
.3948 .626 m
.39742 .62413 L
s
0 .728 1 r
.39798 .40598 m
.39805 .40722 L
s
0 .807 1 r
.5524 .43365 m
.55349 .43211 L
s
.55349 .43211 m
.55186 .43051 L
s
0 .998 1 r
.47093 .76943 m
.46914 .7706 L
s
1 .65 0 r
.54432 .18244 m
.54434 .18215 L
s
.5448 .1825 m
.54432 .18244 L
s
0 .484 1 r
.39803 .3742 m
.39593 .37546 L
s
0 .648 1 r
.46916 .41104 m
.46916 .41259 L
s
0 .479 1 r
.5446 .20037 m
.55422 .20531 L
s
1 .65 0 r
.54434 .18215 m
.54472 .18193 L
s
.54472 .18193 m
.5448 .1825 L
s
.54434 .18215 m
.5448 .1825 L
s
1 0 .749 r
.39828 .64138 m
.39879 .64602 L
s
.39525 .64481 m
.39828 .64138 L
s
0 .484 1 r
.3979 .59701 m
.39576 .59578 L
s
.39827 .59393 m
.3979 .59701 L
s
0 .97 1 r
.39826 .28719 m
.39829 .28625 L
s
.39829 .28625 m
.40044 .28567 L
s
0 .807 1 r
.55186 .43051 m
.55077 .43206 L
s
.021 0 1 r
.47319 .59427 m
.47105 .59269 L
s
.47406 .59086 m
.47319 .59427 L
s
.505 0 1 r
.39766 .56298 m
.39779 .56137 L
s
.39779 .56137 m
.4008 .56051 L
s
.887 0 1 r
.54525 .77197 m
.54886 .77152 L
s
.54585 .76772 m
.54525 .77197 L
s
.54525 .77197 m
.54599 .76985 L
s
.5558 .76021 m
.54525 .77197 L
s
.225 0 1 r
.3999 .68211 m
.40244 .68051 L
s
.40244 .68051 m
.40242 .67916 L
s
.40244 .68051 m
.39941 .67838 L
s
0 .484 1 r
.39576 .59578 m
.39827 .59393 L
s
1 0 .749 r
.39879 .64602 m
.39525 .64481 L
s
.021 0 1 r
.47105 .59269 m
.47406 .59086 L
s
0 .648 1 r
.47076 .4096 m
.46916 .41104 L
s
1 0 .433 r
.32574 .61859 m
.34108 .62474 L
s
.887 0 1 r
.54585 .76772 m
.54599 .76985 L
s
.225 0 1 r
.39941 .67838 m
.3999 .68211 L
s
.40242 .67916 m
.39941 .67838 L
s
.39941 .67838 m
.39988 .68077 L
s
.40818 .68968 m
.39941 .67838 L
s
0 .807 1 r
.55077 .43206 m
.5524 .43365 L
s
0 .728 1 r
.39999 .40484 m
.39798 .40598 L
s
0 .067 1 r
.32997 .6381 m
.32829 .64014 L
s
.32917 .63626 m
.32997 .6381 L
s
.3309 .63906 m
.32997 .6381 L
s
1 0 .812 r
.55144 .22398 m
.54903 .22623 L
s
.55096 .22123 m
.55144 .22398 L
s
.55287 .22512 m
.55144 .22398 L
s
.225 0 1 r
.39988 .68077 m
.3999 .68211 L
s
0 .97 1 r
.40009 .28835 m
.39826 .28719 L
s
.40044 .28567 m
.40009 .28835 L
s
.021 0 1 r
.40125 .43286 m
.39865 .43414 L
s
0 .97 1 r
.39826 .28719 m
.40044 .28567 L
s
.361 0 1 r
.32918 .36324 m
.33139 .36131 L
s
.33139 .36131 m
.33082 .35917 L
s
.33139 .36131 m
.32778 .35984 L
s
.32778 .35984 m
.32918 .36324 L
s
.33082 .35917 m
.32778 .35984 L
s
.32778 .35984 m
.32862 .3611 L
s
.33891 .36668 m
.32778 .35984 L
s
.987 0 1 r
.40156 .64792 m
.41193 .63568 L
s
.505 0 1 r
.4005 .56449 m
.39766 .56298 L
s
.4008 .56051 m
.4005 .56449 L
s
0 .067 1 r
.32829 .64014 m
.32748 .63829 L
s
.3309 .63906 m
.32829 .64014 L
s
0 .998 1 r
.4751 .22302 m
.48147 .21484 L
s
.505 0 1 r
.39766 .56298 m
.4008 .56051 L
s
.887 0 1 r
.54599 .76985 m
.54886 .77152 L
s
1 0 .812 r
.54903 .22623 m
.54856 .22348 L
s
.55287 .22512 m
.54903 .22623 L
s
.225 0 1 r
.40242 .67916 m
.39988 .68077 L
s
.361 0 1 r
.32862 .3611 m
.32918 .36324 L
s
0 .067 1 r
.32748 .63829 m
.32917 .63626 L
s
.32917 .63626 m
.3309 .63906 L
s
1 0 .343 r
.33188 .38555 m
.33536 .38355 L
s
.33536 .38355 m
.33511 .38133 L
s
.33536 .38355 m
.33127 .3806 L
s
0 .484 1 r
.40285 .61758 m
.41017 .60894 L
s
.82 0 1 r
.40509 .36027 m
.40796 .3585 L
s
.40796 .3585 m
.40779 .3565 L
s
.40796 .3585 m
.40442 .35609 L
s
.463 1 0 r
.47773 .44539 m
.47858 .44473 L
s
.47858 .44473 m
.4784 .44404 L
s
.47858 .44473 m
.47735 .44412 L
s
.47735 .44412 m
.47773 .44539 L
s
.4784 .44404 m
.47735 .44412 L
s
.47735 .44412 m
.47755 .4447 L
s
.48092 .4471 m
.47735 .44412 L
s
0 .479 1 r
.55327 .20451 m
.5516 .20601 L
s
.55298 .20264 m
.55327 .20451 L
s
.55422 .20531 m
.55327 .20451 L
s
.463 1 0 r
.47755 .4447 m
.47773 .44539 L
s
.82 0 1 r
.40442 .35609 m
.40509 .36027 L
s
.40779 .3565 m
.40442 .35609 L
s
.40442 .35609 m
.40491 .35827 L
s
.41456 .3676 m
.40442 .35609 L
s
1 0 .343 r
.33127 .3806 m
.33188 .38555 L
s
.33511 .38133 m
.33127 .3806 L
s
.33127 .3806 m
.33163 .38333 L
s
.34242 .39484 m
.33127 .3806 L
s
0 .648 1 r
.47735 .58401 m
.48661 .57787 L
s
1 0 .812 r
.54856 .22348 m
.55096 .22123 L
s
.55096 .22123 m
.55287 .22512 L
s
0 .728 1 r
.40415 .58721 m
.41058 .57874 L
s
.361 0 1 r
.33082 .35917 m
.32862 .3611 L
s
.463 1 0 r
.4784 .44404 m
.47755 .4447 L
s
0 .067 1 r
.32748 .63829 m
.3309 .63906 L
s
.82 0 1 r
.40491 .35827 m
.40509 .36027 L
s
1 0 .343 r
.33163 .38333 m
.33188 .38555 L
s
0 .479 1 r
.5516 .20601 m
.55131 .20414 L
s
.55422 .20531 m
.5516 .20601 L
s
0 .998 1 r
.48106 .21663 m
.4811 .21751 L
s
.47928 .21545 m
.48106 .21663 L
s
.48147 .21484 m
.48106 .21663 L
s
.021 0 1 r
.40545 .55683 m
.41225 .54554 L
s
0 .998 1 r
.47932 .21633 m
.47928 .21545 L
s
.47928 .21545 m
.48147 .21484 L
s
1 0 .812 r
.54856 .22348 m
.55287 .22512 L
s
0 .479 1 r
.55131 .20414 m
.55298 .20264 L
s
.55298 .20264 m
.55422 .20531 L
s
.197 0 1 r
.481 .75307 m
.48349 .75143 L
s
.48349 .75143 m
.48355 .75016 L
s
.48349 .75143 m
.48049 .74934 L
s
0 .103 1 r
.56037 .42313 m
.56258 .42334 L
s
.56127 .41992 m
.56037 .42313 L
s
.56037 .42313 m
.56037 .42159 L
s
.56348 .42167 m
.56037 .42313 L
s
.56816 .4156 m
.56037 .42313 L
s
0 .484 1 r
.4098 .6106 m
.40972 .61201 L
s
.40769 .60933 m
.4098 .6106 L
s
.41017 .60894 m
.4098 .6106 L
s
.987 0 1 r
.41139 .63801 m
.41131 .64003 L
s
.4084 .63623 m
.41139 .63801 L
s
.41193 .63568 m
.41139 .63801 L
s
.197 0 1 r
.48049 .74934 m
.481 .75307 L
s
.48355 .75016 m
.48049 .74934 L
s
.48049 .74934 m
.48105 .7518 L
s
.48943 .76072 m
.48049 .74934 L
s
0 .648 1 r
.48554 .57905 m
.48556 .5806 L
s
.48395 .5776 m
.48554 .57905 L
s
.48661 .57787 m
.48554 .57905 L
s
0 .479 1 r
.55131 .20414 m
.55422 .20531 L
s
.82 0 1 r
.40779 .3565 m
.40491 .35827 L
s
.463 1 0 r
.48092 .5529 m
.48449 .5499 L
s
.197 0 1 r
.48105 .7518 m
.481 .75307 L
s
0 .103 1 r
.56258 .42334 m
.56348 .42167 L
s
.56348 .42167 m
.56127 .41992 L
s
0 .998 1 r
.4811 .21751 m
.47932 .21633 L
s
.48147 .21484 m
.4811 .21751 L
s
1 0 0 r
.33413 .61791 m
.34965 .6085 L
s
0 .728 1 r
.41034 .58039 m
.41027 .58163 L
s
.40832 .57925 m
.41034 .58039 L
s
.41058 .57874 m
.41034 .58039 L
s
0 .484 1 r
.40761 .61074 m
.40769 .60933 L
s
.40769 .60933 m
.41017 .60894 L
s
0 .728 1 r
.40946 .39297 m
.41141 .39177 L
s
.41141 .39177 m
.4113 .39044 L
s
.41141 .39177 m
.40901 .39012 L
s
0 .998 1 r
.47932 .21633 m
.48147 .21484 L
s
1 0 .343 r
.33511 .38133 m
.33163 .38333 L
s
.225 0 1 r
.40818 .31032 m
.41698 .29896 L
s
0 .103 1 r
.56127 .41992 m
.56037 .42159 L
s
1 0 .433 r
.33977 .62339 m
.33737 .62625 L
s
.33864 .62076 m
.33977 .62339 L
s
.34108 .62474 m
.33977 .62339 L
s
0 .728 1 r
.40901 .39012 m
.40946 .39297 L
s
.4113 .39044 m
.40901 .39012 L
s
.40901 .39012 m
.40934 .39165 L
s
.41586 .39805 m
.40901 .39012 L
s
.987 0 1 r
.40831 .63825 m
.4084 .63623 L
s
.4084 .63623 m
.41193 .63568 L
s
0 .728 1 r
.40825 .58048 m
.40832 .57925 L
s
.40832 .57925 m
.41058 .57874 L
s
.887 0 1 r
.5558 .23979 m
.56642 .2516 L
s
0 .648 1 r
.48397 .57915 m
.48395 .5776 L
s
.48395 .5776 m
.48661 .57787 L
s
0 .728 1 r
.40934 .39165 m
.40946 .39297 L
s
0 1 .47 r
.48245 .42921 m
.48336 .42801 L
s
.48336 .42801 m
.48312 .42675 L
s
.48336 .42801 m
.48125 .42747 L
s
.48125 .42747 m
.48245 .42921 L
s
.48312 .42675 m
.48125 .42747 L
s
.48125 .42747 m
.4822 .42795 L
s
.48891 .43 m
.48125 .42747 L
s
0 .807 1 r
.55718 .57081 m
.56354 .57445 L
s
.021 0 1 r
.41227 .54777 m
.4121 .54913 L
s
.40967 .54649 m
.41227 .54777 L
s
.41225 .54554 m
.41227 .54777 L
s
1 .036 0 r
.33635 .32652 m
.33634 .32651 L
s
.33634 .32651 m
.33631 .32649 L
s
.33634 .32651 m
.33631 .32653 L
s
.33631 .32653 m
.33635 .32652 L
s
.33631 .32649 m
.33631 .32653 L
s
.33631 .32653 m
.33633 .3265 L
s
.3364 .32641 m
.33631 .32653 L
s
.33631 .32649 m
.33633 .3265 L
s
.33648 .67368 m
.33646 .67369 L
s
.33649 .67367 m
.33648 .67368 L
s
.33649 .6737 m
.33648 .67368 L
s
0 .648 1 r
.48556 .5806 m
.48397 .57915 L
s
.48661 .57787 m
.48556 .5806 L
s
1 .036 0 r
.33633 .3265 m
.33635 .32652 L
s
.3364 .67359 m
.33649 .6737 L
s
.33646 .67369 m
.33647 .67368 L
s
.33649 .6737 m
.33646 .67369 L
s
.33647 .67368 m
.33649 .67367 L
s
.33649 .67367 m
.33649 .6737 L
s
.33647 .67368 m
.33649 .6737 L
s
.197 0 1 r
.48355 .75016 m
.48105 .7518 L
s
0 .484 1 r
.40972 .61201 m
.40761 .61074 L
s
.41017 .60894 m
.40972 .61201 L
s
.463 1 0 r
.48429 .55049 m
.48411 .55118 L
s
.48344 .54983 m
.48429 .55049 L
s
.48449 .5499 m
.48429 .55049 L
s
0 1 .881 r
.41194 .42343 m
.41374 .42245 L
s
.41374 .42245 m
.41366 .42139 L
s
.41374 .42245 m
.41171 .42088 L
s
0 .484 1 r
.40761 .61074 m
.41017 .60894 L
s
.463 1 0 r
.48326 .55051 m
.48344 .54983 L
s
.48344 .54983 m
.48449 .5499 L
s
0 1 .47 r
.4822 .42795 m
.48245 .42921 L
s
0 .103 1 r
.56037 .42159 m
.56258 .42334 L
s
.021 0 1 r
.4095 .54784 m
.40967 .54649 L
s
.40967 .54649 m
.41225 .54554 L
s
0 .648 1 r
.48397 .57915 m
.48661 .57787 L
s
0 .728 1 r
.41027 .58163 m
.40825 .58048 L
s
.41058 .57874 m
.41027 .58163 L
s
.4113 .39044 m
.40934 .39165 L
s
0 1 .881 r
.41171 .42088 m
.41194 .42343 L
s
.41366 .42139 m
.41171 .42088 L
s
.41171 .42088 m
.41186 .42237 L
s
.41717 .42853 m
.41171 .42088 L
s
0 1 .47 r
.48312 .42675 m
.4822 .42795 L
s
1 0 .433 r
.33737 .62625 m
.33623 .62363 L
s
.34108 .62474 m
.33737 .62625 L
s
0 .728 1 r
.40825 .58048 m
.41058 .57874 L
s
0 1 .881 r
.41186 .42237 m
.41194 .42343 L
s
1 .098 0 r
.33781 .64972 m
.33781 .64968 L
s
.33781 .64968 m
.33775 .64964 L
s
.33781 .64968 m
.33774 .64973 L
s
0 .648 1 r
.41397 .45176 m
.41625 .45085 L
s
.41625 .45085 m
.41598 .44988 L
s
.41625 .45085 m
.4141 .44878 L
s
1 .098 0 r
.33774 .64973 m
.33781 .64972 L
s
.33775 .64964 m
.33774 .64973 L
s
.33774 .64973 m
.33775 .64968 L
s
.33795 .64948 m
.33774 .64973 L
s
.463 1 0 r
.48411 .55118 m
.48326 .55051 L
s
.48449 .5499 m
.48411 .55118 L
s
1 .098 0 r
.33775 .64964 m
.33775 .64968 L
s
.33775 .64968 m
.33781 .64972 L
s
.33795 .35052 m
.33816 .35077 L
s
.987 0 1 r
.41131 .64003 m
.40831 .63825 L
s
.41193 .63568 m
.41131 .64003 L
s
0 .648 1 r
.41369 .4508 m
.41397 .45176 L
s
.4141 .44878 m
.41397 .45176 L
s
1 .098 0 r
.33815 .35072 m
.33809 .35076 L
s
.33815 .35068 m
.33815 .35072 L
s
.33816 .35077 m
.33815 .35072 L
s
.33809 .35076 m
.33809 .35072 L
s
.33816 .35077 m
.33809 .35076 L
s
.33809 .35072 m
.33815 .35068 L
s
.33815 .35068 m
.33816 .35077 L
s
.33809 .35072 m
.33816 .35077 L
s
0 .648 1 r
.41598 .44988 m
.4141 .44878 L
s
.4141 .44878 m
.41369 .4508 L
s
.41848 .45903 m
.4141 .44878 L
s
.463 1 0 r
.48326 .55051 m
.48449 .5499 L
s
.987 0 1 r
.40831 .63825 m
.41193 .63568 L
s
1 0 .433 r
.33623 .62363 m
.33864 .62076 L
s
.33864 .62076 m
.34108 .62474 L
s
.225 0 1 r
.41649 .30138 m
.41649 .30271 L
s
.41395 .29976 m
.41649 .30138 L
s
.41698 .29896 m
.41649 .30138 L
s
.361 0 1 r
.33891 .63332 m
.3501 .62644 L
s
0 1 .881 r
.41366 .42139 m
.41186 .42237 L
s
.021 0 1 r
.4121 .54913 m
.4095 .54784 L
s
.41225 .54554 m
.4121 .54913 L
s
.887 0 1 r
.56564 .24945 m
.56277 .25113 L
s
.56581 .24734 m
.56564 .24945 L
s
.56642 .2516 m
.56564 .24945 L
s
.225 0 1 r
.41395 .30109 m
.41395 .29976 L
s
.41395 .29976 m
.41698 .29896 L
s
.021 0 1 r
.4095 .54784 m
.41225 .54554 L
s
.82 0 1 r
.41456 .6324 m
.42476 .62083 L
s
0 .648 1 r
.41598 .44988 m
.41369 .4508 L
s
1 0 .433 r
.33623 .62363 m
.34108 .62474 L
s
1 .098 0 r
.34137 .65434 m
.34137 .6543 L
s
.34137 .6543 m
.34131 .65426 L
s
.34137 .6543 m
.34129 .65435 L
s
.34129 .65435 m
.34137 .65434 L
s
.34131 .65426 m
.34129 .65435 L
s
.34129 .65435 m
.3413 .6543 L
s
.3415 .65409 m
.34129 .65435 L
s
.34131 .65426 m
.3413 .6543 L
s
.3413 .6543 m
.34137 .65434 L
s
0 .652 1 r
.56568 .78636 m
.56556 .78489 L
s
.56556 .78489 m
.5636 .78375 L
s
.56556 .78489 m
.56318 .78667 L
s
1 .098 0 r
.3415 .34591 m
.34171 .34616 L
s
0 1 .47 r
.48891 .57 m
.49659 .56746 L
s
1 .098 0 r
.3417 .34612 m
.34164 .34615 L
s
.3417 .34607 m
.3417 .34612 L
s
.34171 .34616 m
.3417 .34612 L
s
.34164 .34615 m
.34164 .34611 L
s
.34171 .34616 m
.34164 .34615 L
s
.34164 .34611 m
.3417 .34607 L
s
.3417 .34607 m
.34171 .34616 L
s
.34164 .34611 m
.34171 .34616 L
s
.887 0 1 r
.56277 .25113 m
.56293 .24902 L
s
.56642 .2516 m
.56277 .25113 L
s
.197 0 1 r
.48943 .23928 m
.49841 .22785 L
s
0 .98 1 r
.4168 .73774 m
.41862 .73656 L
s
.41862 .73656 m
.4186 .73563 L
s
.41862 .73656 m
.41643 .73506 L
s
0 .652 1 r
.56318 .78667 m
.56568 .78636 L
s
.5636 .78375 m
.56318 .78667 L
s
.56318 .78667 m
.56371 .78522 L
s
.57047 .7786 m
.56318 .78667 L
s
0 .728 1 r
.41586 .60195 m
.42275 .59398 L
s
1 0 .551 r
.34569 .40123 m
.34913 .39933 L
s
.34913 .39933 m
.34875 .39725 L
s
.34913 .39933 m
.34522 .39642 L
s
1 0 .343 r
.34242 .60516 m
.35365 .59083 L
s
0 .652 1 r
.5636 .78375 m
.56371 .78522 L
s
.505 0 1 r
.41871 .37668 m
.42138 .37497 L
s
.42138 .37497 m
.42112 .37307 L
s
.42138 .37497 m
.41799 .37279 L
s
0 1 .224 r
.56022 .45042 m
.56011 .44951 L
s
.56011 .44951 m
.55901 .44855 L
s
.56011 .44951 m
.55842 .45044 L
s
1 0 0 r
.34841 .61027 m
.34767 .6132 L
s
.3454 .60758 m
.34841 .61027 L
s
.34965 .6085 m
.34841 .61027 L
s
.225 0 1 r
.41649 .30271 m
.41395 .30109 L
s
.41698 .29896 m
.41649 .30271 L
s
0 .98 1 r
.41643 .73506 m
.4168 .73774 L
s
.4186 .73563 m
.41643 .73506 L
s
.41643 .73506 m
.41679 .73681 L
s
.4228 .74321 m
.41643 .73506 L
s
1 0 .551 r
.34522 .39642 m
.34569 .40123 L
s
.34875 .39725 m
.34522 .39642 L
s
.34522 .39642 m
.34531 .39915 L
s
.35526 .41057 m
.34522 .39642 L
s
.505 0 1 r
.41799 .37279 m
.41871 .37668 L
s
.42112 .37307 m
.41799 .37279 L
s
.41799 .37279 m
.41846 .37478 L
s
.42765 .38323 m
.41799 .37279 L
s
0 .98 1 r
.41679 .73681 m
.4168 .73774 L
s
0 1 .224 r
.55842 .45044 m
.56022 .45042 L
s
.55901 .44855 m
.55842 .45044 L
s
.55842 .45044 m
.55911 .44947 L
s
.56438 .44568 m
.55842 .45044 L
s
.225 0 1 r
.41395 .30109 m
.41698 .29896 L
s
0 1 .881 r
.41717 .57147 m
.42265 .56379 L
s
1 0 .551 r
.34531 .39915 m
.34569 .40123 L
s
0 1 .224 r
.55901 .44855 m
.55911 .44947 L
s
.505 0 1 r
.41846 .37478 m
.41871 .37668 L
s
0 .831 1 r
.49301 .79884 m
.49453 .79724 L
s
.49453 .79724 m
.49421 .79597 L
s
.49453 .79724 m
.49189 .79626 L
s
.195 0 1 r
.34595 .37319 m
.34851 .3717 L
s
.34851 .3717 m
.34837 .37002 L
s
.34851 .3717 m
.34546 .36951 L
s
0 1 .47 r
.49563 .56793 m
.49539 .5692 L
s
.49472 .56673 m
.49563 .56793 L
s
.49659 .56746 m
.49563 .56793 L
s
0 .831 1 r
.49189 .79626 m
.49301 .79884 L
s
.49421 .79597 m
.49189 .79626 L
s
.49189 .79626 m
.49269 .79757 L
s
.50052 .802 m
.49189 .79626 L
s
0 1 .224 r
.55911 .44947 m
.56022 .45042 L
s
0 .652 1 r
.56371 .78522 m
.56568 .78636 L
s
.887 0 1 r
.56293 .24902 m
.56581 .24734 L
s
.56581 .24734 m
.56642 .2516 L
s
0 .648 1 r
.41848 .54097 m
.42287 .53067 L
s
0 .98 1 r
.4186 .73563 m
.41679 .73681 L
s
.195 0 1 r
.34546 .36951 m
.34595 .37319 L
s
.34837 .37002 m
.34546 .36951 L
s
.34546 .36951 m
.34581 .37151 L
s
.35397 .38 m
.34546 .36951 L
s
.361 0 1 r
.34924 .62772 m
.34869 .62986 L
s
.34703 .62578 m
.34924 .62772 L
s
.3501 .62644 m
.34924 .62772 L
s
.887 0 1 r
.56293 .24902 m
.56642 .2516 L
s
1 0 0 r
.34466 .61051 m
.3454 .60758 L
s
.3454 .60758 m
.34965 .6085 L
s
0 .807 1 r
.56363 .5737 m
.56199 .5753 L
s
.56254 .57215 m
.56363 .5737 L
s
.56354 .57445 m
.56363 .5737 L
s
0 .831 1 r
.49269 .79757 m
.49301 .79884 L
s
.195 0 1 r
.34581 .37151 m
.34595 .37319 L
s
0 1 .47 r
.49448 .568 m
.49472 .56673 L
s
.49472 .56673 m
.49659 .56746 L
s
.58 0 1 r
.5724 .40973 m
.57532 .40947 L
s
.57325 .40578 m
.5724 .40973 L
s
.5724 .40973 m
.57261 .40756 L
s
.57595 .40769 m
.5724 .40973 L
s
.58183 .39916 m
.5724 .40973 L
s
0 .728 1 r
.4224 .59552 m
.42229 .59684 L
s
.42044 .59431 m
.4224 .59552 L
s
.42275 .59398 m
.4224 .59552 L
s
0 1 .47 r
.49539 .5692 m
.49448 .568 L
s
.49659 .56746 m
.49539 .5692 L
s
0 .807 1 r
.56199 .5753 m
.5609 .57375 L
s
.56354 .57445 m
.56199 .5753 L
s
.466 0 1 r
.49591 .78079 m
.49801 .77852 L
s
.49801 .77852 m
.49754 .7767 L
s
.49801 .77852 m
.49427 .77719 L
s
.58 0 1 r
.57532 .40947 m
.57595 .40769 L
s
.57595 .40769 m
.57325 .40578 L
s
.197 0 1 r
.49782 .23034 m
.49789 .2316 L
s
.49533 .22869 m
.49782 .23034 L
s
.49841 .22785 m
.49782 .23034 L
s
.82 0 1 r
.42423 .62304 m
.42408 .62503 L
s
.42135 .62126 m
.42423 .62304 L
s
.42476 .62083 m
.42423 .62304 L
s
.505 0 1 r
.42112 .37307 m
.41846 .37478 L
s
0 1 .881 r
.42249 .5653 m
.42242 .56635 L
s
.42068 .56431 m
.42249 .5653 L
s
.42265 .56379 m
.42249 .5653 L
s
0 .831 1 r
.49421 .79597 m
.49269 .79757 L
s
.466 0 1 r
.49427 .77719 m
.49591 .78079 L
s
.49754 .7767 m
.49427 .77719 L
s
.49427 .77719 m
.49543 .77896 L
s
.50656 .78497 m
.49427 .77719 L
s
0 .103 1 r
.56816 .5844 m
.576 .59198 L
s
0 .728 1 r
.42033 .59563 m
.42044 .59431 L
s
.42044 .59431 m
.42275 .59398 L
s
.361 0 1 r
.34821 .33659 m
.35119 .3356 L
s
.35119 .3356 m
.35141 .33436 L
s
.35119 .3356 m
.34865 .33271 L
s
0 1 .47 r
.49448 .568 m
.49659 .56746 L
s
.361 0 1 r
.34648 .62792 m
.34703 .62578 L
s
.34703 .62578 m
.3501 .62644 L
s
.58 0 1 r
.57325 .40578 m
.57261 .40756 L
s
1 0 .551 r
.34875 .39725 m
.34531 .39915 L
s
0 1 .881 r
.42061 .56536 m
.42068 .56431 L
s
.42068 .56431 m
.42265 .56379 L
s
0 .807 1 r
.5609 .57375 m
.56254 .57215 L
s
.56254 .57215 m
.56354 .57445 L
s
0 1 .224 r
.56438 .55432 m
.57036 .55908 L
s
1 0 0 r
.34767 .6132 m
.34466 .61051 L
s
.34965 .6085 m
.34767 .6132 L
s
.197 0 1 r
.4954 .22994 m
.49533 .22869 L
s
.49533 .22869 m
.49841 .22785 L
s
0 .067 1 r
.34866 .66661 m
.35147 .66602 L
s
.35147 .66602 m
.3518 .66565 L
s
.35147 .66602 m
.34961 .66334 L
s
0 1 .881 r
.42327 .40945 m
.42499 .40836 L
s
.42499 .40836 m
.42484 .40718 L
s
.42499 .40836 m
.42283 .40695 L
s
.82 0 1 r
.4212 .62325 m
.42135 .62126 L
s
.42135 .62126 m
.42476 .62083 L
s
.361 0 1 r
.34842 .33535 m
.34821 .33659 L
s
.34865 .33271 m
.34821 .33659 L
s
0 .807 1 r
.5609 .57375 m
.56354 .57445 L
s
.195 0 1 r
.34837 .37002 m
.34581 .37151 L
s
0 .648 1 r
.42327 .53272 m
.423 .53367 L
s
.42098 .5318 m
.42327 .53272 L
s
.42287 .53067 m
.42327 .53272 L
s
.466 0 1 r
.49543 .77896 m
.49591 .78079 L
s
0 1 .881 r
.42283 .40695 m
.42327 .40945 L
s
.42484 .40718 m
.42283 .40695 L
s
.42283 .40695 m
.42313 .40827 L
s
.42897 .4138 m
.42283 .40695 L
s
0 .648 1 r
.42071 .53275 m
.42098 .5318 L
s
.42098 .5318 m
.42287 .53067 L
s
.361 0 1 r
.35141 .33436 m
.34865 .33271 L
s
.34865 .33271 m
.34842 .33535 L
s
.35446 .34655 m
.34865 .33271 L
s
1 0 .343 r
.35326 .59361 m
.35303 .59582 L
s
.34977 .59159 m
.35326 .59361 L
s
.35365 .59083 m
.35326 .59361 L
s
0 .067 1 r
.34899 .66625 m
.34866 .66661 L
s
.34961 .66334 m
.34866 .66661 L
s
.361 0 1 r
.34869 .62986 m
.34648 .62792 L
s
.3501 .62644 m
.34869 .62986 L
s
0 1 .881 r
.42313 .40827 m
.42327 .40945 L
s
0 .728 1 r
.42229 .59684 m
.42033 .59563 L
s
.42275 .59398 m
.42229 .59684 L
s
0 .98 1 r
.4228 .25679 m
.42918 .24861 L
s
0 .652 1 r
.57047 .2214 m
.5778 .2295 L
s
0 1 .881 r
.42242 .56635 m
.42061 .56536 L
s
.42265 .56379 m
.42242 .56635 L
s
0 .728 1 r
.42033 .59563 m
.42275 .59398 L
s
0 1 .224 r
.56966 .5581 m
.56856 .55906 L
s
.56977 .55719 m
.56966 .5581 L
s
.57036 .55908 m
.56966 .5581 L
s
1 0 0 r
.34466 .61051 m
.34965 .6085 L
s
0 1 .881 r
.42061 .56536 m
.42265 .56379 L
s
0 .067 1 r
.3518 .66565 m
.34961 .66334 L
s
.34961 .66334 m
.34899 .66625 L
s
.35272 .67728 m
.34961 .66334 L
s
.466 0 1 r
.49754 .7767 m
.49543 .77896 L
s
0 1 .941 r
.57438 .43682 m
.57631 .4366 L
s
.57488 .43427 m
.57438 .43682 L
s
.57438 .43682 m
.57455 .4354 L
s
.57663 .43546 m
.57438 .43682 L
s
.58046 .42984 m
.57438 .43682 L
s
.57631 .4366 m
.57663 .43546 L
s
.57663 .43546 m
.57488 .43427 L
s
.361 0 1 r
.34648 .62792 m
.3501 .62644 L
s
.197 0 1 r
.49789 .2316 m
.4954 .22994 L
s
.49841 .22785 m
.49789 .2316 L
s
.58 0 1 r
.57261 .40756 m
.57532 .40947 L
s
1 0 .343 r
.34954 .5938 m
.34977 .59159 L
s
.34977 .59159 m
.35365 .59083 L
s
0 1 .224 r
.56856 .55906 m
.56867 .55815 L
s
.57036 .55908 m
.56856 .55906 L
s
0 1 .881 r
.42484 .40718 m
.42313 .40827 L
s
.197 0 1 r
.4954 .22994 m
.49841 .22785 L
s
0 1 .941 r
.57488 .43427 m
.57455 .4354 L
s
.82 0 1 r
.42408 .62503 m
.4212 .62325 L
s
.42476 .62083 m
.42408 .62503 L
s
0 1 .286 r
.42651 .44001 m
.428 .43927 L
s
.428 .43927 m
.42788 .43849 L
s
.428 .43927 m
.42642 .43796 L
s
0 .648 1 r
.42287 .53067 m
.423 .53367 L
s
.42071 .53275 m
.42287 .53067 L
s
0 1 .224 r
.56867 .55815 m
.56977 .55719 L
s
.56977 .55719 m
.57036 .55908 L
s
.361 0 1 r
.35141 .33436 m
.34842 .33535 L
s
0 1 .286 r
.42642 .43796 m
.42651 .44001 L
s
.42788 .43849 m
.42642 .43796 L
s
.42642 .43796 m
.42639 .43923 L
s
.43028 .44439 m
.42642 .43796 L
s
.42639 .43923 m
.42651 .44001 L
s
0 .648 1 r
.423 .53367 m
.42071 .53275 L
s
.82 0 1 r
.4212 .62325 m
.42476 .62083 L
s
0 1 .224 r
.56867 .55815 m
.57036 .55908 L
s
0 .067 1 r
.3518 .66565 m
.34899 .66625 L
s
0 1 .47 r
.42826 .46655 m
.43 .46614 L
s
.42783 .46612 m
.42826 .46655 L
s
.42861 .46443 m
.42826 .46655 L
s
0 .98 1 r
.42881 .25038 m
.42881 .25131 L
s
.427 .24919 m
.42881 .25038 L
s
.42918 .24861 m
.42881 .25038 L
s
.938 0 1 r
.57862 .73828 m
.57844 .73615 L
s
.57844 .73615 m
.57555 .73443 L
s
.57844 .73615 m
.57491 .73875 L
s
0 1 .47 r
.43 .46614 m
.42957 .4657 L
s
.43 .46614 m
.42861 .46443 L
s
0 .652 1 r
.57725 .22804 m
.57528 .22918 L
s
.57738 .22657 m
.57725 .22804 L
s
.5778 .2295 m
.57725 .22804 L
s
0 1 .941 r
.57455 .4354 m
.57631 .4366 L
s
0 .067 1 r
.35272 .32272 m
.35584 .30875 L
s
0 .831 1 r
.50052 .198 m
.50918 .19222 L
s
1 .498 0 r
.50071 .82086 m
.501 .82066 L
s
.501 .82066 m
.50101 .82052 L
s
.501 .82066 m
.50064 .82041 L
s
0 1 .47 r
.42957 .4657 m
.42861 .46443 L
s
.42861 .46443 m
.42783 .46612 L
s
.43014 .47294 m
.42861 .46443 L
s
0 .067 1 r
.35645 .31168 m
.3568 .31202 L
s
.35364 .31107 m
.35645 .31168 L
s
.35584 .30875 m
.35645 .31168 L
s
1 .498 0 r
.50064 .82041 m
.50071 .82086 L
s
.50101 .82052 m
.50064 .82041 L
s
.50064 .82041 m
.50071 .82072 L
s
.50172 .8218 m
.50064 .82041 L
s
.50071 .82072 m
.50071 .82086 L
s
0 .98 1 r
.42699 .25012 m
.427 .24919 L
s
.427 .24919 m
.42918 .24861 L
s
.938 0 1 r
.57491 .73875 m
.57862 .73828 L
s
.57555 .73443 m
.57491 .73875 L
s
.57491 .73875 m
.57572 .73656 L
s
.58581 .72676 m
.57491 .73875 L
s
1 .498 0 r
.50101 .82052 m
.50071 .82072 L
s
.23 0 1 r
.42854 .71911 m
.43108 .71745 L
s
.43108 .71745 m
.43107 .71612 L
s
.43108 .71745 m
.42801 .71534 L
s
0 1 .286 r
.42788 .43849 m
.42639 .43923 L
s
0 .652 1 r
.57528 .22918 m
.5754 .22772 L
s
.5778 .2295 m
.57528 .22918 L
s
0 .067 1 r
.35398 .31142 m
.35364 .31107 L
s
.35364 .31107 m
.35584 .30875 L
s
.505 0 1 r
.42765 .61677 m
.43737 .60628 L
s
.938 0 1 r
.57555 .73443 m
.57572 .73656 L
s
1 0 .343 r
.35303 .59582 m
.34954 .5938 L
s
.35365 .59083 m
.35303 .59582 L
s
1 .498 0 r
.50172 .1782 m
.5028 .17682 L
s
.195 0 1 r
.35397 .62 m
.36253 .60946 L
s
.23 0 1 r
.42801 .71534 m
.42854 .71911 L
s
.43107 .71612 m
.42801 .71534 L
s
.42801 .71534 m
.42853 .71777 L
s
.437 .72672 m
.42801 .71534 L
s
1 .498 0 r
.50273 .17712 m
.50274 .17726 L
s
.50243 .17692 m
.50273 .17712 L
s
.5028 .17682 m
.50273 .17712 L
s
.361 0 1 r
.35446 .65345 m
.36029 .63956 L
s
0 1 .47 r
.42957 .4657 m
.42783 .46612 L
s
1 0 .343 r
.34954 .5938 m
.35365 .59083 L
s
1 .498 0 r
.50244 .17706 m
.50243 .17692 L
s
.50243 .17692 m
.5028 .17682 L
s
.23 0 1 r
.42853 .71777 m
.42854 .71911 L
s
0 .98 1 r
.42881 .25131 m
.42699 .25012 L
s
.42918 .24861 m
.42881 .25131 L
s
1 .498 0 r
.50274 .17726 m
.50244 .17706 L
s
.5028 .17682 m
.50274 .17726 L
s
.50244 .17706 m
.5028 .17682 L
s
0 1 .881 r
.42897 .5862 m
.43512 .57933 L
s
0 .98 1 r
.42699 .25012 m
.42918 .24861 L
s
1 0 .551 r
.35526 .58943 m
.36537 .57518 L
s
0 .652 1 r
.5754 .22772 m
.57738 .22657 L
s
.57738 .22657 m
.5778 .2295 L
s
.466 0 1 r
.50719 .79263 m
.50766 .79023 L
s
.50766 .79023 m
.50556 .78828 L
s
.50766 .79023 m
.50391 .79163 L
s
1 0 .907 r
.35996 .41729 m
.36326 .41555 L
s
.36326 .41555 m
.36272 .41367 L
s
.36326 .41555 m
.35963 .41276 L
s
0 .067 1 r
.35584 .30875 m
.3568 .31202 L
s
.35398 .31142 m
.35584 .30875 L
s
.195 0 1 r
.35752 .35826 m
.36009 .35677 L
s
.36009 .35677 m
.35996 .35507 L
s
.36009 .35677 m
.35703 .35457 L
s
0 .652 1 r
.5754 .22772 m
.5778 .2295 L
s
.466 0 1 r
.50391 .79163 m
.50719 .79263 L
s
.50556 .78828 m
.50391 .79163 L
s
.50391 .79163 m
.50509 .79068 L
s
.51626 .78572 m
.50391 .79163 L
s
.021 0 1 r
.43275 .3936 m
.4351 .39199 L
s
.4351 .39199 m
.43475 .39024 L
s
.4351 .39199 m
.43199 .39016 L
s
1 0 .907 r
.35963 .41276 m
.35996 .41729 L
s
.36272 .41367 m
.35963 .41276 L
s
.35963 .41276 m
.35942 .41541 L
s
.36819 .42642 m
.35963 .41276 L
s
0 .103 1 r
.57598 .59041 m
.57376 .59218 L
s
.57509 .58874 m
.57598 .59041 L
s
.576 .59198 m
.57598 .59041 L
s
0 1 .47 r
.43014 .52706 m
.43168 .51852 L
s
0 1 .286 r
.43028 .55561 m
.43415 .54916 L
s
.021 0 1 r
.43199 .39016 m
.43275 .3936 L
s
.43475 .39024 m
.43199 .39016 L
s
.43199 .39016 m
.43241 .39185 L
s
.44084 .39897 m
.43199 .39016 L
s
.361 0 1 r
.3605 .64223 m
.36073 .64345 L
s
.35751 .64123 m
.3605 .64223 L
s
.36029 .63956 m
.3605 .64223 L
s
1 0 .907 r
.35942 .41541 m
.35996 .41729 L
s
1 0 0 r
.35807 .32615 m
.36218 .32481 L
s
.36218 .32481 m
.36257 .3231 L
s
.36218 .32481 m
.35872 .3208 L
s
0 1 .224 r
.5755 .46773 m
.57507 .46706 L
s
.57507 .46706 m
.57376 .46637 L
s
.57507 .46706 m
.57375 .46837 L
s
.938 0 1 r
.57572 .73656 m
.57862 .73828 L
s
.195 0 1 r
.35703 .35457 m
.35752 .35826 L
s
.35996 .35507 m
.35703 .35457 L
s
.35703 .35457 m
.35739 .35656 L
s
.3656 .36506 m
.35703 .35457 L
s
0 .103 1 r
.57376 .59218 m
.57287 .59051 L
s
.576 .59198 m
.57376 .59218 L
s
0 .067 1 r
.3568 .31202 m
.35398 .31142 L
s
.23 0 1 r
.43107 .71612 m
.42853 .71777 L
s
.113 0 1 r
.3592 .38889 m
.36175 .38743 L
s
.36175 .38743 m
.36157 .38581 L
s
.36175 .38743 m
.35876 .38526 L
s
.195 0 1 r
.35739 .35656 m
.35752 .35826 L
s
.021 0 1 r
.43241 .39185 m
.43275 .3936 L
s
0 .831 1 r
.50836 .19355 m
.50805 .19482 L
s
.50684 .19194 m
.50836 .19355 L
s
.50918 .19222 m
.50836 .19355 L
s
0 1 .47 r
.43072 .51981 m
.43246 .52023 L
s
.43028 .52024 m
.43072 .51981 L
s
.43072 .51981 m
.43168 .51852 L
s
.361 0 1 r
.35774 .64245 m
.35751 .64123 L
s
.35751 .64123 m
.36029 .63956 L
s
.466 0 1 r
.50556 .78828 m
.50509 .79068 L
s
0 1 .224 r
.57375 .46837 m
.5755 .46773 L
s
.57376 .46637 m
.57375 .46837 L
s
.57375 .46837 m
.57418 .46703 L
s
.57816 .46176 m
.57375 .46837 L
s
.57376 .46637 m
.57418 .46703 L
s
0 1 .47 r
.43246 .52023 m
.43203 .52065 L
s
.43168 .51852 m
.43246 .52023 L
s
.113 0 1 r
.35876 .38526 m
.3592 .38889 L
s
.36157 .38581 m
.35876 .38526 L
s
.35876 .38526 m
.35902 .38727 L
s
.36689 .39573 m
.35876 .38526 L
s
1 0 0 r
.35846 .32444 m
.35807 .32615 L
s
.35872 .3208 m
.35807 .32615 L
s
.113 0 1 r
.35902 .38727 m
.3592 .38889 L
s
0 1 .941 r
.58046 .57016 m
.58656 .57717 L
s
.195 0 1 r
.36216 .6115 m
.36204 .61317 L
s
.35959 .60999 m
.36216 .6115 L
s
.36253 .60946 m
.36216 .6115 L
s
.466 0 1 r
.50656 .21503 m
.51892 .20719 L
s
0 1 .881 r
.43482 .58066 m
.43468 .58184 L
s
.4331 .57956 m
.43482 .58066 L
s
.43512 .57933 m
.43482 .58066 L
s
0 1 .224 r
.57418 .46703 m
.5755 .46773 L
s
0 .831 1 r
.50653 .19321 m
.50684 .19194 L
s
.50684 .19194 m
.50918 .19222 L
s
1 0 0 r
.36257 .3231 m
.35872 .3208 L
s
.35872 .3208 m
.35846 .32444 L
s
.36675 .33996 m
.35872 .3208 L
s
1 0 .433 r
.36003 .65559 m
.364 .65472 L
s
.364 .65472 m
.36456 .65416 L
s
.364 .65472 m
.36137 .65093 L
s
0 1 .286 r
.43418 .55043 m
.43406 .55121 L
s
.43268 .54969 m
.43418 .55043 L
s
.43415 .54916 m
.43418 .55043 L
s
1 0 .907 r
.58825 .39466 m
.58862 .39278 L
s
.58862 .39278 m
.58558 .39074 L
s
.58862 .39278 m
.58475 .39521 L
s
0 .103 1 r
.57287 .59051 m
.57509 .58874 L
s
.57509 .58874 m
.576 .59198 L
s
1 0 .907 r
.58475 .39521 m
.58825 .39466 L
s
.58558 .39074 m
.58475 .39521 L
s
.58475 .39521 m
.58521 .39261 L
s
.5956 .38261 m
.58475 .39521 L
s
.466 0 1 r
.50509 .79068 m
.50719 .79263 L
s
0 1 .286 r
.43257 .55047 m
.43268 .54969 L
s
.43268 .54969 m
.43415 .54916 L
s
0 1 .881 r
.43296 .58074 m
.4331 .57956 L
s
.4331 .57956 m
.43512 .57933 L
s
.021 0 1 r
.43475 .39024 m
.43241 .39185 L
s
.505 0 1 r
.43688 .6083 m
.43664 .61019 L
s
.4342 .60657 m
.43688 .6083 L
s
.43737 .60628 m
.43688 .6083 L
s
0 1 .47 r
.43168 .51852 m
.43203 .52065 L
s
.43028 .52024 m
.43168 .51852 L
s
.58 0 1 r
.58183 .60084 m
.59133 .61149 L
s
0 .103 1 r
.57287 .59051 m
.576 .59198 L
s
.195 0 1 r
.35996 .35507 m
.35739 .35656 L
s
.35947 .61166 m
.35959 .60999 L
s
.35959 .60999 m
.36253 .60946 L
s
0 .831 1 r
.50805 .19482 m
.50653 .19321 L
s
.50918 .19222 m
.50805 .19482 L
s
0 1 .47 r
.43203 .52065 m
.43028 .52024 L
s
1 0 .907 r
.58558 .39074 m
.58521 .39261 L
s
1 0 .433 r
.36058 .65503 m
.36003 .65559 L
s
.36137 .65093 m
.36003 .65559 L
s
.361 0 1 r
.36029 .63956 m
.36073 .64345 L
s
.35774 .64245 m
.36029 .63956 L
s
1 0 .907 r
.36272 .41367 m
.35942 .41541 L
s
0 1 .224 r
.57816 .53824 m
.58258 .54486 L
s
.361 0 1 r
.36073 .64345 m
.35774 .64245 L
s
.505 0 1 r
.43396 .60846 m
.4342 .60657 L
s
.4342 .60657 m
.43737 .60628 L
s
.113 0 1 r
.36157 .38581 m
.35902 .38727 L
s
0 .831 1 r
.50653 .19321 m
.50918 .19222 L
s
0 1 .286 r
.43406 .55121 m
.43257 .55047 L
s
.43415 .54916 m
.43406 .55121 L
s
0 1 .224 r
.58214 .54351 m
.58082 .54421 L
s
.58257 .54286 m
.58214 .54351 L
s
.58258 .54486 m
.58214 .54351 L
s
0 1 .286 r
.43257 .55047 m
.43415 .54916 L
s
0 1 .881 r
.43468 .58184 m
.43296 .58074 L
s
.43512 .57933 m
.43468 .58184 L
s
1 0 .433 r
.36456 .65416 m
.36137 .65093 L
s
.36137 .65093 m
.36058 .65503 L
s
.36597 .67067 m
.36137 .65093 L
s
0 1 .881 r
.43296 .58074 m
.43512 .57933 L
s
0 1 .286 r
.43762 .42655 m
.43896 .42562 L
s
.43896 .42562 m
.43874 .42465 L
s
.43896 .42562 m
.43719 .42458 L
s
1 0 .551 r
.36525 .57797 m
.36489 .58003 L
s
.3618 .57606 m
.36525 .57797 L
s
.36537 .57518 m
.36525 .57797 L
s
0 1 .286 r
.43719 .42458 m
.43762 .42655 L
s
.43874 .42465 m
.43719 .42458 L
s
.43719 .42458 m
.4374 .42557 L
s
.44216 .42966 m
.43719 .42458 L
s
0 .6 1 r
.36327 .70283 m
.36535 .70152 L
s
.36535 .70152 m
.36529 .70045 L
s
.36535 .70152 m
.36288 .6998 L
s
0 .479 1 r
.58922 .42184 m
.5894 .42055 L
s
.5894 .42055 m
.58728 .41918 L
s
.5894 .42055 m
.58676 .42228 L
s
0 1 .224 r
.58082 .54421 m
.58125 .54355 L
s
.58258 .54486 m
.58082 .54421 L
s
0 .807 1 r
.59321 .47946 m
.59172 .48023 L
s
.59504 .48023 m
.59321 .47946 L
s
.59321 .47946 m
.59326 .4823 L
s
.195 0 1 r
.36204 .61317 m
.35947 .61166 L
s
.36253 .60946 m
.36204 .61317 L
s
0 .479 1 r
.58676 .42228 m
.58922 .42184 L
s
.58728 .41918 m
.58676 .42228 L
s
.58676 .42228 m
.5871 .42046 L
s
.59422 .4134 m
.58676 .42228 L
s
0 1 .286 r
.4374 .42557 m
.43762 .42655 L
s
0 1 .941 r
.58965 .45178 m
.5899 .45081 L
s
.5899 .45081 m
.58799 .4498 L
s
.5899 .45081 m
.58782 .45244 L
s
1 0 0 r
.36257 .3231 m
.35846 .32444 L
s
0 1 .941 r
.58782 .45244 m
.58965 .45178 L
s
.58799 .4498 m
.58782 .45244 L
s
.58782 .45244 m
.58774 .45077 L
s
.59284 .44418 m
.58782 .45244 L
s
0 .807 1 r
.59326 .4823 m
.59355 .481 L
s
.59326 .4823 m
.59172 .48023 L
s
.59504 .48023 m
.59326 .4823 L
s
.59388 .47194 m
.59326 .4823 L
s
0 .6 1 r
.36288 .6998 m
.36327 .70283 L
s
.36529 .70045 m
.36288 .6998 L
s
.36288 .6998 m
.3632 .70176 L
s
.36988 .70904 m
.36288 .6998 L
s
.195 0 1 r
.35947 .61166 m
.36253 .60946 L
s
.23 0 1 r
.437 .27328 m
.44604 .26184 L
s
0 1 .941 r
.58799 .4498 m
.58774 .45077 L
s
0 .479 1 r
.58728 .41918 m
.5871 .42046 L
s
0 .6 1 r
.3632 .70176 m
.36327 .70283 L
s
1 0 .551 r
.36144 .57811 m
.3618 .57606 L
s
.3618 .57606 m
.36537 .57518 L
s
0 1 .224 r
.58125 .54355 m
.58257 .54286 L
s
.58257 .54286 m
.58258 .54486 L
s
.58125 .54355 m
.58258 .54486 L
s
.938 0 1 r
.58581 .27324 m
.59678 .28531 L
s
1 0 .907 r
.58521 .39261 m
.58825 .39466 L
s
0 1 .941 r
.58638 .57573 m
.58462 .57693 L
s
.58606 .5746 m
.58638 .57573 L
s
.58656 .57717 m
.58638 .57573 L
s
.505 0 1 r
.43664 .61019 m
.43396 .60846 L
s
.43737 .60628 m
.43664 .61019 L
s
0 1 .286 r
.43874 .42465 m
.4374 .42557 L
s
1 0 .343 r
.36642 .34101 m
.36989 .33899 L
s
.36989 .33899 m
.36966 .33664 L
s
.36989 .33899 m
.36573 .33604 L
s
0 1 .941 r
.58462 .57693 m
.5843 .5758 L
s
.58656 .57717 m
.58462 .57693 L
s
0 .807 1 r
.59355 .481 m
.59504 .48023 L
s
.505 0 1 r
.43396 .60846 m
.43737 .60628 L
s
0 .807 1 r
.59172 .48023 m
.59355 .481 L
s
1 0 .433 r
.36456 .65416 m
.36058 .65503 L
s
1 0 .343 r
.36573 .33604 m
.36642 .34101 L
s
.36966 .33664 m
.36573 .33604 L
s
.36573 .33604 m
.36619 .33867 L
s
.3773 .35003 m
.36573 .33604 L
s
0 .831 1 r
.51597 .80881 m
.51628 .8071 L
s
.51628 .8071 m
.51476 .80573 L
s
.51628 .8071 m
.51362 .80814 L
s
.466 0 1 r
.51772 .20899 m
.51726 .21081 L
s
.51562 .20671 m
.51772 .20899 L
s
.51892 .20719 m
.51772 .20899 L
s
0 .6 1 r
.36529 .70045 m
.3632 .70176 L
s
0 .831 1 r
.51362 .80814 m
.51597 .80881 L
s
.51476 .80573 m
.51362 .80814 L
s
.51362 .80814 m
.51445 .80745 L
s
.52235 .80378 m
.51362 .80814 L
s
0 .479 1 r
.5871 .42046 m
.58922 .42184 L
s
0 1 .941 r
.58774 .45077 m
.58965 .45178 L
s
1 0 .343 r
.36619 .33867 m
.36642 .34101 L
s
.195 0 1 r
.3656 .63494 m
.37421 .6244 L
s
1 0 .433 r
.36597 .32933 m
.37059 .30954 L
s
.37136 .31369 m
.37194 .3142 L
s
.36739 .3128 m
.37136 .31369 L
s
.37059 .30954 m
.37136 .31369 L
s
0 1 .941 r
.5843 .5758 m
.58606 .5746 L
s
.58606 .5746 m
.58656 .57717 L
s
0 .831 1 r
.51476 .80573 m
.51445 .80745 L
s
.021 0 1 r
.44084 .60103 m
.44974 .59217 L
s
0 1 .941 r
.5843 .5758 m
.58656 .57717 L
s
1 0 0 r
.36675 .66004 m
.37482 .6408 L
s
.113 0 1 r
.36689 .60427 m
.37506 .59375 L
s
1 0 .551 r
.36489 .58003 m
.36144 .57811 L
s
.36537 .57518 m
.36489 .58003 L
s
.466 0 1 r
.51516 .20853 m
.51562 .20671 L
s
.51562 .20671 m
.51892 .20719 L
s
.23 0 1 r
.4455 .26431 m
.4455 .26563 L
s
.44296 .26264 m
.4455 .26431 L
s
.44604 .26184 m
.4455 .26431 L
s
.463 1 0 r
.44126 .45982 m
.44222 .45938 L
s
.44222 .45938 m
.44247 .45891 L
s
.44222 .45938 m
.4413 .45843 L
s
1 0 .433 r
.36796 .31332 m
.36739 .3128 L
s
.36739 .3128 m
.37059 .30954 L
s
0 .831 1 r
.51445 .80745 m
.51597 .80881 L
s
1 0 .551 r
.36144 .57811 m
.36537 .57518 L
s
.466 0 1 r
.51626 .21428 m
.52869 .22024 L
s
0 1 .286 r
.44216 .57034 m
.44716 .56525 L
s
.463 1 0 r
.44151 .45935 m
.44126 .45982 L
s
.4413 .45843 m
.44126 .45982 L
s
.44247 .45891 m
.4413 .45843 L
s
.4413 .45843 m
.44151 .45935 L
s
.44412 .46311 m
.4413 .45843 L
s
1 0 .907 r
.36819 .57358 m
.37681 .55983 L
s
.58 0 1 r
.59109 .60928 m
.58837 .6112 L
s
.59047 .6075 m
.59109 .60928 L
s
.59133 .61149 m
.59109 .60928 L
s
.938 0 1 r
.59593 .28308 m
.59303 .28482 L
s
.59613 .28096 m
.59593 .28308 L
s
.59678 .28531 m
.59593 .28308 L
s
.113 0 1 r
.37073 .37419 m
.37326 .3727 L
s
.37326 .3727 m
.37307 .37102 L
s
.37326 .3727 m
.37023 .37057 L
s
.23 0 1 r
.44296 .26396 m
.44296 .26264 L
s
.44296 .26264 m
.44604 .26184 L
s
.463 1 0 r
.44247 .45891 m
.44151 .45935 L
s
.466 0 1 r
.51726 .21081 m
.51516 .20853 L
s
.51892 .20719 m
.51726 .21081 L
s
1 0 .343 r
.36966 .33664 m
.36619 .33867 L
s
1 0 0 r
.37505 .6445 m
.37547 .64617 L
s
.37094 .64314 m
.37505 .6445 L
s
.37482 .6408 m
.37505 .6445 L
s
.58 0 1 r
.58837 .6112 m
.58775 .60942 L
s
.59133 .61149 m
.58837 .6112 L
s
.113 0 1 r
.37023 .37057 m
.37073 .37419 L
s
.37307 .37102 m
.37023 .37057 L
s
.37023 .37057 m
.37053 .37252 L
s
.3786 .38079 m
.37023 .37057 L
s
.58 0 1 r
.37469 .42961 m
.37486 .43372 L
s
.37712 .4306 m
.37469 .42961 L
s
.37469 .42961 m
.37409 .43212 L
s
.37789 .4322 m
.37469 .42961 L
s
.38122 .44238 m
.37469 .42961 L
s
.37486 .43372 m
.37789 .4322 L
s
.37789 .4322 m
.37712 .4306 L
s
0 .648 1 r
.4463 .4087 m
.44718 .41145 L
s
.44854 .4084 m
.4463 .4087 L
s
.4463 .4087 m
.44668 .40988 L
s
.44903 .40997 m
.4463 .4087 L
s
.45412 .41482 m
.4463 .4087 L
s
0 .627 1 r
.59577 .75306 m
.59563 .75158 L
s
.59563 .75158 m
.59365 .75041 L
s
.59563 .75158 m
.59321 .75337 L
s
.58 0 1 r
.37409 .43212 m
.37486 .43372 L
s
0 .648 1 r
.44718 .41145 m
.44903 .40997 L
s
.44903 .40997 m
.44854 .4084 L
s
.463 1 0 r
.44412 .53689 m
.44694 .53222 L
s
0 .6 1 r
.36988 .29096 m
.37691 .28167 L
s
.113 0 1 r
.37053 .37252 m
.37073 .37419 L
s
0 1 .941 r
.59284 .55582 m
.59787 .56412 L
s
.195 0 1 r
.37382 .62642 m
.37371 .62811 L
s
.37125 .62491 m
.37382 .62642 L
s
.37421 .6244 m
.37382 .62642 L
s
.938 0 1 r
.59303 .28482 m
.59323 .2827 L
s
.59678 .28531 m
.59303 .28482 L
s
.463 1 0 r
.44672 .53314 m
.44698 .5336 L
s
.44577 .5327 m
.44672 .53314 L
s
.44694 .53222 m
.44672 .53314 L
s
.466 0 1 r
.51516 .20853 m
.51892 .20719 L
s
1 0 .433 r
.37059 .30954 m
.37194 .3142 L
s
.36796 .31332 m
.37059 .30954 L
s
0 .627 1 r
.59321 .75337 m
.59577 .75306 L
s
.59365 .75041 m
.59321 .75337 L
s
.59321 .75337 m
.59379 .75188 L
s
.60072 .74516 m
.59321 .75337 L
s
0 .107 1 r
.37284 .40494 m
.37529 .40356 L
s
.37529 .40356 m
.37506 .40205 L
s
.37529 .40356 m
.37246 .40148 L
s
0 .998 1 r
.44583 .77525 m
.44764 .77406 L
s
.44764 .77406 m
.44765 .77316 L
s
.44764 .77406 m
.44546 .77256 L
s
0 .807 1 r
.59388 .52806 m
.59451 .53847 L
s
0 .648 1 r
.44668 .40988 m
.44718 .41145 L
s
1 0 0 r
.37135 .64481 m
.37094 .64314 L
s
.37094 .64314 m
.37482 .6408 L
s
0 .627 1 r
.59365 .75041 m
.59379 .75188 L
s
.463 1 0 r
.44602 .53316 m
.44577 .5327 L
s
.44577 .5327 m
.44694 .53222 L
s
0 .107 1 r
.37246 .40148 m
.37284 .40494 L
s
.37506 .40205 m
.37246 .40148 L
s
.37246 .40148 m
.3726 .40343 L
s
.37991 .41157 m
.37246 .40148 L
s
0 .998 1 r
.44546 .77256 m
.44583 .77525 L
s
.44765 .77316 m
.44546 .77256 L
s
.44546 .77256 m
.44584 .77435 L
s
.45186 .78083 m
.44546 .77256 L
s
.23 0 1 r
.4455 .26563 m
.44296 .26396 L
s
.44604 .26184 m
.4455 .26563 L
s
0 .103 1 r
.60104 .46689 m
.60015 .46804 L
s
.60365 .46806 m
.60104 .46689 L
s
.60104 .46689 m
.60105 .4704 L
s
.60105 .4704 m
.60276 .4692 L
s
.60105 .4704 m
.60015 .46804 L
s
.60365 .46806 m
.60105 .4704 L
s
.6053 .4586 m
.60105 .4704 L
s
1 .498 0 r
.52041 .82464 m
.5204 .82442 L
s
.5204 .82442 m
.5201 .82425 L
s
.5204 .82442 m
.52004 .82469 L
s
0 .479 1 r
.59422 .5866 m
.60171 .59552 L
s
0 1 .286 r
.44693 .56625 m
.44672 .56723 L
s
.44559 .56532 m
.44693 .56625 L
s
.44716 .56525 m
.44693 .56625 L
s
.195 0 1 r
.37114 .6266 m
.37125 .62491 L
s
.37125 .62491 m
.37421 .6244 L
s
1 .498 0 r
.52004 .82469 m
.52041 .82464 L
s
.5201 .82425 m
.52004 .82469 L
s
.52004 .82469 m
.52011 .82447 L
s
.52113 .82348 m
.52004 .82469 L
s
0 .107 1 r
.3726 .40343 m
.37284 .40494 L
s
1 .498 0 r
.5201 .82425 m
.52011 .82447 L
s
0 .998 1 r
.44584 .77435 m
.44583 .77525 L
s
.113 0 1 r
.37479 .59579 m
.37462 .5974 L
s
.37223 .59432 m
.37479 .59579 L
s
.37506 .59375 m
.37479 .59579 L
s
1 0 .433 r
.37194 .3142 m
.36796 .31332 L
s
.463 1 0 r
.44694 .53222 m
.44698 .5336 L
s
.44602 .53316 m
.44694 .53222 L
s
.23 0 1 r
.44296 .26396 m
.44604 .26184 L
s
.463 1 0 r
.44698 .5336 m
.44602 .53316 L
s
1 .498 0 r
.52011 .82447 m
.52041 .82464 L
s
1 0 .551 r
.60155 .37923 m
.60166 .37731 L
s
.60166 .37731 m
.59841 .37517 L
s
.60166 .37731 m
.59762 .38001 L
s
0 .103 1 r
.60276 .4692 m
.60365 .46806 L
s
0 1 .286 r
.44538 .5663 m
.44559 .56532 L
s
.44559 .56532 m
.44716 .56525 L
s
.58 0 1 r
.58775 .60942 m
.59047 .6075 L
s
.59047 .6075 m
.59133 .61149 L
s
.113 0 1 r
.37307 .37102 m
.37053 .37252 L
s
1 0 .551 r
.59762 .38001 m
.60155 .37923 L
s
.59841 .37517 m
.59762 .38001 L
s
.59762 .38001 m
.59829 .37709 L
s
.60947 .36593 m
.59762 .38001 L
s
1 .498 0 r
.52113 .17652 m
.52222 .17772 L
s
0 .648 1 r
.44854 .4084 m
.44668 .40988 L
s
.021 0 1 r
.4493 .59389 m
.44897 .59563 L
s
.44695 .59227 m
.4493 .59389 L
s
.44974 .59217 m
.4493 .59389 L
s
1 0 .907 r
.5956 .61739 m
.60652 .63009 L
s
.113 0 1 r
.37206 .59593 m
.37223 .59432 L
s
.37223 .59432 m
.37506 .59375 L
s
.908 0 1 r
.37426 .68338 m
.37725 .68149 L
s
.37725 .68149 m
.37722 .67991 L
s
.37725 .68149 m
.37369 .67898 L
s
0 .627 1 r
.59379 .75188 m
.59577 .75306 L
s
1 .498 0 r
.52215 .17751 m
.52185 .17768 L
s
.52216 .17728 m
.52215 .17751 L
s
.52222 .17772 m
.52215 .17751 L
s
.938 0 1 r
.59323 .2827 m
.59613 .28096 L
s
.59613 .28096 m
.59678 .28531 L
s
.58 0 1 r
.58775 .60942 m
.59133 .61149 L
s
1 .498 0 r
.52185 .17768 m
.52186 .17745 L
s
.52222 .17772 m
.52185 .17768 L
s
0 .998 1 r
.44765 .77316 m
.44584 .77435 L
s
1 0 .551 r
.59841 .37517 m
.59829 .37709 L
s
0 .6 1 r
.37657 .28366 m
.37651 .28473 L
s
.37448 .28234 m
.37657 .28366 L
s
.37691 .28167 m
.37657 .28366 L
s
0 1 .286 r
.44672 .56723 m
.44538 .5663 L
s
.44716 .56525 m
.44672 .56723 L
s
1 .498 0 r
.52186 .17745 m
.52216 .17728 L
s
.52216 .17728 m
.52222 .17772 L
s
.52186 .17745 m
.52222 .17772 L
s
0 .831 1 r
.52235 .19622 m
.53112 .2006 L
s
.938 0 1 r
.59323 .2827 m
.59678 .28531 L
s
.021 0 1 r
.44662 .59401 m
.44695 .59227 L
s
.44695 .59227 m
.44974 .59217 L
s
.58 0 1 r
.37712 .4306 m
.37409 .43212 L
s
.908 0 1 r
.37369 .67898 m
.37426 .68338 L
s
.37722 .67991 m
.37369 .67898 L
s
.37369 .67898 m
.37423 .6818 L
s
.38396 .69232 m
.37369 .67898 L
s
0 1 .286 r
.44538 .5663 m
.44716 .56525 L
s
.195 0 1 r
.37371 .62811 m
.37114 .6266 L
s
.37421 .6244 m
.37371 .62811 L
s
0 .107 1 r
.37506 .40205 m
.3726 .40343 L
s
0 .479 1 r
.60227 .43669 m
.60238 .43549 L
s
.60238 .43549 m
.60016 .43423 L
s
.60238 .43549 m
.59985 .43738 L
s
0 1 .941 r
.59794 .56243 m
.59603 .56344 L
s
.5977 .56147 m
.59794 .56243 L
s
.59787 .56412 m
.59794 .56243 L
s
.908 0 1 r
.37423 .6818 m
.37426 .68338 L
s
0 .6 1 r
.37443 .2834 m
.37448 .28234 L
s
.37448 .28234 m
.37691 .28167 L
s
.195 0 1 r
.37114 .6266 m
.37421 .6244 L
s
.466 0 1 r
.52748 .21926 m
.52537 .22123 L
s
.52703 .21686 m
.52748 .21926 L
s
.52869 .22024 m
.52748 .21926 L
s
1 0 0 r
.37482 .6408 m
.37547 .64617 L
s
.37135 .64481 m
.37482 .6408 L
s
0 .107 1 r
.60247 .40638 m
.60252 .40499 L
s
.60252 .40499 m
.60018 .40348 L
s
.60252 .40499 m
.59964 .40694 L
s
0 .479 1 r
.59985 .43738 m
.60227 .43669 L
s
.60016 .43423 m
.59985 .43738 L
s
.59985 .43738 m
.60005 .43542 L
s
.60669 .42773 m
.59985 .43738 L
s
0 1 .941 r
.59603 .56344 m
.59578 .56248 L
s
.59787 .56412 m
.59603 .56344 L
s
0 .103 1 r
.60015 .46804 m
.60276 .4692 L
s
.197 0 1 r
.52762 .77367 m
.52752 .77182 L
s
.52752 .77182 m
.52501 .77037 L
s
.52752 .77182 m
.52449 .77406 L
s
0 .807 1 r
.59422 .53715 m
.59272 .53639 L
s
.59605 .53638 m
.59422 .53715 L
s
.59451 .53847 m
.59422 .53715 L
s
0 .479 1 r
.60016 .43423 m
.60005 .43542 L
s
1 0 .907 r
.377 .56254 m
.37647 .56439 L
s
.37369 .56078 m
.377 .56254 L
s
.37681 .55983 m
.377 .56254 L
s
0 .107 1 r
.59964 .40694 m
.60247 .40638 L
s
.60018 .40348 m
.59964 .40694 L
s
.59964 .40694 m
.60013 .40487 L
s
.60808 .39684 m
.59964 .40694 L
s
1 0 0 r
.37547 .64617 m
.37135 .64481 L
s
.113 0 1 r
.37462 .5974 m
.37206 .59593 L
s
.37506 .59375 m
.37462 .5974 L
s
.197 0 1 r
.52449 .77406 m
.52762 .77367 L
s
.52501 .77037 m
.52449 .77406 L
s
.52449 .77406 m
.52511 .77222 L
s
.53364 .76383 m
.52449 .77406 L
s
0 .107 1 r
.60018 .40348 m
.60013 .40487 L
s
.113 0 1 r
.37206 .59593 m
.37506 .59375 L
s
1 0 .907 r
.37316 .56264 m
.37369 .56078 L
s
.37369 .56078 m
.37681 .55983 L
s
.021 0 1 r
.44897 .59563 m
.44662 .59401 L
s
.44974 .59217 m
.44897 .59563 L
s
.197 0 1 r
.52501 .77037 m
.52511 .77222 L
s
1 0 .551 r
.38007 .35742 m
.38342 .35539 L
s
.38342 .35539 m
.383 .35309 L
s
.38342 .35539 m
.37933 .35264 L
s
0 .479 1 r
.60135 .59368 m
.59923 .59507 L
s
.60118 .5924 m
.60135 .59368 L
s
.60171 .59552 m
.60135 .59368 L
s
0 .6 1 r
.37651 .28473 m
.37443 .2834 L
s
.37691 .28167 m
.37651 .28473 L
s
.466 0 1 r
.52537 .22123 m
.52492 .21882 L
s
.52869 .22024 m
.52537 .22123 L
s
0 1 .47 r
.52754 .43198 m
.52915 .43265 L
s
.52857 .43018 m
.52754 .43198 L
s
.52754 .43198 m
.52802 .43139 L
s
.5297 .43144 m
.52754 .43198 L
s
.53417 .42915 m
.52754 .43198 L
s
1 0 .551 r
.59829 .37709 m
.60155 .37923 L
s
0 .807 1 r
.59455 .53562 m
.59605 .53638 L
s
.59451 .53847 m
.59605 .53638 L
s
0 .6 1 r
.37443 .2834 m
.37691 .28167 L
s
0 1 .47 r
.52915 .43265 m
.5297 .43144 L
s
.5297 .43144 m
.52857 .43018 L
s
.021 0 1 r
.44662 .59401 m
.44974 .59217 L
s
1 0 .551 r
.37933 .35264 m
.38007 .35742 L
s
.383 .35309 m
.37933 .35264 L
s
.37933 .35264 m
.37965 .35512 L
s
.39039 .36575 m
.37933 .35264 L
s
0 1 .941 r
.59578 .56248 m
.5977 .56147 L
s
.5977 .56147 m
.59787 .56412 L
s
0 .807 1 r
.59272 .53639 m
.59455 .53562 L
s
.59272 .53639 m
.59451 .53847 L
s
1 0 .343 r
.3773 .64997 m
.38894 .63589 L
s
.908 0 1 r
.37722 .67991 m
.37423 .6818 L
s
0 .479 1 r
.59923 .59507 m
.59906 .59379 L
s
.60171 .59552 m
.59923 .59507 L
s
0 .998 1 r
.45186 .21917 m
.45827 .21088 L
s
0 1 .941 r
.59578 .56248 m
.59787 .56412 L
s
0 .627 1 r
.60072 .25484 m
.60826 .26309 L
s
0 .479 1 r
.60005 .43542 m
.60227 .43669 L
s
1 0 .551 r
.37965 .35512 m
.38007 .35742 L
s
0 1 .47 r
.52857 .43018 m
.52802 .43139 L
s
.466 0 1 r
.52492 .21882 m
.52703 .21686 L
s
.52703 .21686 m
.52869 .22024 L
s
0 .107 1 r
.60013 .40487 m
.60247 .40638 L
s
0 .831 1 r
.53027 .19989 m
.52875 .20127 L
s
.52997 .19818 m
.53027 .19989 L
s
.53112 .2006 m
.53027 .19989 L
s
.113 0 1 r
.3786 .61921 m
.38702 .60894 L
s
0 .807 1 r
.59455 .53562 m
.59451 .53847 L
s
.197 0 1 r
.52511 .77222 m
.52762 .77367 L
s
0 1 .47 r
.52802 .43139 m
.52915 .43265 L
s
.463 1 0 r
.454 .44461 m
.45478 .44395 L
s
.45478 .44395 m
.45478 .44325 L
s
.45478 .44395 m
.45356 .44332 L
s
0 .648 1 r
.45412 .58518 m
.46199 .57902 L
s
0 .479 1 r
.59906 .59379 m
.60118 .5924 L
s
.60118 .5924 m
.60171 .59552 L
s
.466 0 1 r
.52492 .21882 m
.52869 .22024 L
s
0 .831 1 r
.52875 .20127 m
.52846 .19955 L
s
.53112 .2006 m
.52875 .20127 L
s
0 .107 1 r
.37991 .58843 m
.38739 .57828 L
s
1 0 .907 r
.37647 .56439 m
.37316 .56264 L
s
.37681 .55983 m
.37647 .56439 L
s
.463 1 0 r
.45356 .44332 m
.454 .44461 L
s
.45478 .44325 m
.45356 .44332 L
s
.45356 .44332 m
.45401 .44391 L
s
.45772 .44637 m
.45356 .44332 L
s
.45401 .44391 m
.454 .44461 L
s
0 .479 1 r
.59906 .59379 m
.60171 .59552 L
s
1 0 .907 r
.37316 .56264 m
.37681 .55983 L
s
0 .998 1 r
.45789 .21269 m
.4579 .21358 L
s
.45607 .2115 m
.45789 .21269 L
s
.45827 .21088 m
.45789 .21269 L
s
1 0 .907 r
.60603 .62744 m
.60298 .62951 L
s
.60569 .62558 m
.60603 .62744 L
s
.60652 .63009 m
.60603 .62744 L
s
.463 1 0 r
.45478 .44325 m
.45401 .44391 L
s
.908 0 1 r
.60912 .70449 m
.60885 .70242 L
s
.60885 .70242 m
.60596 .70071 L
s
.60885 .70242 m
.60536 .70505 L
s
0 .627 1 r
.60766 .26158 m
.60568 .26276 L
s
.60781 .26011 m
.60766 .26158 L
s
.60826 .26309 m
.60766 .26158 L
s
0 .831 1 r
.52846 .19955 m
.52997 .19818 L
s
.52997 .19818 m
.53112 .2006 L
s
.58 0 1 r
.38122 .55762 m
.38779 .54477 L
s
1 0 .551 r
.383 .35309 m
.37965 .35512 L
s
0 .998 1 r
.45609 .21239 m
.45607 .2115 L
s
.45607 .2115 m
.45827 .21088 L
s
0 .103 1 r
.6053 .5414 m
.60957 .55326 L
s
.197 0 1 r
.45781 .75659 m
.46034 .75493 L
s
.46034 .75493 m
.46037 .75364 L
s
.46034 .75493 m
.45729 .75281 L
s
0 .107 1 r
.38432 .39048 m
.38672 .38903 L
s
.38672 .38903 m
.38646 .38743 L
s
.38672 .38903 m
.38381 .38704 L
s
1 0 .907 r
.60298 .62951 m
.60263 .62765 L
s
.60652 .63009 m
.60298 .62951 L
s
.908 0 1 r
.60536 .70505 m
.60912 .70449 L
s
.60596 .70071 m
.60536 .70505 L
s
.60536 .70505 m
.60623 .70278 L
s
.6163 .69276 m
.60536 .70505 L
s
0 .831 1 r
.52846 .19955 m
.53112 .2006 L
s
0 .627 1 r
.60568 .26276 m
.60583 .2613 L
s
.60826 .26309 m
.60568 .26276 L
s
0 .107 1 r
.38381 .38704 m
.38432 .39048 L
s
.38646 .38743 m
.38381 .38704 L
s
.38381 .38704 m
.38405 .38888 L
s
.3917 .39663 m
.38381 .38704 L
s
.908 0 1 r
.60596 .70071 m
.60623 .70278 L
s
.197 0 1 r
.45729 .75281 m
.45781 .75659 L
s
.46037 .75364 m
.45729 .75281 L
s
.45729 .75281 m
.45783 .7553 L
s
.4663 .76435 m
.45729 .75281 L
s
0 1 .47 r
.4593 .42652 m
.4603 .42827 L
s
.46087 .42577 m
.4593 .42652 L
s
.4593 .42652 m
.45972 .42699 L
s
.46146 .42705 m
.4593 .42652 L
s
.46578 .42903 m
.4593 .42652 L
s
0 .107 1 r
.38405 .38888 m
.38432 .39048 L
s
0 1 .47 r
.4603 .42827 m
.46146 .42705 L
s
.46146 .42705 m
.46087 .42577 L
s
.58 0 1 r
.6119 .45535 m
.61464 .45422 L
s
.6121 .45122 m
.6119 .45535 L
s
.6119 .45535 m
.61161 .45269 L
s
.61512 .45275 m
.6119 .45535 L
s
.61924 .44216 m
.6119 .45535 L
s
0 .479 1 r
.60669 .57227 m
.61355 .58196 L
s
.58 0 1 r
.61464 .45422 m
.61512 .45275 L
s
.61512 .45275 m
.6121 .45122 L
s
.463 1 0 r
.45772 .55363 m
.46189 .55058 L
s
.197 0 1 r
.45783 .7553 m
.45781 .75659 L
s
0 .998 1 r
.4579 .21358 m
.45609 .21239 L
s
.45827 .21088 m
.4579 .21358 L
s
.58 0 1 r
.6121 .45122 m
.61161 .45269 L
s
.113 0 1 r
.38669 .61092 m
.38651 .61258 L
s
.38416 .60941 m
.38669 .61092 L
s
.38702 .60894 m
.38669 .61092 L
s
0 .998 1 r
.45609 .21239 m
.45827 .21088 L
s
0 .103 1 r
.39068 .45039 m
.39326 .4492 L
s
.38958 .44916 m
.39068 .45039 L
s
.39069 .44686 m
.39068 .45039 L
s
.39216 .44797 m
.39069 .44686 L
s
.39069 .44686 m
.38958 .44916 L
s
.39326 .4492 m
.39069 .44686 L
s
.39434 .45846 m
.39069 .44686 L
s
1 0 .343 r
.38845 .63858 m
.38825 .6409 L
s
.38497 .63653 m
.38845 .63858 L
s
.38894 .63589 m
.38845 .63858 L
s
.908 0 1 r
.38396 .30768 m
.39429 .29427 L
s
0 1 .47 r
.45972 .42699 m
.4603 .42827 L
s
0 .627 1 r
.60583 .2613 m
.60781 .26011 L
s
.60781 .26011 m
.60826 .26309 L
s
0 .479 1 r
.38696 .42135 m
.38922 .42011 L
s
.38922 .42011 m
.38892 .41878 L
s
.38922 .42011 m
.38667 .4182 L
s
0 .107 1 r
.60808 .60316 m
.61656 .61331 L
s
0 .103 1 r
.39326 .4492 m
.39216 .44797 L
s
.197 0 1 r
.53364 .23617 m
.54283 .24644 L
s
0 .479 1 r
.38667 .4182 m
.38696 .42135 L
s
.38892 .41878 m
.38667 .4182 L
s
.38667 .4182 m
.38665 .42002 L
s
.39302 .42753 m
.38667 .4182 L
s
0 .627 1 r
.60583 .2613 m
.60826 .26309 L
s
0 .107 1 r
.38723 .58026 m
.38701 .58176 L
s
.38477 .57887 m
.38723 .58026 L
s
.38739 .57828 m
.38723 .58026 L
s
.463 1 0 r
.46144 .55118 m
.46144 .55187 L
s
.46067 .55051 m
.46144 .55118 L
s
.46189 .55058 m
.46144 .55118 L
s
.113 0 1 r
.38398 .61108 m
.38416 .60941 L
s
.38416 .60941 m
.38702 .60894 L
s
0 1 .47 r
.46087 .42577 m
.45972 .42699 L
s
0 .479 1 r
.38665 .42002 m
.38696 .42135 L
s
0 1 .47 r
.53417 .57085 m
.54082 .5737 L
s
1 0 .343 r
.61519 .36328 m
.61506 .36137 L
s
.61506 .36137 m
.61169 .35918 L
s
.61506 .36137 m
.61095 .36425 L
s
1 0 .907 r
.60263 .62765 m
.60569 .62558 L
s
.60569 .62558 m
.60652 .63009 L
s
.463 1 0 r
.46067 .55121 m
.46067 .55051 L
s
.46067 .55051 m
.46189 .55058 L
s
0 .107 1 r
.38646 .38743 m
.38405 .38888 L
s
1 0 .343 r
.38477 .63885 m
.38497 .63653 L
s
.38497 .63653 m
.38894 .63589 L
s
.908 0 1 r
.60623 .70278 m
.60912 .70449 L
s
0 .107 1 r
.38455 .58037 m
.38477 .57887 L
s
.38477 .57887 m
.38739 .57828 L
s
1 0 .551 r
.60947 .63407 m
.62141 .64826 L
s
0 .648 1 r
.46159 .58021 m
.4611 .58178 L
s
.45973 .57873 m
.46159 .58021 L
s
.46199 .57902 m
.46159 .58021 L
s
.197 0 1 r
.46037 .75364 m
.45783 .7553 L
s
.463 1 0 r
.46144 .55187 m
.46067 .55121 L
s
.46189 .55058 m
.46144 .55187 L
s
1 0 .343 r
.61095 .36425 m
.61519 .36328 L
s
.61169 .35918 m
.61095 .36425 L
s
.61095 .36425 m
.61182 .36109 L
s
.62344 .34912 m
.61095 .36425 L
s
1 0 .907 r
.60263 .62765 m
.60652 .63009 L
s
.463 1 0 r
.46067 .55121 m
.46189 .55058 L
s
0 .648 1 r
.53798 .42105 m
.5403 .42122 L
s
.53889 .41824 m
.53798 .42105 L
s
.53798 .42105 m
.53846 .41969 L
s
.54073 .41977 m
.53798 .42105 L
s
.54609 .41442 m
.53798 .42105 L
s
.5403 .42122 m
.54073 .41977 L
s
.54073 .41977 m
.53889 .41824 L
s
0 .107 1 r
.61538 .42102 m
.61537 .41969 L
s
.61537 .41969 m
.61297 .41825 L
s
.61537 .41969 m
.61256 .42175 L
s
0 .648 1 r
.45924 .5803 m
.45973 .57873 L
s
.45973 .57873 m
.46199 .57902 L
s
1 0 .343 r
.61169 .35918 m
.61182 .36109 L
s
0 .107 1 r
.61256 .42175 m
.61538 .42102 L
s
.61297 .41825 m
.61256 .42175 L
s
.61256 .42175 m
.61298 .41959 L
s
.62064 .41117 m
.61256 .42175 L
s
0 .103 1 r
.39216 .44797 m
.38958 .44916 L
s
.113 0 1 r
.38651 .61258 m
.38398 .61108 L
s
.38702 .60894 m
.38651 .61258 L
s
.58 0 1 r
.61161 .45269 m
.61464 .45422 L
s
.113 0 1 r
.61606 .39039 m
.61599 .38896 L
s
.61599 .38896 m
.61353 .38737 L
s
.61599 .38896 m
.61299 .39105 L
s
0 .479 1 r
.38892 .41878 m
.38665 .42002 L
s
0 .648 1 r
.53889 .41824 m
.53846 .41969 L
s
0 .107 1 r
.61297 .41825 m
.61298 .41959 L
s
0 .479 1 r
.61334 .57997 m
.61112 .58125 L
s
.61324 .57879 m
.61334 .57997 L
s
.61355 .58196 m
.61334 .57997 L
s
.113 0 1 r
.38398 .61108 m
.38702 .60894 L
s
0 .103 1 r
.60784 .55203 m
.60696 .5509 L
s
.61047 .55086 m
.60784 .55203 L
s
.60957 .55326 m
.60784 .55203 L
s
.113 0 1 r
.61299 .39105 m
.61606 .39039 L
s
.61353 .38737 m
.61299 .39105 L
s
.61299 .39105 m
.61359 .3888 L
s
.62204 .38016 m
.61299 .39105 L
s
0 .107 1 r
.38701 .58176 m
.38455 .58037 L
s
.38739 .57828 m
.38701 .58176 L
s
.58 0 1 r
.38837 .54732 m
.38761 .54891 L
s
.38532 .54579 m
.38837 .54732 L
s
.38779 .54477 m
.38837 .54732 L
s
0 .648 1 r
.4611 .58178 m
.45924 .5803 L
s
.46199 .57902 m
.4611 .58178 L
s
0 .479 1 r
.61112 .58125 m
.61102 .58006 L
s
.61355 .58196 m
.61112 .58125 L
s
.58 0 1 r
.38456 .54738 m
.38532 .54579 L
s
.38532 .54579 m
.38779 .54477 L
s
.113 0 1 r
.61353 .38737 m
.61359 .3888 L
s
0 .103 1 r
.60958 .54973 m
.61047 .55086 L
s
.60957 .55326 m
.61047 .55086 L
s
0 .107 1 r
.38455 .58037 m
.38739 .57828 L
s
.908 0 1 r
.39372 .29713 m
.39372 .29869 L
s
.39073 .29522 m
.39372 .29713 L
s
.39429 .29427 m
.39372 .29713 L
s
.197 0 1 r
.54219 .24457 m
.53968 .24604 L
s
.5423 .24273 m
.54219 .24457 L
s
.54283 .24644 m
.54219 .24457 L
s
1 0 .343 r
.38825 .6409 m
.38477 .63885 L
s
.38894 .63589 m
.38825 .6409 L
s
0 .648 1 r
.53846 .41969 m
.5403 .42122 L
s
.463 1 0 r
.53939 .44942 m
.53936 .44876 L
s
.53936 .44876 m
.5386 .44807 L
s
.53936 .44876 m
.53815 .44937 L
s
0 .107 1 r
.61604 .61121 m
.6137 .61273 L
s
.61601 .60983 m
.61604 .61121 L
s
.61656 .61331 m
.61604 .61121 L
s
1 0 .907 r
.39415 .37422 m
.39728 .37224 L
s
.39728 .37224 m
.39667 .37005 L
s
.39728 .37224 m
.39337 .36978 L
s
0 .648 1 r
.45924 .5803 m
.46199 .57902 L
s
.463 1 0 r
.53815 .44937 m
.53939 .44942 L
s
.5386 .44807 m
.53815 .44937 L
s
.53815 .44937 m
.53863 .44873 L
s
.54239 .44622 m
.53815 .44937 L
s
1 0 .907 r
.39337 .36978 m
.39415 .37422 L
s
.39667 .37005 m
.39337 .36978 L
s
.39337 .36978 m
.39354 .37203 L
s
.40358 .38159 m
.39337 .36978 L
s
1 0 .343 r
.38477 .63885 m
.38894 .63589 L
s
.463 1 0 r
.5386 .44807 m
.53863 .44873 L
s
0 1 .47 r
.54033 .5731 m
.5392 .57436 L
s
.53978 .57189 m
.54033 .5731 L
s
.54082 .5737 m
.54033 .5731 L
s
.197 0 1 r
.53968 .24604 m
.5398 .24419 L
s
.54283 .24644 m
.53968 .24604 L
s
1 0 .551 r
.39039 .63425 m
.40153 .62104 L
s
0 .107 1 r
.61298 .41959 m
.61538 .42102 L
s
.908 0 1 r
.39072 .29678 m
.39073 .29522 L
s
.39073 .29522 m
.39429 .29427 L
s
1 0 .343 r
.61182 .36109 m
.61519 .36328 L
s
0 .107 1 r
.6137 .61273 m
.61367 .61135 L
s
.61656 .61331 m
.6137 .61273 L
s
.463 1 0 r
.53863 .44873 m
.53939 .44942 L
s
1 0 .907 r
.39354 .37203 m
.39415 .37422 L
s
0 .627 1 r
.39195 .74041 m
.39401 .73907 L
s
.39401 .73907 m
.39397 .73802 L
s
.39401 .73907 m
.39153 .73737 L
s
0 1 .47 r
.46578 .57097 m
.47229 .56845 L
s
0 .479 1 r
.61102 .58006 m
.61324 .57879 L
s
.61324 .57879 m
.61355 .58196 L
s
0 1 .47 r
.5392 .57436 m
.53865 .57316 L
s
.54082 .5737 m
.5392 .57436 L
s
.113 0 1 r
.61359 .3888 m
.61606 .39039 L
s
0 .627 1 r
.39153 .73737 m
.39195 .74041 L
s
.39397 .73802 m
.39153 .73737 L
s
.39153 .73737 m
.39191 .73936 L
s
.39869 .74661 m
.39153 .73737 L
s
0 .479 1 r
.61102 .58006 m
.61355 .58196 L
s
.197 0 1 r
.4663 .23565 m
.47534 .22405 L
s
0 .103 1 r
.60696 .5509 m
.60958 .54973 L
s
.60696 .5509 m
.60957 .55326 L
s
0 .107 1 r
.3917 .60337 m
.39964 .59373 L
s
0 .998 1 r
.54409 .78955 m
.544 .7882 L
s
.544 .7882 m
.5422 .78716 L
s
.544 .7882 m
.54183 .78982 L
s
0 .627 1 r
.39191 .73936 m
.39195 .74041 L
s
0 1 .47 r
.53865 .57316 m
.53978 .57189 L
s
.53978 .57189 m
.54082 .5737 L
s
.908 0 1 r
.6163 .30724 m
.62731 .3196 L
s
0 .103 1 r
.60958 .54973 m
.60957 .55326 L
s
0 .998 1 r
.54183 .78982 m
.54409 .78955 L
s
.5422 .78716 m
.54183 .78982 L
s
.54183 .78982 m
.54229 .78851 L
s
.54843 .78249 m
.54183 .78982 L
s
.58 0 1 r
.38761 .54891 m
.38456 .54738 L
s
.38779 .54477 m
.38761 .54891 L
s
0 .998 1 r
.5422 .78716 m
.54229 .78851 L
s
.197 0 1 r
.5398 .24419 m
.5423 .24273 L
s
.5423 .24273 m
.54283 .24644 L
s
.463 1 0 r
.54239 .55378 m
.54665 .55693 L
s
.58 0 1 r
.38456 .54738 m
.38779 .54477 L
s
0 .479 1 r
.39302 .57247 m
.3994 .56309 L
s
0 1 .47 r
.53865 .57316 m
.54082 .5737 L
s
1 0 .551 r
.62069 .64528 m
.61743 .64745 L
s
.6206 .64338 m
.62069 .64528 L
s
.62141 .64826 m
.62069 .64528 L
s
0 .107 1 r
.61367 .61135 m
.61601 .60983 L
s
.61601 .60983 m
.61656 .61331 L
s
.197 0 1 r
.5398 .24419 m
.54283 .24644 L
s
.908 0 1 r
.39372 .29869 m
.39072 .29678 L
s
.39429 .29427 m
.39372 .29869 L
s
0 .831 1 r
.46991 .80301 m
.47145 .80139 L
s
.47145 .80139 m
.47111 .8001 L
s
.47145 .80139 m
.46878 .80039 L
s
0 .107 1 r
.61367 .61135 m
.61656 .61331 L
s
0 .627 1 r
.39397 .73802 m
.39191 .73936 L
s
0 .831 1 r
.46878 .80039 m
.46991 .80301 L
s
.47111 .8001 m
.46878 .80039 L
s
.46878 .80039 m
.46957 .80173 L
s
.47747 .80623 m
.46878 .80039 L
s
.908 0 1 r
.39072 .29678 m
.39429 .29427 L
s
1 0 .907 r
.39667 .37005 m
.39354 .37203 L
s
0 .103 1 r
.39434 .54154 m
.398 .52988 L
s
.463 1 0 r
.54616 .55629 m
.5454 .55698 L
s
.54619 .55563 m
.54616 .55629 L
s
.54665 .55693 m
.54616 .55629 L
s
0 .998 1 r
.54229 .78851 m
.54409 .78955 L
s
1 0 .551 r
.61743 .64745 m
.61733 .64555 L
s
.62141 .64826 m
.61743 .64745 L
s
.58 0 1 r
.61924 .55784 m
.62662 .57112 L
s
0 .831 1 r
.46957 .80173 m
.46991 .80301 L
s
.463 1 0 r
.5454 .55698 m
.54543 .55632 L
s
.54665 .55693 m
.5454 .55698 L
s
1 0 .907 r
.62717 .4388 m
.62735 .43711 L
s
.62735 .43711 m
.62409 .43532 L
s
.62735 .43711 m
.62372 .43992 L
s
0 .479 1 r
.39835 .40717 m
.40053 .40582 L
s
.40053 .40582 m
.40018 .40437 L
s
.40053 .40582 m
.39786 .40407 L
s
1 0 .907 r
.62372 .43992 m
.62717 .4388 L
s
.62409 .43532 m
.62372 .43992 L
s
.62372 .43992 m
.62389 .43701 L
s
.63328 .4256 m
.62372 .43992 L
s
0 .479 1 r
.39786 .40407 m
.39835 .40717 L
s
.40018 .40437 m
.39786 .40407 L
s
.39786 .40407 m
.398 .40572 L
s
.4049 .41259 m
.39786 .40407 L
s
.463 1 0 r
.54543 .55632 m
.54619 .55563 L
s
.54619 .55563 m
.54665 .55693 L
s
.466 0 1 r
.47283 .78471 m
.47497 .78241 L
s
.47497 .78241 m
.47446 .78056 L
s
.47497 .78241 m
.47118 .78106 L
s
.197 0 1 r
.47478 .22658 m
.47482 .22784 L
s
.47224 .2249 m
.47478 .22658 L
s
.47534 .22405 m
.47478 .22658 L
s
.463 1 0 r
.54543 .55632 m
.54665 .55693 L
s
1 0 .907 r
.62409 .43532 m
.62389 .43701 L
s
0 .107 1 r
.62064 .58883 m
.62875 .59946 L
s
0 1 .47 r
.47185 .56893 m
.47127 .57021 L
s
.47069 .5677 m
.47185 .56893 L
s
.47229 .56845 m
.47185 .56893 L
s
0 .831 1 r
.47111 .8001 m
.46957 .80173 L
s
.466 0 1 r
.47118 .78106 m
.47283 .78471 L
s
.47446 .78056 m
.47118 .78106 L
s
.47118 .78106 m
.47232 .78286 L
s
.48355 .78897 m
.47118 .78106 L
s
0 .479 1 r
.398 .40572 m
.39835 .40717 L
s
0 .648 1 r
.54609 .58558 m
.55425 .59224 L
s
0 .107 1 r
.39938 .5956 m
.39913 .59718 L
s
.39697 .59414 m
.39938 .5956 L
s
.39964 .59373 m
.39938 .5956 L
s
0 .807 1 r
.40498 .46421 m
.40672 .46339 L
s
.40335 .46339 m
.40498 .46421 L
s
.40499 .46133 m
.40498 .46421 L
s
.908 0 1 r
.6264 .31728 m
.62351 .31902 L
s
.6267 .31523 m
.6264 .31728 L
s
.62731 .3196 m
.6264 .31728 L
s
0 1 .47 r
.47012 .56898 m
.47069 .5677 L
s
.47069 .5677 m
.47229 .56845 L
s
.197 0 1 r
.47228 .22617 m
.47224 .2249 L
s
.47224 .2249 m
.47534 .22405 L
s
0 .807 1 r
.40509 .46258 m
.40499 .46133 L
s
.40499 .46133 m
.40335 .46339 L
s
.40672 .46339 m
.40499 .46133 L
s
.4052 .47166 m
.40499 .46133 L
s
.113 0 1 r
.62204 .61984 m
.63114 .63079 L
s
0 .479 1 r
.39941 .56493 m
.39911 .56625 L
s
.39714 .56368 m
.39941 .56493 L
s
.3994 .56309 m
.39941 .56493 L
s
1 0 .551 r
.40118 .62358 m
.40078 .62586 L
s
.39782 .62152 m
.40118 .62358 L
s
.40153 .62104 m
.40118 .62358 L
s
0 .107 1 r
.39672 .59572 m
.39697 .59414 L
s
.39697 .59414 m
.39964 .59373 L
s
.466 0 1 r
.47232 .78286 m
.47283 .78471 L
s
0 1 .47 r
.47127 .57021 m
.47012 .56898 L
s
.47229 .56845 m
.47127 .57021 L
s
1 0 .551 r
.61733 .64555 m
.6206 .64338 L
s
.6206 .64338 m
.62141 .64826 L
s
0 .6 1 r
.62647 .71931 m
.6263 .71785 L
s
.6263 .71785 m
.62428 .71666 L
s
.6263 .71785 m
.62386 .71968 L
s
0 .479 1 r
.39684 .565 m
.39714 .56368 L
s
.39714 .56368 m
.3994 .56309 L
s
0 1 .941 r
.40171 .43815 m
.40365 .43715 L
s
.40365 .43715 m
.40326 .43609 L
s
.40365 .43715 m
.40155 .4355 L
s
0 .627 1 r
.39869 .25339 m
.40587 .24412 L
s
0 1 .941 r
.40155 .4355 m
.40171 .43815 L
s
.40326 .43609 m
.40155 .4355 L
s
.40155 .4355 m
.40131 .43709 L
s
.40623 .44361 m
.40155 .4355 L
s
0 .998 1 r
.54843 .21751 m
.55505 .22486 L
s
0 .479 1 r
.40018 .40437 m
.398 .40572 L
s
.908 0 1 r
.62351 .31902 m
.6238 .31696 L
s
.62731 .3196 m
.62351 .31902 L
s
.021 0 1 r
.55347 .40699 m
.5537 .40542 L
s
.5537 .40542 m
.55137 .40373 L
s
.5537 .40542 m
.55057 .40726 L
s
1 0 .343 r
.62344 .65088 m
.63602 .6661 L
s
0 .807 1 r
.40672 .46339 m
.40509 .46258 L
s
0 1 .941 r
.40131 .43709 m
.40171 .43815 L
s
1 0 .551 r
.61733 .64555 m
.62141 .64826 L
s
.021 0 1 r
.55057 .40726 m
.55347 .40699 L
s
.55137 .40373 m
.55057 .40726 L
s
.55057 .40726 m
.55114 .4053 L
s
.55987 .39775 m
.55057 .40726 L
s
0 1 .47 r
.47012 .56898 m
.47229 .56845 L
s
0 .6 1 r
.62386 .71968 m
.62647 .71931 L
s
.62428 .71666 m
.62386 .71968 L
s
.62386 .71968 m
.62445 .71811 L
s
.63145 .71118 m
.62386 .71968 L
s
0 .807 1 r
.40509 .46258 m
.40335 .46339 L
s
1 0 .551 r
.39742 .6238 m
.39782 .62152 L
s
.39782 .62152 m
.40153 .62104 L
s
1 0 0 r
.63031 .35548 m
.62945 .35429 L
s
.62945 .35429 m
.62542 .35279 L
s
.62945 .35429 m
.62612 .35815 L
s
.113 0 1 r
.62886 .40487 m
.62876 .40346 L
s
.62876 .40346 m
.62626 .40191 L
s
.62876 .40346 m
.62578 .40561 L
s
.466 0 1 r
.47446 .78056 m
.47232 .78286 L
s
0 .6 1 r
.62428 .71666 m
.62445 .71811 L
s
.197 0 1 r
.47482 .22784 m
.47228 .22617 L
s
.47534 .22405 m
.47482 .22784 L
s
.021 0 1 r
.55137 .40373 m
.55114 .4053 L
s
1 0 .907 r
.62389 .43701 m
.62717 .4388 L
s
.113 0 1 r
.62578 .40561 m
.62886 .40487 L
s
.62626 .40191 m
.62578 .40561 L
s
.62578 .40561 m
.62637 .40332 L
s
.63469 .39449 m
.62578 .40561 L
s
0 .107 1 r
.39913 .59718 m
.39672 .59572 L
s
.39964 .59373 m
.39913 .59718 L
s
.197 0 1 r
.47228 .22617 m
.47534 .22405 L
s
0 .103 1 r
.39652 .53101 m
.39911 .5322 L
s
.39542 .53223 m
.39652 .53101 L
s
.39652 .53101 m
.398 .52988 L
s
.113 0 1 r
.62626 .40191 m
.62637 .40332 L
s
.195 0 1 r
.62995 .37392 m
.62978 .3725 L
s
.62978 .3725 m
.62728 .37088 L
s
.62978 .3725 m
.62675 .37466 L
s
1 0 0 r
.62542 .35279 m
.62627 .35398 L
s
.62542 .35279 m
.62612 .35815 L
s
0 .107 1 r
.39672 .59572 m
.39964 .59373 L
s
.62832 .59727 m
.62591 .59871 L
s
.62834 .59594 m
.62832 .59727 L
s
.62875 .59946 m
.62832 .59727 L
s
0 .479 1 r
.39911 .56625 m
.39684 .565 L
s
.3994 .56309 m
.39911 .56625 L
s
0 .103 1 r
.39911 .5322 m
.39801 .53342 L
s
.398 .52988 m
.39911 .5322 L
s
.938 0 1 r
.40307 .72087 m
.40608 .71891 L
s
.40608 .71891 m
.40604 .71734 L
s
.40608 .71891 m
.40245 .71641 L
s
0 1 .941 r
.40326 .43609 m
.40131 .43709 L
s
0 .479 1 r
.39684 .565 m
.3994 .56309 L
s
1 0 0 r
.62612 .35815 m
.63031 .35548 L
s
.62612 .35815 m
.62627 .35398 L
s
.63485 .33804 m
.62612 .35815 L
s
.195 0 1 r
.62675 .37466 m
.62995 .37392 L
s
.62728 .37088 m
.62675 .37466 L
s
.62675 .37466 m
.62745 .37231 L
s
.6361 .36335 m
.62675 .37466 L
s
0 .6 1 r
.62445 .71811 m
.62647 .71931 L
s
.908 0 1 r
.6238 .31696 m
.6267 .31523 L
s
.6267 .31523 m
.62731 .3196 L
s
0 .998 1 r
.55458 .22354 m
.55278 .22458 L
s
.55467 .2222 m
.55458 .22354 L
s
.55505 .22486 m
.55458 .22354 L
s
0 .107 1 r
.62591 .59871 m
.62594 .59739 L
s
.62875 .59946 m
.62591 .59871 L
s
0 1 .286 r
.5549 .43409 m
.55505 .43318 L
s
.55505 .43318 m
.55371 .43222 L
s
.55505 .43318 m
.55326 .43423 L
s
.58 0 1 r
.6269 .56841 m
.62386 .56995 L
s
.62643 .56696 m
.6269 .56841 L
s
.62662 .57112 m
.6269 .56841 L
s
.195 0 1 r
.62728 .37088 m
.62745 .37231 L
s
0 .627 1 r
.40547 .24613 m
.40545 .24717 L
s
.40341 .24478 m
.40547 .24613 L
s
.40587 .24412 m
.40547 .24613 L
s
0 1 .286 r
.55326 .43423 m
.5549 .43409 L
s
.55371 .43222 m
.55326 .43423 L
s
.55326 .43423 m
.55356 .43313 L
s
.55849 .42886 m
.55326 .43423 L
s
.908 0 1 r
.6238 .31696 m
.62731 .3196 L
s
.58 0 1 r
.62386 .56995 m
.62338 .5685 L
s
.62662 .57112 m
.62386 .56995 L
s
.021 0 1 r
.55114 .4053 m
.55347 .40699 L
s
.938 0 1 r
.40245 .71641 m
.40307 .72087 L
s
.40604 .71734 m
.40245 .71641 L
s
.40245 .71641 m
.40302 .71929 L
s
.413 .7299 m
.40245 .71641 L
s
.113 0 1 r
.63051 .6285 m
.62804 .6301 L
s
.63059 .62709 m
.63051 .6285 L
s
.63114 .63079 m
.63051 .6285 L
s
0 .831 1 r
.47747 .19377 m
.4862 .18791 L
s
1 .498 0 r
.47766 .82535 m
.47796 .82515 L
s
.47796 .82515 m
.47797 .825 L
s
.47796 .82515 m
.4776 .82489 L
s
0 .648 1 r
.55375 .59085 m
.55191 .5924 L
s
.55333 .58941 m
.55375 .59085 L
s
.55425 .59224 m
.55375 .59085 L
s
.58 0 1 r
.40793 .38761 m
.40873 .39155 L
s
.4107 .38763 m
.40793 .38761 L
s
.40793 .38761 m
.4079 .38952 L
s
.41152 .38967 m
.40793 .38761 L
s
.41686 .39755 m
.40793 .38761 L
s
1 .498 0 r
.4776 .82489 m
.47766 .82535 L
s
.47797 .825 m
.4776 .82489 L
s
.4776 .82489 m
.47766 .8252 L
s
.47868 .8263 m
.4776 .82489 L
s
.47766 .8252 m
.47766 .82535 L
s
0 1 .286 r
.55371 .43222 m
.55356 .43313 L
s
1 0 .551 r
.40078 .62586 m
.39742 .6238 L
s
.40153 .62104 m
.40078 .62586 L
s
0 .998 1 r
.55278 .22458 m
.55287 .22324 L
s
.55505 .22486 m
.55278 .22458 L
s
1 .498 0 r
.47797 .825 m
.47766 .8252 L
s
.58 0 1 r
.40873 .39155 m
.41152 .38967 L
s
.41152 .38967 m
.4107 .38763 L
s
.938 0 1 r
.40302 .71929 m
.40307 .72087 L
s
1 0 .433 r
.63415 .68938 m
.63315 .68825 L
s
.63315 .68825 m
.62924 .68751 L
s
.63315 .68825 m
.6307 .69235 L
s
0 .627 1 r
.40338 .24582 m
.40341 .24478 L
s
.40341 .24478 m
.40587 .24412 L
s
.113 0 1 r
.62637 .40332 m
.62886 .40487 L
s
1 0 .907 r
.40358 .61841 m
.41386 .60651 L
s
.23 0 1 r
.55766 .73994 m
.55753 .73808 L
s
.55753 .73808 m
.55501 .73659 L
s
.55753 .73808 m
.55445 .74034 L
s
0 .648 1 r
.55191 .5924 m
.55149 .59095 L
s
.55425 .59224 m
.55191 .5924 L
s
1 .498 0 r
.47868 .1737 m
.47977 .17229 L
s
1 0 .551 r
.39742 .6238 m
.40153 .62104 L
s
.113 0 1 r
.62804 .6301 m
.62812 .62869 L
s
.63114 .63079 m
.62804 .6301 L
s
.463 1 0 r
.55475 .46699 m
.55445 .46655 L
s
.55445 .46655 m
.55351 .46609 L
s
.55445 .46655 m
.55355 .46749 L
s
.58 0 1 r
.4079 .38952 m
.40873 .39155 L
s
0 1 .286 r
.55356 .43313 m
.5549 .43409 L
s
0 .103 1 r
.39801 .53342 m
.39542 .53223 L
s
.39542 .53223 m
.398 .52988 L
s
1 .498 0 r
.4797 .1726 m
.47971 .17275 L
s
.4794 .1724 m
.4797 .1726 L
s
.47977 .17229 m
.4797 .1726 L
s
.47941 .17255 m
.4794 .1724 L
s
.4794 .1724 m
.47977 .17229 L
s
.463 1 0 r
.55351 .46609 m
.55381 .46653 L
s
.55351 .46609 m
.55355 .46749 L
s
.23 0 1 r
.55445 .74034 m
.55766 .73994 L
s
.55501 .73659 m
.55445 .74034 L
s
.55445 .74034 m
.55514 .73844 L
s
.56389 .72994 m
.55445 .74034 L
s
.463 1 0 r
.55355 .46749 m
.55475 .46699 L
s
.55355 .46749 m
.55381 .46653 L
s
.55645 .46273 m
.55355 .46749 L
s
1 0 .433 r
.62924 .68751 m
.63024 .68863 L
s
.62924 .68751 m
.6307 .69235 L
s
0 .998 1 r
.55287 .22324 m
.55467 .2222 L
s
.55467 .2222 m
.55505 .22486 L
s
1 .498 0 r
.47971 .17275 m
.47941 .17255 L
s
.47977 .17229 m
.47971 .17275 L
s
0 .107 1 r
.62594 .59739 m
.62834 .59594 L
s
.62834 .59594 m
.62875 .59946 L
s
1 .498 0 r
.47941 .17255 m
.47977 .17229 L
s
.195 0 1 r
.62745 .37231 m
.62995 .37392 L
s
0 .479 1 r
.4049 .58741 m
.41198 .57884 L
s
0 .103 1 r
.398 .52988 m
.39801 .53342 L
s
.23 0 1 r
.55501 .73659 m
.55514 .73844 L
s
0 .998 1 r
.55287 .22324 m
.55505 .22486 L
s
0 .107 1 r
.62594 .59739 m
.62875 .59946 L
s
.463 1 0 r
.55381 .46653 m
.55475 .46699 L
s
0 .627 1 r
.40545 .24717 m
.40338 .24582 L
s
.40587 .24412 m
.40545 .24717 L
s
1 0 0 r
.62627 .35398 m
.63031 .35548 L
s
0 .648 1 r
.55149 .59095 m
.55333 .58941 L
s
.55333 .58941 m
.55425 .59224 L
s
.466 0 1 r
.4842 .79673 m
.4847 .79429 L
s
.4847 .79429 m
.48255 .79231 L
s
.4847 .79429 m
.48089 .79572 L
s
1 0 .343 r
.63511 .66289 m
.63173 .6651 L
s
.63527 .661 m
.63511 .66289 L
s
.63602 .6661 m
.63511 .66289 L
s
0 .807 1 r
.4052 .52834 m
.40541 .51795 L
s
0 .627 1 r
.40338 .24582 m
.40587 .24412 L
s
1 0 .433 r
.6307 .69235 m
.63415 .68938 L
s
.6307 .69235 m
.63024 .68863 L
s
.63569 .67279 m
.6307 .69235 L
s
.466 0 1 r
.48089 .79572 m
.4842 .79673 L
s
.48255 .79231 m
.48089 .79572 L
s
.48089 .79572 m
.48205 .79476 L
s
.49333 .78973 m
.48089 .79572 L
s
.938 0 1 r
.40604 .71734 m
.40302 .71929 L
s
0 1 .941 r
.40623 .55639 m
.41092 .54824 L
s
.113 0 1 r
.62812 .62869 m
.63059 .62709 L
s
.63059 .62709 m
.63114 .63079 L
s
0 .6 1 r
.63145 .28882 m
.63907 .29736 L
s
.463 1 0 r
.55645 .53727 m
.55936 .54204 L
s
0 .648 1 r
.55149 .59095 m
.55425 .59224 L
s
.58 0 1 r
.62338 .5685 m
.62643 .56696 L
s
.62643 .56696 m
.62662 .57112 L
s
.62338 .5685 m
.62662 .57112 L
s
.463 1 0 r
.5591 .54107 m
.55815 .54153 L
s
.5594 .54064 m
.5591 .54107 L
s
.55936 .54204 m
.5591 .54107 L
s
.113 0 1 r
.62812 .62869 m
.63114 .63079 L
s
.58 0 1 r
.4107 .38763 m
.4079 .38952 L
s
1 0 .343 r
.63173 .6651 m
.63189 .66321 L
s
.63602 .6661 m
.63173 .6651 L
s
0 .831 1 r
.48539 .18926 m
.48506 .19054 L
s
.48385 .18763 m
.48539 .18926 L
s
.4862 .18791 m
.48539 .18926 L
s
.466 0 1 r
.48255 .79231 m
.48205 .79476 L
s
.463 1 0 r
.55815 .54153 m
.55846 .5411 L
s
.55936 .54204 m
.55815 .54153 L
s
.23 0 1 r
.55514 .73844 m
.55766 .73994 L
s
1 0 .551 r
.64014 .42288 m
.6401 .42102 L
s
.6401 .42102 m
.63671 .41902 L
s
.6401 .42102 m
.63618 .42395 L
s
1 0 .907 r
.63328 .5744 m
.64291 .58882 L
s
.463 1 0 r
.5594 .54064 m
.55936 .54204 L
s
.55846 .5411 m
.55936 .54204 L
s
.55846 .5411 m
.5594 .54064 L
s
0 1 .286 r
.55849 .57114 m
.56374 .57653 L
s
.466 0 1 r
.48355 .21103 m
.49602 .20307 L
s
1 0 .551 r
.63618 .42395 m
.64014 .42288 L
s
.63671 .41902 m
.63618 .42395 L
s
.63618 .42395 m
.63674 .42088 L
s
.64743 .40891 m
.63618 .42395 L
s
0 .831 1 r
.48351 .18891 m
.48385 .18763 L
s
.48385 .18763 m
.4862 .18791 L
s
1 0 .433 r
.63024 .68863 m
.63415 .68938 L
s
.466 0 1 r
.48205 .79476 m
.4842 .79673 L
s
1 0 .551 r
.63671 .41902 m
.63674 .42088 L
s
.113 0 1 r
.63469 .60551 m
.64365 .6167 L
s
0 1 .941 r
.4124 .42191 m
.41288 .42448 L
s
.41424 .42203 m
.4124 .42191 L
s
.4124 .42191 m
.41243 .42322 L
s
.41469 .42329 m
.4124 .42191 L
s
.4182 .42867 m
.4124 .42191 L
s
1 0 0 r
.63485 .66196 m
.64361 .68215 L
s
0 1 .941 r
.41288 .42448 m
.41469 .42329 L
s
.41469 .42329 m
.41424 .42203 L
s
.021 0 1 r
.55987 .60225 m
.56924 .61181 L
s
0 .807 1 r
.40532 .51923 m
.40706 .52003 L
s
.40368 .52004 m
.40532 .51923 L
s
.40532 .51923 m
.40541 .51795 L
s
0 .831 1 r
.48506 .19054 m
.48351 .18891 L
s
.4862 .18791 m
.48506 .19054 L
s
0 .6 1 r
.63847 .29577 m
.63645 .29698 L
s
.63865 .29432 m
.63847 .29577 L
s
.63907 .29736 m
.63847 .29577 L
s
0 .479 1 r
.41183 .58051 m
.41148 .58197 L
s
.40964 .57915 m
.41183 .58051 L
s
.41198 .57884 m
.41183 .58051 L
s
0 1 .941 r
.41243 .42322 m
.41288 .42448 L
s
1 0 .433 r
.63569 .32721 m
.6407 .34681 L
s
.64115 .34304 m
.63723 .3438 L
s
.64217 .34197 m
.64115 .34304 L
s
.6407 .34681 m
.64115 .34304 L
s
0 1 .941 r
.41115 .54985 m
.41076 .55091 L
s
.4092 .54884 m
.41115 .54985 L
s
.41092 .54824 m
.41115 .54985 L
s
.195 0 1 r
.6361 .63665 m
.64551 .64801 L
s
1 0 .343 r
.63189 .66321 m
.63527 .661 L
s
.63527 .661 m
.63602 .6661 L
s
0 1 .941 r
.40881 .54989 m
.4092 .54884 L
s
.4092 .54884 m
.41092 .54824 L
s
0 .479 1 r
.40929 .58061 m
.40964 .57915 L
s
.40964 .57915 m
.41198 .57884 L
s
0 .831 1 r
.48351 .18891 m
.4862 .18791 L
s
0 .6 1 r
.63645 .29698 m
.63662 .29553 L
s
.63907 .29736 m
.63645 .29698 L
s
.505 0 1 r
.5668 .3918 m
.56689 .39013 L
s
.56689 .39013 m
.56423 .38829 L
s
.56689 .39013 m
.56346 .39231 L
s
1 0 .343 r
.63189 .66321 m
.63602 .6661 L
s
1 0 .907 r
.41366 .60881 m
.41307 .61099 L
s
.41052 .6068 m
.41366 .60881 L
s
.41386 .60651 m
.41366 .60881 L
s
1 0 .433 r
.63723 .3438 m
.63824 .34273 L
s
.6407 .34681 m
.63723 .3438 L
s
0 .807 1 r
.40706 .52003 m
.40543 .52084 L
s
.40541 .51795 m
.40706 .52003 L
s
0 1 .286 r
.56343 .57542 m
.56209 .57638 L
s
.56328 .57451 m
.56343 .57542 L
s
.56374 .57653 m
.56343 .57542 L
s
.505 0 1 r
.56346 .39231 m
.5668 .3918 L
s
.56423 .38829 m
.56346 .39231 L
s
.56346 .39231 m
.56414 .38996 L
s
.57376 .38095 m
.56346 .39231 L
s
0 1 .224 r
.41628 .45654 m
.41766 .45586 L
s
.41766 .45586 m
.418 .45515 L
s
.41766 .45586 m
.41627 .45452 L
s
1 0 0 r
.64344 .67791 m
.6394 .67944 L
s
.64432 .67677 m
.64344 .67791 L
s
.64361 .68215 m
.64344 .67791 L
s
0 .807 1 r
.40543 .52084 m
.40368 .52004 L
s
.40368 .52004 m
.40541 .51795 L
s
0 1 .941 r
.41424 .42203 m
.41243 .42322 L
s
0 1 .286 r
.56209 .57638 m
.56194 .57548 L
s
.56374 .57653 m
.56209 .57638 L
s
.195 0 1 r
.64265 .38826 m
.64247 .38681 L
s
.64247 .38681 m
.63996 .38519 L
s
.64247 .38681 m
.63943 .38898 L
s
.505 0 1 r
.56423 .38829 m
.56414 .38996 L
s
1 0 .907 r
.40992 .60898 m
.41052 .6068 L
s
.41052 .6068 m
.41386 .60651 L
s
.938 0 1 r
.413 .2701 m
.42361 .25653 L
s
0 1 .224 r
.41627 .45452 m
.41628 .45654 L
s
.418 .45515 m
.41627 .45452 L
s
.41627 .45452 m
.41662 .45583 L
s
.42062 .46117 m
.41627 .45452 L
s
.41662 .45583 m
.41628 .45654 L
s
1 0 .551 r
.63674 .42088 m
.64014 .42288 L
s
0 .6 1 r
.63662 .29553 m
.63865 .29432 L
s
.63865 .29432 m
.63907 .29736 L
s
0 .479 1 r
.41148 .58197 m
.40929 .58061 L
s
.41198 .57884 m
.41148 .58197 L
s
0 1 .941 r
.41076 .55091 m
.40881 .54989 L
s
.41092 .54824 m
.41076 .55091 L
s
.23 0 1 r
.56389 .27006 m
.57337 .28052 L
s
.195 0 1 r
.63943 .38898 m
.64265 .38826 L
s
.63996 .38519 m
.63943 .38898 L
s
.63943 .38898 m
.64015 .38664 L
s
.64885 .37768 m
.63943 .38898 L
s
0 .6 1 r
.63662 .29553 m
.63907 .29736 L
s
0 .807 1 r
.40541 .51795 m
.40543 .52084 L
s
0 1 .941 r
.40881 .54989 m
.41092 .54824 L
s
1 0 0 r
.6394 .67944 m
.64027 .6783 L
s
.64361 .68215 m
.6394 .67944 L
s
0 1 .286 r
.56194 .57548 m
.56328 .57451 L
s
.56328 .57451 m
.56374 .57653 L
s
0 .479 1 r
.40929 .58061 m
.41198 .57884 L
s
.195 0 1 r
.63996 .38519 m
.64015 .38664 L
s
.113 0 1 r
.64304 .61437 m
.64054 .61594 L
s
.64316 .61297 m
.64304 .61437 L
s
.64365 .6167 m
.64304 .61437 L
s
0 1 .224 r
.418 .45515 m
.41662 .45583 L
s
0 1 .881 r
.56798 .41915 m
.56802 .41808 L
s
.56802 .41808 m
.56631 .41692 L
s
.56802 .41808 m
.56584 .4195 L
s
0 1 .286 r
.56194 .57548 m
.56374 .57653 L
s
.361 0 1 r
.64494 .35633 m
.64436 .35545 L
s
.64436 .35545 m
.64141 .35434 L
s
.64436 .35545 m
.64189 .35826 L
s
0 1 .881 r
.56584 .4195 m
.56798 .41915 L
s
.56631 .41692 m
.56584 .4195 L
s
.56584 .4195 m
.56627 .418 L
s
.57236 .41218 m
.56584 .4195 L
s
0 1 .286 r
.56841 .4495 m
.56844 .44877 L
s
.56844 .44877 m
.56694 .44801 L
s
.56844 .44877 m
.56685 .45009 L
s
1 0 .433 r
.64217 .34197 m
.6407 .34681 L
s
.63824 .34273 m
.6407 .34681 L
s
0 .831 1 r
.49304 .81315 m
.49337 .81141 L
s
.49337 .81141 m
.49182 .81003 L
s
.49337 .81141 m
.49068 .81247 L
s
1 0 .907 r
.64271 .58586 m
.63942 .58767 L
s
.64254 .58419 m
.64271 .58586 L
s
.64291 .58882 m
.64271 .58586 L
s
0 1 .881 r
.56631 .41692 m
.56627 .418 L
s
0 1 .286 r
.56685 .45009 m
.56841 .4495 L
s
.56694 .44801 m
.56685 .45009 L
s
.56685 .45009 m
.56691 .44874 L
s
.57097 .44339 m
.56685 .45009 L
s
.466 0 1 r
.49484 .2049 m
.49435 .20675 L
s
.49269 .20259 m
.49484 .2049 L
s
.49602 .20307 m
.49484 .2049 L
s
0 1 .286 r
.56694 .44801 m
.56691 .44874 L
s
.195 0 1 r
.64478 .64562 m
.64228 .64725 L
s
.64497 .64421 m
.64478 .64562 L
s
.64551 .64801 m
.64478 .64562 L
s
0 .831 1 r
.49068 .81247 m
.49304 .81315 L
s
.49182 .81003 m
.49068 .81247 L
s
.49068 .81247 m
.4915 .81177 L
s
.49947 .80806 m
.49068 .81247 L
s
.113 0 1 r
.64054 .61594 m
.64066 .61454 L
s
.64365 .6167 m
.64054 .61594 L
s
.505 0 1 r
.56414 .38996 m
.5668 .3918 L
s
.361 0 1 r
.64141 .35434 m
.64199 .35522 L
s
.64141 .35434 m
.64189 .35826 L
s
.021 0 1 r
.56864 .60982 m
.5663 .61153 L
s
.56842 .60826 m
.56864 .60982 L
s
.56924 .61181 m
.56864 .60982 L
s
0 .103 1 r
.42283 .4066 m
.42368 .40981 L
s
.42493 .40619 m
.42283 .4066 L
s
.42283 .4066 m
.42264 .40795 L
s
.42597 .40804 m
.42283 .4066 L
s
.43024 .41362 m
.42283 .4066 L
s
0 1 .224 r
.42062 .53883 m
.42498 .53217 L
s
1 0 .907 r
.63942 .58767 m
.63925 .586 L
s
.64291 .58882 m
.63942 .58767 L
s
0 1 .47 r
.56904 .47903 m
.56869 .47943 L
s
.57082 .47944 m
.56904 .47903 L
s
.56904 .47903 m
.56942 .48118 L
s
.361 0 1 r
.64189 .35826 m
.64494 .35633 L
s
.64189 .35826 m
.64199 .35522 L
s
.64831 .34363 m
.64189 .35826 L
s
1 0 .433 r
.63824 .34273 m
.64217 .34197 L
s
1 0 .907 r
.41307 .61099 m
.40992 .60898 L
s
.41386 .60651 m
.41307 .61099 L
s
0 1 .47 r
.57048 .47984 m
.57082 .47944 L
s
.57082 .47944 m
.56942 .48118 L
s
0 .831 1 r
.49182 .81003 m
.4915 .81177 L
s
.195 0 1 r
.64015 .38664 m
.64265 .38826 L
s
.64228 .64725 m
.64246 .64584 L
s
.64551 .64801 m
.64228 .64725 L
s
0 1 .224 r
.42463 .53349 m
.42497 .53421 L
s
.42325 .53281 m
.42463 .53349 L
s
.42498 .53217 m
.42463 .53349 L
s
0 .103 1 r
.42368 .40981 m
.42597 .40804 L
s
.42597 .40804 m
.42493 .40619 L
s
.58 0 1 r
.41686 .60245 m
.42586 .59243 L
s
0 1 .47 r
.56942 .48118 m
.57048 .47984 L
s
.56942 .48118 m
.56869 .47943 L
s
.57112 .47245 m
.56942 .48118 L
s
.021 0 1 r
.5663 .61153 m
.56608 .60997 L
s
.56924 .61181 m
.5663 .61153 L
s
0 1 .881 r
.56627 .418 m
.56798 .41915 L
s
0 1 .286 r
.56691 .44874 m
.56841 .4495 L
s
.466 0 1 r
.4922 .20443 m
.49269 .20259 L
s
.49269 .20259 m
.49602 .20307 L
s
1 0 .907 r
.40992 .60898 m
.41386 .60651 L
s
0 .103 1 r
.42264 .40795 m
.42368 .40981 L
s
1 0 0 r
.64432 .67677 m
.64361 .68215 L
s
.64027 .6783 m
.64361 .68215 L
s
0 .831 1 r
.4915 .81177 m
.49304 .81315 L
s
0 1 .224 r
.42359 .53352 m
.42325 .53281 L
s
.42325 .53281 m
.42498 .53217 L
s
.466 0 1 r
.49333 .21027 m
.50586 .21629 L
s
.23 0 1 r
.57266 .27859 m
.57014 .2801 L
s
.57281 .27674 m
.57266 .27859 L
s
.57337 .28052 m
.57266 .27859 L
s
0 1 .941 r
.4182 .57133 m
.42402 .56454 L
s
.113 0 1 r
.64066 .61454 m
.64316 .61297 L
s
.64316 .61297 m
.64365 .6167 L
s
.938 0 1 r
.423 .25946 m
.42298 .26102 L
s
.41998 .25749 m
.423 .25946 L
s
.42361 .25653 m
.423 .25946 L
s
1 0 0 r
.64027 .6783 m
.64432 .67677 L
s
.113 0 1 r
.64066 .61454 m
.64365 .6167 L
s
0 1 .47 r
.56869 .47943 m
.57048 .47984 L
s
0 .067 1 r
.64922 .69261 m
.64853 .69183 L
s
.64853 .69183 m
.64574 .69131 L
s
.64853 .69183 m
.64679 .69474 L
s
0 1 .224 r
.42497 .53421 m
.42359 .53352 L
s
.42498 .53217 m
.42497 .53421 L
s
.42359 .53352 m
.42498 .53217 L
s
.466 0 1 r
.49435 .20675 m
.4922 .20443 L
s
.49602 .20307 m
.49435 .20675 L
s
.361 0 1 r
.64199 .35522 m
.64494 .35633 L
s
.021 0 1 r
.56608 .60997 m
.56842 .60826 L
s
.56842 .60826 m
.56924 .61181 L
s
.195 0 1 r
.64246 .64584 m
.64497 .64421 L
s
.64497 .64421 m
.64551 .64801 L
s
.23 0 1 r
.57014 .2801 m
.57028 .27825 L
s
.57337 .28052 m
.57014 .2801 L
s
0 .067 1 r
.64574 .69131 m
.64642 .6921 L
s
.64574 .69131 m
.64679 .69474 L
s
0 .103 1 r
.42493 .40619 m
.42264 .40795 L
s
.195 0 1 r
.64246 .64584 m
.64551 .64801 L
s
.938 0 1 r
.41996 .25904 m
.41998 .25749 L
s
.41998 .25749 m
.42361 .25653 L
s
0 .652 1 r
.4212 .77847 m
.42325 .77713 L
s
.42325 .77713 m
.42325 .77611 L
s
.42325 .77713 m
.42079 .77542 L
s
1 0 .907 r
.63925 .586 m
.64254 .58419 L
s
.64254 .58419 m
.64291 .58882 L
s
.021 0 1 r
.56608 .60997 m
.56924 .61181 L
s
0 1 .286 r
.57097 .55661 m
.57511 .56333 L
s
0 1 .47 r
.57112 .52755 m
.57282 .53629 L
s
1 0 .907 r
.63925 .586 m
.64291 .58882 L
s
.466 0 1 r
.4922 .20443 m
.49602 .20307 L
s
0 .652 1 r
.42079 .77542 m
.4212 .77847 L
s
.42325 .77611 m
.42079 .77542 L
s
.42079 .77542 m
.42119 .77746 L
s
.42796 .78478 m
.42079 .77542 L
s
0 .98 1 r
.57445 .75578 m
.57434 .75444 L
s
.57434 .75444 m
.57253 .75337 L
s
.57434 .75444 m
.57214 .75606 L
s
0 .067 1 r
.64679 .69474 m
.64922 .69261 L
s
.64679 .69474 m
.64642 .6921 L
s
.65023 .68084 m
.64679 .69474 L
s
1 0 .343 r
.65345 .40644 m
.65323 .40448 L
s
.65323 .40448 m
.64982 .40232 L
s
.65323 .40448 m
.64913 .40744 L
s
0 .652 1 r
.42119 .77746 m
.4212 .77847 L
s
1 0 .551 r
.64743 .59109 m
.65876 .60624 L
s
0 .98 1 r
.57214 .75606 m
.57445 .75578 L
s
.57253 .75337 m
.57214 .75606 L
s
.57214 .75606 m
.57264 .75471 L
s
.57892 .74861 m
.57214 .75606 L
s
1 .498 0 r
.49752 .82921 m
.49751 .82898 L
s
.49751 .82898 m
.49721 .8288 L
s
.49751 .82898 m
.49715 .82925 L
s
0 1 .881 r
.57236 .58782 m
.57891 .59516 L
s
1 .498 0 r
.49715 .82925 m
.49752 .82921 L
s
.49721 .8288 m
.49715 .82925 L
s
.49715 .82925 m
.49722 .82904 L
s
.49824 .82803 m
.49715 .82925 L
s
0 1 .47 r
.57176 .53494 m
.57141 .53455 L
s
.57355 .53453 m
.57176 .53494 L
s
.57282 .53629 m
.57176 .53494 L
s
1 .498 0 r
.49721 .8288 m
.49722 .82904 L
s
0 .98 1 r
.57253 .75337 m
.57264 .75471 L
s
.23 0 1 r
.57028 .27825 m
.57281 .27674 L
s
.57281 .27674 m
.57337 .28052 L
s
1 .498 0 r
.49722 .82904 m
.49752 .82921 L
s
1 0 .343 r
.64913 .40744 m
.65345 .40644 L
s
.64982 .40232 m
.64913 .40744 L
s
.64913 .40744 m
.65003 .40429 L
s
.66168 .3921 m
.64913 .40744 L
s
0 1 .47 r
.57321 .53413 m
.57355 .53453 L
s
.57282 .53629 m
.57355 .53453 L
s
.361 0 1 r
.64831 .65637 m
.65475 .67104 L
s
.23 0 1 r
.57028 .27825 m
.57337 .28052 L
s
.195 0 1 r
.64885 .62232 m
.65832 .63368 L
s
1 .498 0 r
.49824 .17197 m
.49934 .17319 L
s
1 0 .343 r
.64982 .40232 m
.65003 .40429 L
s
.938 0 1 r
.42298 .26102 m
.41996 .25904 L
s
.42361 .25653 m
.42298 .26102 L
s
.505 0 1 r
.57376 .61905 m
.58411 .63047 L
s
0 1 .286 r
.57504 .56196 m
.57354 .56273 L
s
.57502 .56124 m
.57504 .56196 L
s
.57511 .56333 m
.57504 .56196 L
s
0 .067 1 r
.64642 .6921 m
.64922 .69261 L
s
0 .652 1 r
.42325 .77611 m
.42119 .77746 L
s
1 .498 0 r
.49927 .17298 m
.49897 .17315 L
s
.49928 .17274 m
.49927 .17298 L
s
.49934 .17319 m
.49927 .17298 L
s
0 1 .941 r
.42398 .56587 m
.42354 .56713 L
s
.42216 .56468 m
.42398 .56587 L
s
.42402 .56454 m
.42398 .56587 L
s
0 1 .286 r
.57354 .56273 m
.57351 .562 L
s
.57511 .56333 m
.57354 .56273 L
s
1 .498 0 r
.49897 .17315 m
.49898 .17292 L
s
.49934 .17319 m
.49897 .17315 L
s
.938 0 1 r
.41996 .25904 m
.42361 .25653 L
s
0 .98 1 r
.57264 .75471 m
.57445 .75578 L
s
1 .498 0 r
.49898 .17292 m
.49928 .17274 L
s
.49928 .17274 m
.49934 .17319 L
s
.49898 .17292 m
.49934 .17319 L
s
0 1 .47 r
.57321 .53413 m
.57282 .53629 L
s
.57141 .53455 m
.57282 .53629 L
s
0 .831 1 r
.49947 .19194 m
.50831 .19638 L
s
0 .067 1 r
.65023 .31916 m
.65368 .33309 L
s
0 1 .941 r
.42172 .56593 m
.42216 .56468 L
s
.42216 .56468 m
.42402 .56454 L
s
0 .067 1 r
.65404 .33042 m
.65124 .33095 L
s
.65473 .32966 m
.65404 .33042 L
s
.65368 .33309 m
.65404 .33042 L
s
.361 0 1 r
.65464 .66797 m
.65168 .66909 L
s
.65524 .66712 m
.65464 .66797 L
s
.65475 .67104 m
.65464 .66797 L
s
0 1 .224 r
.42878 .44162 m
.42994 .44067 L
s
.42994 .44067 m
.42998 .43968 L
s
.42994 .44067 m
.42819 .4397 L
s
.82 0 1 r
.58044 .37598 m
.5804 .37426 L
s
.5804 .37426 m
.57752 .37233 L
s
.5804 .37426 m
.5768 .37668 L
s
0 1 .47 r
.57141 .53455 m
.57321 .53413 L
s
.466 0 1 r
.50466 .21531 m
.50252 .2173 L
s
.50418 .21287 m
.50466 .21531 L
s
.50586 .21629 m
.50466 .21531 L
s
0 .067 1 r
.65124 .33095 m
.65194 .33018 L
s
.65368 .33309 m
.65124 .33095 L
s
0 1 .224 r
.42819 .4397 m
.42878 .44162 L
s
.42998 .43968 m
.42819 .4397 L
s
.42819 .4397 m
.42881 .44062 L
s
.43413 .44443 m
.42819 .4397 L
s
0 .648 1 r
.5808 .46748 m
.58092 .46657 L
s
.58092 .46657 m
.5786 .46563 L
s
.58092 .46657 m
.57874 .46869 L
s
.82 0 1 r
.5768 .37668 m
.58044 .37598 L
s
.57752 .37233 m
.5768 .37668 L
s
.5768 .37668 m
.57756 .37405 L
s
.58774 .36403 m
.5768 .37668 L
s
.197 0 1 r
.50478 .77753 m
.5047 .77565 L
s
.5047 .77565 m
.50215 .77418 L
s
.5047 .77565 m
.50162 .77792 L
s
0 .648 1 r
.5786 .46563 m
.57847 .46654 L
s
.5786 .46563 m
.57874 .46869 L
s
0 1 .286 r
.57351 .562 m
.57502 .56124 L
s
.57502 .56124 m
.57511 .56333 L
s
.57351 .562 m
.57511 .56333 L
s
0 1 .881 r
.57847 .59364 m
.57676 .5948 L
s
.57844 .59257 m
.57847 .59364 L
s
.57891 .59516 m
.57847 .59364 L
s
.361 0 1 r
.65168 .66909 m
.65228 .66824 L
s
.65475 .67104 m
.65168 .66909 L
s
0 1 .224 r
.42881 .44062 m
.42878 .44162 L
s
0 .648 1 r
.57874 .46869 m
.5808 .46748 L
s
.57874 .46869 m
.57847 .46654 L
s
.58354 .45802 m
.57874 .46869 L
s
.58 0 1 r
.42587 .59438 m
.42505 .59641 L
s
.42306 .59247 m
.42587 .59438 L
s
.42586 .59243 m
.42587 .59438 L
s
.82 0 1 r
.57752 .37233 m
.57756 .37405 L
s
0 1 .941 r
.42354 .56713 m
.42172 .56593 L
s
.42402 .56454 m
.42354 .56713 L
s
.197 0 1 r
.50162 .77792 m
.50478 .77753 L
s
.50215 .77418 m
.50162 .77792 L
s
.50162 .77792 m
.50223 .77606 L
s
.51085 .76756 m
.50162 .77792 L
s
.361 0 1 r
.65654 .37129 m
.65678 .36936 L
s
.65678 .36936 m
.65469 .36723 L
s
.65678 .36936 m
.65312 .37084 L
s
0 1 .881 r
.57676 .5948 m
.57673 .59373 L
s
.57891 .59516 m
.57676 .5948 L
s
0 1 .224 r
.42998 .43968 m
.42881 .44062 L
s
1 0 .343 r
.65003 .40429 m
.65345 .40644 L
s
.58 0 1 r
.42224 .59451 m
.42306 .59247 L
s
.42306 .59247 m
.42586 .59243 L
s
.197 0 1 r
.50215 .77418 m
.50223 .77606 L
s
.361 0 1 r
.65312 .37084 m
.65654 .37129 L
s
.65469 .36723 m
.65312 .37084 L
s
.65312 .37084 m
.65444 .36916 L
s
.66562 .36293 m
.65312 .37084 L
s
0 1 .941 r
.42172 .56593 m
.42402 .56454 L
s
1 0 0 r
.65836 .3898 m
.65869 .38711 L
s
.65869 .38711 m
.65584 .38419 L
s
.65869 .38711 m
.65364 .38912 L
s
0 1 .881 r
.58116 .4342 m
.5811 .43323 L
s
.5811 .43323 m
.57929 .43219 L
s
.5811 .43323 m
.57905 .43481 L
s
0 .728 1 r
.58142 .40348 m
.58139 .4023 L
s
.58139 .4023 m
.57943 .40101 L
s
.58139 .4023 m
.57895 .40396 L
s
.466 0 1 r
.50252 .2173 m
.50203 .21486 L
s
.50586 .21629 m
.50252 .2173 L
s
0 .067 1 r
.65473 .32966 m
.65368 .33309 L
s
.65194 .33018 m
.65368 .33309 L
s
0 1 .881 r
.57905 .43481 m
.58116 .4342 L
s
.57929 .43219 m
.57905 .43481 L
s
.57905 .43481 m
.57934 .43316 L
s
.58494 .42671 m
.57905 .43481 L
s
1 0 0 r
.65364 .38912 m
.65836 .3898 L
s
.65584 .38419 m
.65364 .38912 L
s
.65364 .38912 m
.65551 .38687 L
s
.671 .37845 m
.65364 .38912 L
s
0 .807 1 r
.43507 .42391 m
.43601 .42619 L
s
.43654 .42291 m
.43507 .42391 L
s
.43507 .42391 m
.43483 .42452 L
s
.43771 .42458 m
.43507 .42391 L
s
.44112 .42708 m
.43507 .42391 L
s
.195 0 1 r
.65757 .63131 m
.65507 .63293 L
s
.65778 .62987 m
.65757 .63131 L
s
.65832 .63368 m
.65757 .63131 L
s
0 .728 1 r
.57895 .40396 m
.58142 .40348 L
s
.57943 .40101 m
.57895 .40396 L
s
.57895 .40396 m
.57946 .40219 L
s
.58634 .39539 m
.57895 .40396 L
s
0 1 .881 r
.57929 .43219 m
.57934 .43316 L
s
0 .652 1 r
.42796 .21522 m
.43516 .20582 L
s
0 .98 1 r
.57892 .25139 m
.58573 .25887 L
s
0 .728 1 r
.57943 .40101 m
.57946 .40219 L
s
0 1 .881 r
.57673 .59373 m
.57844 .59257 L
s
.57844 .59257 m
.57891 .59516 L
s
.361 0 1 r
.65469 .36723 m
.65444 .36916 L
s
0 .067 1 r
.65194 .33018 m
.65473 .32966 L
s
1 0 .551 r
.65816 .60311 m
.65475 .60513 L
s
.65822 .60128 m
.65816 .60311 L
s
.65876 .60624 m
.65816 .60311 L
s
.361 0 1 r
.65524 .66712 m
.65475 .67104 L
s
.65228 .66824 m
.65475 .67104 L
s
0 .648 1 r
.57847 .46654 m
.5808 .46748 L
s
0 1 .881 r
.57673 .59373 m
.57891 .59516 L
s
.466 0 1 r
.50203 .21486 m
.50418 .21287 L
s
.50418 .21287 m
.50586 .21629 L
s
.195 0 1 r
.65507 .63293 m
.65527 .6315 L
s
.65832 .63368 m
.65507 .63293 L
s
0 .807 1 r
.43601 .42619 m
.43771 .42458 L
s
.43771 .42458 m
.43654 .42291 L
s
.361 0 1 r
.65228 .66824 m
.65524 .66712 L
s
0 .831 1 r
.50747 .19566 m
.50593 .19706 L
s
.50716 .19392 m
.50747 .19566 L
s
.50831 .19638 m
.50747 .19566 L
s
.82 0 1 r
.57756 .37405 m
.58044 .37598 L
s
.505 0 1 r
.5834 .62808 m
.58074 .62993 L
s
.58333 .62642 m
.5834 .62808 L
s
.58411 .63047 m
.5834 .62808 L
s
.197 0 1 r
.50223 .77606 m
.50478 .77753 L
s
0 1 .47 r
.50541 .43166 m
.50564 .43044 L
s
.50564 .43044 m
.50472 .42915 L
s
.50564 .43044 m
.50348 .43097 L
s
1 0 0 r
.65584 .38419 m
.65551 .38687 L
s
0 1 .224 r
.43413 .55557 m
.44009 .55083 L
s
0 .807 1 r
.43483 .42452 m
.43601 .42619 L
s
0 1 .881 r
.57934 .43316 m
.58116 .4342 L
s
1 0 .551 r
.65475 .60513 m
.65481 .6033 L
s
.65876 .60624 m
.65475 .60513 L
s
.58 0 1 r
.42505 .59641 m
.42224 .59451 L
s
.42586 .59243 m
.42505 .59641 L
s
.361 0 1 r
.65444 .36916 m
.65654 .37129 L
s
0 1 .47 r
.50348 .43097 m
.50541 .43166 L
s
.50472 .42915 m
.50348 .43097 L
s
.50348 .43097 m
.50448 .43037 L
s
.51138 .42815 m
.50348 .43097 L
s
0 .728 1 r
.57946 .40219 m
.58142 .40348 L
s
0 .103 1 r
.43024 .58638 m
.43772 .57929 L
s
.466 0 1 r
.50203 .21486 m
.50586 .21629 L
s
0 .831 1 r
.50593 .19706 m
.50561 .19532 L
s
.50831 .19638 m
.50593 .19706 L
s
.505 0 1 r
.58074 .62993 m
.58066 .62828 L
s
.58411 .63047 m
.58074 .62993 L
s
.58 0 1 r
.42224 .59451 m
.42586 .59243 L
s
.887 0 1 r
.43257 .75891 m
.43557 .75695 L
s
.43557 .75695 m
.43557 .75544 L
s
.43557 .75695 m
.43196 .75445 L
s
0 .807 1 r
.43654 .42291 m
.43483 .42452 L
s
0 1 .47 r
.50472 .42915 m
.50448 .43037 L
s
0 .98 1 r
.58521 .2575 m
.5834 .25857 L
s
.58533 .25617 m
.58521 .2575 L
s
.58573 .25887 m
.58521 .2575 L
s
0 1 .47 r
.50448 .43037 m
.50541 .43166 L
s
.195 0 1 r
.65527 .6315 m
.65778 .62987 L
s
.65778 .62987 m
.65832 .63368 L
s
0 .652 1 r
.43475 .20788 m
.43475 .20889 L
s
.43269 .20653 m
.43475 .20788 L
s
.43516 .20582 m
.43475 .20788 L
s
0 1 .224 r
.43946 .55176 m
.4395 .55275 L
s
.43829 .55081 m
.43946 .55176 L
s
.44009 .55083 m
.43946 .55176 L
s
0 .831 1 r
.50561 .19532 m
.50716 .19392 L
s
.50716 .19392 m
.50831 .19638 L
s
1 0 0 r
.65551 .38687 m
.65836 .3898 L
s
.887 0 1 r
.43196 .75445 m
.43257 .75891 L
s
.43557 .75544 m
.43196 .75445 L
s
.43196 .75445 m
.43256 .7574 L
s
.44251 .76809 m
.43196 .75445 L
s
.195 0 1 r
.65527 .6315 m
.65832 .63368 L
s
0 .98 1 r
.5834 .25857 m
.58352 .25724 L
s
.58573 .25887 m
.5834 .25857 L
s
0 .648 1 r
.58354 .54198 m
.58835 .55269 L
s
.887 0 1 r
.43256 .7574 m
.43257 .75891 L
s
0 .652 1 r
.43269 .20753 m
.43269 .20653 L
s
.43269 .20653 m
.43516 .20582 L
s
0 1 .224 r
.43833 .5518 m
.43829 .55081 L
s
.43829 .55081 m
.44009 .55083 L
s
0 .831 1 r
.50561 .19532 m
.50831 .19638 L
s
.225 0 1 r
.5884 .7057 m
.58821 .70389 L
s
.58821 .70389 m
.58567 .70239 L
s
.58821 .70389 m
.58514 .70618 L
s
.505 0 1 r
.58066 .62828 m
.58333 .62642 L
s
.58333 .62642 m
.58411 .63047 L
s
0 1 .224 r
.4395 .55275 m
.43833 .5518 L
s
.44009 .55083 m
.4395 .55275 L
s
1 0 .551 r
.65481 .6033 m
.65822 .60128 L
s
.65822 .60128 m
.65876 .60624 L
s
0 1 .881 r
.58494 .57329 m
.59085 .58141 L
s
.225 0 1 r
.58514 .70618 m
.5884 .7057 L
s
.58567 .70239 m
.58514 .70618 L
s
.58514 .70618 m
.58586 .7042 L
s
.59463 .69549 m
.58514 .70618 L
s
0 1 .224 r
.43833 .5518 m
.44009 .55083 L
s
0 .98 1 r
.58352 .25724 m
.58533 .25617 L
s
.58533 .25617 m
.58573 .25887 L
s
.505 0 1 r
.58066 .62828 m
.58411 .63047 L
s
1 0 .551 r
.65481 .6033 m
.65876 .60624 L
s
0 .98 1 r
.58352 .25724 m
.58573 .25887 L
s
.225 0 1 r
.58567 .70239 m
.58586 .7042 L
s
0 .652 1 r
.43475 .20889 m
.43269 .20753 L
s
.43516 .20582 m
.43475 .20889 L
s
1 0 .343 r
.66168 .6079 m
.67432 .62336 L
s
0 .728 1 r
.58634 .60461 m
.59376 .61322 L
s
0 .652 1 r
.43269 .20753 m
.43516 .20582 L
s
.197 0 1 r
.51085 .23244 m
.52012 .24286 L
s
.887 0 1 r
.43557 .75544 m
.43256 .7574 L
s
1 .098 0 r
.66249 .658 m
.66255 .65796 L
s
.66255 .65796 m
.66256 .65792 L
s
.66255 .65796 m
.66248 .6579 L
s
.66248 .6579 m
.66249 .658 L
s
.66256 .65792 m
.66248 .6579 L
s
.66248 .6579 m
.6625 .65796 L
s
.66271 .65819 m
.66248 .6579 L
s
.6625 .65796 m
.66249 .658 L
s
.66256 .65792 m
.6625 .65796 L
s
0 1 .47 r
.51138 .57185 m
.5193 .57468 L
s
1 0 .433 r
.6659 .37584 m
.66811 .37309 L
s
.66811 .37309 m
.66734 .37009 L
s
.66811 .37309 m
.66316 .37193 L
s
1 .098 0 r
.66271 .34181 m
.66294 .34153 L
s
.66292 .34159 m
.66293 .34162 L
s
.66286 .34155 m
.66292 .34159 L
s
.66294 .34153 m
.66292 .34159 L
s
.66287 .34158 m
.66286 .34155 L
s
.66286 .34155 m
.66294 .34153 L
s
.66293 .34162 m
.66287 .34158 L
s
.66294 .34153 m
.66293 .34162 L
s
.66287 .34158 m
.66294 .34153 L
s
1 0 .433 r
.66316 .37193 m
.6659 .37584 L
s
.66734 .37009 m
.66316 .37193 L
s
.66316 .37193 m
.66513 .37284 L
s
.68051 .37716 m
.66316 .37193 L
s
0 .648 1 r
.58861 .55052 m
.58628 .55146 L
s
.58849 .54962 m
.58861 .55052 L
s
.58835 .55269 m
.58861 .55052 L
s
.58628 .55146 m
.58616 .55057 L
s
.58835 .55269 m
.58628 .55146 L
s
.021 0 1 r
.59297 .45216 m
.59294 .45088 L
s
.59294 .45088 m
.5903 .44953 L
s
.59294 .45088 m
.59015 .45321 L
s
.82 0 1 r
.58774 .63597 m
.59876 .64869 L
s
0 1 .881 r
.59054 .57974 m
.58873 .58079 L
s
.5906 .57878 m
.59054 .57974 L
s
.59085 .58141 m
.59054 .57974 L
s
.021 0 1 r
.59015 .45321 m
.59297 .45216 L
s
.5903 .44953 m
.59015 .45321 L
s
.59015 .45321 m
.59033 .45081 L
s
.59759 .44134 m
.59015 .45321 L
s
.225 0 1 r
.58586 .7042 m
.5884 .7057 L
s
.021 0 1 r
.5903 .44953 m
.59033 .45081 L
s
0 1 .881 r
.58873 .58079 m
.58879 .57982 L
s
.59085 .58141 m
.58873 .58079 L
s
.987 0 1 r
.59438 .35963 m
.59422 .35792 L
s
.59422 .35792 m
.59123 .35595 L
s
.59422 .35792 m
.59056 .36049 L
s
.361 0 1 r
.66562 .63707 m
.6782 .64503 L
s
0 1 .47 r
.5183 .57408 m
.51737 .57537 L
s
.51807 .57286 m
.5183 .57408 L
s
.5193 .57468 m
.5183 .57408 L
s
1 0 .433 r
.66513 .37284 m
.6659 .37584 L
s
.987 0 1 r
.59056 .36049 m
.59438 .35963 L
s
.59123 .35595 m
.59056 .36049 L
s
.59056 .36049 m
.59139 .35767 L
s
.60183 .34699 m
.59056 .36049 L
s
0 .728 1 r
.59324 .61143 m
.59127 .61274 L
s
.59327 .61026 m
.59324 .61143 L
s
.59376 .61322 m
.59324 .61143 L
s
.463 1 0 r
.51704 .44872 m
.51722 .44805 L
s
.51722 .44805 m
.51635 .44735 L
s
.51722 .44805 m
.51595 .44868 L
s
.51595 .44868 m
.51704 .44872 L
s
.51635 .44735 m
.51595 .44868 L
s
.51595 .44868 m
.51617 .44802 L
s
.51967 .44546 m
.51595 .44868 L
s
1 .098 0 r
.66647 .65358 m
.66653 .65354 L
s
.66653 .65354 m
.66653 .6535 L
s
.66653 .65354 m
.66645 .65349 L
s
0 .648 1 r
.58849 .54962 m
.58835 .55269 L
s
.58616 .55057 m
.58835 .55269 L
s
1 .098 0 r
.66645 .65349 m
.66647 .65358 L
s
.66653 .6535 m
.66645 .65349 L
s
.66645 .65349 m
.66647 .65355 L
s
.66669 .65376 m
.66645 .65349 L
s
.66647 .65355 m
.66647 .65358 L
s
0 .728 1 r
.59446 .41835 m
.59436 .41722 L
s
.59436 .41722 m
.59234 .416 L
s
.59436 .41722 m
.592 .41898 L
s
1 .098 0 r
.66653 .6535 m
.66647 .65355 L
s
0 .648 1 r
.51653 .42005 m
.51649 .41859 L
s
.51649 .41859 m
.51487 .41702 L
s
.51649 .41859 m
.51378 .41987 L
s
.58616 .55057 m
.58849 .54962 L
s
.987 0 1 r
.59123 .35595 m
.59139 .35767 L
s
1 .098 0 r
.66669 .34624 m
.66693 .34596 L
s
.66691 .34602 m
.66692 .34605 L
s
.66685 .34598 m
.66691 .34602 L
s
.66693 .34596 m
.66691 .34602 L
s
.66686 .34601 m
.66685 .34598 L
s
.66685 .34598 m
.66693 .34596 L
s
.197 0 1 r
.51949 .24097 m
.51694 .24245 L
s
.51959 .23909 m
.51949 .24097 L
s
.52012 .24286 m
.51949 .24097 L
s
1 .098 0 r
.66692 .34605 m
.66686 .34601 L
s
.66693 .34596 m
.66692 .34605 L
s
.463 1 0 r
.51635 .44735 m
.51617 .44802 L
s
1 .098 0 r
.66686 .34601 m
.66693 .34596 L
s
0 1 .881 r
.58879 .57982 m
.5906 .57878 L
s
.5906 .57878 m
.59085 .58141 L
s
0 .103 1 r
.43789 .58067 m
.43686 .58253 L
s
.43559 .5789 m
.43789 .58067 L
s
.43772 .57929 m
.43789 .58067 L
s
0 .484 1 r
.59515 .38731 m
.59506 .38606 L
s
.59506 .38606 m
.59295 .38468 L
s
.59506 .38606 m
.59246 .38787 L
s
0 .728 1 r
.592 .41898 m
.59446 .41835 L
s
.59234 .416 m
.592 .41898 L
s
.592 .41898 m
.59243 .41712 L
s
.59901 .40991 m
.592 .41898 L
s
1 0 .433 r
.66734 .37009 m
.66513 .37284 L
s
0 1 .47 r
.51737 .57537 m
.51714 .57415 L
s
.5193 .57468 m
.51737 .57537 L
s
0 1 .881 r
.58879 .57982 m
.59085 .58141 L
s
0 .728 1 r
.59127 .61274 m
.59131 .61156 L
s
.59376 .61322 m
.59127 .61274 L
s
.59234 .416 m
.59243 .41712 L
s
0 .648 1 r
.51378 .41987 m
.51653 .42005 L
s
.51487 .41702 m
.51378 .41987 L
s
.51378 .41987 m
.51491 .41848 L
s
.5234 .41321 m
.51378 .41987 L
s
.021 0 1 r
.59033 .45081 m
.59297 .45216 L
s
0 .103 1 r
.43455 .58076 m
.43559 .5789 L
s
.43559 .5789 m
.43772 .57929 L
s
0 1 .47 r
.51714 .57415 m
.51807 .57286 L
s
.51807 .57286 m
.5193 .57468 L
s
.463 1 0 r
.51617 .44802 m
.51704 .44872 L
s
0 .484 1 r
.59246 .38787 m
.59515 .38731 L
s
.59295 .38468 m
.59246 .38787 L
s
.59246 .38787 m
.59303 .38592 L
s
.60042 .37846 m
.59246 .38787 L
s
.59295 .38468 m
.59303 .38592 L
s
1 .036 0 r
.66834 .3212 m
.66836 .32119 L
s
.66836 .32119 m
.66838 .32117 L
s
.66836 .32119 m
.66834 .32116 L
s
.197 0 1 r
.51694 .24245 m
.51703 .24057 L
s
.52012 .24286 m
.51694 .24245 L
s
1 .036 0 r
.66834 .32116 m
.66834 .3212 L
s
.66838 .32117 m
.66834 .32116 L
s
.66834 .32116 m
.66836 .32118 L
s
.66844 .32128 m
.66834 .32116 L
s
.66836 .32118 m
.66834 .3212 L
s
.66851 .67862 m
.66853 .67864 L
s
.66849 .67861 m
.66851 .67862 L
s
.66853 .6786 m
.66851 .67862 L
s
.66838 .32117 m
.66836 .32118 L
s
.66844 .67872 m
.66853 .6786 L
s
.66851 .67863 m
.66849 .67861 L
s
.66849 .67861 m
.66853 .6786 L
s
0 .648 1 r
.51487 .41702 m
.51491 .41848 L
s
1 .036 0 r
.66853 .67864 m
.66851 .67863 L
s
.66853 .6786 m
.66853 .67864 L
s
.66851 .67863 m
.66853 .6786 L
s
1 0 .343 r
.67337 .62014 m
.66995 .62231 L
s
.67362 .6182 m
.67337 .62014 L
s
.67432 .62336 m
.67337 .62014 L
s
0 .807 1 r
.44112 .57292 m
.44722 .56972 L
s
0 1 .47 r
.51714 .57415 m
.5193 .57468 L
s
0 .728 1 r
.59131 .61156 m
.59327 .61026 L
s
.59327 .61026 m
.59376 .61322 L
s
.82 0 1 r
.59796 .64601 m
.59508 .64796 L
s
.59802 .64431 m
.59796 .64601 L
s
.59876 .64869 m
.59796 .64601 L
s
0 .648 1 r
.51491 .41848 m
.51653 .42005 L
s
.887 0 1 r
.44251 .23191 m
.45312 .21819 L
s
0 .728 1 r
.59243 .41712 m
.59446 .41835 L
s
0 .998 1 r
.52138 .79364 m
.52131 .79228 L
s
.52131 .79228 m
.51948 .79123 L
s
.52131 .79228 m
.5191 .79392 L
s
.987 0 1 r
.59139 .35767 m
.59438 .35963 L
s
0 .728 1 r
.59131 .61156 m
.59376 .61322 L
s
0 .103 1 r
.43686 .58253 m
.43455 .58076 L
s
.43772 .57929 m
.43686 .58253 L
s
.225 0 1 r
.59463 .30451 m
.60417 .31526 L
s
1 0 .343 r
.66995 .62231 m
.6702 .62038 L
s
.67432 .62336 m
.66995 .62231 L
s
0 .998 1 r
.5191 .79392 m
.52138 .79364 L
s
.51948 .79123 m
.5191 .79392 L
s
.5191 .79392 m
.51955 .79259 L
s
.52576 .78649 m
.5191 .79392 L
s
0 .484 1 r
.59303 .38592 m
.59515 .38731 L
s
1 0 0 r
.671 .62155 m
.68851 .63232 L
s
0 .998 1 r
.51948 .79123 m
.51955 .79259 L
s
0 .479 1 r
.44533 .80683 m
.4471 .80501 L
s
.4471 .80501 m
.44671 .80358 L
s
.4471 .80501 m
.44409 .80387 L
s
0 .103 1 r
.43455 .58076 m
.43772 .57929 L
s
.197 0 1 r
.51703 .24057 m
.51959 .23909 L
s
.51959 .23909 m
.52012 .24286 L
s
.463 1 0 r
.51967 .55454 m
.52341 .55776 L
s
.82 0 1 r
.59508 .64796 m
.59513 .64626 L
s
.59876 .64869 m
.59508 .64796 L
s
0 .479 1 r
.44409 .80387 m
.44533 .80683 L
s
.44671 .80358 m
.44409 .80387 L
s
.44409 .80387 m
.44495 .8054 L
s
.45377 .81057 m
.44409 .80387 L
s
.197 0 1 r
.51703 .24057 m
.52012 .24286 L
s
1 0 .812 r
.44736 .78796 m
.44991 .78526 L
s
.44991 .78526 m
.4493 .7831 L
s
.44991 .78526 m
.44544 .78365 L
s
.361 0 1 r
.67684 .64332 m
.67474 .64547 L
s
.67661 .6414 m
.67684 .64332 L
s
.6782 .64503 m
.67684 .64332 L
s
0 .479 1 r
.44495 .8054 m
.44533 .80683 L
s
1 0 .812 r
.44544 .78365 m
.44736 .78796 L
s
.4493 .7831 m
.44544 .78365 L
s
.44544 .78365 m
.44674 .7858 L
s
.4599 .79307 m
.44544 .78365 L
s
0 .998 1 r
.51955 .79259 m
.52138 .79364 L
s
.021 0 1 r
.59759 .55866 m
.60508 .57059 L
s
.463 1 0 r
.52318 .5571 m
.52231 .5578 L
s
.52301 .55643 m
.52318 .5571 L
s
.52341 .55776 m
.52318 .5571 L
s
0 .479 1 r
.44671 .80358 m
.44495 .8054 L
s
0 .067 1 r
.67661 .35913 m
.67815 .35719 L
s
.67815 .35719 m
.67761 .35504 L
s
.67815 .35719 m
.67464 .35638 L
s
1 0 .343 r
.6702 .62038 m
.67362 .6182 L
s
.67362 .6182 m
.67432 .62336 L
s
.82 0 1 r
.59513 .64626 m
.59802 .64431 L
s
.59802 .64431 m
.59876 .64869 L
s
0 .067 1 r
.67464 .35638 m
.67661 .35913 L
s
.67761 .35504 m
.67464 .35638 L
s
.67464 .35638 m
.67607 .35699 L
s
.68702 .35994 m
.67464 .35638 L
s
.463 1 0 r
.52231 .5578 m
.52214 .55713 L
s
.52341 .55776 m
.52231 .5578 L
s
.361 0 1 r
.67474 .64547 m
.67451 .64355 L
s
.6782 .64503 m
.67474 .64547 L
s
0 .728 1 r
.59901 .59009 m
.60604 .59919 L
s
1 0 .812 r
.44674 .7858 m
.44736 .78796 L
s
0 .648 1 r
.5234 .58679 m
.53307 .59347 L
s
.225 0 1 r
.60343 .31325 m
.60089 .31476 L
s
.60364 .31145 m
.60343 .31325 L
s
.60417 .31526 m
.60343 .31325 L
s
1 0 .343 r
.6702 .62038 m
.67432 .62336 L
s
.82 0 1 r
.59513 .64626 m
.59876 .64869 L
s
.887 0 1 r
.45249 .22119 m
.45251 .22268 L
s
.44948 .21921 m
.45249 .22119 L
s
.45312 .21819 m
.45249 .22119 L
s
.463 1 0 r
.52214 .55713 m
.52301 .55643 L
s
.52301 .55643 m
.52341 .55776 L
s
.52214 .55713 m
.52341 .55776 L
s
0 .484 1 r
.60042 .62154 m
.60841 .63099 L
s
.505 0 1 r
.60591 .43641 m
.60579 .4349 L
s
.60579 .4349 m
.60293 .43329 L
s
.60579 .4349 m
.60259 .43742 L
s
0 .067 1 r
.67607 .35699 m
.67661 .35913 L
s
.361 0 1 r
.67451 .64355 m
.67661 .6414 L
s
.67661 .6414 m
.6782 .64503 L
s
.225 0 1 r
.60089 .31476 m
.60109 .31296 L
s
.60417 .31526 m
.60089 .31476 L
s
1 0 .812 r
.4493 .7831 m
.44674 .7858 L
s
.887 0 1 r
.44949 .2207 m
.44948 .21921 L
s
.44948 .21921 m
.45312 .21819 L
s
.505 0 1 r
.60259 .43742 m
.60591 .43641 L
s
.60293 .43329 m
.60259 .43742 L
s
.60259 .43742 m
.60304 .4348 L
s
.61176 .42454 m
.60259 .43742 L
s
0 .998 1 r
.52576 .21351 m
.53243 .22096 L
s
0 .067 1 r
.67761 .35504 m
.67607 .35699 L
s
.505 0 1 r
.60293 .43329 m
.60304 .4348 L
s
.987 0 1 r
.60183 .65301 m
.61317 .66659 L
s
0 .97 1 r
.60541 .72152 m
.60527 .7202 L
s
.60527 .7202 m
.60344 .71912 L
s
.60527 .7202 m
.60306 .72185 L
s
.361 0 1 r
.67451 .64355 m
.6782 .64503 L
s
.021 0 1 r
.60488 .56815 m
.60223 .56951 L
s
.60492 .56688 m
.60488 .56815 L
s
.60508 .57059 m
.60488 .56815 L
s
0 .648 1 r
.53191 .59207 m
.53029 .59365 L
s
.53197 .59061 m
.53191 .59207 L
s
.53307 .59347 m
.53191 .59207 L
s
0 .728 1 r
.60559 .59731 m
.60356 .59854 L
s
.6057 .59619 m
.60559 .59731 L
s
.60604 .59919 m
.60559 .59731 L
s
0 .97 1 r
.60306 .72185 m
.60541 .72152 L
s
.60344 .71912 m
.60306 .72185 L
s
.60306 .72185 m
.60358 .72044 L
s
.60991 .71417 m
.60306 .72185 L
s
0 .807 1 r
.44744 .57033 m
.44626 .57201 L
s
.44573 .56871 m
.44744 .57033 L
s
.44722 .56972 m
.44744 .57033 L
s
.021 0 1 r
.60223 .56951 m
.60227 .56824 L
s
.60508 .57059 m
.60223 .56951 L
s
0 .97 1 r
.60344 .71912 m
.60358 .72044 L
s
.021 0 1 r
.53013 .40563 m
.52998 .40404 L
s
.52998 .40404 m
.52778 .40231 L
s
.52998 .40404 m
.52687 .40588 L
s
1 0 .749 r
.60914 .35117 m
.60845 .35008 L
s
.60845 .35008 m
.60487 .3487 L
s
.60845 .35008 m
.60543 .35348 L
s
.225 0 1 r
.60109 .31296 m
.60364 .31145 L
s
.60364 .31145 m
.60417 .31526 L
s
0 .728 1 r
.60356 .59854 m
.60367 .59742 L
s
.60604 .59919 m
.60356 .59854 L
s
0 .807 1 r
.44455 .57039 m
.44573 .56871 L
s
.44573 .56871 m
.44722 .56972 L
s
.225 0 1 r
.60109 .31296 m
.60417 .31526 L
s
0 .484 1 r
.6081 .40202 m
.60797 .4008 L
s
.60797 .4008 m
.60581 .39946 L
s
.60797 .4008 m
.60541 .40267 L
s
.887 0 1 r
.45251 .22268 m
.44949 .2207 L
s
.45312 .21819 m
.45251 .22268 L
s
1 0 .433 r
.68051 .62284 m
.69802 .61757 L
s
0 .648 1 r
.53029 .59365 m
.53035 .59219 L
s
.53307 .59347 m
.53029 .59365 L
s
.021 0 1 r
.52687 .40588 m
.53013 .40563 L
s
.52778 .40231 m
.52687 .40588 L
s
.52687 .40588 m
.52793 .4039 L
s
.5373 .3963 m
.52687 .40588 L
s
1 0 0 r
.68657 .63002 m
.68372 .63298 L
s
.68628 .62734 m
.68657 .63002 L
s
.68851 .63232 m
.68657 .63002 L
s
0 .484 1 r
.60782 .62901 m
.6057 .63041 L
s
.60792 .62778 m
.60782 .62901 L
s
.60841 .63099 m
.60782 .62901 L
s
1 0 .749 r
.60487 .3487 m
.60556 .34979 L
s
.60487 .3487 m
.60543 .35348 L
s
0 .998 1 r
.53197 .21962 m
.53014 .22067 L
s
.53205 .21825 m
.53197 .21962 L
s
.53243 .22096 m
.53197 .21962 L
s
0 .484 1 r
.60541 .40267 m
.6081 .40202 L
s
.60581 .39946 m
.60541 .40267 L
s
.60541 .40267 m
.60595 .40067 L
s
.61318 .39299 m
.60541 .40267 L
s
.887 0 1 r
.44949 .2207 m
.45312 .21819 L
s
.505 0 1 r
.60304 .4348 m
.60591 .43641 L
s
.021 0 1 r
.52778 .40231 m
.52793 .4039 L
s
0 .807 1 r
.44626 .57201 m
.44455 .57039 L
s
.44722 .56972 m
.44626 .57201 L
s
1 .65 0 r
.45365 .82967 m
.45405 .8294 L
s
.45405 .8294 m
.45405 .82921 L
s
.45405 .8294 m
.45356 .82907 L
s
0 .369 1 r
.60917 .37067 m
.60903 .36942 L
s
.60903 .36942 m
.60684 .36799 L
s
.60903 .36942 m
.60636 .37131 L
s
0 .97 1 r
.60358 .72044 m
.60541 .72152 L
s
0 .484 1 r
.60581 .39946 m
.60595 .40067 L
s
1 0 .749 r
.60543 .35348 m
.60914 .35117 L
s
.60543 .35348 m
.60556 .34979 L
s
.61333 .33574 m
.60543 .35348 L
s
1 .65 0 r
.45356 .82907 m
.45365 .82967 L
s
.45405 .82921 m
.45356 .82907 L
s
.45356 .82907 m
.45365 .82948 L
s
.45499 .83093 m
.45356 .82907 L
s
.45365 .82948 m
.45365 .82967 L
s
0 .479 1 r
.45377 .18943 m
.46349 .18269 L
s
0 .648 1 r
.53035 .59219 m
.53197 .59061 L
s
.53197 .59061 m
.53307 .59347 L
s
0 .484 1 r
.6057 .63041 m
.6058 .62918 L
s
.60841 .63099 m
.6057 .63041 L
s
1 .65 0 r
.45405 .82921 m
.45365 .82948 L
s
0 .998 1 r
.53014 .22067 m
.53022 .21931 L
s
.53243 .22096 m
.53014 .22067 L
s
0 .807 1 r
.44455 .57039 m
.44722 .56972 L
s
0 .728 1 r
.60367 .59742 m
.6057 .59619 L
s
.6057 .59619 m
.60604 .59919 L
s
0 .369 1 r
.60636 .37131 m
.60917 .37067 L
s
.60684 .36799 m
.60636 .37131 L
s
.60636 .37131 m
.60698 .36925 L
s
.6146 .36141 m
.60636 .37131 L
s
.463 1 0 r
.53246 .46652 m
.5325 .46608 L
s
.5325 .46608 m
.53144 .46562 L
s
.5325 .46608 m
.53147 .46704 L
s
0 1 .286 r
.53179 .43314 m
.53168 .43222 L
s
.53168 .43222 m
.53044 .43124 L
s
.53168 .43222 m
.52992 .43327 L
s
.463 1 0 r
.53144 .46562 m
.53139 .46606 L
s
.53144 .46562 m
.53147 .46704 L
s
.53147 .46704 m
.53246 .46652 L
s
.53147 .46704 m
.53139 .46606 L
s
.53385 .4622 m
.53147 .46704 L
s
0 .728 1 r
.60367 .59742 m
.60604 .59919 L
s
.021 0 1 r
.60227 .56824 m
.60492 .56688 L
s
.60492 .56688 m
.60508 .57059 L
s
0 .648 1 r
.53035 .59219 m
.53307 .59347 L
s
0 .369 1 r
.60684 .36799 m
.60698 .36925 L
s
1 0 .812 r
.45911 .80216 m
.45972 .79929 L
s
.45972 .79929 m
.45717 .79697 L
s
.45972 .79929 m
.45525 .80099 L
s
.021 0 1 r
.60227 .56824 m
.60508 .57059 L
s
.23 0 1 r
.53507 .74335 m
.53497 .74146 L
s
.53497 .74146 m
.5324 .73994 L
s
.53497 .74146 m
.53184 .74375 L
s
1 .65 0 r
.45499 .16907 m
.45642 .16721 L
s
0 1 .286 r
.52992 .43327 m
.53179 .43314 L
s
.53044 .43124 m
.52992 .43327 L
s
.52992 .43327 m
.53055 .43216 L
s
.5359 .42785 m
.52992 .43327 L
s
1 0 .812 r
.45525 .80099 m
.45911 .80216 L
s
.45717 .79697 m
.45525 .80099 L
s
.45525 .80099 m
.45655 .79985 L
s
.46976 .79386 m
.45525 .80099 L
s
.021 0 1 r
.52793 .4039 m
.53013 .40563 L
s
.824 0 1 r
.61295 .68984 m
.61216 .68887 L
s
.61216 .68887 m
.60869 .68822 L
s
.61216 .68887 m
.60997 .69247 L
s
0 1 .286 r
.53044 .43124 m
.53055 .43216 L
s
1 0 0 r
.68372 .63298 m
.68343 .6303 L
s
.68851 .63232 m
.68372 .63298 L
s
.987 0 1 r
.61231 .66372 m
.60931 .66571 L
s
.61249 .66203 m
.61231 .66372 L
s
.61317 .66659 m
.61231 .66372 L
s
1 .65 0 r
.45633 .16762 m
.45634 .16781 L
s
.45593 .16735 m
.45633 .16762 L
s
.45642 .16721 m
.45633 .16762 L
s
.23 0 1 r
.53184 .74375 m
.53507 .74335 L
s
.5324 .73994 m
.53184 .74375 L
s
.53184 .74375 m
.5325 .74183 L
s
.54134 .73321 m
.53184 .74375 L
s
0 .484 1 r
.60595 .40067 m
.6081 .40202 L
s
.463 1 0 r
.53139 .46606 m
.53246 .46652 L
s
1 .65 0 r
.45594 .16754 m
.45593 .16735 L
s
.45593 .16735 m
.45642 .16721 L
s
0 .998 1 r
.53022 .21931 m
.53205 .21825 L
s
.53205 .21825 m
.53243 .22096 L
s
1 .036 0 r
.68433 .66116 m
.68435 .66117 L
s
.68434 .66113 m
.68433 .66116 L
s
.68433 .66116 m
.68433 .66115 L
s
.68436 .66115 m
.68433 .66116 L
s
.68441 .66109 m
.68433 .66116 L
s
.68435 .66117 m
.68436 .66115 L
s
.68436 .66115 m
.68434 .66113 L
s
0 .484 1 r
.6058 .62918 m
.60792 .62778 L
s
.60792 .62778 m
.60841 .63099 L
s
1 .036 0 r
.68434 .66113 m
.68433 .66115 L
s
.68433 .66115 m
.68435 .66117 L
s
.68441 .33891 m
.6845 .33899 L
s
1 .65 0 r
.45634 .16781 m
.45594 .16754 L
s
.45642 .16721 m
.45634 .16781 L
s
.23 0 1 r
.5324 .73994 m
.5325 .74183 L
s
1 .036 0 r
.6845 .33898 m
.68447 .33899 L
s
.68449 .33896 m
.6845 .33898 L
s
.6845 .33899 m
.6845 .33898 L
s
0 .998 1 r
.53022 .21931 m
.53243 .22096 L
s
1 .036 0 r
.68447 .33899 m
.68447 .33897 L
s
.6845 .33899 m
.68447 .33899 L
s
1 .65 0 r
.45594 .16754 m
.45642 .16721 L
s
1 .036 0 r
.68447 .33897 m
.68449 .33896 L
s
.68449 .33896 m
.6845 .33899 L
s
.68447 .33897 m
.6845 .33899 L
s
0 1 .286 r
.53055 .43216 m
.53179 .43314 L
s
.824 0 1 r
.60869 .68822 m
.60948 .6892 L
s
.60869 .68822 m
.60997 .69247 L
s
0 .484 1 r
.6058 .62918 m
.60841 .63099 L
s
0 .369 1 r
.60698 .36925 m
.60917 .37067 L
s
1 0 .749 r
.60556 .34979 m
.60914 .35117 L
s
1 0 .812 r
.45717 .79697 m
.45655 .79985 L
s
.987 0 1 r
.60931 .66571 m
.60949 .66402 L
s
.61317 .66659 m
.60931 .66571 L
s
0 .97 1 r
.60991 .28583 m
.61678 .29353 L
s
.463 1 0 r
.53385 .5378 m
.53622 .54265 L
s
.824 0 1 r
.60997 .69247 m
.61295 .68984 L
s
.60997 .69247 m
.60948 .6892 L
s
.61419 .67525 m
.60997 .69247 L
s
1 0 0 r
.68343 .6303 m
.68628 .62734 L
s
.68628 .62734 m
.68851 .63232 L
s
.908 0 1 r
.68834 .39134 m
.69126 .38951 L
s
.69126 .38951 m
.69155 .3875 L
s
.69126 .38951 m
.68766 .38689 L
s
0 .067 1 r
.68702 .64006 m
.69948 .63649 L
s
.23 0 1 r
.5325 .74183 m
.53507 .74335 L
s
1 0 .812 r
.45655 .79985 m
.45911 .80216 L
s
.908 0 1 r
.68766 .38689 m
.68834 .39134 L
s
.69155 .3875 m
.68766 .38689 L
s
.68766 .38689 m
.68863 .38932 L
s
.69909 .39954 m
.68766 .38689 L
s
0 .479 1 r
.46262 .18424 m
.46224 .18567 L
s
.46085 .18241 m
.46262 .18424 L
s
.46349 .18269 m
.46262 .18424 L
s
.463 1 0 r
.5363 .54167 m
.53524 .54213 L
s
.53626 .54123 m
.5363 .54167 L
s
.53622 .54265 m
.5363 .54167 L
s
.505 0 1 r
.61176 .57546 m
.62098 .58841 L
s
.463 1 0 r
.53524 .54213 m
.53519 .54169 L
s
.53622 .54265 m
.53524 .54213 L
s
.908 0 1 r
.68863 .38932 m
.68834 .39134 L
s
0 1 .286 r
.5359 .57215 m
.5419 .57758 L
s
1 0 .812 r
.4599 .20693 m
.47447 .19743 L
s
1 0 0 r
.68343 .6303 m
.68851 .63232 L
s
.987 0 1 r
.60949 .66402 m
.61249 .66203 L
s
.61249 .66203 m
.61317 .66659 L
s
.824 0 1 r
.60948 .6892 m
.61295 .68984 L
s
0 .479 1 r
.46047 .18384 m
.46085 .18241 L
s
.46085 .18241 m
.46349 .18269 L
s
0 .484 1 r
.61318 .60701 m
.62098 .61674 L
s
.463 1 0 r
.53626 .54123 m
.53622 .54265 L
s
.53519 .54169 m
.53622 .54265 L
s
0 .97 1 r
.61625 .2921 m
.61442 .29319 L
s
.6164 .29078 m
.61625 .2921 L
s
.61678 .29353 m
.61625 .2921 L
s
1 0 .749 r
.61333 .66426 m
.62127 .68207 L
s
.463 1 0 r
.53519 .54169 m
.53626 .54123 L
s
.021 0 1 r
.5373 .6037 m
.54777 .61333 L
s
.987 0 1 r
.60949 .66402 m
.61317 .66659 L
s
.82 0 1 r
.61928 .42015 m
.61909 .41849 L
s
.61909 .41849 m
.6161 .41669 L
s
.61909 .41849 m
.61561 .42111 L
s
.824 0 1 r
.61419 .32475 m
.61841 .34201 L
s
.6189 .3387 m
.61543 .33935 L
s
.61971 .33776 m
.6189 .3387 L
s
.61841 .34201 m
.6189 .3387 L
s
0 1 .286 r
.54126 .57646 m
.54002 .57745 L
s
.54138 .57554 m
.54126 .57646 L
s
.5419 .57758 m
.54126 .57646 L
s
0 .97 1 r
.61442 .29319 m
.61457 .29187 L
s
.61678 .29353 m
.61442 .29319 L
s
1 0 .433 r
.69598 .61851 m
.69523 .62152 L
s
.69377 .61573 m
.69598 .61851 L
s
.69802 .61757 m
.69598 .61851 L
s
0 .479 1 r
.46224 .18567 m
.46047 .18384 L
s
.46349 .18269 m
.46224 .18567 L
s
0 .369 1 r
.6146 .63859 m
.62288 .64853 L
s
.82 0 1 r
.61561 .42111 m
.61928 .42015 L
s
.6161 .41669 m
.61561 .42111 L
s
.61561 .42111 m
.61628 .41835 L
s
.62602 .40761 m
.61561 .42111 L
s
.908 0 1 r
.69155 .3875 m
.68863 .38932 L
s
0 1 .286 r
.54002 .57745 m
.54014 .57653 L
s
.5419 .57758 m
.54002 .57745 L
s
.82 0 1 r
.6161 .41669 m
.61628 .41835 L
s
.824 0 1 r
.61543 .33935 m
.61623 .33842 L
s
.61841 .34201 m
.61543 .33935 L
s
0 .479 1 r
.46047 .18384 m
.46349 .18269 L
s
1 0 .749 r
.62112 .67833 m
.61753 .67972 L
s
.62184 .67728 m
.62112 .67833 L
s
.62127 .68207 m
.62112 .67833 L
s
0 .97 1 r
.61457 .29187 m
.6164 .29078 L
s
.6164 .29078 m
.61678 .29353 L
s
.505 0 1 r
.54379 .39022 m
.5436 .38853 L
s
.5436 .38853 m
.54102 .38665 L
s
.5436 .38853 m
.54019 .39073 L
s
0 1 .286 r
.54014 .57653 m
.54138 .57554 L
s
.54138 .57554 m
.5419 .57758 L
s
0 .97 1 r
.61457 .29187 m
.61678 .29353 L
s
0 1 .286 r
.54014 .57653 m
.5419 .57758 L
s
.505 0 1 r
.6205 .58575 m
.61763 .58738 L
s
.62063 .58426 m
.6205 .58575 L
s
.62098 .58841 m
.6205 .58575 L
s
0 .484 1 r
.62042 .61472 m
.61827 .61607 L
s
.62057 .61351 m
.62042 .61472 L
s
.62098 .61674 m
.62042 .61472 L
s
1 0 .749 r
.61753 .67972 m
.61825 .67867 L
s
.62127 .68207 m
.61753 .67972 L
s
.23 0 1 r
.54134 .26679 m
.5509 .27739 L
s
.021 0 1 r
.54668 .61132 m
.54448 .61307 L
s
.54685 .60973 m
.54668 .61132 L
s
.54777 .61333 m
.54668 .61132 L
s
.505 0 1 r
.54019 .39073 m
.54379 .39022 L
s
.54102 .38665 m
.54019 .39073 L
s
.54019 .39073 m
.54121 .38834 L
s
.55129 .37926 m
.54019 .39073 L
s
1 0 .433 r
.69302 .61875 m
.69377 .61573 L
s
.69377 .61573 m
.69802 .61757 L
s
0 .067 1 r
.69801 .63711 m
.69748 .63926 L
s
.69648 .63515 m
.69801 .63711 L
s
.69948 .63649 m
.69801 .63711 L
s
0 .369 1 r
.62204 .38525 m
.62188 .38398 L
s
.62188 .38398 m
.61968 .38257 L
s
.62188 .38398 m
.61921 .3859 L
s
0 .479 1 r
.4688 .81828 m
.46917 .81633 L
s
.46917 .81633 m
.4674 .81477 L
s
.46917 .81633 m
.46615 .81754 L
s
.505 0 1 r
.54102 .38665 m
.54121 .38834 L
s
.61763 .58738 m
.61776 .58588 L
s
.62098 .58841 m
.61763 .58738 L
s
.824 0 1 r
.61971 .33776 m
.61841 .34201 L
s
.61623 .33842 m
.61841 .34201 L
s
0 .484 1 r
.61827 .61607 m
.61842 .61486 L
s
.62098 .61674 m
.61827 .61607 L
s
0 .479 1 r
.46615 .81754 m
.4688 .81828 L
s
.4674 .81477 m
.46615 .81754 L
s
.46615 .81754 m
.46703 .81673 L
s
.47594 .81245 m
.46615 .81754 L
s
.82 0 1 r
.61628 .41835 m
.61928 .42015 L
s
0 .369 1 r
.62224 .64644 m
.62005 .64788 L
s
.6224 .6452 m
.62224 .64644 L
s
.62288 .64853 m
.62224 .64644 L
s
.61921 .3859 m
.62204 .38525 L
s
.61968 .38257 m
.61921 .3859 L
s
.61921 .3859 m
.61984 .38383 L
s
.62746 .37593 m
.61921 .3859 L
s
0 1 .881 r
.54518 .41799 m
.54505 .4169 L
s
.54505 .4169 m
.54338 .41572 L
s
.54505 .4169 m
.54288 .41833 L
s
1 0 .433 r
.69523 .62152 m
.69302 .61875 L
s
.69802 .61757 m
.69523 .62152 L
s
0 .369 1 r
.61968 .38257 m
.61984 .38383 L
s
.021 0 1 r
.54448 .61307 m
.54465 .61149 L
s
.54777 .61333 m
.54448 .61307 L
s
0 .186 1 r
.62383 .35264 m
.62334 .35183 L
s
.62334 .35183 m
.62072 .35083 L
s
.62334 .35183 m
.62112 .35431 L
s
.824 0 1 r
.61623 .33842 m
.61971 .33776 L
s
0 1 .881 r
.54288 .41833 m
.54518 .41799 L
s
.54338 .41572 m
.54288 .41833 L
s
.54288 .41833 m
.54351 .41681 L
s
.54989 .41093 m
.54288 .41833 L
s
0 .479 1 r
.4674 .81477 m
.46703 .81673 L
s
0 .369 1 r
.62005 .64788 m
.6202 .64663 L
s
.62288 .64853 m
.62005 .64788 L
s
0 1 .286 r
.54546 .44877 m
.54513 .44803 L
s
.54513 .44803 m
.54373 .44725 L
s
.54513 .44803 m
.54362 .44936 L
s
0 .067 1 r
.69594 .6373 m
.69648 .63515 L
s
.69648 .63515 m
.69948 .63649 L
s
0 1 .881 r
.54338 .41572 m
.54351 .41681 L
s
1 0 .812 r
.47312 .19962 m
.47253 .20178 L
s
.47056 .1969 m
.47312 .19962 L
s
.47447 .19743 m
.47312 .19962 L
s
0 .186 1 r
.62072 .35083 m
.62122 .35163 L
s
.62072 .35083 m
.62112 .35431 L
s
0 .484 1 r
.61842 .61486 m
.62057 .61351 L
s
.62057 .61351 m
.62098 .61674 L
s
.505 0 1 r
.54121 .38834 m
.54379 .39022 L
s
0 .186 1 r
.62112 .35431 m
.62383 .35264 L
s
.62112 .35431 m
.62122 .35163 L
s
.62691 .3414 m
.62112 .35431 L
s
0 1 .286 r
.54362 .44936 m
.54546 .44877 L
s
.54373 .44725 m
.54362 .44936 L
s
.54362 .44936 m
.54406 .44798 L
s
.54848 .44259 m
.54362 .44936 L
s
1 0 .749 r
.62184 .67728 m
.62127 .68207 L
s
.61825 .67867 m
.62127 .68207 L
s
0 1 .286 r
.54373 .44725 m
.54406 .44798 L
s
0 .067 1 r
.69748 .63926 m
.69594 .6373 L
s
.69948 .63649 m
.69748 .63926 L
s
0 .484 1 r
.61842 .61486 m
.62098 .61674 L
s
0 .479 1 r
.46703 .81673 m
.4688 .81828 L
s
.021 0 1 r
.54465 .61149 m
.54685 .60973 L
s
.54685 .60973 m
.54777 .61333 L
s
1 0 .749 r
.61825 .67867 m
.62184 .67728 L
s
.505 0 1 r
.61776 .58588 m
.62063 .58426 L
s
.62063 .58426 m
.62098 .58841 L
s
1 0 .433 r
.69302 .61875 m
.69802 .61757 L
s
0 .369 1 r
.61984 .38383 m
.62204 .38525 L
s
0 1 .881 r
.54351 .41681 m
.54518 .41799 L
s
.505 0 1 r
.61776 .58588 m
.62098 .58841 L
s
0 1 .47 r
.54754 .47955 m
.54654 .47914 L
s
.54654 .47914 m
.54506 .47871 L
s
.54654 .47914 m
.54572 .4809 L
s
.021 0 1 r
.54465 .61149 m
.54777 .61333 L
s
1 0 .812 r
.46976 .20614 m
.48438 .21332 L
s
.23 0 1 r
.55021 .27543 m
.54764 .27696 L
s
.55033 .27356 m
.55021 .27543 L
s
.5509 .27739 m
.55021 .27543 L
s
0 1 .286 r
.54406 .44798 m
.54546 .44877 L
s
0 .369 1 r
.6202 .64663 m
.6224 .6452 L
s
.6224 .6452 m
.62288 .64853 L
s
.908 0 1 r
.69909 .60046 m
.71058 .58774 L
s
0 .369 1 r
.6202 .64663 m
.62288 .64853 L
s
0 .067 1 r
.69594 .6373 m
.69948 .63649 L
s
1 0 .812 r
.46997 .19906 m
.47056 .1969 L
s
.47056 .1969 m
.47447 .19743 L
s
0 1 .47 r
.5512 .53499 m
.54972 .53543 L
s
.55221 .53459 m
.5512 .53499 L
s
.55155 .53678 m
.5512 .53499 L
s
0 .186 1 r
.62122 .35163 m
.62383 .35264 L
s
0 1 .47 r
.54506 .47871 m
.54606 .47912 L
s
.54506 .47871 m
.54572 .4809 L
s
.23 0 1 r
.54764 .27696 m
.54776 .27509 L
s
.5509 .27739 m
.54764 .27696 L
s
0 .526 1 r
.62796 .69397 m
.62737 .69327 L
s
.62737 .69327 m
.62486 .69281 L
s
.62737 .69327 m
.6258 .69588 L
s
0 1 .47 r
.54572 .4809 m
.54754 .47955 L
s
.54572 .4809 m
.54606 .47912 L
s
.54863 .47206 m
.54572 .4809 L
s
.54606 .47912 m
.54754 .47955 L
s
0 1 .286 r
.54848 .55741 m
.55335 .5642 L
s
0 .526 1 r
.62486 .69281 m
.62546 .69351 L
s
.62486 .69281 m
.6258 .69588 L
s
0 1 .47 r
.54863 .52794 m
.55155 .53678 L
s
1 0 .812 r
.47253 .20178 m
.46997 .19906 L
s
.47447 .19743 m
.47253 .20178 L
s
0 .98 1 r
.552 .75943 m
.55191 .75806 L
s
.55191 .75806 m
.55007 .75698 L
s
.55191 .75806 m
.54967 .75971 L
s
0 1 .47 r
.54972 .53543 m
.55073 .53503 L
s
.55155 .53678 m
.54972 .53543 L
s
0 .526 1 r
.6258 .69588 m
.62796 .69397 L
s
.6258 .69588 m
.62546 .69351 L
s
.62885 .68342 m
.6258 .69588 L
s
1 .65 0 r
.47376 .83427 m
.47375 .83396 L
s
.47375 .83396 m
.47335 .83373 L
s
.47375 .83396 m
.47326 .83432 L
s
0 1 .47 r
.55221 .53459 m
.55155 .53678 L
s
.55073 .53503 m
.55155 .53678 L
s
.82 0 1 r
.62602 .59239 m
.6365 .60598 L
s
0 .98 1 r
.54967 .75971 m
.552 .75943 L
s
.55007 .75698 m
.54967 .75971 L
s
.54967 .75971 m
.55015 .75835 L
s
.5565 .75216 m
.54967 .75971 L
s
1 .65 0 r
.47326 .83432 m
.47376 .83427 L
s
.47335 .83373 m
.47326 .83432 L
s
.47326 .83432 m
.47335 .83404 L
s
.4747 .83271 m
.47326 .83432 L
s
0 1 .47 r
.55073 .53503 m
.55221 .53459 L
s
1 .65 0 r
.47335 .83373 m
.47335 .83404 L
s
0 1 .286 r
.55291 .56282 m
.55151 .5636 L
s
.55325 .56208 m
.55291 .56282 L
s
.55335 .5642 m
.55291 .56282 L
s
0 1 .881 r
.54989 .58907 m
.55692 .59649 L
s
0 .98 1 r
.55007 .75698 m
.55015 .75835 L
s
1 .65 0 r
.47335 .83404 m
.47376 .83427 L
s
.23 0 1 r
.54776 .27509 m
.55033 .27356 L
s
.55033 .27356 m
.5509 .27739 L
s
0 .186 1 r
.62691 .6586 m
.63273 .67155 L
s
0 1 .286 r
.55151 .5636 m
.55185 .56287 L
s
.55335 .5642 m
.55151 .5636 L
s
1 0 .812 r
.46997 .19906 m
.47447 .19743 L
s
.23 0 1 r
.54776 .27509 m
.5509 .27739 L
s
0 .369 1 r
.62746 .62407 m
.63574 .63407 L
s
1 .65 0 r
.4747 .16729 m
.47615 .1689 L
s
.987 0 1 r
.633 .4034 m
.63276 .40165 L
s
.63276 .40165 m
.62972 .39972 L
s
.63276 .40165 m
.62911 .4043 L
s
.505 0 1 r
.55129 .62074 m
.56245 .63227 L
s
0 .526 1 r
.62546 .69351 m
.62796 .69397 L
s
1 .65 0 r
.47606 .16862 m
.47565 .16885 L
s
.47606 .16831 m
.47606 .16862 L
s
.47615 .1689 m
.47606 .16862 L
s
.887 0 1 r
.48028 .78316 m
.48022 .78092 L
s
.48022 .78092 m
.4772 .77919 L
s
.48022 .78092 m
.47658 .78361 L
s
0 .98 1 r
.55015 .75835 m
.552 .75943 L
s
0 1 .286 r
.55185 .56287 m
.55325 .56208 L
s
.55325 .56208 m
.55335 .5642 L
s
1 .65 0 r
.47565 .16885 m
.47566 .16854 L
s
.47615 .1689 m
.47565 .16885 L
s
.908 0 1 r
.70958 .59021 m
.7099 .59221 L
s
.70665 .58837 m
.70958 .59021 L
s
.71058 .58774 m
.70958 .59021 L
s
0 1 .286 r
.55185 .56287 m
.55335 .5642 L
s
.987 0 1 r
.62911 .4043 m
.633 .4034 L
s
.62972 .39972 m
.62911 .4043 L
s
.62911 .4043 m
.62996 .40147 L
s
.6404 .39055 m
.62911 .4043 L
s
0 .479 1 r
.47594 .18755 m
.48579 .19267 L
s
0 .526 1 r
.62885 .31658 m
.6319 .32906 L
s
.63224 .32667 m
.62974 .32714 L
s
.63285 .32599 m
.63224 .32667 L
s
.6319 .32906 m
.63224 .32667 L
s
0 .186 1 r
.63262 .66884 m
.63 .66985 L
s
.63312 .66806 m
.63262 .66884 L
s
.63273 .67155 m
.63262 .66884 L
s
1 .65 0 r
.47566 .16854 m
.47606 .16831 L
s
.47606 .16831 m
.47615 .1689 L
s
.47566 .16854 m
.47615 .1689 L
s
0 1 .881 r
.55628 .59495 m
.55461 .59614 L
s
.55642 .59387 m
.55628 .59495 L
s
.55692 .59649 m
.55628 .59495 L
s
.987 0 1 r
.62972 .39972 m
.62996 .40147 L
s
.887 0 1 r
.47658 .78361 m
.48028 .78316 L
s
.4772 .77919 m
.47658 .78361 L
s
.47658 .78361 m
.47726 .78142 L
s
.48741 .77139 m
.47658 .78361 L
s
0 .6 1 r
.70732 .3754 m
.70934 .37414 L
s
.70934 .37414 m
.7096 .37272 L
s
.70934 .37414 m
.70685 .37231 L
s
0 .526 1 r
.62974 .32714 m
.63034 .32646 L
s
.6319 .32906 m
.62974 .32714 L
s
.82 0 1 r
.55773 .37418 m
.55753 .37244 L
s
.55753 .37244 m
.55468 .37048 L
s
.55753 .37244 m
.55392 .37488 L
s
0 .186 1 r
.63 .66985 m
.63051 .66907 L
s
.63273 .67155 m
.63 .66985 L
s
.887 0 1 r
.4772 .77919 m
.47726 .78142 L
s
.908 0 1 r
.70697 .59037 m
.70665 .58837 L
s
.70665 .58837 m
.71058 .58774 L
s
0 .6 1 r
.70685 .37231 m
.70732 .3754 L
s
.7096 .37272 m
.70685 .37231 L
s
.70685 .37231 m
.70758 .37399 L
s
.7149 .3811 m
.70685 .37231 L
s
0 1 .881 r
.55461 .59614 m
.55475 .59505 L
s
.55692 .59649 m
.55461 .59614 L
s
0 .6 1 r
.70758 .37399 m
.70732 .3754 L
s
1 0 .812 r
.48302 .21215 m
.48046 .21449 L
s
.48243 .20927 m
.48302 .21215 L
s
.48438 .21332 m
.48302 .21215 L
s
.82 0 1 r
.55392 .37488 m
.55773 .37418 L
s
.55468 .37048 m
.55392 .37488 L
s
.55392 .37488 m
.55488 .37221 L
s
.56539 .36209 m
.55392 .37488 L
s
0 .369 1 r
.63509 .63198 m
.63289 .63341 L
s
.63527 .63073 m
.63509 .63198 L
s
.63574 .63407 m
.63509 .63198 L
s
.82 0 1 r
.6358 .60316 m
.63279 .60498 L
s
.63601 .60152 m
.6358 .60316 L
s
.6365 .60598 m
.6358 .60316 L
s
.55468 .37048 m
.55488 .37221 L
s
0 .526 1 r
.63285 .32599 m
.6319 .32906 L
s
.63034 .32646 m
.6319 .32906 L
s
0 .648 1 r
.55758 .467 m
.55679 .46608 L
s
.55679 .46608 m
.55471 .46511 L
s
.55679 .46608 m
.55489 .46821 L
s
0 1 .881 r
.55475 .59505 m
.55642 .59387 L
s
.55642 .59387 m
.55692 .59649 L
s
0 .728 1 r
.55881 .40209 m
.55866 .40089 L
s
.55866 .40089 m
.55672 .39957 L
s
.55866 .40089 m
.55621 .40256 L
s
0 1 .881 r
.55848 .43325 m
.55822 .43226 L
s
.55822 .43226 m
.55646 .4312 L
s
.55822 .43226 m
.55619 .43386 L
s
.505 0 1 r
.5614 .62985 m
.55882 .63175 L
s
.56161 .62818 m
.5614 .62985 L
s
.56245 .63227 m
.5614 .62985 L
s
0 1 .881 r
.55475 .59505 m
.55692 .59649 L
s
0 .186 1 r
.63312 .66806 m
.63273 .67155 L
s
.63051 .66907 m
.63273 .67155 L
s
.987 0 1 r
.62996 .40147 m
.633 .4034 L
s
0 .526 1 r
.63034 .32646 m
.63285 .32599 L
s
0 .186 1 r
.63642 .36849 m
.63664 .3668 L
s
.63664 .3668 m
.63475 .36492 L
s
.63664 .3668 m
.6334 .36813 L
s
0 .369 1 r
.63289 .63341 m
.63306 .63215 L
s
.63574 .63407 m
.63289 .63341 L
s
0 .98 1 r
.5565 .24784 m
.56335 .25542 L
s
0 .6 1 r
.7096 .37272 m
.70758 .37399 L
s
0 .186 1 r
.63051 .66907 m
.63312 .66806 L
s
.82 0 1 r
.63279 .60498 m
.633 .60334 L
s
.6365 .60598 m
.63279 .60498 L
s
0 .728 1 r
.55621 .40256 m
.55881 .40209 L
s
.55672 .39957 m
.55621 .40256 L
s
.55621 .40256 m
.55687 .40077 L
s
.56398 .39389 m
.55621 .40256 L
s
0 .186 1 r
.6334 .36813 m
.63642 .36849 L
s
.63475 .36492 m
.6334 .36813 L
s
.6334 .36813 m
.63454 .36661 L
s
.64437 .36097 m
.6334 .36813 L
s
.887 0 1 r
.47726 .78142 m
.48028 .78316 L
s
0 1 .881 r
.55619 .43386 m
.55848 .43325 L
s
.55646 .4312 m
.55619 .43386 L
s
.55619 .43386 m
.55671 .43219 L
s
.56256 .42567 m
.55619 .43386 L
s
1 0 .812 r
.48046 .21449 m
.47987 .21161 L
s
.48438 .21332 m
.48046 .21449 L
s
.908 0 1 r
.7099 .59221 m
.70697 .59037 L
s
.71058 .58774 m
.7099 .59221 L
s
0 1 .881 r
.55646 .4312 m
.55671 .43219 L
s
0 .648 1 r
.55471 .46511 m
.5555 .46603 L
s
.55471 .46511 m
.55489 .46821 L
s
0 .728 1 r
.55672 .39957 m
.55687 .40077 L
s
0 .648 1 r
.55489 .46821 m
.55758 .467 L
s
.55489 .46821 m
.5555 .46603 L
s
.56115 .45742 m
.55489 .46821 L
s
1 0 .749 r
.63877 .38698 m
.63906 .38461 L
s
.63906 .38461 m
.63648 .38203 L
s
.63906 .38461 m
.6346 .38645 L
s
.908 0 1 r
.70697 .59037 m
.71058 .58774 L
s
.505 0 1 r
.55882 .63175 m
.55903 .63007 L
s
.56245 .63227 m
.55882 .63175 L
s
0 .479 1 r
.48488 .19184 m
.48311 .1934 L
s
.48452 .18988 m
.48488 .19184 L
s
.48579 .19267 m
.48488 .19184 L
s
1 0 .749 r
.6346 .38645 m
.63877 .38698 L
s
.63648 .38203 m
.6346 .38645 L
s
.6346 .38645 m
.63619 .38439 L
s
.6498 .3767 m
.6346 .38645 L
s
0 .186 1 r
.63475 .36492 m
.63454 .36661 L
s
.82 0 1 r
.55488 .37221 m
.55773 .37418 L
s
0 .369 1 r
.63306 .63215 m
.63527 .63073 L
s
.63527 .63073 m
.63574 .63407 L
s
0 1 .881 r
.55671 .43219 m
.55848 .43325 L
s
0 .648 1 r
.5555 .46603 m
.55758 .467 L
s
1 0 .812 r
.47987 .21161 m
.48243 .20927 L
s
.48243 .20927 m
.48438 .21332 L
s
0 .728 1 r
.55687 .40077 m
.55881 .40209 L
s
0 .369 1 r
.63306 .63215 m
.63574 .63407 L
s
0 .479 1 r
.48311 .1934 m
.48275 .19144 L
s
.48579 .19267 m
.48311 .1934 L
s
0 .186 1 r
.63454 .36661 m
.63642 .36849 L
s
0 .98 1 r
.56285 .25403 m
.56101 .25512 L
s
.56295 .25267 m
.56285 .25403 L
s
.56335 .25542 m
.56285 .25403 L
s
1 0 .749 r
.63648 .38203 m
.63619 .38439 L
s
.82 0 1 r
.633 .60334 m
.63601 .60152 L
s
.63601 .60152 m
.6365 .60598 L
s
0 .807 1 r
.48001 .43064 m
.47986 .42904 L
s
.47986 .42904 m
.47903 .42734 L
s
.47986 .42904 m
.47726 .42971 L
s
.505 0 1 r
.55903 .63007 m
.56161 .62818 L
s
.56161 .62818 m
.56245 .63227 L
s
.82 0 1 r
.633 .60334 m
.6365 .60598 L
s
0 .98 1 r
.56101 .25512 m
.56111 .25376 L
s
.56335 .25542 m
.56101 .25512 L
s
1 0 .812 r
.47987 .21161 m
.48438 .21332 L
s
0 .479 1 r
.48275 .19144 m
.48452 .18988 L
s
.48452 .18988 m
.48579 .19267 L
s
0 .648 1 r
.56115 .54258 m
.56743 .55339 L
s
.505 0 1 r
.55903 .63007 m
.56245 .63227 L
s
0 .6 1 r
.7149 .6189 m
.72298 .61008 L
s
0 .648 1 r
.56681 .55119 m
.56473 .55217 L
s
.56761 .55028 m
.56681 .55119 L
s
.56743 .55339 m
.56681 .55119 L
s
.225 0 1 r
.56609 .70865 m
.56594 .7068 L
s
.56594 .7068 m
.56335 .70528 L
s
.56594 .7068 m
.56282 .70912 L
s
1 0 .749 r
.63619 .38439 m
.63877 .38698 L
s
0 .807 1 r
.47726 .42971 m
.48001 .43064 L
s
.47903 .42734 m
.47726 .42971 L
s
.47726 .42971 m
.47918 .42894 L
s
.4886 .42614 m
.47726 .42971 L
s
0 .479 1 r
.48275 .19144 m
.48579 .19267 L
s
0 1 .881 r
.56256 .57433 m
.56896 .58255 L
s
.225 0 1 r
.56282 .70912 m
.56609 .70865 L
s
.56335 .70528 m
.56282 .70912 L
s
.56282 .70912 m
.56349 .70712 L
s
.57234 .69829 m
.56282 .70912 L
s
0 .807 1 r
.47903 .42734 m
.47918 .42894 L
s
0 .98 1 r
.56111 .25376 m
.56295 .25267 L
s
.56295 .25267 m
.56335 .25542 L
s
0 .807 1 r
.47918 .42894 m
.48001 .43064 L
s
.225 0 1 r
.56335 .70528 m
.56349 .70712 L
s
0 .648 1 r
.56473 .55217 m
.56553 .55126 L
s
.56743 .55339 m
.56473 .55217 L
s
0 .98 1 r
.56111 .25376 m
.56335 .25542 L
s
.987 0 1 r
.6404 .60945 m
.65176 .62328 L
s
0 .728 1 r
.56398 .60611 m
.57178 .61482 L
s
.887 0 1 r
.48741 .22861 m
.4983 .24091 L
s
0 1 .224 r
.49533 .4484 m
.49558 .44745 L
s
.49558 .44745 m
.49427 .44645 L
s
.49558 .44745 m
.49376 .44842 L
s
.49376 .44842 m
.49533 .4484 L
s
.49427 .44645 m
.49376 .44842 L
s
.49376 .44842 m
.49402 .44741 L
s
.49898 .44344 m
.49376 .44842 L
s
1 0 0 r
.64144 .66044 m
.64144 .66045 L
s
.64144 .66044 m
.64144 .66044 L
s
.64144 .66044 m
.64144 .66045 L
s
.64144 .66045 m
.64144 .66044 L
s
.64144 .66045 m
.64144 .66044 L
s
.64144 .66045 m
.64144 .66045 L
s
.64144 .66045 m
.64144 .66045 L
s
.64144 .66044 m
.64144 .66045 L
s
.64144 .66045 m
.64144 .66044 L
s
.64144 .33955 m
.64144 .33954 L
s
.64144 .33954 m
.64144 .33954 L
s
.64143 .33954 m
.64144 .33954 L
s
.64144 .33954 m
.64144 .33954 L
s
.64144 .33954 m
.64143 .33954 L
s
.64143 .33954 m
.64144 .33954 L
s
.64144 .33954 m
.64144 .33954 L
s
.64144 .33954 m
.64144 .33954 L
s
.64144 .33954 m
.64144 .33954 L
s
0 .648 1 r
.56761 .55028 m
.56743 .55339 L
s
.56553 .55126 m
.56743 .55339 L
s
0 1 .224 r
.49427 .44645 m
.49402 .44741 L
s
0 1 .881 r
.56843 .58086 m
.56666 .58193 L
s
.56869 .57988 m
.56843 .58086 L
s
.56896 .58255 m
.56843 .58086 L
s
0 .648 1 r
.56553 .55126 m
.56761 .55028 L
s
.938 0 1 r
.72047 .42702 m
.72342 .42518 L
s
.72342 .42518 m
.72382 .4232 L
s
.72342 .42518 m
.71983 .4225 L
s
.82 0 1 r
.56539 .63791 m
.57693 .65078 L
s
0 .6 1 r
.72223 .61178 m
.7225 .61319 L
s
.72022 .61051 m
.72223 .61178 L
s
.72298 .61008 m
.72223 .61178 L
s
0 .807 1 r
.4886 .57386 m
.49996 .57744 L
s
.49801 .57667 m
.49719 .57837 L
s
.49817 .57507 m
.49801 .57667 L
s
.49996 .57744 m
.49801 .57667 L
s
.225 0 1 r
.56349 .70712 m
.56609 .70865 L
s
0 1 .881 r
.56666 .58193 m
.56692 .58095 L
s
.56896 .58255 m
.56666 .58193 L
s
.938 0 1 r
.71983 .4225 m
.72047 .42702 L
s
.72382 .4232 m
.71983 .4225 L
s
.71983 .4225 m
.72086 .42504 L
s
.73143 .4356 m
.71983 .4225 L
s
0 1 .224 r
.49402 .44741 m
.49533 .4484 L
s
0 .6 1 r
.72048 .61192 m
.72022 .61051 L
s
.72022 .61051 m
.72298 .61008 L
s
.021 0 1 r
.57003 .45145 m
.56946 .45015 L
s
.56946 .45015 m
.56697 .44877 L
s
.56946 .45015 m
.5668 .45251 L
s
.938 0 1 r
.72086 .42504 m
.72047 .42702 L
s
.824 0 1 r
.64657 .37434 m
.6485 .37192 L
s
.6485 .37192 m
.6478 .36928 L
s
.6485 .37192 m
.64414 .37092 L
s
.987 0 1 r
.57198 .35761 m
.57177 .35587 L
s
.57177 .35587 m
.56875 .35388 L
s
.57177 .35587 m
.56806 .35847 L
s
.824 0 1 r
.64414 .37092 m
.64657 .37434 L
s
.6478 .36928 m
.64414 .37092 L
s
.64414 .37092 m
.64586 .3717 L
s
.6594 .37539 m
.64414 .37092 L
s
0 .728 1 r
.5711 .61301 m
.56916 .61434 L
s
.57127 .61182 m
.5711 .61301 L
s
.57178 .61482 m
.5711 .61301 L
s
0 .186 1 r
.64437 .63903 m
.65541 .64624 L
s
0 1 .881 r
.56692 .58095 m
.56869 .57988 L
s
.56869 .57988 m
.56896 .58255 L
s
0 .807 1 r
.49719 .57837 m
.49735 .57678 L
s
.49996 .57744 m
.49719 .57837 L
s
0 1 .881 r
.56692 .58095 m
.56896 .58255 L
s
.987 0 1 r
.56806 .35847 m
.57198 .35761 L
s
.56875 .35388 m
.56806 .35847 L
s
.56806 .35847 m
.56896 .35561 L
s
.5796 .34479 m
.56806 .35847 L
s
0 .807 1 r
.49735 .57678 m
.49817 .57507 L
s
.49817 .57507 m
.49996 .57744 L
s
.021 0 1 r
.5668 .45251 m
.57003 .45145 L
s
.56697 .44877 m
.5668 .45251 L
s
.5668 .45251 m
.56754 .45007 L
s
.57533 .4405 m
.5668 .45251 L
s
1 0 0 r
.64546 .65596 m
.64546 .65596 L
s
.64546 .65596 m
.64546 .65596 L
s
.64546 .65596 m
.64546 .65596 L
s
.64546 .65596 m
.64546 .65596 L
s
.64546 .65597 m
.64546 .65596 L
s
.64546 .65596 m
.64546 .65596 L
s
.64546 .65596 m
.64546 .65596 L
s
.64546 .65596 m
.64546 .65596 L
s
.64546 .65596 m
.64546 .65596 L
s
.64546 .34403 m
.64546 .34403 L
s
.021 0 1 r
.56697 .44877 m
.56754 .45007 L
s
1 0 0 r
.64546 .34402 m
.64546 .34403 L
s
.64545 .34403 m
.64546 .34402 L
s
.64546 .34402 m
.64546 .34403 L
s
.64546 .34403 m
.64545 .34403 L
s
.64545 .34403 m
.64546 .34403 L
s
.64546 .34403 m
.64546 .34403 L
s
.64546 .34403 m
.64546 .34403 L
s
.64546 .34403 m
.64546 .34403 L
s
0 .728 1 r
.56916 .61434 m
.56932 .61315 L
s
.57178 .61482 m
.56916 .61434 L
s
0 .6 1 r
.7225 .61319 m
.72048 .61192 L
s
.72298 .61008 m
.7225 .61319 L
s
0 .728 1 r
.57196 .41716 m
.57173 .41602 L
s
.57173 .41602 m
.56973 .41478 L
s
.57173 .41602 m
.56937 .4178 L
s
.987 0 1 r
.56875 .35388 m
.56896 .35561 L
s
0 .807 1 r
.49735 .57678 m
.49996 .57744 L
s
0 .6 1 r
.72048 .61192 m
.72298 .61008 L
s
0 .484 1 r
.57274 .38568 m
.57258 .38442 L
s
.57258 .38442 m
.57046 .38301 L
s
.57258 .38442 m
.56996 .38625 L
s
.987 0 1 r
.65087 .6204 m
.64782 .62234 L
s
.65114 .61867 m
.65087 .6204 L
s
.65176 .62328 m
.65087 .6204 L
s
.887 0 1 r
.49758 .23868 m
.49456 .24043 L
s
.49767 .23646 m
.49758 .23868 L
s
.4983 .24091 m
.49758 .23868 L
s
0 .103 1 r
.4913 .4199 m
.49084 .41816 L
s
.49084 .41816 m
.48923 .41628 L
s
.49084 .41816 m
.48782 .41962 L
s
.824 0 1 r
.64586 .3717 m
.64657 .37434 L
s
0 .728 1 r
.56937 .4178 m
.57196 .41716 L
s
.56973 .41478 m
.56937 .4178 L
s
.56937 .4178 m
.56996 .41592 L
s
.57675 .40862 m
.56937 .4178 L
s
.938 0 1 r
.72382 .4232 m
.72086 .42504 L
s
0 .728 1 r
.56973 .41478 m
.56996 .41592 L
s
0 .484 1 r
.56996 .38625 m
.57274 .38568 L
s
.57046 .38301 m
.56996 .38625 L
s
.56996 .38625 m
.57062 .38427 L
s
.57818 .37672 m
.56996 .38625 L
s
1 .005 0 r
.64724 .68128 m
.64724 .68129 L
s
.64724 .68128 m
.64724 .68128 L
s
.64725 .68128 m
.64724 .68128 L
s
.64725 .68128 m
.64724 .68129 L
s
.64724 .68128 m
.64725 .68128 L
s
.64724 .68128 m
.64725 .68128 L
s
.64721 .68128 m
.64725 .68128 L
s
.64724 .68128 m
.64724 .68128 L
s
.64724 .68129 m
.64724 .68128 L
s
.64721 .31872 m
.64718 .31872 L
s
.64719 .31872 m
.64719 .31872 L
s
.64719 .31872 m
.64719 .31871 L
s
.64719 .31872 m
.64718 .31872 L
s
.64719 .31872 m
.64719 .31872 L
s
.64718 .31872 m
.64719 .31872 L
s
.64719 .31871 m
.64719 .31872 L
s
.64719 .31871 m
.64718 .31872 L
s
.64718 .31872 m
.64719 .31872 L
s
.82 0 1 r
.57593 .64807 m
.57308 .65005 L
s
.57616 .64635 m
.57593 .64807 L
s
.57693 .65078 m
.57593 .64807 L
s
0 .728 1 r
.56932 .61315 m
.57127 .61182 L
s
.57127 .61182 m
.57178 .61482 L
s
0 .484 1 r
.57046 .38301 m
.57062 .38427 L
s
.824 0 1 r
.6478 .36928 m
.64586 .3717 L
s
0 .652 1 r
.49752 .7987 m
.49746 .79714 L
s
.49746 .79714 m
.49538 .79596 L
s
.49746 .79714 m
.49496 .799 L
s
.021 0 1 r
.56754 .45007 m
.57003 .45145 L
s
0 1 .224 r
.49898 .55656 m
.50422 .56156 L
s
.987 0 1 r
.64782 .62234 m
.64809 .62061 L
s
.65176 .62328 m
.64782 .62234 L
s
0 .728 1 r
.56932 .61315 m
.57178 .61482 L
s
.887 0 1 r
.49456 .24043 m
.49465 .23821 L
s
.4983 .24091 m
.49456 .24043 L
s
0 .103 1 r
.48782 .41962 m
.4913 .4199 L
s
.48923 .41628 m
.48782 .41962 L
s
.48782 .41962 m
.48969 .41802 L
s
.50006 .41197 m
.48782 .41962 L
s
0 .652 1 r
.49496 .799 m
.49752 .7987 L
s
.49538 .79596 m
.49496 .799 L
s
.49496 .799 m
.49544 .79751 L
s
.50244 .79061 m
.49496 .799 L
s
.987 0 1 r
.56896 .35561 m
.57198 .35761 L
s
0 .652 1 r
.49538 .79596 m
.49544 .79751 L
s
0 .728 1 r
.56996 .41592 m
.57196 .41716 L
s
.225 0 1 r
.57234 .30171 m
.58191 .3126 L
s
0 .103 1 r
.48923 .41628 m
.48969 .41802 L
s
.82 0 1 r
.57308 .65005 m
.57331 .64833 L
s
.57693 .65078 m
.57308 .65005 L
s
1 0 .749 r
.6498 .6233 m
.66513 .63312 L
s
0 .484 1 r
.57062 .38427 m
.57274 .38568 L
s
0 .103 1 r
.48969 .41802 m
.4913 .4199 L
s
0 .186 1 r
.65424 .6447 m
.65236 .64659 L
s
.65404 .643 m
.65424 .6447 L
s
.65541 .64624 m
.65424 .6447 L
s
0 .652 1 r
.49544 .79751 m
.49752 .7987 L
s
.987 0 1 r
.64809 .62061 m
.65114 .61867 L
s
.65114 .61867 m
.65176 .62328 L
s
.887 0 1 r
.49465 .23821 m
.49767 .23646 L
s
.49767 .23646 m
.4983 .24091 L
s
.987 0 1 r
.64809 .62061 m
.65176 .62328 L
s
.887 0 1 r
.49465 .23821 m
.4983 .24091 L
s
0 1 .224 r
.50395 .56053 m
.50264 .56153 L
s
.5037 .55958 m
.50395 .56053 L
s
.50422 .56156 m
.50395 .56053 L
s
.021 0 1 r
.57533 .5595 m
.58389 .57156 L
s
.82 0 1 r
.57331 .64833 m
.57616 .64635 L
s
.57616 .64635 m
.57693 .65078 L
s
0 .186 1 r
.65236 .64659 m
.65215 .6449 L
s
.65541 .64624 m
.65236 .64659 L
s
0 1 .224 r
.50264 .56153 m
.50239 .56058 L
s
.50422 .56156 m
.50264 .56153 L
s
.82 0 1 r
.57331 .64833 m
.57693 .65078 L
s
0 .728 1 r
.57675 .59138 m
.58416 .6006 L
s
0 .103 1 r
.50006 .58803 m
.51234 .59571 L
s
0 .186 1 r
.65215 .6449 m
.65404 .643 L
s
.65404 .643 m
.65541 .64624 L
s
.225 0 1 r
.58121 .31056 m
.57862 .3121 L
s
.58137 .30873 m
.58121 .31056 L
s
.58191 .3126 m
.58121 .31056 L
s
0 1 .224 r
.50239 .56058 m
.5037 .55958 L
s
.5037 .55958 m
.50422 .56156 L
s
.938 0 1 r
.73143 .5644 m
.74311 .55121 L
s
0 .526 1 r
.65669 .35722 m
.65808 .35548 L
s
.65808 .35548 m
.65757 .35356 L
s
.65808 .35548 m
.65493 .35476 L
s
.021 0 1 r
.58313 .56909 m
.58064 .57048 L
s
.58371 .5678 m
.58313 .56909 L
s
.58389 .57156 m
.58313 .56909 L
s
0 .526 1 r
.65493 .35476 m
.65669 .35722 L
s
.65757 .35356 m
.65493 .35476 L
s
.65493 .35476 m
.65618 .3553 L
s
.66596 .35792 m
.65493 .35476 L
s
0 1 .224 r
.50239 .56058 m
.50422 .56156 L
s
0 .103 1 r
.51044 .59409 m
.50884 .59598 L
s
.51092 .59236 m
.51044 .59409 L
s
.51234 .59571 m
.51044 .59409 L
s
0 .484 1 r
.57818 .62328 m
.58643 .63286 L
s
0 .186 1 r
.65215 .6449 m
.65541 .64624 L
s
.225 0 1 r
.57862 .3121 m
.57878 .31027 L
s
.58191 .3126 m
.57862 .3121 L
s
.505 0 1 r
.58326 .43548 m
.5828 .43394 L
s
.5828 .43394 m
.58002 .4323 L
s
.5828 .43394 m
.57965 .43649 L
s
0 .652 1 r
.50244 .20939 m
.50994 .21781 L
s
.021 0 1 r
.58064 .57048 m
.58122 .5692 L
s
.58389 .57156 m
.58064 .57048 L
s
.987 0 1 r
.5796 .65521 m
.59121 .66898 L
s
0 .526 1 r
.65618 .3553 m
.65669 .35722 L
s
0 .728 1 r
.58356 .59869 m
.58155 .59994 L
s
.5838 .59756 m
.58356 .59869 L
s
.58416 .6006 m
.58356 .59869 L
s
0 1 .224 r
.51088 .4664 m
.51099 .46571 L
s
.51099 .46571 m
.50945 .465 L
s
.51099 .46571 m
.50944 .46708 L
s
0 .97 1 r
.58321 .72471 m
.58308 .72336 L
s
.58308 .72336 m
.58122 .72227 L
s
.58308 .72336 m
.58083 .72504 L
s
0 1 .224 r
.50944 .46708 m
.51088 .4664 L
s
.50945 .465 m
.50944 .46708 L
s
.50944 .46708 m
.50934 .46569 L
s
.51308 .46018 m
.50944 .46708 L
s
.50945 .465 m
.50934 .46569 L
s
0 .526 1 r
.65757 .35356 m
.65618 .3553 L
s
0 .103 1 r
.50884 .59598 m
.50932 .59425 L
s
.51234 .59571 m
.50884 .59598 L
s
0 .97 1 r
.58083 .72504 m
.58321 .72471 L
s
.58122 .72227 m
.58083 .72504 L
s
.58083 .72504 m
.58135 .72361 L
s
.58775 .71726 m
.58083 .72504 L
s
.505 0 1 r
.57965 .43649 m
.58326 .43548 L
s
.58002 .4323 m
.57965 .43649 L
s
.57965 .43649 m
.58047 .43383 L
s
.58961 .42345 m
.57965 .43649 L
s
1 0 .749 r
.587 .34902 m
.58638 .34792 L
s
.58638 .34792 m
.58273 .34653 L
s
.58638 .34792 m
.58328 .35137 L
s
0 .728 1 r
.58155 .59994 m
.58179 .59881 L
s
.58416 .6006 m
.58155 .59994 L
s
.505 0 1 r
.58002 .4323 m
.58047 .43383 L
s
1 0 .749 r
.66347 .63102 m
.66089 .63363 L
s
.66321 .62866 m
.66347 .63102 L
s
.66513 .63312 m
.66347 .63102 L
s
0 .97 1 r
.58122 .72227 m
.58135 .72361 L
s
.225 0 1 r
.57878 .31027 m
.58137 .30873 L
s
.58137 .30873 m
.58191 .3126 L
s
0 .103 1 r
.50932 .59425 m
.51092 .59236 L
s
.51092 .59236 m
.51234 .59571 L
s
.58 0 1 r
.50517 .40544 m
.50464 .40358 L
s
.50464 .40358 m
.50233 .40154 L
s
.50464 .40358 m
.50118 .40565 L
s
.021 0 1 r
.58122 .5692 m
.58371 .5678 L
s
.58371 .5678 m
.58389 .57156 L
s
.225 0 1 r
.57878 .31027 m
.58191 .3126 L
s
0 .484 1 r
.58575 .63085 m
.58363 .63227 L
s
.58592 .62961 m
.58575 .63085 L
s
.58643 .63286 m
.58575 .63085 L
s
.021 0 1 r
.58122 .5692 m
.58389 .57156 L
s
0 .103 1 r
.50932 .59425 m
.51234 .59571 L
s
.824 0 1 r
.6594 .62461 m
.67477 .62011 L
s
0 1 .224 r
.50934 .46569 m
.51088 .4664 L
s
0 .484 1 r
.5858 .4006 m
.58559 .39936 L
s
.58559 .39936 m
.58344 .398 L
s
.58559 .39936 m
.58301 .40126 L
s
1 0 .749 r
.58273 .34653 m
.58335 .34763 L
s
.58273 .34653 m
.58328 .35137 L
s
.938 0 1 r
.51078 .74858 m
.51069 .74634 L
s
.51069 .74634 m
.50764 .74455 L
s
.51069 .74634 m
.50698 .74906 L
s
.74204 .55381 m
.74246 .55577 L
s
.73908 .55195 m
.74204 .55381 L
s
.74311 .55121 m
.74204 .55381 L
s
1 0 .749 r
.58328 .35137 m
.587 .34902 L
s
.58328 .35137 m
.58335 .34763 L
s
.5912 .33337 m
.58328 .35137 L
s
0 .97 1 r
.58135 .72361 m
.58321 .72471 L
s
0 .652 1 r
.50944 .2163 m
.50737 .21749 L
s
.50951 .21476 m
.50944 .2163 L
s
.50994 .21781 m
.50944 .2163 L
s
0 .728 1 r
.58179 .59881 m
.5838 .59756 L
s
.5838 .59756 m
.58416 .6006 L
s
0 .369 1 r
.58695 .36881 m
.58678 .36753 L
s
.58678 .36753 m
.58457 .36609 L
s
.58678 .36753 m
.58408 .36945 L
s
0 .484 1 r
.58301 .40126 m
.5858 .4006 L
s
.58344 .398 m
.58301 .40126 L
s
.58301 .40126 m
.58364 .39923 L
s
.59104 .39144 m
.58301 .40126 L
s
.58363 .63227 m
.5838 .63103 L
s
.58643 .63286 m
.58363 .63227 L
s
0 1 .941 r
.50722 .43381 m
.50689 .43263 L
s
.50689 .43263 m
.50534 .43136 L
s
.50689 .43263 m
.50468 .43403 L
s
0 .728 1 r
.58179 .59881 m
.58416 .6006 L
s
.58 0 1 r
.50118 .40565 m
.50517 .40544 L
s
.50233 .40154 m
.50118 .40565 L
s
.50118 .40565 m
.50286 .4034 L
s
.51407 .3948 m
.50118 .40565 L
s
1 0 .749 r
.66089 .63363 m
.66063 .63127 L
s
.66513 .63312 m
.66089 .63363 L
s
0 .484 1 r
.58344 .398 m
.58364 .39923 L
s
.505 0 1 r
.58047 .43383 m
.58326 .43548 L
s
.938 0 1 r
.50698 .74906 m
.51078 .74858 L
s
.50764 .74455 m
.50698 .74906 L
s
.50698 .74906 m
.50773 .74679 L
s
.51815 .73657 m
.50698 .74906 L
s
0 .369 1 r
.58408 .36945 m
.58695 .36881 L
s
.58457 .36609 m
.58408 .36945 L
s
.58408 .36945 m
.58473 .36736 L
s
.59248 .35941 m
.58408 .36945 L
s
.58 0 1 r
.50233 .40154 m
.50286 .4034 L
s
0 .627 1 r
.73994 .41131 m
.74197 .41005 L
s
.74197 .41005 m
.74225 .40867 L
s
.74197 .41005 m
.7395 .4082 L
s
0 .652 1 r
.50737 .21749 m
.50743 .21595 L
s
.50994 .21781 m
.50737 .21749 L
s
0 .369 1 r
.58457 .36609 m
.58473 .36736 L
s
0 1 .941 r
.50468 .43403 m
.50722 .43381 L
s
.50534 .43136 m
.50468 .43403 L
s
.50468 .43403 m
.50566 .43255 L
s
.51266 .42681 m
.50468 .43403 L
s
.938 0 1 r
.50764 .74455 m
.50773 .74679 L
s
.73949 .55391 m
.73908 .55195 L
s
.73908 .55195 m
.74311 .55121 L
s
0 1 .941 r
.50534 .43136 m
.50566 .43255 L
s
.987 0 1 r
.59028 .66606 m
.58725 .66808 L
s
.59051 .66435 m
.59028 .66606 L
s
.59121 .66898 m
.59028 .66606 L
s
0 .627 1 r
.7395 .4082 m
.73994 .41131 L
s
.74225 .40867 m
.7395 .4082 L
s
.7395 .4082 m
.74022 .40994 L
s
.74751 .41715 m
.7395 .4082 L
s
.824 0 1 r
.59081 .69258 m
.59003 .69159 L
s
.59003 .69159 m
.58651 .69094 L
s
.59003 .69159 m
.58781 .69525 L
s
0 1 .224 r
.51308 .53982 m
.51673 .54674 L
s
0 .484 1 r
.5838 .63103 m
.58592 .62961 L
s
.58592 .62961 m
.58643 .63286 L
s
0 .627 1 r
.74022 .40994 m
.73994 .41131 L
s
1 0 .749 r
.66063 .63127 m
.66321 .62866 L
s
.66321 .62866 m
.66513 .63312 L
s
0 .484 1 r
.58364 .39923 m
.5858 .4006 L
s
.58 0 1 r
.50286 .4034 m
.50517 .40544 L
s
0 .484 1 r
.5838 .63103 m
.58643 .63286 L
s
1 .005 0 r
.66335 .66342 m
.66335 .66342 L
s
.66335 .66341 m
.66335 .66342 L
s
.66335 .66342 m
.66334 .66342 L
s
.66335 .66342 m
.66335 .66342 L
s
.66333 .66341 m
.66335 .66342 L
s
.66334 .66342 m
.66335 .66342 L
s
.66335 .66341 m
.66334 .66342 L
s
.66335 .66342 m
.66335 .66341 L
s
.66335 .66342 m
.66335 .66342 L
s
.66333 .33659 m
.66332 .33661 L
s
.66332 .33661 m
.66331 .33661 L
s
.66331 .33661 m
.66332 .3366 L
s
.66331 .33661 m
.66332 .33661 L
s
.66332 .33661 m
.66332 .33661 L
s
.66332 .33661 m
.66332 .33661 L
s
.66332 .3366 m
.66332 .33661 L
s
.66332 .3366 m
.66332 .33661 L
s
.66332 .33661 m
.66332 .33661 L
s
0 1 .941 r
.50566 .43255 m
.50722 .43381 L
s
.824 0 1 r
.58651 .69094 m
.58728 .69193 L
s
.58651 .69094 m
.58781 .69525 L
s
0 .652 1 r
.50743 .21595 m
.50951 .21476 L
s
.50951 .21476 m
.50994 .21781 L
s
1 0 .749 r
.58335 .34763 m
.587 .34902 L
s
0 .369 1 r
.58473 .36736 m
.58695 .36881 L
s
.987 0 1 r
.58725 .66808 m
.58748 .66637 L
s
.59121 .66898 m
.58725 .66808 L
s
0 .652 1 r
.50743 .21595 m
.50994 .21781 L
s
0 .97 1 r
.58775 .28274 m
.59469 .29055 L
s
.824 0 1 r
.58781 .69525 m
.59081 .69258 L
s
.58781 .69525 m
.58728 .69193 L
s
.59206 .67778 m
.58781 .69525 L
s
1 0 .749 r
.66063 .63127 m
.66513 .63312 L
s
0 .627 1 r
.74225 .40867 m
.74022 .40994 L
s
.938 0 1 r
.50773 .74679 m
.51078 .74858 L
s
.74246 .55577 m
.73949 .55391 L
s
.74311 .55121 m
.74246 .55577 L
s
0 1 .224 r
.51682 .54534 m
.51528 .54606 L
s
.51672 .54466 m
.51682 .54534 L
s
.51673 .54674 m
.51682 .54534 L
s
.51528 .54606 m
.51517 .54537 L
s
.51673 .54674 m
.51528 .54606 L
s
.938 0 1 r
.73949 .55391 m
.74311 .55121 L
s
0 .526 1 r
.66596 .64208 m
.67707 .63891 L
s
.505 0 1 r
.58961 .57655 m
.59962 .58965 L
s
0 1 .941 r
.51266 .57319 m
.52066 .58043 L
s
.225 0 1 r
.66878 .39089 m
.67134 .38931 L
s
.67134 .38931 m
.67159 .38755 L
s
.67134 .38931 m
.6682 .38701 L
s
.987 0 1 r
.58748 .66637 m
.59051 .66435 L
s
.59051 .66435 m
.59121 .66898 L
s
0 1 .224 r
.51517 .54537 m
.51672 .54466 L
s
.51672 .54466 m
.51673 .54674 L
s
.51517 .54537 m
.51673 .54674 L
s
.824 0 1 r
.58728 .69193 m
.59081 .69258 L
s
.225 0 1 r
.6682 .38701 m
.66878 .39089 L
s
.67159 .38755 m
.6682 .38701 L
s
.6682 .38701 m
.66903 .38914 L
s
.67814 .39809 m
.6682 .38701 L
s
.987 0 1 r
.58748 .66637 m
.59121 .66898 L
s
.824 0 1 r
.67299 .6209 m
.67231 .62356 L
s
.67106 .61846 m
.67299 .6209 L
s
.67477 .62011 m
.67299 .6209 L
s
0 .484 1 r
.59104 .60856 m
.59911 .61841 L
s
0 .97 1 r
.59416 .2891 m
.5923 .2902 L
s
.5943 .28777 m
.59416 .2891 L
s
.59469 .29055 m
.59416 .2891 L
s
1 0 .749 r
.5912 .66663 m
.59915 .6847 L
s
.58 0 1 r
.51407 .6052 m
.52701 .61609 L
s
.225 0 1 r
.66903 .38914 m
.66878 .39089 L
s
0 1 .941 r
.51967 .57893 m
.51812 .5802 L
s
.52 .57775 m
.51967 .57893 L
s
.52066 .58043 m
.51967 .57893 L
s
.824 0 1 r
.59206 .32222 m
.59633 .33973 L
s
.59684 .33637 m
.59331 .33703 L
s
.59763 .33542 m
.59684 .33637 L
s
.59633 .33973 m
.59684 .33637 L
s
0 .97 1 r
.5923 .2902 m
.59243 .28887 L
s
.59469 .29055 m
.5923 .2902 L
s
.82 0 1 r
.59692 .41898 m
.59655 .4173 L
s
.59655 .4173 m
.59358 .41547 L
s
.59655 .4173 m
.59307 .41995 L
s
0 .369 1 r
.59248 .64059 m
.60092 .65067 L
s
0 .627 1 r
.74751 .58285 m
.75555 .57386 L
s
.824 0 1 r
.59331 .33703 m
.5941 .33608 L
s
.59633 .33973 m
.59331 .33703 L
s
.505 0 1 r
.59876 .58695 m
.59598 .58861 L
s
.59925 .58544 m
.59876 .58695 L
s
.59962 .58965 m
.59876 .58695 L
s
0 1 .941 r
.51812 .5802 m
.51845 .57902 L
s
.52066 .58043 m
.51812 .5802 L
s
.824 0 1 r
.67038 .62112 m
.67106 .61846 L
s
.67106 .61846 m
.67477 .62011 L
s
.82 0 1 r
.59307 .41995 m
.59692 .41898 L
s
.59358 .41547 m
.59307 .41995 L
s
.59307 .41995 m
.59395 .41715 L
s
.604 .40627 m
.59307 .41995 L
s
.58 0 1 r
.52529 .6138 m
.52299 .61586 L
s
.52585 .61196 m
.52529 .6138 L
s
.52701 .61609 m
.52529 .6138 L
s
1 0 .749 r
.59907 .68091 m
.59541 .68232 L
s
.59972 .67985 m
.59907 .68091 L
s
.59915 .6847 m
.59907 .68091 L
s
1 0 .907 r
.51916 .38999 m
.51869 .38804 L
s
.51869 .38804 m
.51587 .38586 L
s
.51869 .38804 m
.51485 .39053 L
s
.225 0 1 r
.67159 .38755 m
.66903 .38914 L
s
0 .97 1 r
.59243 .28887 m
.5943 .28777 L
s
.5943 .28777 m
.59469 .29055 L
s
.82 0 1 r
.59358 .41547 m
.59395 .41715 L
s
0 1 .941 r
.51845 .57902 m
.52 .57775 L
s
.52 .57775 m
.52066 .58043 L
s
0 .97 1 r
.59243 .28887 m
.59469 .29055 L
s
0 .484 1 r
.59846 .61636 m
.59631 .61773 L
s
.59868 .61513 m
.59846 .61636 L
s
.59911 .61841 m
.59846 .61636 L
s
.824 0 1 r
.67231 .62356 m
.67038 .62112 L
s
.67477 .62011 m
.67231 .62356 L
s
0 1 .941 r
.51845 .57902 m
.52066 .58043 L
s
0 .526 1 r
.67578 .63946 m
.67529 .64138 L
s
.67439 .6377 m
.67578 .63946 L
s
.67707 .63891 m
.67578 .63946 L
s
.505 0 1 r
.59598 .58861 m
.59646 .5871 L
s
.59962 .58965 m
.59598 .58861 L
s
1 0 .749 r
.59541 .68232 m
.59605 .68126 L
s
.59915 .6847 m
.59541 .68232 L
s
.938 0 1 r
.51815 .26343 m
.52938 .27598 L
s
1 0 .907 r
.51485 .39053 m
.51916 .38999 L
s
.51587 .38586 m
.51485 .39053 L
s
.51485 .39053 m
.51633 .38781 L
s
.52818 .37751 m
.51485 .39053 L
s
0 .484 1 r
.59631 .61773 m
.59653 .61651 L
s
.59911 .61841 m
.59631 .61773 L
s
0 .479 1 r
.52078 .41841 m
.52046 .41707 L
s
.52046 .41707 m
.51846 .41561 L
s
.52046 .41707 m
.51783 .41885 L
s
0 .369 1 r
.59993 .38359 m
.59974 .3823 L
s
.59974 .3823 m
.59752 .38087 L
s
.59974 .3823 m
.59705 .38424 L
s
.824 0 1 r
.59763 .33542 m
.59633 .33973 L
s
.5941 .33608 m
.59633 .33973 L
s
0 .369 1 r
.60024 .64855 m
.59803 .65001 L
s
.60042 .64729 m
.60024 .64855 L
s
.60092 .65067 m
.60024 .64855 L
s
.58 0 1 r
.52299 .61586 m
.52354 .61402 L
s
.52701 .61609 m
.52299 .61586 L
s
1 0 .907 r
.51587 .38586 m
.51633 .38781 L
s
.887 0 1 r
.75323 .46366 m
.75616 .4618 L
s
.75616 .4618 m
.75659 .45987 L
s
.75616 .4618 m
.75257 .45915 L
s
0 .627 1 r
.75481 .57562 m
.7551 .57698 L
s
.75278 .57435 m
.75481 .57562 L
s
.75555 .57386 m
.75481 .57562 L
s
0 .526 1 r
.6739 .63963 m
.67439 .6377 L
s
.67439 .6377 m
.67707 .63891 L
s
0 .369 1 r
.59705 .38424 m
.59993 .38359 L
s
.59752 .38087 m
.59705 .38424 L
s
.59705 .38424 m
.59771 .38215 L
s
.60545 .37414 m
.59705 .38424 L
s
0 1 .941 r
.52098 .44965 m
.5204 .44864 L
s
.5204 .44864 m
.5187 .44758 L
s
.5204 .44864 m
.51847 .45033 L
s
0 .479 1 r
.51783 .41885 m
.52078 .41841 L
s
.51846 .41561 m
.51783 .41885 L
s
.51783 .41885 m
.51877 .41696 L
s
.52676 .40964 m
.51783 .41885 L
s
.824 0 1 r
.67038 .62112 m
.67477 .62011 L
s
.82 0 1 r
.59395 .41715 m
.59692 .41898 L
s
0 .186 1 r
.60178 .3505 m
.60128 .34969 L
s
.60128 .34969 m
.59863 .34867 L
s
.60128 .34969 m
.59903 .3522 L
s
.824 0 1 r
.5941 .33608 m
.59763 .33542 L
s
0 .369 1 r
.59752 .38087 m
.59771 .38215 L
s
.887 0 1 r
.75257 .45915 m
.75323 .46366 L
s
.75659 .45987 m
.75257 .45915 L
s
.75257 .45915 m
.75367 .46173 L
s
.76432 .47227 m
.75257 .45915 L
s
0 .479 1 r
.51846 .41561 m
.51877 .41696 L
s
0 .526 1 r
.67529 .64138 m
.6739 .63963 L
s
.67707 .63891 m
.67529 .64138 L
s
0 .369 1 r
.59803 .65001 m
.59821 .64875 L
s
.60092 .65067 m
.59803 .65001 L
s
0 .627 1 r
.75308 .57571 m
.75278 .57435 L
s
.75278 .57435 m
.75555 .57386 L
s
.505 0 1 r
.59646 .5871 m
.59925 .58544 L
s
.59925 .58544 m
.59962 .58965 L
s
.58 0 1 r
.52354 .61402 m
.52585 .61196 L
s
.52585 .61196 m
.52701 .61609 L
s
0 .484 1 r
.59653 .61651 m
.59868 .61513 L
s
.59868 .61513 m
.59911 .61841 L
s
.505 0 1 r
.59646 .5871 m
.59962 .58965 L
s
.887 0 1 r
.75367 .46173 m
.75323 .46366 L
s
0 .186 1 r
.59863 .34867 m
.59912 .34948 L
s
.59863 .34867 m
.59903 .3522 L
s
0 .484 1 r
.59653 .61651 m
.59911 .61841 L
s
0 1 .941 r
.51847 .45033 m
.52098 .44965 L
s
.5187 .44758 m
.51847 .45033 L
s
.51847 .45033 m
.51928 .44858 L
s
.52535 .44176 m
.51847 .45033 L
s
.5187 .44758 m
.51928 .44858 L
s
.58 0 1 r
.52354 .61402 m
.52701 .61609 L
s
0 .186 1 r
.59903 .3522 m
.60178 .3505 L
s
.59903 .3522 m
.59912 .34948 L
s
.6049 .33911 m
.59903 .3522 L
s
1 0 .907 r
.51633 .38781 m
.51916 .38999 L
s
1 0 .749 r
.59972 .67985 m
.59915 .6847 L
s
.59605 .68126 m
.59915 .6847 L
s
0 .807 1 r
.52998 .53785 m
.52909 .53871 L
s
.532 .53705 m
.52998 .53785 L
s
.53163 .54003 m
.52998 .53785 L
s
0 .479 1 r
.51877 .41696 m
.52078 .41841 L
s
0 .526 1 r
.6739 .63963 m
.67707 .63891 L
s
1 0 .749 r
.59605 .68126 m
.59972 .67985 L
s
0 .369 1 r
.59771 .38215 m
.59993 .38359 L
s
0 .627 1 r
.7551 .57698 m
.75308 .57571 L
s
.75555 .57386 m
.7551 .57698 L
s
0 1 .941 r
.51928 .44858 m
.52098 .44965 L
s
0 .369 1 r
.59821 .64875 m
.60042 .64729 L
s
.60042 .64729 m
.60092 .65067 L
s
.225 0 1 r
.67814 .60191 m
.68812 .59078 L
s
0 .627 1 r
.75308 .57571 m
.75555 .57386 L
s
0 .369 1 r
.59821 .64875 m
.60092 .65067 L
s
0 .807 1 r
.53111 .53791 m
.532 .53705 L
s
.532 .53705 m
.53163 .54003 L
s
.938 0 1 r
.5286 .27367 m
.52554 .27548 L
s
.52872 .27145 m
.5286 .27367 L
s
.52938 .27598 m
.5286 .27367 L
s
0 .807 1 r
.53163 .54003 m
.52909 .53871 L
s
.53111 .53791 m
.53163 .54003 L
s
.5262 .52928 m
.53163 .54003 L
s
.887 0 1 r
.75659 .45987 m
.75367 .46173 L
s
0 .186 1 r
.59912 .34948 m
.60178 .3505 L
s
0 .526 1 r
.60596 .69678 m
.60539 .69606 L
s
.60539 .69606 m
.60284 .69559 L
s
.60539 .69606 m
.60378 .69871 L
s
0 .627 1 r
.52836 .76404 m
.52828 .7625 L
s
.52828 .7625 m
.52619 .76127 L
s
.52828 .7625 m
.52574 .76437 L
s
0 .807 1 r
.52909 .53871 m
.53111 .53791 L
s
0 .526 1 r
.60284 .69559 m
.60341 .69631 L
s
.60284 .69559 m
.60378 .69871 L
s
0 1 .941 r
.52535 .55824 m
.53224 .56683 L
s
.938 0 1 r
.52554 .27548 m
.52566 .27326 L
s
.52938 .27598 m
.52554 .27548 L
s
0 .627 1 r
.52574 .76437 m
.52836 .76404 L
s
.52619 .76127 m
.52574 .76437 L
s
.52574 .76437 m
.52627 .76282 L
s
.53343 .75582 m
.52574 .76437 L
s
.52619 .76127 m
.52627 .76282 L
s
0 1 .941 r
.53141 .56508 m
.52972 .56615 L
s
.53201 .56408 m
.53141 .56508 L
s
.53224 .56683 m
.53141 .56508 L
s
0 .807 1 r
.5233 .48015 m
.52128 .47933 L
s
.52128 .47933 m
.52038 .47849 L
s
.52128 .47933 m
.52075 .48147 L
s
0 .526 1 r
.60378 .69871 m
.60596 .69678 L
s
.60378 .69871 m
.60341 .69631 L
s
.60685 .68607 m
.60378 .69871 L
s
.82 0 1 r
.604 .59373 m
.61499 .60748 L
s
0 .807 1 r
.5262 .47072 m
.52075 .48147 L
s
0 .479 1 r
.52676 .59036 m
.53572 .5996 L
s
0 .186 1 r
.6049 .66089 m
.61079 .67403 L
s
0 1 .941 r
.52972 .56615 m
.53031 .56515 L
s
.53224 .56683 m
.52972 .56615 L
s
0 .369 1 r
.60545 .62586 m
.61388 .63601 L
s
0 .807 1 r
.5224 .47931 m
.5233 .48015 L
s
.52075 .48147 m
.5233 .48015 L
s
.225 0 1 r
.68727 .59294 m
.68754 .59469 L
s
.68471 .59134 m
.68727 .59294 L
s
.68812 .59078 m
.68727 .59294 L
s
1 0 .907 r
.52818 .62249 m
.54157 .63557 L
s
0 .627 1 r
.52627 .76282 m
.52836 .76404 L
s
0 .526 1 r
.60341 .69631 m
.60596 .69678 L
s
.987 0 1 r
.61093 .40199 m
.61064 .40022 L
s
.61064 .40022 m
.60758 .39826 L
s
.61064 .40022 m
.60695 .40291 L
s
.938 0 1 r
.52566 .27326 m
.52872 .27145 L
s
.52872 .27145 m
.52938 .27598 L
s
0 1 .941 r
.53031 .56515 m
.53201 .56408 L
s
.53201 .56408 m
.53224 .56683 L
s
.53031 .56515 m
.53224 .56683 L
s
0 .526 1 r
.60685 .31393 m
.60992 .32659 L
s
0 .807 1 r
.52038 .47849 m
.52075 .48147 L
s
.52075 .48147 m
.5224 .47931 L
s
0 .526 1 r
.61029 .32416 m
.60774 .32464 L
s
.61087 .32347 m
.61029 .32416 L
s
.60992 .32659 m
.61029 .32416 L
s
0 .186 1 r
.61068 .67128 m
.60803 .67231 L
s
.61119 .67049 m
.61068 .67128 L
s
.61079 .67403 m
.61068 .67128 L
s
.938 0 1 r
.52566 .27326 m
.52938 .27598 L
s
0 .807 1 r
.52038 .47849 m
.5224 .47931 L
s
1 0 .551 r
.53338 .37391 m
.53299 .37191 L
s
.53299 .37191 m
.5298 .36965 L
s
.53299 .37191 m
.5289 .37469 L
s
0 .479 1 r
.53477 .59768 m
.53276 .59915 L
s
.53509 .59634 m
.53477 .59768 L
s
.53572 .5996 m
.53477 .59768 L
s
.225 0 1 r
.68498 .59308 m
.68471 .59134 L
s
.68471 .59134 m
.68812 .59078 L
s
.987 0 1 r
.60695 .40291 m
.61093 .40199 L
s
.60758 .39826 m
.60695 .40291 L
s
.60695 .40291 m
.60787 .40003 L
s
.6185 .38896 m
.60695 .40291 L
s
0 .526 1 r
.60774 .32464 m
.60832 .32394 L
s
.60992 .32659 m
.60774 .32464 L
s
.987 0 1 r
.60758 .39826 m
.60787 .40003 L
s
0 .186 1 r
.60803 .67231 m
.60853 .67152 L
s
.61079 .67403 m
.60803 .67231 L
s
0 .97 1 r
.6873 .37422 m
.68913 .37308 L
s
.68913 .37308 m
.68934 .3718 L
s
.68913 .37308 m
.68688 .37142 L
s
.82 0 1 r
.61408 .60463 m
.61111 .60648 L
s
.61448 .60297 m
.61408 .60463 L
s
.61499 .60748 m
.61408 .60463 L
s
1 0 .551 r
.5289 .37469 m
.53338 .37391 L
s
.5298 .36965 m
.5289 .37469 L
s
.5289 .37469 m
.53018 .37164 L
s
.5424 .36008 m
.5289 .37469 L
s
0 .479 1 r
.53276 .59915 m
.53309 .59781 L
s
.53572 .5996 m
.53276 .59915 L
s
.887 0 1 r
.76432 .52773 m
.77614 .51454 L
s
0 .97 1 r
.68688 .37142 m
.6873 .37422 L
s
.68934 .3718 m
.68688 .37142 L
s
.68688 .37142 m
.68751 .37294 L
s
.69409 .37937 m
.68688 .37142 L
s
0 .107 1 r
.53465 .40227 m
.53438 .40083 L
s
.53438 .40083 m
.53207 .39924 L
s
.53438 .40083 m
.53146 .40285 L
s
0 .369 1 r
.6132 .63389 m
.61098 .63534 L
s
.61341 .63262 m
.6132 .63389 L
s
.61388 .63601 m
.6132 .63389 L
s
1 0 .551 r
.5298 .36965 m
.53018 .37164 L
s
0 .479 1 r
.53419 .4339 m
.53373 .43265 L
s
.53373 .43265 m
.53163 .43132 L
s
.53373 .43265 m
.53125 .43461 L
s
1 0 .907 r
.54005 .63282 m
.53723 .63502 L
s
.54055 .63089 m
.54005 .63282 L
s
.54157 .63557 m
.54005 .63282 L
s
0 .97 1 r
.68751 .37294 m
.6873 .37422 L
s
0 .526 1 r
.61087 .32347 m
.60992 .32659 L
s
.60832 .32394 m
.60992 .32659 L
s
.225 0 1 r
.68754 .59469 m
.68498 .59308 L
s
.68812 .59078 m
.68754 .59469 L
s
0 .107 1 r
.53146 .40285 m
.53465 .40227 L
s
.53207 .39924 m
.53146 .40285 L
s
.53146 .40285 m
.53234 .40068 L
s
.54097 .39235 m
.53146 .40285 L
s
.225 0 1 r
.68498 .59308 m
.68812 .59078 L
s
.82 0 1 r
.61111 .60648 m
.6115 .60482 L
s
.61499 .60748 m
.61111 .60648 L
s
0 .479 1 r
.53309 .59781 m
.53509 .59634 L
s
.53509 .59634 m
.53572 .5996 L
s
0 .186 1 r
.61119 .67049 m
.61079 .67403 L
s
.60853 .67152 m
.61079 .67403 L
s
0 .369 1 r
.61098 .63534 m
.61118 .63407 L
s
.61388 .63601 m
.61098 .63534 L
s
0 .526 1 r
.60832 .32394 m
.61087 .32347 L
s
0 .186 1 r
.61447 .36658 m
.6147 .36486 L
s
.6147 .36486 m
.61279 .36296 L
s
.6147 .36486 m
.61142 .36622 L
s
0 .627 1 r
.53343 .24418 m
.54114 .25277 L
s
0 .107 1 r
.53207 .39924 m
.53234 .40068 L
s
0 .479 1 r
.53125 .43461 m
.53419 .4339 L
s
.53163 .43132 m
.53125 .43461 L
s
.53125 .43461 m
.53208 .43256 L
s
.53954 .42459 m
.53125 .43461 L
s
.987 0 1 r
.60787 .40003 m
.61093 .40199 L
s
0 .186 1 r
.60853 .67152 m
.61119 .67049 L
s
0 .479 1 r
.53309 .59781 m
.53572 .5996 L
s
.53163 .43132 m
.53208 .43256 L
s
0 .186 1 r
.61142 .36622 m
.61447 .36658 L
s
.61279 .36296 m
.61142 .36622 L
s
.61142 .36622 m
.61255 .36467 L
s
.62251 .35895 m
.61142 .36622 L
s
0 .103 1 r
.53301 .46782 m
.53147 .46662 L
s
.53147 .46662 m
.52953 .46536 L
s
.53147 .46662 m
.52956 .46904 L
s
0 .97 1 r
.68934 .3718 m
.68751 .37294 L
s
1 0 .749 r
.6169 .38534 m
.61724 .38294 L
s
.61724 .38294 m
.6146 .38032 L
s
.61724 .38294 m
.61271 .3848 L
s
1 0 .907 r
.53723 .63502 m
.53772 .63309 L
s
.54157 .63557 m
.53723 .63502 L
s
1 0 .551 r
.53018 .37164 m
.53338 .37391 L
s
1 0 .749 r
.61271 .3848 m
.6169 .38534 L
s
.6146 .38032 m
.61271 .3848 L
s
.61271 .3848 m
.61426 .38272 L
s
.62799 .37491 m
.61271 .3848 L
s
0 .186 1 r
.61279 .36296 m
.61255 .36467 L
s
0 .369 1 r
.61118 .63407 m
.61341 .63262 L
s
.61341 .63262 m
.61388 .63601 L
s
0 .479 1 r
.53208 .43256 m
.53419 .4339 L
s
0 .107 1 r
.53234 .40068 m
.53465 .40227 L
s
0 .103 1 r
.54516 .55294 m
.54323 .55422 L
s
.54671 .55177 m
.54516 .55294 L
s
.54669 .55544 m
.54516 .55294 L
s
0 .369 1 r
.61118 .63407 m
.61388 .63601 L
s
.82 0 1 r
.6115 .60482 m
.61448 .60297 L
s
.61448 .60297 m
.61499 .60748 L
s
.6115 .60482 m
.61499 .60748 L
s
0 .103 1 r
.52953 .46536 m
.53107 .46656 L
s
.52953 .46536 m
.52956 .46904 L
s
.52956 .46904 m
.53301 .46782 L
s
.52956 .46904 m
.53107 .46656 L
s
.53812 .4568 m
.52956 .46904 L
s
0 .186 1 r
.61255 .36467 m
.61447 .36658 L
s
1 0 .749 r
.6146 .38032 m
.61426 .38272 L
s
.908 0 1 r
.54214 .71339 m
.54202 .71122 L
s
.54202 .71122 m
.53894 .70943 L
s
.54202 .71122 m
.53833 .71396 L
s
.887 0 1 r
.775 .51717 m
.77546 .51908 L
s
.77207 .51528 m
.775 .51717 L
s
.77614 .51454 m
.775 .51717 L
s
1 0 .907 r
.53772 .63309 m
.54055 .63089 L
s
.54055 .63089 m
.54157 .63557 L
s
0 .627 1 r
.5406 .2512 m
.5385 .25243 L
s
.54069 .24966 m
.5406 .2512 L
s
.54114 .25277 m
.5406 .2512 L
s
0 .103 1 r
.53107 .46656 m
.53301 .46782 L
s
1 0 .907 r
.53772 .63309 m
.54157 .63557 L
s
.908 0 1 r
.53833 .71396 m
.54214 .71339 L
s
.53894 .70943 m
.53833 .71396 L
s
.53833 .71396 m
.53906 .7116 L
s
.5494 .70118 m
.53833 .71396 L
s
0 .103 1 r
.53812 .5432 m
.54669 .55544 L
s
0 .652 1 r
.773 .44793 m
.775 .44665 L
s
.775 .44665 m
.77532 .44531 L
s
.775 .44665 m
.77253 .44482 L
s
0 .627 1 r
.5385 .25243 m
.53859 .25089 L
s
.54114 .25277 m
.5385 .25243 L
s
0 .97 1 r
.69409 .62063 m
.70134 .61265 L
s
.908 0 1 r
.53894 .70943 m
.53906 .7116 L
s
.887 0 1 r
.77253 .5172 m
.77207 .51528 L
s
.77207 .51528 m
.77614 .51454 L
s
0 .103 1 r
.54323 .55422 m
.54479 .55304 L
s
.54669 .55544 m
.54323 .55422 L
s
1 0 .749 r
.61426 .38272 m
.6169 .38534 L
s
0 .652 1 r
.77253 .44482 m
.773 .44793 L
s
.77532 .44531 m
.77253 .44482 L
s
.77253 .44482 m
.77331 .44659 L
s
.78066 .45381 m
.77253 .44482 L
s
0 .103 1 r
.54671 .55177 m
.54669 .55544 L
s
.54479 .55304 m
.54669 .55544 L
s
.54479 .55304 m
.54671 .55177 L
s
0 .479 1 r
.53954 .57541 m
.54786 .58547 L
s
0 .652 1 r
.77331 .44659 m
.773 .44793 L
s
.987 0 1 r
.6185 .61104 m
.63012 .62506 L
s
0 .627 1 r
.53859 .25089 m
.54069 .24966 L
s
.54069 .24966 m
.54114 .25277 L
s
0 .107 1 r
.54097 .60765 m
.55052 .6182 L
s
0 .627 1 r
.53859 .25089 m
.54114 .25277 L
s
1 0 0 r
.61956 .33721 m
.61956 .33721 L
s
.61956 .33721 m
.61956 .33721 L
s
.61956 .33721 m
.61956 .33721 L
s
.61956 .33721 m
.61956 .33721 L
s
.61956 .33721 m
.61956 .33721 L
s
.61956 .33721 m
.61956 .33721 L
s
.61955 .33722 m
.61956 .33721 L
s
.61956 .33721 m
.61956 .33721 L
s
.61956 .33721 m
.61956 .33721 L
s
.61955 .66278 m
.61953 .66278 L
s
.61954 .66278 m
.61954 .66278 L
s
.61954 .66278 m
.61954 .66278 L
s
.61954 .66278 m
.61953 .66278 L
s
.61954 .66278 m
.61954 .66278 L
s
.61954 .66278 m
.61953 .66278 L
s
.61954 .66278 m
.61954 .66278 L
s
.61953 .66278 m
.61954 .66278 L
s
.61953 .66278 m
.61954 .66278 L
s
0 .479 1 r
.54701 .5834 m
.54491 .58475 L
s
.54748 .58216 m
.54701 .5834 L
s
.54786 .58547 m
.54701 .5834 L
s
0 .652 1 r
.77532 .44531 m
.77331 .44659 L
s
.908 0 1 r
.53906 .7116 m
.54214 .71339 L
s
.887 0 1 r
.77546 .51908 m
.77253 .5172 L
s
.77614 .51454 m
.77546 .51908 L
s
0 .97 1 r
.70069 .61418 m
.70091 .61546 L
s
.69886 .61304 m
.70069 .61418 L
s
.70134 .61265 m
.70069 .61418 L
s
1 0 .551 r
.5424 .63992 m
.55598 .65461 L
s
1 0 .812 r
.77759 .48069 m
.78121 .47948 L
s
.78121 .47948 m
.7822 .47824 L
s
.78121 .47948 m
.77838 .47587 L
s
.887 0 1 r
.77253 .5172 m
.77614 .51454 L
s
1 0 .343 r
.54791 .35728 m
.54763 .35529 L
s
.54763 .35529 m
.54417 .35299 L
s
.54763 .35529 m
.54338 .35828 L
s
0 .97 1 r
.69907 .61431 m
.69886 .61304 L
s
.69886 .61304 m
.70134 .61265 L
s
0 .479 1 r
.54491 .58475 m
.54538 .58351 L
s
.54786 .58547 m
.54491 .58475 L
s
1 0 .812 r
.77858 .47944 m
.77759 .48069 L
s
.77838 .47587 m
.77759 .48069 L
s
.23 0 1 r
.70131 .42719 m
.70389 .42559 L
s
.70389 .42559 m
.70421 .42387 L
s
.70389 .42559 m
.70076 .42325 L
s
.824 0 1 r
.62473 .37252 m
.62671 .37006 L
s
.62671 .37006 m
.62597 .36738 L
s
.62671 .37006 m
.62228 .36905 L
s
1 0 .343 r
.54338 .35828 m
.54791 .35728 L
s
.54417 .35299 m
.54338 .35828 L
s
.54338 .35828 m
.54445 .35498 L
s
.55672 .34252 m
.54338 .35828 L
s
.824 0 1 r
.62228 .36905 m
.62473 .37252 L
s
.62597 .36738 m
.62228 .36905 L
s
.62228 .36905 m
.62399 .36983 L
s
.63767 .37357 m
.62228 .36905 L
s
0 .107 1 r
.54962 .616 m
.54731 .6176 L
s
.5499 .61457 m
.54962 .616 L
s
.55052 .6182 m
.54962 .616 L
s
.58 0 1 r
.5457 .45217 m
.54457 .45063 L
s
.54457 .45063 m
.54198 .449 L
s
.54457 .45063 m
.5417 .45331 L
s
0 .186 1 r
.62251 .64105 m
.63367 .64837 L
s
1 0 .812 r
.7822 .47824 m
.77838 .47587 L
s
.77838 .47587 m
.77858 .47944 L
s
.78598 .49388 m
.77838 .47587 L
s
0 .107 1 r
.5479 .41755 m
.54754 .41616 L
s
.54754 .41616 m
.54517 .41464 L
s
.54754 .41616 m
.54471 .41829 L
s
.23 0 1 r
.70076 .42325 m
.70131 .42719 L
s
.70421 .42387 m
.70076 .42325 L
s
.70076 .42325 m
.70163 .42547 L
s
.71078 .43466 m
.70076 .42325 L
s
1 0 .343 r
.54417 .35299 m
.54445 .35498 L
s
0 .97 1 r
.70091 .61546 m
.69907 .61431 L
s
.70134 .61265 m
.70091 .61546 L
s
.113 0 1 r
.5488 .38558 m
.54856 .38409 L
s
.54856 .38409 m
.54607 .38242 L
s
.54856 .38409 m
.54548 .38626 L
s
0 .479 1 r
.54538 .58351 m
.54748 .58216 L
s
.54748 .58216 m
.54786 .58547 L
s
.23 0 1 r
.70163 .42547 m
.70131 .42719 L
s
0 .97 1 r
.69907 .61431 m
.70134 .61265 L
s
0 .479 1 r
.54538 .58351 m
.54786 .58547 L
s
1 0 0 r
.62361 .34176 m
.62362 .34176 L
s
.62361 .34176 m
.62361 .34176 L
s
.62362 .34176 m
.62361 .34176 L
s
.62362 .34176 m
.62362 .34176 L
s
.62361 .34176 m
.62362 .34176 L
s
.62362 .34176 m
.62362 .34176 L
s
.6236 .34177 m
.62362 .34176 L
s
.62362 .34176 m
.62362 .34176 L
s
.62362 .34176 m
.62361 .34176 L
s
.6236 .65823 m
.62359 .65823 L
s
.62359 .65823 m
.62359 .65823 L
s
.62359 .65823 m
.62359 .65823 L
s
.62359 .65823 m
.62359 .65823 L
s
.62359 .65823 m
.62359 .65823 L
s
.62359 .65823 m
.62359 .65823 L
s
.62359 .65823 m
.62359 .65823 L
s
.62359 .65823 m
.62359 .65823 L
s
.62359 .65823 m
.62359 .65823 L
s
.987 0 1 r
.62917 .62213 m
.6261 .62411 L
s
.62949 .62038 m
.62917 .62213 L
s
.63012 .62506 m
.62917 .62213 L
s
0 .107 1 r
.54471 .41829 m
.5479 .41755 L
s
.54517 .41464 m
.54471 .41829 L
s
.54471 .41829 m
.54553 .41603 L
s
.55385 .40729 m
.54471 .41829 L
s
.54731 .6176 m
.54759 .61617 L
s
.55052 .6182 m
.54731 .6176 L
s
.113 0 1 r
.54548 .38626 m
.5488 .38558 L
s
.54607 .38242 m
.54548 .38626 L
s
.54548 .38626 m
.5463 .38391 L
s
.55529 .37492 m
.54548 .38626 L
s
0 .107 1 r
.54517 .41464 m
.54553 .41603 L
s
.824 0 1 r
.62399 .36983 m
.62473 .37252 L
s
0 .652 1 r
.78066 .54619 m
.78883 .53716 L
s
.113 0 1 r
.54607 .38242 m
.5463 .38391 L
s
.58 0 1 r
.5417 .45331 m
.5457 .45217 L
s
.54198 .449 m
.5417 .45331 L
s
.5417 .45331 m
.54311 .45053 L
s
.55241 .43963 m
.5417 .45331 L
s
.54198 .449 m
.54311 .45053 L
s
1 .005 0 r
.62538 .31609 m
.62538 .31609 L
s
.62538 .31608 m
.62538 .31609 L
s
.62538 .31609 m
.62537 .31608 L
s
.62538 .31608 m
.62538 .31609 L
s
.62538 .31608 m
.62538 .31609 L
s
.62537 .31608 m
.62538 .31609 L
s
.62538 .31608 m
.62537 .31608 L
s
.62538 .31608 m
.62538 .31608 L
s
.62538 .31609 m
.62538 .31608 L
s
1 0 .551 r
.55464 .65151 m
.55145 .6538 L
s
.55506 .64953 m
.55464 .65151 L
s
.55598 .65461 m
.55464 .65151 L
s
1 .005 0 r
.62538 .68392 m
.62537 .68393 L
s
.62537 .68393 m
.62537 .68392 L
s
.62537 .68392 m
.62537 .68392 L
s
.62537 .68392 m
.62537 .68393 L
s
.62538 .68392 m
.62537 .68393 L
s
.62537 .68393 m
.62537 .68393 L
s
.62537 .68392 m
.62538 .68392 L
s
.62537 .68392 m
.62537 .68393 L
s
.62537 .68393 m
.62538 .68392 L
s
.987 0 1 r
.6261 .62411 m
.62642 .62236 L
s
.63012 .62506 m
.6261 .62411 L
s
.824 0 1 r
.62597 .36738 m
.62399 .36983 L
s
.23 0 1 r
.70421 .42387 m
.70163 .42547 L
s
1 0 .812 r
.7822 .47824 m
.77858 .47944 L
s
1 0 .343 r
.54445 .35498 m
.54791 .35728 L
s
0 .107 1 r
.54759 .61617 m
.5499 .61457 L
s
.5499 .61457 m
.55052 .6182 L
s
.54553 .41603 m
.5479 .41755 L
s
.54759 .61617 m
.55052 .6182 L
s
.58 0 1 r
.54311 .45053 m
.5457 .45217 L
s
.908 0 1 r
.5494 .29882 m
.56054 .31168 L
s
.113 0 1 r
.5463 .38391 m
.5488 .38558 L
s
1 0 .551 r
.55145 .6538 m
.55186 .65183 L
s
.55598 .65461 m
.55145 .6538 L
s
1 0 .749 r
.62799 .62509 m
.64339 .63507 L
s
0 .186 1 r
.6325 .6468 m
.63058 .64872 L
s
.63228 .64508 m
.6325 .6468 L
s
.63367 .64837 m
.6325 .6468 L
s
0 .652 1 r
.78804 .53894 m
.78836 .54028 L
s
.78603 .53765 m
.78804 .53894 L
s
.78883 .53716 m
.78804 .53894 L
s
.987 0 1 r
.62642 .62236 m
.62949 .62038 L
s
.62949 .62038 m
.63012 .62506 L
s
.62642 .62236 m
.63012 .62506 L
s
1 0 .812 r
.78598 .50612 m
.79361 .48804 L
s
0 .652 1 r
.78635 .53899 m
.78603 .53765 L
s
.78603 .53765 m
.78883 .53716 L
s
.58 0 1 r
.55241 .56037 m
.56315 .57409 L
s
0 .186 1 r
.63058 .64872 m
.63036 .64701 L
s
.63367 .64837 m
.63058 .64872 L
s
1 0 .551 r
.55186 .65183 m
.55506 .64953 L
s
.55506 .64953 m
.55598 .65461 L
s
.58 0 1 r
.56172 .57127 m
.55914 .57292 L
s
.56287 .56976 m
.56172 .57127 L
s
.56315 .57409 m
.56172 .57127 L
s
1 0 .551 r
.55186 .65183 m
.55598 .65461 L
s
0 .107 1 r
.55385 .59271 m
.56303 .60376 L
s
1 0 .812 r
.79339 .49167 m
.7944 .49287 L
s
.78976 .49045 m
.79339 .49167 L
s
.79361 .48804 m
.79339 .49167 L
s
0 .652 1 r
.78836 .54028 m
.78635 .53899 L
s
.78883 .53716 m
.78836 .54028 L
s
0 .186 1 r
.63036 .64701 m
.63228 .64508 L
s
.63228 .64508 m
.63367 .64837 L
s
0 .652 1 r
.78635 .53899 m
.78883 .53716 L
s
.23 0 1 r
.71078 .56534 m
.72086 .55387 L
s
0 .526 1 r
.63493 .35514 m
.63634 .35337 L
s
.63634 .35337 m
.63582 .35142 L
s
.63634 .35337 m
.63315 .35264 L
s
.63315 .35264 m
.63493 .35514 L
s
.63582 .35142 m
.63315 .35264 L
s
.63315 .35264 m
.6344 .35319 L
s
.64429 .35584 m
.63315 .35264 L
s
.908 0 1 r
.55978 .30928 m
.55669 .31109 L
s
.55992 .30712 m
.55978 .30928 L
s
.56054 .31168 m
.55978 .30928 L
s
.113 0 1 r
.55529 .62508 m
.56514 .63648 L
s
1 0 .812 r
.79077 .49165 m
.78976 .49045 L
s
.78976 .49045 m
.79361 .48804 L
s
0 .186 1 r
.63036 .64701 m
.63367 .64837 L
s
.58 0 1 r
.55914 .57292 m
.56029 .57141 L
s
.56315 .57409 m
.55914 .57292 L
s
0 .6 1 r
.5598 .72891 m
.55967 .72738 L
s
.55967 .72738 m
.55754 .72614 L
s
.55967 .72738 m
.55711 .7293 L
s
1 0 .907 r
.55915 .43607 m
.55832 .4343 L
s
.55832 .4343 m
.55529 .4324 L
s
.55832 .4343 m
.55483 .4372 L
s
1 0 .343 r
.55672 .65748 m
.57016 .67334 L
s
0 .526 1 r
.6344 .35319 m
.63493 .35514 L
s
.908 0 1 r
.55669 .31109 m
.55684 .30893 L
s
.56054 .31168 m
.55669 .31109 L
s
1 0 0 r
.56382 .34915 m
.56313 .34792 L
s
.56313 .34792 m
.55887 .34635 L
s
.56313 .34792 m
.55958 .35195 L
s
0 .107 1 r
.56219 .60147 m
.55981 .603 L
s
.56256 .6001 m
.56219 .60147 L
s
.56303 .60376 m
.56219 .60147 L
s
0 .6 1 r
.55711 .7293 m
.5598 .72891 L
s
.55754 .72614 m
.55711 .7293 L
s
.55711 .7293 m
.55768 .72767 L
s
.56494 .72043 m
.55711 .7293 L
s
.58 0 1 r
.56029 .57141 m
.56287 .56976 L
s
.56287 .56976 m
.56315 .57409 L
s
0 .6 1 r
.55754 .72614 m
.55768 .72767 L
s
.58 0 1 r
.56029 .57141 m
.56315 .57409 L
s
0 .526 1 r
.63582 .35142 m
.6344 .35319 L
s
.113 0 1 r
.56194 .40069 m
.56165 .39921 L
s
.56165 .39921 m
.55912 .39758 L
s
.56165 .39921 m
.5586 .40145 L
s
1 0 .749 r
.64178 .63294 m
.63914 .63558 L
s
.64147 .63055 m
.64178 .63294 L
s
.64339 .63507 m
.64178 .63294 L
s
1 0 .907 r
.55483 .4372 m
.55915 .43607 L
s
.55529 .4324 m
.55483 .4372 L
s
.55483 .4372 m
.55612 .43416 L
s
.56682 .42233 m
.55483 .4372 L
s
1 0 0 r
.55887 .34635 m
.55955 .34758 L
s
.55887 .34635 m
.55958 .35195 L
s
0 .107 1 r
.55981 .603 m
.56019 .60163 L
s
.56303 .60376 m
.55981 .603 L
s
1 0 .907 r
.55529 .4324 m
.55612 .43416 L
s
1 0 .812 r
.79361 .48804 m
.7944 .49287 L
s
.79077 .49165 m
.79361 .48804 L
s
.195 0 1 r
.56327 .36839 m
.56307 .3669 L
s
.56307 .3669 m
.56047 .36521 L
s
.56307 .3669 m
.55991 .36915 L
s
1 0 0 r
.55958 .35195 m
.56382 .34915 L
s
.55958 .35195 m
.55955 .34758 L
s
.56842 .33094 m
.55958 .35195 L
s
.23 0 1 r
.71996 .55612 m
.7203 .55782 L
s
.71737 .55451 m
.71996 .55612 L
s
.72086 .55387 m
.71996 .55612 L
s
.113 0 1 r
.56429 .63409 m
.56179 .63577 L
s
.56454 .63262 m
.56429 .63409 L
s
.56514 .63648 m
.56429 .63409 L
s
.824 0 1 r
.63767 .62643 m
.65317 .62187 L
s
.113 0 1 r
.5586 .40145 m
.56194 .40069 L
s
.55912 .39758 m
.5586 .40145 L
s
.5586 .40145 m
.55941 .39905 L
s
.56826 .38986 m
.5586 .40145 L
s
0 .6 1 r
.55768 .72767 m
.5598 .72891 L
s
1 0 .812 r
.7944 .49287 m
.79077 .49165 L
s
.113 0 1 r
.55912 .39758 m
.55941 .39905 L
s
.908 0 1 r
.55684 .30893 m
.55992 .30712 L
s
.55992 .30712 m
.56054 .31168 L
s
.195 0 1 r
.55991 .36915 m
.56327 .36839 L
s
.56047 .36521 m
.55991 .36915 L
s
.55991 .36915 m
.56067 .36669 L
s
.56971 .35736 m
.55991 .36915 L
s
.908 0 1 r
.55684 .30893 m
.56054 .31168 L
s
.195 0 1 r
.56047 .36521 m
.56067 .36669 L
s
.23 0 1 r
.71771 .55621 m
.71737 .55451 L
s
.71737 .55451 m
.72086 .55387 L
s
0 .479 1 r
.79666 .47734 m
.7991 .47647 L
s
.7991 .47647 m
.79979 .47558 L
s
.7991 .47647 m
.79713 .47403 L
s
1 0 .749 r
.63914 .63558 m
.63882 .6332 L
s
.64339 .63507 m
.63914 .63558 L
s
0 .107 1 r
.56019 .60163 m
.56256 .6001 L
s
.56256 .6001 m
.56303 .60376 L
s
.113 0 1 r
.56179 .63577 m
.56204 .6343 L
s
.56514 .63648 m
.56179 .63577 L
s
1 0 .433 r
.56775 .69768 m
.56695 .69649 L
s
.56695 .69649 m
.5628 .6957 L
s
.56695 .69649 m
.56427 .70077 L
s
0 .107 1 r
.56019 .60163 m
.56303 .60376 L
s
1 0 .907 r
.55612 .43416 m
.55915 .43607 L
s
0 .479 1 r
.79734 .47644 m
.79666 .47734 L
s
.79713 .47403 m
.79666 .47734 L
s
.79979 .47558 m
.79713 .47403 L
s
.79713 .47403 m
.79734 .47644 L
s
.8026 .48617 m
.79713 .47403 L
s
0 .98 1 r
.72017 .41063 m
.72201 .40948 L
s
.72201 .40948 m
.72225 .40823 L
s
.72201 .40948 m
.71976 .40781 L
s
.113 0 1 r
.55941 .39905 m
.56194 .40069 L
s
1 0 .433 r
.5628 .6957 m
.56359 .69689 L
s
.5628 .6957 m
.56427 .70077 L
s
1 0 .343 r
.56903 .66997 m
.56557 .6723 L
s
.56936 .66801 m
.56903 .66997 L
s
.57016 .67334 m
.56903 .66997 L
s
0 .98 1 r
.71976 .40781 m
.72017 .41063 L
s
.72225 .40823 m
.71976 .40781 L
s
.71976 .40781 m
.72041 .40938 L
s
.72701 .41594 m
.71976 .40781 L
s
1 0 .749 r
.63882 .6332 m
.64147 .63055 L
s
.64147 .63055 m
.64339 .63507 L
s
1 .005 0 r
.64165 .33423 m
.64165 .33423 L
s
.64165 .33422 m
.64165 .33423 L
s
.64165 .33423 m
.64165 .33422 L
s
.64166 .33422 m
.64165 .33423 L
s
.64164 .33421 m
.64165 .33423 L
s
.64165 .33422 m
.64165 .33423 L
s
.64165 .33422 m
.64165 .33422 L
s
.64166 .33422 m
.64165 .33422 L
s
.64165 .33423 m
.64166 .33422 L
s
.64164 .66579 m
.64162 .66581 L
s
.64163 .66581 m
.64162 .66581 L
s
.64162 .66581 m
.64163 .6658 L
s
.64162 .66581 m
.64162 .66581 L
s
.64163 .66581 m
.64163 .66581 L
s
.64162 .66581 m
.64163 .66581 L
s
.64163 .6658 m
.64163 .66581 L
s
.64163 .6658 m
.64162 .66581 L
s
.64162 .66581 m
.64163 .66581 L
s
.195 0 1 r
.56067 .36669 m
.56327 .36839 L
s
0 .98 1 r
.72041 .40938 m
.72017 .41063 L
s
.113 0 1 r
.56204 .6343 m
.56454 .63262 L
s
.56454 .63262 m
.56514 .63648 L
s
1 0 0 r
.55955 .34758 m
.56382 .34915 L
s
.23 0 1 r
.7203 .55782 m
.71771 .55621 L
s
.72086 .55387 m
.7203 .55782 L
s
1 0 .433 r
.56427 .70077 m
.56775 .69768 L
s
.56427 .70077 m
.56359 .69689 L
s
.56929 .68038 m
.56427 .70077 L
s
.113 0 1 r
.56204 .6343 m
.56514 .63648 L
s
.23 0 1 r
.71771 .55621 m
.72086 .55387 L
s
0 .479 1 r
.79979 .47558 m
.79734 .47644 L
s
0 .6 1 r
.56494 .27957 m
.5728 .28846 L
s
1 0 .343 r
.56557 .6723 m
.56589 .67034 L
s
.57016 .67334 m
.56557 .6723 L
s
1 0 .749 r
.63882 .6332 m
.64339 .63507 L
s
0 .98 1 r
.72225 .40823 m
.72041 .40938 L
s
0 .526 1 r
.64429 .64416 m
.6555 .64094 L
s
1 0 .907 r
.56682 .57767 m
.57886 .5926 L
s
.225 0 1 r
.64709 .38929 m
.64968 .38769 L
s
.64968 .38769 m
.64994 .3859 L
s
.64968 .38769 m
.6465 .38535 L
s
0 .479 1 r
.8026 .51383 m
.80808 .50166 L
s
1 0 .433 r
.56359 .69689 m
.56775 .69768 L
s
.225 0 1 r
.6465 .38535 m
.64709 .38929 L
s
.64994 .3859 m
.6465 .38535 L
s
.6465 .38535 m
.64734 .38751 L
s
.65658 .39659 m
.6465 .38535 L
s
.824 0 1 r
.6514 .62267 m
.65069 .62537 L
s
.64943 .6202 m
.6514 .62267 L
s
.65317 .62187 m
.6514 .62267 L
s
.113 0 1 r
.56826 .61014 m
.57797 .62179 L
s
1 0 0 r
.56842 .66906 m
.57731 .69018 L
s
1 0 .343 r
.56589 .67034 m
.56936 .66801 L
s
.56936 .66801 m
.57016 .67334 L
s
0 .6 1 r
.57222 .28682 m
.57009 .28807 L
s
.57236 .28529 m
.57222 .28682 L
s
.5728 .28846 m
.57222 .28682 L
s
.225 0 1 r
.64734 .38751 m
.64709 .38929 L
s
1 0 .551 r
.57299 .41945 m
.57239 .41751 L
s
.57239 .41751 m
.56906 .4154 L
s
.57239 .41751 m
.56846 .42055 L
s
0 .479 1 r
.80786 .50409 m
.80856 .50497 L
s
.80542 .50322 m
.80786 .50409 L
s
.80808 .50166 m
.80786 .50409 L
s
1 0 .343 r
.56589 .67034 m
.57016 .67334 L
s
1 0 .433 r
.56929 .31962 m
.57432 .34007 L
s
1 0 .907 r
.57753 .58952 m
.5745 .59144 L
s
.5784 .58778 m
.57753 .58952 L
s
.57886 .5926 m
.57753 .58952 L
s
1 0 .433 r
.57499 .33614 m
.57084 .33694 L
s
.5758 .335 m
.57499 .33614 L
s
.57432 .34007 m
.57499 .33614 L
s
.195 0 1 r
.56971 .64264 m
.57956 .6545 L
s
0 .6 1 r
.57009 .28807 m
.57024 .28655 L
s
.5728 .28846 m
.57009 .28807 L
s
0 .98 1 r
.72701 .58406 m
.73427 .5759 L
s
0 .479 1 r
.80611 .5041 m
.80542 .50322 L
s
.80542 .50322 m
.80808 .50166 L
s
1 0 .551 r
.56846 .42055 m
.57299 .41945 L
s
.56906 .4154 m
.56846 .42055 L
s
.56846 .42055 m
.56966 .41733 L
s
.58133 .4049 m
.56846 .42055 L
s
1 0 .433 r
.57084 .33694 m
.57164 .33581 L
s
.57432 .34007 m
.57084 .33694 L
s
.824 0 1 r
.64871 .62289 m
.64943 .6202 L
s
.64943 .6202 m
.65317 .62187 L
s
1 0 .551 r
.56906 .4154 m
.56966 .41733 L
s
1 0 0 r
.57731 .68574 m
.57304 .68733 L
s
.57803 .68456 m
.57731 .68574 L
s
.57731 .69018 m
.57731 .68574 L
s
.225 0 1 r
.64994 .3859 m
.64734 .38751 L
s
1 0 .907 r
.5745 .59144 m
.57536 .5897 L
s
.57886 .5926 m
.5745 .59144 L
s
.195 0 1 r
.5763 .38333 m
.57608 .38183 L
s
.57608 .38183 m
.57348 .38013 L
s
.57608 .38183 m
.57292 .38409 L
s
.824 0 1 r
.65069 .62537 m
.64871 .62289 L
s
.65317 .62187 m
.65069 .62537 L
s
0 .6 1 r
.57024 .28655 m
.57236 .28529 L
s
.57236 .28529 m
.5728 .28846 L
s
0 .526 1 r
.65422 .6415 m
.6537 .64346 L
s
.6528 .63972 m
.65422 .6415 L
s
.6555 .64094 m
.65422 .6415 L
s
.113 0 1 r
.57714 .61936 m
.57461 .62101 L
s
.57745 .6179 m
.57714 .61936 L
s
.57797 .62179 m
.57714 .61936 L
s
0 .479 1 r
.80808 .50166 m
.80856 .50497 L
s
.80611 .5041 m
.80808 .50166 L
s
0 .6 1 r
.57024 .28655 m
.5728 .28846 L
s
1 0 0 r
.57304 .68733 m
.57374 .68615 L
s
.57731 .69018 m
.57304 .68733 L
s
0 .479 1 r
.80856 .50497 m
.80611 .5041 L
s
.195 0 1 r
.57292 .38409 m
.5763 .38333 L
s
.57348 .38013 m
.57292 .38409 L
s
.57292 .38409 m
.57369 .38164 L
s
.58279 .37229 m
.57292 .38409 L
s
0 .98 1 r
.73361 .57749 m
.73387 .57873 L
s
.73177 .57633 m
.73361 .57749 L
s
.73427 .5759 m
.73361 .57749 L
s
.195 0 1 r
.57348 .38013 m
.57369 .38164 L
s
.361 0 1 r
.57876 .35001 m
.57819 .34909 L
s
.57819 .34909 m
.5751 .34793 L
s
.57819 .34909 m
.5756 .35202 L
s
.113 0 1 r
.57461 .62101 m
.57491 .61955 L
s
.57797 .62179 m
.57461 .62101 L
s
0 .526 1 r
.65229 .64168 m
.6528 .63972 L
s
.6528 .63972 m
.6555 .64094 L
s
.195 0 1 r
.57878 .65201 m
.57618 .65371 L
s
.579 .65054 m
.57878 .65201 L
s
.57956 .6545 m
.57878 .65201 L
s
1 0 .551 r
.56966 .41733 m
.57299 .41945 L
s
1 0 .433 r
.5758 .335 m
.57432 .34007 L
s
.57164 .33581 m
.57432 .34007 L
s
.824 0 1 r
.64871 .62289 m
.65317 .62187 L
s
1 0 .907 r
.57536 .5897 m
.5784 .58778 L
s
.5784 .58778 m
.57886 .5926 L
s
0 .98 1 r
.73202 .57757 m
.73177 .57633 L
s
.73177 .57633 m
.73427 .5759 L
s
1 0 .907 r
.57536 .5897 m
.57886 .5926 L
s
0 .526 1 r
.6537 .64346 m
.65229 .64168 L
s
.6555 .64094 m
.6537 .64346 L
s
.361 0 1 r
.5751 .34793 m
.57566 .34885 L
s
.5751 .34793 m
.5756 .35202 L
s
.5756 .35202 m
.57876 .35001 L
s
.5756 .35202 m
.57566 .34885 L
s
.58224 .33674 m
.5756 .35202 L
s
.197 0 1 r
.73437 .46436 m
.73693 .46273 L
s
.73693 .46273 m
.73728 .46105 L
s
.73693 .46273 m
.73379 .46042 L
s
.195 0 1 r
.57618 .65371 m
.57639 .65225 L
s
.57956 .6545 m
.57618 .65371 L
s
1 0 .433 r
.57164 .33581 m
.5758 .335 L
s
.195 0 1 r
.57369 .38164 m
.5763 .38333 L
s
.113 0 1 r
.57491 .61955 m
.57745 .6179 L
s
.57745 .6179 m
.57797 .62179 L
s
.197 0 1 r
.73379 .46042 m
.73437 .46436 L
s
.73728 .46105 m
.73379 .46042 L
s
.73379 .46042 m
.73472 .46267 L
s
.74397 .47186 m
.73379 .46042 L
s
0 .98 1 r
.73387 .57873 m
.73202 .57757 L
s
.73427 .5759 m
.73387 .57873 L
s
0 .526 1 r
.65229 .64168 m
.6555 .64094 L
s
.113 0 1 r
.57491 .61955 m
.57797 .62179 L
s
0 .98 1 r
.73202 .57757 m
.73427 .5759 L
s
.197 0 1 r
.73472 .46267 m
.73437 .46436 L
s
1 0 0 r
.57803 .68456 m
.57731 .69018 L
s
.57374 .68615 m
.57731 .69018 L
s
.225 0 1 r
.65658 .60341 m
.6667 .59211 L
s
1 0 0 r
.57374 .68615 m
.57803 .68456 L
s
0 .067 1 r
.58317 .7011 m
.58253 .70027 L
s
.58253 .70027 m
.5796 .69973 L
s
.58253 .70027 m
.58068 .70331 L
s
.195 0 1 r
.57639 .65225 m
.579 .65054 L
s
.579 .65054 m
.57956 .6545 L
s
.361 0 1 r
.57566 .34885 m
.57876 .35001 L
s
.195 0 1 r
.57639 .65225 m
.57956 .6545 L
s
0 .067 1 r
.5796 .69973 m
.58023 .70056 L
s
.5796 .69973 m
.58068 .70331 L
s
.197 0 1 r
.73728 .46105 m
.73472 .46267 L
s
0 .067 1 r
.58068 .70331 m
.58317 .7011 L
s
.58068 .70331 m
.58023 .70056 L
s
.58421 .68881 m
.58068 .70331 L
s
1 0 .551 r
.58133 .5951 m
.59428 .61084 L
s
1 0 .343 r
.58717 .4023 m
.58678 .40025 L
s
.58678 .40025 m
.58328 .39799 L
s
.58678 .40025 m
.58255 .40333 L
s
.361 0 1 r
.58224 .66326 m
.58889 .67858 L
s
.195 0 1 r
.58279 .62771 m
.59271 .63957 L
s
.225 0 1 r
.66583 .5943 m
.66611 .59607 L
s
.66323 .59268 m
.66583 .5943 L
s
.6667 .59211 m
.66583 .5943 L
s
0 .067 1 r
.58023 .70056 m
.58317 .7011 L
s
1 0 .343 r
.58255 .40333 m
.58717 .4023 L
s
.58328 .39799 m
.58255 .40333 L
s
.58255 .40333 m
.58366 .40003 L
s
.59596 .38733 m
.58255 .40333 L
s
1 .65 0 r
.81995 .48647 m
.82034 .48622 L
s
.82034 .48622 m
.82041 .48596 L
s
.82034 .48622 m
.81985 .48586 L
s
.81985 .48586 m
.81995 .48647 L
s
.82041 .48596 m
.81985 .48586 L
s
.81985 .48586 m
.82002 .48621 L
s
.82148 .48765 m
.81985 .48586 L
s
.82002 .48621 m
.81995 .48647 L
s
1 0 .343 r
.58328 .39799 m
.58366 .40003 L
s
0 .067 1 r
.58421 .31119 m
.58774 .32573 L
s
.58818 .32295 m
.58525 .32349 L
s
.58882 .32214 m
.58818 .32295 L
s
.58774 .32573 m
.58818 .32295 L
s
1 .65 0 r
.82041 .48596 m
.82002 .48621 L
s
.361 0 1 r
.58882 .67537 m
.58572 .67654 L
s
.5894 .67448 m
.58882 .67537 L
s
.58889 .67858 m
.58882 .67537 L
s
.225 0 1 r
.66351 .59445 m
.66323 .59268 L
s
.66323 .59268 m
.6667 .59211 L
s
0 .067 1 r
.58525 .32349 m
.58588 .32269 L
s
.58774 .32573 m
.58525 .32349 L
s
1 .65 0 r
.82148 .51235 m
.8231 .51056 L
s
.361 0 1 r
.58572 .67654 m
.5863 .67566 L
s
.58889 .67858 m
.58572 .67654 L
s
1 0 .551 r
.59303 .60757 m
.58971 .60971 L
s
.59366 .60566 m
.59303 .60757 L
s
.59428 .61084 m
.59303 .60757 L
s
0 .97 1 r
.66582 .37237 m
.66769 .37121 L
s
.66769 .37121 m
.66788 .36991 L
s
.66769 .37121 m
.6654 .36953 L
s
1 .65 0 r
.82294 .51091 m
.82301 .51117 L
s
.82254 .51066 m
.82294 .51091 L
s
.8231 .51056 m
.82294 .51091 L
s
.82261 .51092 m
.82254 .51066 L
s
.82254 .51066 m
.8231 .51056 L
s
.197 0 1 r
.74397 .52814 m
.75421 .51664 L
s
0 .97 1 r
.6654 .36953 m
.66582 .37237 L
s
.66788 .36991 m
.6654 .36953 L
s
.6654 .36953 m
.66601 .37107 L
s
.67268 .37759 m
.6654 .36953 L
s
.361 0 1 r
.59064 .36561 m
.59096 .3636 L
s
.59096 .3636 m
.58874 .36137 L
s
.59096 .3636 m
.58712 .36514 L
s
1 .65 0 r
.82301 .51117 m
.82261 .51092 L
s
.8231 .51056 m
.82301 .51117 L
s
.82261 .51092 m
.8231 .51056 L
s
1 0 0 r
.59263 .38494 m
.5931 .38214 L
s
.5931 .38214 m
.59006 .37908 L
s
.5931 .38214 m
.58781 .38424 L
s
0 .97 1 r
.66601 .37107 m
.66582 .37237 L
s
.361 0 1 r
.58712 .36514 m
.59064 .36561 L
s
.58874 .36137 m
.58712 .36514 L
s
.58712 .36514 m
.58843 .36338 L
s
.6 .35687 m
.58712 .36514 L
s
.225 0 1 r
.66611 .59607 m
.66351 .59445 L
s
.6667 .59211 m
.66611 .59607 L
s
.195 0 1 r
.59191 .63708 m
.5893 .63879 L
s
.59214 .63559 m
.59191 .63708 L
s
.59271 .63957 m
.59191 .63708 L
s
1 0 0 r
.58781 .38424 m
.59263 .38494 L
s
.59006 .37908 m
.58781 .38424 L
s
.58781 .38424 m
.58958 .38188 L
s
.60553 .37306 m
.58781 .38424 L
s
0 .067 1 r
.58882 .32214 m
.58774 .32573 L
s
.58588 .32269 m
.58774 .32573 L
s
1 0 .343 r
.58366 .40003 m
.58717 .4023 L
s
.225 0 1 r
.66351 .59445 m
.6667 .59211 L
s
1 0 .551 r
.58971 .60971 m
.59034 .6078 L
s
.59428 .61084 m
.58971 .60971 L
s
.361 0 1 r
.5894 .67448 m
.58889 .67858 L
s
.5863 .67566 m
.58889 .67858 L
s
.58874 .36137 m
.58843 .36338 L
s
0 .067 1 r
.58588 .32269 m
.58882 .32214 L
s
.195 0 1 r
.5893 .63879 m
.58953 .6373 L
s
.59271 .63957 m
.5893 .63879 L
s
0 .97 1 r
.66788 .36991 m
.66601 .37107 L
s
.361 0 1 r
.5863 .67566 m
.5894 .67448 L
s
1 0 0 r
.59006 .37908 m
.58958 .38188 L
s
.361 0 1 r
.58843 .36338 m
.59064 .36561 L
s
.197 0 1 r
.75325 .51893 m
.75363 .5206 L
s
.75069 .51729 m
.75325 .51893 L
s
.75421 .51664 m
.75325 .51893 L
s
1 0 .551 r
.59034 .6078 m
.59366 .60566 L
s
.59366 .60566 m
.59428 .61084 L
s
.195 0 1 r
.58953 .6373 m
.59214 .63559 L
s
.59214 .63559 m
.59271 .63957 L
s
1 0 .551 r
.59034 .6078 m
.59428 .61084 L
s
.195 0 1 r
.58953 .6373 m
.59271 .63957 L
s
1 0 0 r
.58958 .38188 m
.59263 .38494 L
s
.197 0 1 r
.75106 .51896 m
.75069 .51729 L
s
.75069 .51729 m
.75421 .51664 L
s
0 .97 1 r
.67268 .62241 m
.67998 .61431 L
s
0 .998 1 r
.75354 .44778 m
.75537 .44661 L
s
.75537 .44661 m
.75564 .44539 L
s
.75537 .44661 m
.75312 .44495 L
s
.75312 .44495 m
.75354 .44778 L
s
.75564 .44539 m
.75312 .44495 L
s
.75312 .44495 m
.7538 .44655 L
s
.76048 .45313 m
.75312 .44495 L
s
.7538 .44655 m
.75354 .44778 L
s
.197 0 1 r
.75363 .5206 m
.75106 .51896 L
s
.75421 .51664 m
.75363 .5206 L
s
1 0 .343 r
.59596 .61267 m
.60946 .62878 L
s
.197 0 1 r
.75106 .51896 m
.75421 .51664 L
s
1 .098 0 r
.59679 .66498 m
.59686 .66494 L
s
.59686 .66494 m
.59686 .66491 L
s
.59686 .66494 m
.59678 .66489 L
s
.59678 .66489 m
.59679 .66498 L
s
.59686 .66491 m
.59678 .66489 L
s
.59678 .66489 m
.59679 .66495 L
s
.59701 .66518 m
.59678 .66489 L
s
.59679 .66495 m
.59679 .66498 L
s
.59686 .66491 m
.59679 .66495 L
s
.59701 .33482 m
.59725 .33452 L
s
1 0 .433 r
.60021 .37034 m
.60255 .36748 L
s
.60255 .36748 m
.60169 .36434 L
s
.60255 .36748 m
.59738 .36625 L
s
1 .098 0 r
.59723 .33458 m
.59724 .33462 L
s
.59717 .33454 m
.59723 .33458 L
s
.59725 .33452 m
.59723 .33458 L
s
.59717 .33458 m
.59717 .33454 L
s
.59717 .33454 m
.59725 .33452 L
s
.59724 .33462 m
.59717 .33458 L
s
.59725 .33452 m
.59724 .33462 L
s
.59717 .33458 m
.59725 .33452 L
s
0 .97 1 r
.67935 .61587 m
.67955 .61716 L
s
.67748 .6147 m
.67935 .61587 L
s
.67998 .61431 m
.67935 .61587 L
s
1 0 .433 r
.59738 .36625 m
.60021 .37034 L
s
.60169 .36434 m
.59738 .36625 L
s
.59738 .36625 m
.59934 .3672 L
s
.61529 .3717 m
.59738 .36625 L
s
0 .998 1 r
.75564 .44539 m
.7538 .44655 L
s
0 .97 1 r
.67768 .616 m
.67748 .6147 L
s
.67748 .6147 m
.67998 .61431 L
s
.466 0 1 r
.7586 .48222 m
.76177 .48118 L
s
.76177 .48118 m
.76262 .4801 L
s
.76177 .48118 m
.7593 .47801 L
s
.23 0 1 r
.67995 .42611 m
.68258 .42449 L
s
.68258 .42449 m
.68288 .42275 L
s
.68258 .42449 m
.67939 .42212 L
s
.361 0 1 r
.6 .64313 m
.61296 .65146 L
s
1 0 .433 r
.59934 .3672 m
.60021 .37034 L
s
.23 0 1 r
.67939 .42212 m
.67995 .42611 L
s
.68288 .42275 m
.67939 .42212 L
s
.67939 .42212 m
.68025 .42437 L
s
.68952 .4337 m
.67939 .42212 L
s
.466 0 1 r
.75944 .48114 m
.7586 .48222 L
s
.7593 .47801 m
.7586 .48222 L
s
0 .97 1 r
.67955 .61716 m
.67768 .616 L
s
.67998 .61431 m
.67955 .61716 L
s
1 .098 0 r
.60088 .66038 m
.60094 .66034 L
s
.60094 .66034 m
.60094 .6603 L
s
.60094 .66034 m
.60086 .66028 L
s
.60086 .66028 m
.60088 .66038 L
s
.60094 .6603 m
.60086 .66028 L
s
.60086 .66028 m
.60088 .66034 L
s
.6011 .66057 m
.60086 .66028 L
s
.60088 .66034 m
.60088 .66038 L
s
.23 0 1 r
.68025 .42437 m
.67995 .42611 L
s
1 .098 0 r
.60094 .6603 m
.60088 .66034 L
s
0 .97 1 r
.67768 .616 m
.67998 .61431 L
s
1 .098 0 r
.6011 .33943 m
.60135 .33914 L
s
.466 0 1 r
.76262 .4801 m
.7593 .47801 L
s
.7593 .47801 m
.75944 .48114 L
s
.76584 .49379 m
.7593 .47801 L
s
1 .098 0 r
.60133 .3392 m
.60133 .33924 L
s
.60127 .33916 m
.60133 .3392 L
s
.60135 .33914 m
.60133 .3392 L
s
.60127 .3392 m
.60127 .33916 L
s
.60127 .33916 m
.60135 .33914 L
s
.60133 .33924 m
.60127 .3392 L
s
.60135 .33914 m
.60133 .33924 L
s
.60127 .3392 m
.60135 .33914 L
s
1 0 .433 r
.60169 .36434 m
.59934 .3672 L
s
1 0 .343 r
.60829 .62542 m
.60479 .6277 L
s
.60871 .6234 m
.60829 .62542 L
s
.60946 .62878 m
.60829 .62542 L
s
0 .998 1 r
.76048 .54687 m
.76786 .53865 L
s
1 .036 0 r
.60284 .31325 m
.60284 .31329 L
s
.60286 .31326 m
.60284 .31325 L
s
.60284 .31325 m
.60283 .31327 L
s
.60287 .31327 m
.60284 .31325 L
s
.60289 .31337 m
.60284 .31325 L
s
.60284 .31329 m
.60287 .31327 L
s
.60283 .31327 m
.60284 .31329 L
s
.60287 .31327 m
.60286 .31326 L
s
.60286 .31326 m
.60283 .31327 L
s
.60289 .68663 m
.60295 .68652 L
s
.60293 .68652 m
.60295 .68654 L
s
.60292 .68654 m
.60293 .68652 L
s
.60293 .68652 m
.60295 .68652 L
s
.60295 .68654 m
.60294 .68655 L
s
.60295 .68652 m
.60295 .68654 L
s
.60294 .68655 m
.60292 .68654 L
s
.60292 .68654 m
.60295 .68652 L
s
.60295 .68652 m
.60294 .68655 L
s
.23 0 1 r
.68288 .42275 m
.68025 .42437 L
s
1 0 .343 r
.60479 .6277 m
.6052 .62569 L
s
.60946 .62878 m
.60479 .6277 L
s
.466 0 1 r
.76262 .4801 m
.75944 .48114 L
s
1 0 0 r
.60553 .62694 m
.62341 .63822 L
s
0 .998 1 r
.76716 .54027 m
.76744 .54149 L
s
.76533 .5391 m
.76716 .54027 L
s
.76786 .53865 m
.76716 .54027 L
s
.7656 .54032 m
.76533 .5391 L
s
.76533 .5391 m
.76786 .53865 L
s
.361 0 1 r
.61162 .64967 m
.6094 .65192 L
s
.61133 .64767 m
.61162 .64967 L
s
.61296 .65146 m
.61162 .64967 L
s
.466 0 1 r
.76584 .50621 m
.7724 .49038 L
s
1 0 .343 r
.6052 .62569 m
.60871 .6234 L
s
.60871 .6234 m
.60946 .62878 L
s
.6052 .62569 m
.60946 .62878 L
s
0 .067 1 r
.61129 .35288 m
.61293 .35085 L
s
.61293 .35085 m
.61231 .34861 L
s
.61293 .35085 m
.60926 .35001 L
s
0 .998 1 r
.76744 .54149 m
.7656 .54032 L
s
.76786 .53865 m
.76744 .54149 L
s
0 .067 1 r
.60926 .35001 m
.61129 .35288 L
s
.61231 .34861 m
.60926 .35001 L
s
.60926 .35001 m
.61066 .35063 L
s
.62198 .3537 m
.60926 .35001 L
s
.466 0 1 r
.77224 .49356 m
.77311 .4946 L
s
.76907 .4925 m
.77224 .49356 L
s
.7724 .49038 m
.77224 .49356 L
s
.361 0 1 r
.6094 .65192 m
.60911 .64992 L
s
.61296 .65146 m
.6094 .65192 L
s
0 .998 1 r
.7656 .54032 m
.76786 .53865 L
s
.23 0 1 r
.68952 .5663 m
.69969 .55467 L
s
.466 0 1 r
.76993 .49354 m
.76907 .4925 L
s
.76907 .4925 m
.7724 .49038 L
s
.361 0 1 r
.60911 .64992 m
.61133 .64767 L
s
.61133 .64767 m
.61296 .65146 L
s
0 .067 1 r
.61066 .35063 m
.61129 .35288 L
s
.61231 .34861 m
.61066 .35063 L
s
.361 0 1 r
.60911 .64992 m
.61296 .65146 L
s
.466 0 1 r
.7724 .49038 m
.77311 .4946 L
s
.76993 .49354 m
.7724 .49038 L
s
.77311 .4946 m
.76993 .49354 L
s
.23 0 1 r
.69881 .55695 m
.69913 .55868 L
s
.69617 .55532 m
.69881 .55695 L
s
.69969 .55467 m
.69881 .55695 L
s
1 0 .433 r
.61529 .6283 m
.63337 .62281 L
s
1 0 0 r
.62156 .6358 m
.61851 .6389 L
s
.62112 .63301 m
.62156 .6358 L
s
.62341 .63822 m
.62156 .6358 L
s
.23 0 1 r
.6965 .55704 m
.69617 .55532 L
s
.69617 .55532 m
.69969 .55467 L
s
0 .831 1 r
.7773 .47783 m
.77955 .47706 L
s
.77955 .47706 m
.78016 .47626 L
s
.77955 .47706 m
.77776 .47481 L
s
0 .98 1 r
.69898 .4093 m
.70086 .40814 L
s
.70086 .40814 m
.70109 .40687 L
s
.70086 .40814 m
.69858 .40644 L
s
0 .831 1 r
.77791 .47703 m
.7773 .47783 L
s
.77776 .47481 m
.7773 .47783 L
s
1 0 0 r
.61851 .6389 m
.61808 .63611 L
s
.62341 .63822 m
.61851 .6389 L
s
0 .831 1 r
.78016 .47626 m
.77776 .47481 L
s
.77776 .47481 m
.77791 .47703 L
s
.78263 .48597 m
.77776 .47481 L
s
0 .98 1 r
.69858 .40644 m
.69898 .4093 L
s
.70109 .40687 m
.69858 .40644 L
s
.69858 .40644 m
.69921 .40803 L
s
.70589 .41469 m
.69858 .40644 L
s
1 .036 0 r
.61921 .66834 m
.6192 .66832 L
s
.6192 .66832 m
.61918 .6683 L
s
.6192 .66832 m
.61917 .66834 L
s
.61917 .66834 m
.61921 .66834 L
s
.61918 .6683 m
.61917 .66834 L
s
.61917 .66834 m
.61919 .66832 L
s
.6193 .66825 m
.61917 .66834 L
s
.61918 .6683 m
.61919 .66832 L
s
.61919 .66832 m
.61921 .66834 L
s
.6193 .33175 m
.61943 .33184 L
s
.61941 .33182 m
.61939 .33184 L
s
.61942 .3318 m
.61941 .33182 L
s
.61943 .33184 m
.61941 .33182 L
s
.61939 .33184 m
.6194 .33182 L
s
.61943 .33184 m
.61939 .33184 L
s
.6194 .33182 m
.61942 .3318 L
s
.61942 .3318 m
.61943 .33184 L
s
.6194 .33182 m
.61943 .33184 L
s
0 .98 1 r
.69921 .40803 m
.69898 .4093 L
s
.23 0 1 r
.69913 .55868 m
.6965 .55704 L
s
.69969 .55467 m
.69913 .55868 L
s
.6965 .55704 m
.69969 .55467 L
s
0 .831 1 r
.78016 .47626 m
.77791 .47703 L
s
1 0 0 r
.61808 .63611 m
.62112 .63301 L
s
.62112 .63301 m
.62341 .63822 L
s
.908 0 1 r
.62319 .38649 m
.62625 .38459 L
s
.62625 .38459 m
.62654 .38248 L
s
.62625 .38459 m
.62249 .38185 L
s
0 .98 1 r
.70109 .40687 m
.69921 .40803 L
s
0 .067 1 r
.62198 .6463 m
.63478 .64258 L
s
.908 0 1 r
.62249 .38185 m
.62319 .38649 L
s
.62654 .38248 m
.62249 .38185 L
s
.62249 .38185 m
.62348 .38438 L
s
.63437 .39505 m
.62249 .38185 L
s
.62348 .38438 m
.62319 .38649 L
s
1 0 0 r
.61808 .63611 m
.62341 .63822 L
s
0 .831 1 r
.78263 .51403 m
.7875 .50286 L
s
.78734 .50509 m
.78796 .50587 L
s
.78509 .50431 m
.78734 .50509 L
s
.7875 .50286 m
.78734 .50509 L
s
1 0 .433 r
.63132 .62378 m
.63049 .62693 L
s
.62899 .62089 m
.63132 .62378 L
s
.63337 .62281 m
.63132 .62378 L
s
0 .831 1 r
.78571 .5051 m
.78509 .50431 L
s
.78509 .50431 m
.7875 .50286 L
s
0 .98 1 r
.70589 .58531 m
.71324 .57702 L
s
.908 0 1 r
.62654 .38248 m
.62348 .38438 L
s
0 .831 1 r
.7875 .50286 m
.78796 .50587 L
s
.78571 .5051 m
.7875 .50286 L
s
.78796 .50587 m
.78571 .5051 L
s
1 0 .433 r
.62816 .62404 m
.62899 .62089 L
s
.62899 .62089 m
.63337 .62281 L
s
0 .067 1 r
.63334 .64322 m
.63273 .64547 L
s
.63169 .64118 m
.63334 .64322 L
s
.63478 .64258 m
.63334 .64322 L
s
0 .98 1 r
.71258 .57864 m
.71283 .5799 L
s
.71071 .57747 m
.71258 .57864 L
s
.71324 .57702 m
.71258 .57864 L
s
1 0 .433 r
.63049 .62693 m
.62816 .62404 L
s
.63337 .62281 m
.63049 .62693 L
s
0 .98 1 r
.71095 .57873 m
.71071 .57747 L
s
.71071 .57747 m
.71324 .57702 L
s
0 .067 1 r
.63108 .64343 m
.63169 .64118 L
s
.63169 .64118 m
.63478 .64258 L
s
.197 0 1 r
.71333 .46383 m
.71593 .46218 L
s
.71593 .46218 m
.71627 .46047 L
s
.71593 .46218 m
.71275 .45983 L
s
0 .067 1 r
.63273 .64547 m
.63108 .64343 L
s
.63478 .64258 m
.63273 .64547 L
s
.197 0 1 r
.71275 .45983 m
.71333 .46383 L
s
.71627 .46047 m
.71275 .45983 L
s
.71275 .45983 m
.71366 .46212 L
s
.72302 .47144 m
.71275 .45983 L
s
0 .98 1 r
.71283 .5799 m
.71095 .57873 L
s
.71324 .57702 m
.71283 .5799 L
s
1 0 .433 r
.62816 .62404 m
.63337 .62281 L
s
0 .98 1 r
.71095 .57873 m
.71324 .57702 L
s
.197 0 1 r
.71366 .46212 m
.71333 .46383 L
s
.908 0 1 r
.63437 .60495 m
.64632 .59166 L
s
0 .067 1 r
.63108 .64343 m
.63478 .64258 L
s
.197 0 1 r
.71627 .46047 m
.71366 .46212 L
s
.908 0 1 r
.6453 .59424 m
.64562 .59633 L
s
.64224 .59232 m
.6453 .59424 L
s
.64632 .59166 m
.6453 .59424 L
s
1 .498 0 r
.8005 .48655 m
.80081 .48635 L
s
.80081 .48635 m
.80086 .48615 L
s
.80081 .48635 m
.80043 .48607 L
s
.80043 .48607 m
.8005 .48655 L
s
.80086 .48615 m
.80043 .48607 L
s
.80043 .48607 m
.80055 .48635 L
s
.80169 .48747 m
.80043 .48607 L
s
.80055 .48635 m
.8005 .48655 L
s
.80086 .48615 m
.80055 .48635 L
s
0 .6 1 r
.64287 .36983 m
.64501 .36851 L
s
.64501 .36851 m
.6452 .36703 L
s
.64501 .36851 m
.64239 .3666 L
s
1 .498 0 r
.80169 .51253 m
.80294 .51114 L
s
.908 0 1 r
.64255 .59441 m
.64224 .59232 L
s
.64224 .59232 m
.64632 .59166 L
s
0 .6 1 r
.64239 .3666 m
.64287 .36983 L
s
.6452 .36703 m
.64239 .3666 L
s
.64239 .3666 m
.64306 .36835 L
s
.65062 .37576 m
.64239 .3666 L
s
1 .498 0 r
.80282 .51141 m
.80287 .51162 L
s
.80251 .51122 m
.80282 .51141 L
s
.80294 .51114 m
.80282 .51141 L
s
.80256 .51142 m
.80251 .51122 L
s
.80251 .51122 m
.80294 .51114 L
s
0 .6 1 r
.64306 .36835 m
.64287 .36983 L
s
1 .498 0 r
.80287 .51162 m
.80256 .51142 L
s
.80294 .51114 m
.80287 .51162 L
s
.197 0 1 r
.72302 .52856 m
.73336 .51689 L
s
1 .498 0 r
.80256 .51142 m
.80294 .51114 L
s
0 .6 1 r
.6452 .36703 m
.64306 .36835 L
s
.908 0 1 r
.64562 .59633 m
.64255 .59441 L
s
.64632 .59166 m
.64562 .59633 L
s
.64255 .59441 m
.64632 .59166 L
s
.197 0 1 r
.73241 .51921 m
.73277 .52091 L
s
.7298 .51755 m
.73241 .51921 L
s
.73336 .51689 m
.73241 .51921 L
s
.73015 .51924 m
.7298 .51755 L
s
.7298 .51755 m
.73336 .51689 L
s
0 .6 1 r
.65062 .62424 m
.65888 .61503 L
s
0 .998 1 r
.73268 .447 m
.73454 .44581 L
s
.73454 .44581 m
.7348 .44457 L
s
.73454 .44581 m
.73225 .44413 L
s
.73225 .44413 m
.73268 .447 L
s
.7348 .44457 m
.73225 .44413 L
s
.73225 .44413 m
.73293 .44575 L
s
.73968 .45243 m
.73225 .44413 L
s
.73293 .44575 m
.73268 .447 L
s
.197 0 1 r
.73277 .52091 m
.73015 .51924 L
s
.73336 .51689 m
.73277 .52091 L
s
.73015 .51924 m
.73336 .51689 L
s
.938 0 1 r
.65634 .42374 m
.65946 .42182 L
s
.65946 .42182 m
.65979 .41975 L
s
.65946 .42182 m
.65568 .41902 L
s
0 .998 1 r
.7348 .44457 m
.73293 .44575 L
s
0 .6 1 r
.6582 .6168 m
.6584 .61828 L
s
.65606 .61547 m
.6582 .6168 L
s
.65888 .61503 m
.6582 .6168 L
s
.938 0 1 r
.65568 .41902 m
.65634 .42374 L
s
.65979 .41975 m
.65568 .41902 L
s
.65568 .41902 m
.65666 .42167 L
s
.66761 .4327 m
.65568 .41902 L
s
0 .6 1 r
.65625 .61695 m
.65606 .61547 L
s
.65606 .61547 m
.65888 .61503 L
s
.466 0 1 r
.73779 .48195 m
.74101 .48089 L
s
.74101 .48089 m
.74185 .4798 L
s
.74101 .48089 m
.7385 .47768 L
s
.938 0 1 r
.65666 .42167 m
.65634 .42374 L
s
.466 0 1 r
.73862 .48086 m
.73779 .48195 L
s
.7385 .47768 m
.73779 .48195 L
s
.74185 .4798 m
.7385 .47768 L
s
.7385 .47768 m
.73862 .48086 L
s
.7451 .4937 m
.7385 .47768 L
s
0 .6 1 r
.6584 .61828 m
.65625 .61695 L
s
.65888 .61503 m
.6584 .61828 L
s
.65625 .61695 m
.65888 .61503 L
s
0 .998 1 r
.73968 .54757 m
.74714 .53923 L
s
.938 0 1 r
.65979 .41975 m
.65666 .42167 L
s
.466 0 1 r
.74185 .4798 m
.73862 .48086 L
s
0 .998 1 r
.74645 .54088 m
.74672 .54212 L
s
.74458 .53969 m
.74645 .54088 L
s
.74714 .53923 m
.74645 .54088 L
s
.74484 .54093 m
.74458 .53969 L
s
.74458 .53969 m
.74714 .53923 L
s
.466 0 1 r
.7451 .5063 m
.75173 .49023 L
s
0 .998 1 r
.74672 .54212 m
.74484 .54093 L
s
.74714 .53923 m
.74672 .54212 L
s
.466 0 1 r
.75159 .49346 m
.75244 .49452 L
s
.74836 .49239 m
.75159 .49346 L
s
.75173 .49023 m
.75159 .49346 L
s
0 .998 1 r
.74484 .54093 m
.74714 .53923 L
s
.938 0 1 r
.66761 .5673 m
.67962 .55353 L
s
.466 0 1 r
.74921 .49345 m
.74836 .49239 L
s
.74836 .49239 m
.75173 .49023 L
s
.75173 .49023 m
.75244 .49452 L
s
.74921 .49345 m
.75173 .49023 L
s
.75244 .49452 m
.74921 .49345 L
s
.938 0 1 r
.6786 .55624 m
.67895 .55829 L
s
.67547 .55429 m
.6786 .55624 L
s
.67962 .55353 m
.6786 .55624 L
s
0 .627 1 r
.67635 .4073 m
.67849 .40599 L
s
.67849 .40599 m
.67873 .40455 L
s
.67849 .40599 m
.67589 .40406 L
s
0 .831 1 r
.75668 .47749 m
.75896 .47671 L
s
.75896 .47671 m
.75956 .4759 L
s
.75896 .47671 m
.75714 .47444 L
s
.938 0 1 r
.67582 .55634 m
.67547 .55429 L
s
.67547 .55429 m
.67962 .55353 L
s
0 .627 1 r
.67589 .40406 m
.67635 .4073 L
s
.67873 .40455 m
.67589 .40406 L
s
.67589 .40406 m
.67659 .40587 L
s
.68415 .41341 m
.67589 .40406 L
s
0 .831 1 r
.75727 .47668 m
.75668 .47749 L
s
.75714 .47444 m
.75668 .47749 L
s
0 .627 1 r
.67659 .40587 m
.67635 .4073 L
s
0 .831 1 r
.75956 .4759 m
.75714 .47444 L
s
.75714 .47444 m
.75727 .47668 L
s
.76205 .48575 m
.75714 .47444 L
s
0 .627 1 r
.67873 .40455 m
.67659 .40587 L
s
0 .831 1 r
.75956 .4759 m
.75727 .47668 L
s
.938 0 1 r
.67895 .55829 m
.67582 .55634 L
s
.67962 .55353 m
.67895 .55829 L
s
.67582 .55634 m
.67962 .55353 L
s
0 .831 1 r
.76205 .51425 m
.76697 .5029 L
s
.76683 .50517 m
.76744 .50596 L
s
.76454 .50438 m
.76683 .50517 L
s
.76697 .5029 m
.76683 .50517 L
s
.76515 .50517 m
.76454 .50438 L
s
.76454 .50438 m
.76697 .5029 L
s
0 .627 1 r
.68415 .58659 m
.69243 .57721 L
s
0 .831 1 r
.76697 .5029 m
.76744 .50596 L
s
.76515 .50517 m
.76697 .5029 L
s
.76744 .50596 m
.76515 .50517 L
s
.887 0 1 r
.69005 .46202 m
.69314 .46007 L
s
.69314 .46007 m
.6935 .45805 L
s
.69314 .46007 m
.68937 .4573 L
s
0 .627 1 r
.69171 .57904 m
.69197 .58047 L
s
.68958 .57771 m
.69171 .57904 L
s
.69243 .57721 m
.69171 .57904 L
s
.887 0 1 r
.68937 .4573 m
.69005 .46202 L
s
.6935 .45805 m
.68937 .4573 L
s
.68937 .4573 m
.69041 .46 L
s
.70144 .47101 m
.68937 .4573 L
s
0 .627 1 r
.68983 .57914 m
.68958 .57771 L
s
.68958 .57771 m
.69243 .57721 L
s
.887 0 1 r
.69041 .46 m
.69005 .46202 L
s
0 .627 1 r
.69197 .58047 m
.68983 .57914 L
s
.69243 .57721 m
.69197 .58047 L
s
.68983 .57914 m
.69243 .57721 L
s
.887 0 1 r
.6935 .45805 m
.69041 .46 L
s
1 .498 0 r
.7801 .48634 m
.78041 .48614 L
s
.78041 .48614 m
.78046 .48594 L
s
.78041 .48614 m
.78003 .48586 L
s
.78003 .48586 m
.7801 .48634 L
s
.78046 .48594 m
.78003 .48586 L
s
.78003 .48586 m
.78015 .48614 L
s
.7813 .48728 m
.78003 .48586 L
s
.78015 .48614 m
.7801 .48634 L
s
.78046 .48594 m
.78015 .48614 L
s
.7813 .51272 m
.78257 .5113 L
s
.78245 .51159 m
.7825 .51179 L
s
.78213 .51139 m
.78245 .51159 L
s
.78257 .5113 m
.78245 .51159 L
s
.78218 .51159 m
.78213 .51139 L
s
.78213 .51139 m
.78257 .5113 L
s
.7825 .51179 m
.78218 .51159 L
s
.78257 .5113 m
.7825 .51179 L
s
.78218 .51159 m
.78257 .5113 L
s
.887 0 1 r
.70144 .52899 m
.71358 .5152 L
s
.7125 .51795 m
.71289 .51995 L
s
.70941 .51598 m
.7125 .51795 L
s
.71358 .5152 m
.7125 .51795 L
s
0 .652 1 r
.71037 .44556 m
.71249 .44422 L
s
.71249 .44422 m
.71276 .44281 L
s
.71249 .44422 m
.7099 .44231 L
s
.887 0 1 r
.70979 .51798 m
.70941 .51598 L
s
.70941 .51598 m
.71358 .5152 L
s
0 .652 1 r
.7099 .44231 m
.71037 .44556 L
s
.71276 .44281 m
.7099 .44231 L
s
.7099 .44231 m
.71064 .44415 L
s
.71826 .45171 m
.7099 .44231 L
s
.71064 .44415 m
.71037 .44556 L
s
.71276 .44281 m
.71064 .44415 L
s
.887 0 1 r
.71289 .51995 m
.70979 .51798 L
s
.71358 .5152 m
.71289 .51995 L
s
1 0 .812 r
.71507 .47981 m
.71887 .47855 L
s
.71887 .47855 m
.71983 .47724 L
s
.71887 .47855 m
.71588 .47476 L
s
.887 0 1 r
.70979 .51798 m
.71358 .5152 L
s
1 0 .812 r
.71602 .4785 m
.71507 .47981 L
s
.71588 .47476 m
.71507 .47981 L
s
.71983 .47724 m
.71588 .47476 L
s
.71588 .47476 m
.71602 .4785 L
s
.72373 .4936 m
.71588 .47476 L
s
0 .652 1 r
.71826 .54829 m
.72666 .53886 L
s
1 0 .812 r
.71983 .47724 m
.71602 .4785 L
s
0 .652 1 r
.7259 .54072 m
.72618 .54212 L
s
.72377 .53937 m
.7259 .54072 L
s
.72666 .53886 m
.7259 .54072 L
s
1 0 .812 r
.72373 .5064 m
.7316 .48749 L
s
0 .652 1 r
.72405 .54077 m
.72377 .53937 L
s
.72377 .53937 m
.72666 .53886 L
s
1 0 .812 r
.73144 .49129 m
.73242 .49255 L
s
.72764 .49001 m
.73144 .49129 L
s
.7316 .48749 m
.73144 .49129 L
s
0 .652 1 r
.72618 .54212 m
.72405 .54077 L
s
.72666 .53886 m
.72618 .54212 L
s
.72405 .54077 m
.72666 .53886 L
s
1 0 .812 r
.72861 .49127 m
.72764 .49001 L
s
.72764 .49001 m
.7316 .48749 L
s
.7316 .48749 m
.73242 .49255 L
s
.72861 .49127 m
.7316 .48749 L
s
.73242 .49255 m
.72861 .49127 L
s
0 .479 1 r
.73473 .4763 m
.7373 .4754 L
s
.7373 .4754 m
.73795 .47446 L
s
.7373 .4754 m
.73521 .47284 L
s
.73537 .47536 m
.73473 .4763 L
s
.73521 .47284 m
.73473 .4763 L
s
.73795 .47446 m
.73521 .47284 L
s
.73521 .47284 m
.73537 .47536 L
s
.74084 .48554 m
.73521 .47284 L
s
.73795 .47446 m
.73537 .47536 L
s
.74084 .51446 m
.74649 .50174 L
s
.74632 .50428 m
.74697 .5052 L
s
.74374 .50337 m
.74632 .50428 L
s
.74649 .50174 m
.74632 .50428 L
s
.74439 .50429 m
.74374 .50337 L
s
.74374 .50337 m
.74649 .50174 L
s
.74649 .50174 m
.74697 .5052 L
s
.74439 .50429 m
.74649 .50174 L
s
.74697 .5052 m
.74439 .50429 L
s
1 .65 0 r
.75871 .48585 m
.75912 .48558 L
s
.75912 .48558 m
.75918 .48531 L
s
.75912 .48558 m
.75861 .48521 L
s
.75861 .48521 m
.75871 .48585 L
s
.75918 .48531 m
.75861 .48521 L
s
.75861 .48521 m
.75877 .48558 L
s
.76028 .48708 m
.75861 .48521 L
s
.75877 .48558 m
.75871 .48585 L
s
.75918 .48531 m
.75877 .48558 L
s
.76028 .51292 m
.76196 .51104 L
s
.7618 .51142 m
.76186 .51169 L
s
.76138 .51115 m
.7618 .51142 L
s
.76196 .51104 m
.7618 .51142 L
s
.76145 .51142 m
.76138 .51115 L
s
.76138 .51115 m
.76196 .51104 L
s
.76186 .51169 m
.76145 .51142 L
s
.76196 .51104 m
.76186 .51169 L
s
.76145 .51142 m
.76196 .51104 L
s
0 g
.001 w
[ .01 .01 ] 0 setdash
.19183 .17439 m
.77367 .11868 L
s
.77367 .11868 m
.77367 .88132 L
s
.77367 .88132 m
.19183 .82561 L
s
.19183 .82561 m
.19183 .17439 L
s
.84275 .13784 m
.77367 .11868 L
s
.77367 .11868 m
.77367 .88132 L
s
.77367 .88132 m
.84275 .86216 L
s
.84275 .86216 m
.84275 .13784 L
s
.003 w
[ ] 0 setdash
.84275 .13784 m
.77367 .11868 L
s
.25 Mabswid
.83552 .13584 m
.83552 .14209 L
s
gsave
.83552 .12334 -73.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.8091 .12851 m
.8091 .13476 L
s
gsave
.8091 .11601 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7816 .12088 m
.7816 .12713 L
s
gsave
.7816 .10838 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.82901 .13403 m
.82901 .13778 L
s
.82244 .13221 m
.82244 .13596 L
s
.8158 .13037 m
.8158 .13412 L
s
.80233 .12663 m
.80233 .13038 L
s
.79549 .12473 m
.79549 .12848 L
s
.78858 .12282 m
.78858 .12657 L
s
.84196 .13762 m
.84196 .14137 L
s
.77454 .11892 m
.77454 .12267 L
s
gsave
.8091 .05351 -68.8125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{413, 413},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006M0001WA000`40O003h00OogooWWoo003oOonN
Ool00?mooiioo`00ogooWWoo003oOonNOol00?mooiioo`00ogooWWoo003oOonNOol00?mooiioo`00
ogooWWoo003oOonNOol00?mooiioo`00ogooWWoo003oOom2Ool30002Ool3001DOol00?moodAoo`04
001oogoo001FOol00?moodAoo`04001oogoo001FOol00?moodEoo`8005Moo`00ogooAGoo0P00Egoo
003oOom4Ool01000Oomoo`00EWoo003oOom4Ool01000Oomoo`00EWoo002jOol30024Ool30002Ool3
001DOol00;]oo`03001oogoo0=moo`00^goo00<007ooOol0ggoo002kOol00`00Oomoo`3OOol00;Yo
o`03001oo`000>1oo`00^Woo00<007oo0000h7oo002iOol01@00Oomoogoo0000ggoo002hOol30000
17oo00000000gWoo003oOonNOol00?mooiioo`00ogooWWoo003oOonNOol00?mooiioo`00ogooWWoo
003oOolgOol40003Ool3001MOol00?moocMoo`07001oogooOol007oo00000goo00<007ooOol0FWoo
003oOolIOol30002Ool30003Ool3000AOol00`00Oomoo`02Ool01@00Oomoogoo0000G7oo003oOolJ
Ool01000Oomoo`000goo00<007oo00000goo00<007ooOol03goo00D007ooOomoo`0000=oo`03001o
ogoo009oo`<005Eoo`00ogoo6Woo00@007ooOol000=oo`03001oo`0000=oo`03001oogoo011oo`04
001oogoo0003Ool01@00Oomoogoo00000goo00<007ooOol0DWoo003oOolJOol01000Oomoo`000goo
00<007oo00000goo00<007ooOol047oo00@007ooOol000=oo`05001oogooOol00003Ool00`00Oomo
o`1BOol00?mooaYoo`04001oogoo0003Ool00`00Ool00003Ool00`00Oomoo`0=Ool01000Oomoo`00
0Woo00D007ooOomoo`0000=oo`05001oogooOol00007Ool40003Ool30013Ool00>Moo`@000=oo`<0
02Qoo`04001oogoo0003Ool00`00Ool00003Ool00`00Oomoo`0>Ool20004Ool30004Ool01@00Oomo
ogoo00001goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`10Ool00>]oo`03001oo`0000=oo`03
001oogoo02Eoo`04001oogoo0003Ool00`00Ool00003Ool00`00Oomoo`0KOol01@00Oomoogoo0000
27oo00<007ooOol00Woo00D007ooOomoo`00049oo`00jgoo00<007oo00000goo00<007ooOol097oo
0P000goo0`000goo0`007Woo00@007ooOomoo`L000=oo`05001oogooOol00003Ool00`00Oomoo`10
Ool00>]oo`03001oo`0000=oo`03001oogoo055oo`<000]oo`04001oogoo0003Ool00`00Oomoo`10
Ool00;aoo`<002aoo`03001oo`0000=oo`03001oogoo05moo`04001oogoo0003Ool00`00Oomoo`10
Ool00;]oo`05001oogooOol0000WOol40002Ool01@00Oomoogoo0000GWoo00@007ooOol0009oo`05
001oogooOol00012Ool00;]oo`05001oogooOol0000XOol00`00Oomoo`02Ool01@00Oomoogoo0000
@Woo2@0057oo0P0017oo0`00@goo002kOol01@00Oomoogoo0000:7oo10000Woo0`00>7oo2`0000=o
o`00Ool00Woo00<007ooOol00`00GWoo002@Ool40003Ool3000QOol01@00Oomoogoo0000Ggoo3000
2Woo00D007ooOomoo`00009oo`03001oogoo00D005Uoo`00U7oo00<007oo00000goo00<007ooOol0
7Woo00D007ooOomoo`0005Eoo`d000Qoo`03001oogoo00aoo`04001oogoo0002Ool00`00Oomoo`04
001GOol009Aoo`03001oo`0000=oo`03001oogoo01ioo`05001oogooOol0001:Ool<0009Ool00`00
Oomoo`0GOol00`00Oomoo`06Ool01000Ool007oo0`00E7oo0028Ool70005Ool00`00Ool00003Ool0
0`00Oomoo`0OOol30011Ool:00000goo001oo`08Ool00`00Oomoo`07Ool00`00Oomoo`0ROol01@00
Oomoo`00Ool01000D7oo001UOol30002Ool30003Ool3000QOol00`00Ool00003Ool00`00Oomoo`1H
Ool=0009Ool00`00Oomoo`0iOol01@00Oomoo`00Ool01000CGoo001VOol01000Oomoo`000goo00<0
07oo00000goo00<007ooOol06Woo10000Woo00D007ooOomoo`00051oo`/00003Ool007oo00Qoo`03
001oogoo04Qoo`03001oogoo00@004Yoo`00IWoo00@007ooOol000=oo`03001oo`0000=oo`03001o
ogoo01]oo`03001oogoo009oo`05001oogooOol00016Ool:0002Ool00`00Oomoo`07Ool00`00Oomo
o`0oOol00`00Oomoo`0>Ool30002Ool60018Ool005aoo`L000=oo`04001oogoo0003Ool00`00Ool0
0003Ool00`00Oomoo`0KOol40002Ool3000lOol>0009Ool00`00Oomoo`19Ool00`00Oomoo`05Ool5
0002Ool20007Ool01000Oomoo`00B7oo001VOol01000Oomoo`000goo00<007oo00000goo00<007oo
Ool0EWoo2P0017oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0@goo0`000goo1@005Woo
00<007ooOol0AWoo001VOol01000Oomoo`000goo00<007oo00000goo00<007ooOol0Bgoo2`0017oo
00<007ooOol01goo00<007ooOol0CWoo0`000goo0P001Woo00<007ooOol067oo00<007ooOol0AWoo
001VOol01000Oomoo`000goo00<007oo00000goo00<007ooOol0@Goo2P0000=oo`0000000goo00<0
07ooOol01Woo00<007ooOol0CWoo1@000goo0P003Woo00<007ooOol05goo0P00B7oo001UOol20003
Ool30003Ool3000iOol;0007Ool00`00Oomoo`06Ool00`00Oomoo`1:Ool30002Ool5000fOol00`00
Oomoo`16Ool00:9oo`/000Qoo`03001oogoo00Ioo`03001oogoo04Uoo`D000=oo`80041oo`03001o
ogoo04Ioo`00V7oo2P0000=oo`0000001goo00<007ooOol0CGoo0`000goo1@00CGoo00<007ooOol0
AWoo002=Ool;0002Ool00`00Oomoo`06Ool00`00Oomoo`1<Ool50003Ool2000mOol00`00Oomoo`0H
Ool00`00Oomoo`16Ool008=oo`X000Aoo`03001oogoo00Ioo`03001oogoo04eoo`D004Yoo`03001o
ogoo01Qoo`03001oogoo04Ioo`00N7oo3@0017oo00<007ooOol01Goo00<007ooOol0BGoo0`000goo
1@00DGoo00<007ooOol067oo00<007ooOol0AWoo001^Ool;0007Ool00`00Oomoo`0>Ool00`00Oomo
o`0XOol00gj0Oomoo`05Ool00gj0Oomoo`0<Ool50003Ool2001LOol00`00Oomoo`0HOol00`00Oomo
o`16Ool006Aoo`X0009oo`03001oogoo00Eoo`03001oogoo045oo`03OX1oogoo00Eoo`04OX000000
0003Ool5001YOol00`00Oomoo`0HOol00`00Oomoo`16Ool005Uoo`d0009oo`03001oogoo00Eoo`03
001oogoo04Qoo`D000=oo`80009mh0Ioo`03ON1oogoo08Aoo`03001oogoo04Ioo`00E7oo1@001goo
00<007ooOol01Goo00<007ooOol0@goo0`000goo1@0037oo00=mh7ooOol01Goo00=mh7ooOol0Q7oo
00<007ooOol0AWoo001DOol00`00Oomoo`020003Ool30009Ool00`00Oomoo`0iOol50003Ool2000P
Ool2ON06Ool00ggPOomoo`1kOol00`00Oomoo`16Ool005Aoo`03001oogoo00Qoo`8003]oo`D002eo
o`03ON1oogoo06Qoo`03001oogoo01Moo`8004Qoo`00E7oo00<007ooOol03Goo1@009Woo0P000goo
1@009Goo0P7o5goo0Wj01Woo00=nP7ooOol0Egoo00<007ooOol067oo00<007ooOol0AWoo001DOol0
0`00Oomoo`0EOol3000FOol50003Ool2000^Ool30OmiOol00`00Oomoo`0HOol00`00Oomoo`16Ool0
06moo`04001oogooOol30002Ool20003Ool5000jOol00`7oOomoo`05Ool20Ol00goo0el3G`1`Ool0
0`00Oomoo`0HOol00`00Oomoo`16Ool007Ioo`8004=oo`030Omoogoo00Qoo`81o`030emoogoo06io
o`03001oogoo01Qoo`03001oogoo04Ioo`00MWoo00<007ooOol0CGoo00<3G`7o0Ol017oo0P=O00=o
o`=O0el0PWoo00<007ooOol0AWoo001DOol00`00Oomoo`0OOol00`00Oomoo`1<Ool00`=OOol1o`07
Ool30el7Ool20OmiOol00`00Oomoo`16Ool005Aoo`03001oogoo01moo`03001oogoo04Uoo`9l6@Yo
o`040emoo`=O0el4Ool40el00`7oOomoo`1gOol00`00Oomoo`16Ool005Aoo`03001oogoo01moo`03
001oogoo04Qoo`=l6AAoo`030Ol3G`=O00Aoo`81oeQoo`03001oogoo01Qoo`03001oogoo04Ioo`00
E7oo00<007ooOol0JGoo00Al6GooOoml6@Moo`8h7`Yoo`030Omoo`=O00Moo`81oeIoo`03001oogoo
01Qoo`03001oogoo04Ioo`00E7oo00<007ooOol0GGoo00<2WgooOol027oo00=l6GooOol01goo13PO
5Goo0P7oEGoo00<007ooOol067oo00<007ooOol0AWoo001fOol00`00Oomoo`0jOol20Yl9Ool017`I
Oomoogoo0W`I17oo00@h7gooOolh7`Moo`<h7f=oo`03001oogoo01Ioo`<004Qoo`00MWoo00<007oo
Ool0>Woo0P:O27oo00<3ogooOol017oo17`I0goo0SPO00=oo`:OOol00Woo0cPO27oo0W`IFWoo00<0
07ooOol067oo00<007ooOol03Woo0`000Woo0`000goo0`00:Woo001fOol00`00Oomoo`0iOol00`:O
Oomoo`07Ool20ol8Ool2O1T5Ool2>1l00`:OOolh7`06Ool010?oOomoogoo0g`IMGoo00<007ooOol0
3goo00@007ooOol000=oo`03001oo`0000=oo`03001oogoo02Moo`00E7oo00<007ooOol07goo00<0
07ooOol0>7oo00<2WgooOol027oo00<3ogooOol01Woo00<3og`IOol01Woo0SPO0P:O0Woo0SPO0Woo
00@3ogooOoml6@9oo`03O1Uoogoo07=oo`03001oogoo00moo`04001oogoo0003Ool00`00Ool00003
Ool00`00Oomoo`0WOol005Aoo`03001oogoo01moo`03001oogoo049oo`03L1l3ogoo00Moo`83o`Mo
o`8h7`82W`Aoo`<h7`83o`9oo`9l6@9oo`030omoogoo05Eoo`03001oogoo01Qoo`03001oogoo00Eo
o`L000=oo`04001oogoo0003Ool00`00Ool00003Ool00`00Oomoo`0WOol005Aoo`03001oogoo06=o
o`9`7`Uoo`030omoogoo00Ioo`82W`Moo`8h7`83o`Aoo`9l6@030oml6Goo05Eoo`03001oogoo01Qo
o`03001oogoo00moo`04001oogoo0003Ool00`00Ool00003Ool00`00Oomoo`0WOol005Aoo`03001o
ogoo06=oo`9`7`Qoo`030omoogoo00Moo`030Ymoogoo011oo`03O1T3o`?o00Eoo`030Ymoogoo04eo
o`03001oogoo01Qoo`03001oogoo00moo`04001oogoo0003Ool00`00Ool00003Ool00`00Oomoo`0W
Ool005Aoo`03001oogoo069oo`03L1moogoo00Moo`8H7`Uoo`030Ymoogoo011oo`03O1T3o`?o00Io
o`030Ymoogoo04aoo`03001oogoo01Qoo`03001oogoo00moo`04001oogoo0003Ool00`00Ool00003
Ool00`00Oomoo`0WOol007Ioo`03001oogoo041oo`03L1moogoo00Moo`8H7`Aoo`03L1moogoo008H
7aeoo`82Wdaoo`03001oogoo01Qoo`03001oogoo00ioo`8000=oo`<000=oo`<002Yoo`00MWoo00<0
07ooOol0?goo00=`7gooOol01goo00<H7gooOol017oo00=`7gooOol00QPO1goo0W0O57oo0P:OIgoo
00<007ooOol0AWoo001fOol00`00Oomoo`0nOol00g0OOomoo`07Ool00aPOOomoo`06Ool0170OOolH
7aPO17oo00<H7gooOol00W0OOGoo00<007ooOol0AWoo001DOol00`00Oomoo`0OOol00`00Oomoo`17
Ool00aPOOomoo`08Ool3L1l4Ool011POOomoog0O1Goo00<H7gooOol0MWoo00<007ooOol0AWoo001D
Ool00`00Oomoo`0OOol00`00Oomoo`1AOol011POL1m`7g0O1Goo00<H7g0O61l01Goo00<H7gooOol0
Fgoo00<007ooOol05goo0P00B7oo001DOol00`00Oomoo`1bOol00aPOOom`7`02L1l5Ool00g0O61lH
7`06Ool00aPOOomoo`04Ool2L1mDOol00`00Oomoo`0HOol00`00Oomoo`16Ool005Aoo`03001oogoo
059oo`030Ymoogoo02Ioo`04L1mooaPO61l5Ool010:OOolH7aPO1Woo00=`7gooOol0DGoo00<007oo
Ool067oo00<007ooOol0AWoo001DOol00`00Oomoo`1AOol20YlaOol010:OOolH7aPO1goo00=`7goo
Ool0D7oo00<007ooOol067oo00<007ooOol0AWoo001fOol00`00Oomoo`0_Ool00`:OOomoo`06Ool2
0olYOol00`:OOomoo`05Ool010?oOom`7g0ODGoo00<007ooOol067oo00<007ooOol0AWoo001fOol0
0`00Oomoo`0^Ool00`:OOomoo`07Ool20olZOol00`:OOomoo`04Ool00`?oOom`7`02L1l4Ool00`?o
Oomoo`1TOol00`00Oomoo`16Ool007Ioo`03001oogoo02eoo`030Ymoogoo00Moo`030omoogoo00Mo
o`83ob5oo`82W`Ioo`83o`Ioo`030omoogoo06Aoo`03001oogoo04Ioo`00E7oo00<007ooOol07goo
00<007ooOol0=Woo00=h7gooOol027oo0P?o1goo0P:O87oo0P?o1goo0P?o1Goo00<2WgooOol0G7oo
00<007ooOol0AWoo001DOol00`00Oomoo`0OOol00`00Oomoo`0eOol2N1l9Ool00`?oOomoo`07Ool2
0YlYOol20ol6Ool00`:OOomoo`10Ool00`00Oomoo`0HOol00`00Oomoo`16Ool005Aoo`03001oogoo
05Moo`9h7`Qoo`0371moogoo00Moo`030Ymoogoo039oo`82Wd1oo`03001oogoo01Qoo`03001oogoo
04Ioo`00E7oo00<007ooOol0EWoo00=h7gooOol01goo0Q`O27oo00<2WgooOol04Goo00=h7gooOol0
7goo0P:O@7oo00<007ooOol067oo00<007ooOol0AWoo001DOol00`00Oomoo`1FOol00gPOOomoo`07
Ool271l7Ool271l9Ool00gPOOomoo`07Ool00gPOOomoo`06Ool00a`OOomoo`1HOol00`00Oomoo`0G
Ool20018Ool007Ioo`03001oogoo03=oo`03N1moogoo00Moo`0371moogoo00Moo`8L7`Qoo`9h7`Yo
o`03N1moogoo00Eoo`0371moogoo05Qoo`03001oogoo01Qoo`03001oogoo04Ioo`00MWoo00<007oo
Ool0<Woo00=h7gooOol027oo00<L7gooOol01goo00<L7gooOol01goo0WPO2goo00=h7gooN1l01Goo
00<L7gooOol01Goo00<L7gooOol0JWoo00<007ooOol0AWoo001fOol00`00Oomoo`0lOol00a`OOomo
o`07Ool00a`OOomoo`07Ool00gPOOomoo`0<Ool2N1l6Ool271l5Ool00a`OOomoo`05Ool00gPOOomo
o`1ROol00`00Oomoo`16Ool005Aoo`03001oogoo01moo`03001oogoo04Eoo`0371moogoo00Moo`03
N1moogoo00eoo`9h7`Ioo`8L7`Ioo`0371mooa`O00Eoo`03N1moogoo065oo`03001oogoo04Ioo`00
E7oo00<007ooOol07goo00<007ooOol0CWoo00=h7gooOol067oo00<L7gooOol00Woo00@2Ogoo71lL
7`Ioo`03N1moogoo04Eoo`03001oogoo01Qoo`03001oogoo04Ioo`00E7oo00<007ooOol0AGoo0P9o
BGoo00@2Ogoo71lL7`Moo`9h7dEoo`03001oogoo01Qoo`03001oogoo04Ioo`00E7oo00<007ooOol0
AGoo0P9oBWoo00<2OgooOol01Goo00@3ogooN1mh7dEoo`03001oogoo01Qoo`03001oogoo04Ioo`00
E7oo00<007ooOol0AGoo00<2OgooOol01goo00<3ogooOol0@7oo0P9o1Woo00@3ogooOomh7`Aoo`03
0omoogoo03eoo`03001oogoo01Qoo`03001oogoo04Ioo`00MWoo00<007ooOol08Woo00<2OgooOol0
27oo00<3ogooOol01Woo0P?o>7oo0P9o1goo0P?o1Goo00<3ogooOol01Goo00<2OgooOol0=Goo00<0
07ooOol067oo00<007ooOol0AWoo001fOol00`00Oomoo`0QOol00`9oOomoo`08Ool00`?oOomoo`07
Ool20ol7Ool20WlhOol20ol6Ool20ol6Ool00`9oOomoo`1?Ool00`00Oomoo`16Ool007Ioo`03001o
ogoo02]oo`03M1moogoo00Moo`030omoogoo00Moo`82Od1oo`83o`Moo`82Odmoo`03001oogoo04Io
o`00E7oo00<007ooOol07goo00<007ooOol0:Woo0W@O27oo00<3ogooOol01goo00<2OgooOol0BGoo
0P9oCWoo0P00B7oo001DOol00`00Oomoo`0OOol00`00Oomoo`0ZOol2M1l7Ool271l8Ool00`9oOomo
o`0XOol00g@OOomoo`1EOol00`00Oomoo`0HOol00`00Oomoo`16Ool005Aoo`03001oogoo04]oo`03
M1moogoo00Moo`8L7`Moo`8L7`Qoo`9d7b1oo`03M1moogoo00Ioo`0371moogoo04aoo`03001oogoo
01Qoo`03001oogoo04Ioo`00E7oo00<007ooOol0BWoo00=d7gooOol01goo00<L7gooOol01goo0Q`O
1goo0g@O8Goo00=d7gooOol01Woo00<L7gooOol01Goo00<L7gooOol0@goo00<007ooOol067oo00<0
07ooOol0AWoo001DOol00`00Oomoo`19Ool00g@OOomoo`07Ool00a`OOomoo`08Ool271l8Ool00g@O
Oomoo`0QOol00g@OOomd7`06Ool00a`OOomoo`04Ool00a`OOomoo`05Ool00g@OOomoo`0kOol00`00
Oomoo`0HOol00`00Oomoo`16Ool007Ioo`03001oogoo01aoo`0305moogoo009oo`9l3@eoo`0371mo
ogoo00Qoo`0371moogoo00Moo`03M1moogoo02=oo`9d7`Ioo`8L7`Ioo`0371moogoo00Eoo`03M1mo
ogoo03Yoo`03001oogoo01Qoo`03001oogoo04Ioo`00MWoo00<007ooOol06goo0P1O0goo0g`=5goo
00<L7gooOol01goo00=d7gooOol097oo0W@O1Woo0a`O00<0GgooOol00goo00<L7g`POol01Goo00=d
7gooOol0E7oo00<007ooOol0AWoo001fOol00`00Oomoo`0LOol00`1OOomoo`02Ool2O0d2Ool00`8O
Oomoo`03Ool00fPOOomoo`0EOol00g@OOomoo`0`Ool00`1OOomoo`03Ool011`OO21oo`8O1Goo00=d
7g`0Ool0Dgoo00<007ooOol0AWoo001DOol00`00Oomoo`0OOol00`00Oomoo`0KOol00`1OOomoo`03
Ool017`=Oomoogoo0P8O0goo0VPO0Woo0P8O17oo00EX7gooOomoo`1O00Aoo`03O0eoogoo03Ioo`03
05moogoo00Ioo`030Qmoogoo00=oo`9d7`030Qmoogoo055oo`03001oogoo04Ioo`00E7oo00<007oo
Ool07goo00<007ooOol06goo00<0GgooOol00goo00El3GooOomoo`8O00Eoo`05J1moogooOol27`03
Ool2J1l2Ool205l3Ool2O0dbOol00g`=Oomoo`03Ool00`1OOomoo`06Ool00`8OOomoo`03Ool2M1l0
0`8OOomoo`05Ool00g`005moo`0^Ool00`00Oomoo`0HOol00`00Oomoo`16Ool005Aoo`03001oogoo
03eoo`0305moog`000=oo`04O0eoogoo0Ql5Ool00fPOOomoo`02Ool00`8OOomoo`02Ool2J1l2Ool0
101OOomoogoo0g`=<Goo00=l3GooOol00goo0P1O00=oofPOOol01Goo00<27gooOol017oo00<27goo
Ool01Woo00<0GgooOol017oo00=l87ooOol09Woo00<007ooOol067oo00<007ooOol0AWoo001DOol0
0`00Oomoo`0oOol2O002Ool017`=Oomoo`8O1Goo00EX7gooOomoo`8O00Eoo`04J1moogoo05l5Ool0
0g`=Oomoo`0`Ool00g`=Oomoo`03Ool205l00gooJ1moo`04Ool20Ql00fPOOomoo`04Ool00`8OOomo
o`05Ool00`1OOomoo`0]Ool00`00Oomoo`0GOol20018Ool005Aoo`03001oogoo03Ioo`03O21oogoo
00Ioo`9l0003Ooml3Goo00Eoo`9l5`03OomX7goo009oo`060Qmoog`GO1MoofPO0goo00<0GgooO000
0goo00=l3GooOol0<Goo00=l3GooOol00goo00<0GgooJ1l01Woo00<27fPOOol01Goo0P8O00=l3Goo
Ool017oo00<0GgooOol0;7oo00<007ooOol067oo00<007ooOol0AWoo001fOol00`00Oomoo`0NOol0
0g`0Ooml3@06Ool2O1L00fPOOomoo`04Ool3O1L01VPOOomoogoo05moo`9l0003Ooml3Goo03=oo`03
O0eoogoo00Eoo`03J1moogoo00Eoo`03J1moogoo00Aoo`030Qmoog`=00Eoo`80Gbioo`03001oogoo
01Qoo`03001oogoo04Ioo`00MWoo00<007ooOol06Goo00</7gooOol00goo00=l07ooOol01Woo00=l
5fPOOol01Goo0W`G00=oofPOOol017oo0W`000=oog`=Ool0<Goo00=l07ooO0d027oo00=X7gooOol0
1Goo00=X7g`PO2001Goo00=l3GooOol00goo0P1OBGoo00<007ooOol0AWoo001DOol00`00Oomoo`0O
Ool00`00Oomoo`0IOol2;1l4Ool00g`0Oomoo`06Ool00g`GOomoo`06Ool00g`GOomX7`06Ool00g`0
Ooml3@0bOol017`0Ooml3G`=1Goo00Al5gooJ1mlH0Eoo`03O1MX7goo00Moo`03O0el07oo04eoo`03
001oogoo04Ioo`00E7oo00<007ooOol07goo00<007ooOol06Goo0R`O17oo00Al07`:O0Yoo`80_`Ao
o`03O1Moogoo00Ioo`03O1Moogoo00Eoo`03O01oog`=035oo`03O01oog`=009l3@9oo`04;1moogoo
O1L3J1l5Ool017`GJ1mX7g`01Goo00=l07`=Ool027oo00=l07ooOol01Goo00=l87ooOol0>goo00<0
07ooOol0AWoo001DOol00`00Oomoo`0OOol00`00Oomoo`0JOol00b`OOomoo`03Ool2O0X00goo0;l0
_`04Ool00g`GO1ml7`020;l4Ool017`GOomoob`O1Goo00=l07ooOol0<7oo00El07ooOomoog`=009o
o`03;1moog`G009oo`08J1moogaPO600_gooO1Moo`=X7`Eoo`03O01l3G`0011oo`03O21oogoo021o
o`03001oogoo01Qoo`03001oogoo04Ioo`00E7oo00<007ooOol0?7oo00</7gooOol00goo0W`:0Woo
00<0_gooOol00goo0W`O0P2o17oo00=l5g`OO1l00R`O17oo0g`:;Goo00Al2WooOoml00Eoo`04;1mo
ogooO1L6Ool00`2oOoml5`02Ool016POOoml002o0Woo00Il07ooO0el3GooO005Ool2O60ZOol00`00
Oomoo`0HOol00`00Oomoo`16Ool005Aoo`03001oogoo035oo`03O21oogoo00Aoo`9lH0=oo`03;1mo
ogoo00Aoo`03O0Yoo`2o00Eoo`9l7`03Ool0_goo00Aoo`9l7`03Ool/7goo00=oo`=l2Reoo`03O0Yo
og`000Ioo`03;1moog`G00Ioo`030;moog`G00Ioo`040;moogooO003O0d2Ool00b`OOomoo`04Ool0
0gaPOomoo`0WOol00`00Oomoo`0HOol00`00Oomoo`16Ool008moo`06O61oogooO01oob`O17oo00El
07ooO01l2P2o00Moo`03O1l0_goo00Aoo`9l7`03Ool/7goo00Aoo`9l2Raoo`04O0Yoog`0O004Ool2
;1l00gooO1Ml5`05Ool0102oO1moog`G1Goo00@0_gooOoml00=oo`04O0eoogoo;1l6Ool00gaPOomo
o`0WOol00`00Oomoo`0HOol00`00Oomoo`16Ool007Ioo`03001oogoo01Eoo`03O61oogoo00aoo`03
O0X0_goo009oo`06O01oog`POoml7`2o1Woo00=l7b`OOol01Woo00=l2WooOol0:7oo00=l2WooOol0
0g`00goo0R`O00Aoog`GO1Ml5`=oo`<0_`04O1L0G`1O05l2Ool20;l2Ool00g`0Oomoo`03Ool00b`O
Oomoo`0_Ool00`00Oomoo`0HOol00`00Oomoo`16Ool007Ioo`03001oogoo01moo`03O01oogoo00=o
o`=l4@Ioo`04O1moogooOol2O602Ool00g`O;1moo`06Ool00g`:Oomoo`0TOol00g`:Ooml2P03Ool0
0g`0Oomoo`02Ool01G`O;1moogooO1L01Goo00<0_gooOol00W`G101O0P2o0W`000Ioo`8O0Ql27goo
;1l4Ool00`8OOomoo`14Ool3000>Ool40003Ool3000`Ool005Aoo`03001oogoo01moo`03001oogoo
01aoo`8H7`Moo`=l4@03O01oogoo00Aoo`03J1moogaP00Eoo`03O1moogoo00Ioo`03O0Yoogoo02=o
o`9l2PQoo`9l7`Ioo`=l7`Uoo`0305moog`0009l0003Ool27goo00827`=oo`@27`Eoo`0305moogoo
03ioo`03001oogoo011oo`03001oo`0000=oo`03001oogoo02eoo`00E7oo00<007ooOol07goo00<0
07ooOol077oo0aPO1Woo0W`A00<1OgooOol01Goo0VPO00=lH7ooOol017oo0VPO1Woo0W`A97oo0W`:
1goo00=l7aPOO1l01Woo0g`O0R`O1Woo00Al2WooOoml00Eoo`8/7`Aoo`030Qmoogoo00827`9oo`@0
Gcioo`03001oogoo011oo`03001oo`0000=oo`03001oogoo02eoo`00E7oo00<007ooOol0<goo0R`O
2goo00<H7gooOol01Goo00<1Og`AOol01Woo0VPO00<1OgooOol017oo0VPO1Woo0g`A8Woo00=l4Goo
Ool027oo00<H7gooOol01Goo00=l7b`O;1l01Goo0g`:00=oo`2o0;l01Woo0P2o37oo00<0GgooOol0
0P1O8Goo00<007ooOol067oo00<007ooOol01Goo1`0017oo00<007oo00000goo00<007ooOol0;Goo
001DOol00`00Oomoo`0cOol3;1l7Ool20;l2Ool00aPOOomoo`03Ool0102oOol1Og`A1goo00<1OfPO
Ool01Goo0VPO1goo0W`A8Woo00=l4GooOol01Woo00=X7aPOOol01Woo0R`O00<1OgooOol017oo00Al
2P2o0;l0_`Ioo`0361l0_goo00Qoo`8/7bUoo`03001oogoo01Qoo`03001oogoo011oo`03001oo`00
00=oo`03001oogoo02eoo`00E7oo00<007ooOol0;goo0P1O1Goo00</7gooOol01Goo0`2o00=ooaPO
Ool00Woo0`2o00=oo`5oO1400goo0R`O0goo00=X7gooOol00goo00<H7gooJ1l027oo00=l4GooOol0
7Woo00=l4GooOol01Goo00<H7goo61l01goo00<1Ob`O;1l00Woo0W`=0goo0`2o1Woo0P2o27oo0R`O
:goo00<007ooOol067oo00<007ooOol037oo10000Woo00D007ooOomoo`0002moo`00MWoo00<007oo
Ool02Woo0`1O1goo00@27b`O0Ql27`Moo`030;l27`8O00=oo`<0_`03Ool1Ogoo009oo`</7`=oo`03
J1moogoo00Eoo`03J1moogoo00Ioo`03O15oogoo01aoo`03O15oogoo00Ioo`8H7`Qoo`81O`=oo`El
3@03O140_goo00=oo`03J1moogoo0080_`04Ool2O`9o0Wl2Ool2;1l]Ool00`00Oomoo`0HOol00`00
Oomoo`0=Ool00`00Oomoo`02Ool01@00Oomoogoo0000;goo001fOol00`00Oomoo`0:Ool205l8Ool2
0Ql2Ool261l4Ool20Ql017oo31l<7``O17oo00<0_`1O05l00W`M0goo00</7gooOol02Goo00=X7goo
Ool01Woo00=l4GooOol067oo00=l4GooO1401goo00=X7goo61l02Goo00<1OgooOol00goo00Al3Goo
0Gl1O`9l3@=oo`AX7`Aoo`82O`04J1moob`O;1l3Ool00`?oOomoo`05Ool00`?oOomoo`0jOol00`00
Oomoo`0=Ool40002Ool3000`Ool007Ioo`03001oogoo00eoo`=l00Eoo`030Qmoogoo008H7`=oo`82
7`9oo`<<7`9oo`<0G`9oo`9l7@Aoo`03;1moogoo00907bYoo`=l4@Moo`9X7`Moo`03J1mooaPO00Mo
o`9l00=oo`05O0eoogooOomX7`0261l3J1l017ooJ1mX7`9o0fPO0Woo00=l3@?oO0d01Woo0P?o1Woo
0P9o<goo00<007ooOol0AWoo001DOol00`00Oomoo`0OOol00`00Oomoo`0=Ool3O008Ool00g`G61mo
o`07Ool231l2Ool205l3Ool00g`M0Oml7@06Ool3@1l6Ool3@1l5Ool3O1dHOol00g`AOomoo`07Ool0
0``OJ1moo`06Ool00fPO61moo`05Ool017`AO01l4@5o1goo0W`G1Woo00=X7goo0Wl00Woo00EX7goo
Ooml3@?o00=l3@=oo`83o`Ioo`82Oc=oo`03001oogoo04Ioo`00E7oo00<007ooOol07goo00<007oo
Ool03Woo00Al07ooO01l00Ioo`9l5`0361ml5goo00Aoo`9l5`030Gl<7goo00Aoo`05O001O`7oOoml
7@05Ool00aPO@1m07`06Ool00``O@1moo`05Ool3O1dGOol2O1d8Ool00``OOomoo`07Ool00aPOOomo
o`04Ool2O0000`7oOol1O`06Ool00g`G0Gmoo`06Ool2O1L7Ool01G`00omoogooO0d017oo00<3ogoo
Ool01Goo00<2OgooOol05Goo00<007ooOol067oo00<007ooOol0AWoo001DOol00`00Oomoo`0aOol2
O0d017ooO0Yl2W`:0goo00El5gooOolH7g`G00Eoo`9l5`030Gl<7goo00=oo`=l00030Omoog`M00Eo
o`0361mood0O00Eoo`0331mood0O00Ioo`03O1eoog`M01Eoo`03O1eoogoo00Moo`0331m07goo00Io
o`8H7`Eoo`9l0004Ool1O`7o0Gl4Ool3O1L00`5oOomoo`04Ool2O1L00aPOOomoo`04Ool2O00:Ool0
0`?oOomoo`05Ool00`9oOomoo`0DOol00`00Oomoo`0HOol00`00Oomoo`16Ool005Aoo`03001oogoo
02eoo`04O0eoog`=O0d3Ool3O0X4Ool2J1l00gooO1ml7`07Ool00`5oOomoo`02Ool01G`0Oomoog`0
0Ol01goo00<H7goo@1l01goo00=07gooOol01Woo00=l7GooOol04Goo00=l7GooOol01goo0P`O1goo
00<1oaPO61l01Goo0W`000=l7@5o0Gl017oo0g`G00<1Og@OM1l00goo0W`G00=ooaPOOol01Goo00=l
07ooOol0:Goo00<007ooOol05goo0P00B7oo001DOol00`00Oomoo`0]Ool2O0d5Ool2O0X00gooJ1mX
7`02J1l3Ool017`O31l<7fPO0Woo0VPO0Woo0W`O0goo0W`=00Aoog`:O0Yl2PIoo`0361moogoo00Mo
o`03@1moogoo00Ioo`03O1eoogoo00ioo`9l7@Qoo`04@1l<7``O31l7Ool20Ol5Ool3O0000`7o0Gmo
o`04Ool2O1L20Gl2M1l2Ool3O1L011POOolL7a`O0Woo0W`0;7oo00<007ooOol067oo00<007ooOol0
AWoo001fOol00`00Oomoo`04Ool00`9oOomoo`03Ool2O0d2Ool00`?oOomoo`03Ool00g`:J1mX7`06
Ool231l3J1l4Ool00g`O07l0O`02O0d3Ool2O0X2B1lYOol2O1d8Ool2@1l7Ool2@1l9Ool00`7oO0Yo
o`05Ool231l017`OOomoog@O17oo00=l5aPO61l00Q`O00Aoog`0O01l00=oo`8L7`Eoo`=d7amoo`03
001oogoo01Qoo`03001oogoo04Ioo`00MWoo00<007ooOol017oo00<2OgooOol01goo00<3ogooOol0
17oo00Al2VPOOol3o`Eoo`0431mX7goo0Wl4Ool00g`O07l0O`05Ool00g`:Oom87`02B1l6Ool00``O
01l07`06Ool00`1o01l07`0EOol3O1d7Ool3@1l7Ool00d0O31moo`05Ool01G`MOol1ogooO0X01Woo
0P`O00El7gooOomoog@O00Aoo`05O1mooa`OOolL7`02Ool017`0Oomoogoo0Q`O1Woo0W@O>Woo00<0
07ooOol0AWoo001fOol00`00Oomoo`02Ool20Wl8Ool20ol8Ool00g`:0omoo`06Ool00``OOol2O`04
Ool2O0d00`7o07moo`05Ool00`7o0_m87`06Ool00``O01l07`06Ool00`1o01l07`06Ool2B1lHOol0
0`1oOomoo`05Ool00d0O0_l<7`06Ool2O1d00`7oO0Yoo`06Ool00`7oO1moo`04Ool017@OOomoog`O
1Goo00@L7gooOoml2PAoo`0371moogoo00Aoo`03M1moogoo03Qoo`03001oogoo04Ioo`00E7oo00<0
07ooOol07goo00<007ooOol00Woo0P9o27oo0P?o1goo0P?o00=l2W`AOol01Woo00<<7gooOol01Woo
00<1o`1oOol01Woo00<2odPOOol01Goo0P;o00<07gooOol00goo00<0O`0O01l01Woo00=87gooB1l0
2goo0TPO27oo00<07`1oOol027oo00<<7gooOol01Goo00<2o`7oO0X01Woo00<0OgooO1l01goo00=d
7g`OOol01Woo00<L7gooO0X01Goo00<L7gooOol017oo00=d7gooOol0=goo00<007ooOol0AWoo001D
Ool00`00Oomoo`0OOol00`00Oomoo`0EOol20ol00gooO15l4@04Ool20Wl2Ool00fPOOomoo`05Ool0
0`7oOomoo`06Ool00`;oB1moo`05Ool00``O0_l07`07Ool00`0OOomoo`06Ool00dPOOomoo`07Ool0
0dPOOomoo`06Ool00`1o01l0O`08Ool231l7Ool3O0X7Ool00g`O0Oml7`07Ool00g`OOomoo`07Ool0
0g`:Oomoo`05Ool00a`OOomoo`04Ool00g@OOomoo`0KOol00`00Oomoo`0HOol00`00Oomoo`16Ool0
05Aoo`03001oogoo03Yoo`9l4@Aoo`82O`9oo`0307mX7goo00Ioo`9X7`Ioo`=l4@Ioo`0331l2ogoo
00Moo`0301moogoo00Ioo`03B1moogoo00=oo`03B1moodPO00Uoo`80O`Qoo`030_l<7``O00Ioo`04
0_ml2W`:O0X6Ool00`7oO1ml7`05Ool010`OO1ml7g`O27oo00=l2WooOol03Woo00=d7gooOol06Woo
00<007ooOol067oo00<007ooOol0AWoo001DOol00`00Oomoo`0/Ool00g@OOomoo`0=Ool00g`AOomo
o`05Ool207l7Ool00fPO0Ol1o`05Ool3O14OOol2B1l8Ool201l207l6Ool201l20_l7Ool010;oO0Yl
2W`:17oo0P1o00<1og`OO1l01Goo00@<7g`OO1ml7`Eoo`=l2PQoo`030Ymoogoo02=oo`03001oogoo
01Qoo`03001oogoo04Ioo`00E7oo00<007ooOol0;7oo00=d7gooOol01Woo00<L7gooOol017oo00Al
4GooOolL7`Eoo`0307mX7goo00Eoo`03J1l1o`7o00Eoo`03O15oo`;o0080O`Ioo`80OaEoo`=87`Mo
o`807`Qoo`807`Ioo`04B1moodPOO147Ool00`1oJ1moo`07Ool231l7Ool3O0X8Ool20Yl7Ool20olK
Ool00`00Oomoo`0HOol00`00Oomoo`16Ool007Ioo`03001oogoo00Uoo`03M1moogoo00Moo`0371mo
ogoo00Eoo`03O15ooa`O00Ioo`0307moog@O00Eoo`030_l1ogoo00Moo`80O`Ioo`0307l2W`:O00Mo
o`81oaioo`0301moo`1o00Ioo`987`030_ml4Goo00Moo`03J1moogoo00Ioo`03J1moogoo00Eoo`03
O15l2Woo00Uoo`82W`Moo`030omoogoo00Eoo`83o`Ioo`82W`]oo`03001oogoo01Qoo`03001oogoo
04Ioo`00MWoo00<007ooOol027oo00=d7gooOol01goo00<L7gooOol01goo00=l4GooOol01Woo00<0
Og@OOol01Woo00<1ogooOol01Woo0P1o1Woo00<3o0:OOol01Woo0P:O1Woo0P1o0Woo0P1o2Goo00<1
ogooOol01Woo00<3o01oOol01Woo00=87gooO1401goo00<2ofPOOol01Woo00<0OgooJ1l01goo00=l
4GooOol02goo00<2WgooOol01Goo00<3ogooOol017oo0P?o1Woo0P:O9Woo00<007ooOol0AWoo001f
Ool00`00Oomoo`06Ool2M1l8Ool271l8Ool271l017ooO1el7G`M1Goo00=d7gooOol01goo00<1ogoo
Ool01Woo00<2o`1oOol01Goo00<0O`:OOol01Goo00@2Wgoo0Yl2W`Aoo`0407moo`1o07l9Ool00`:O
0Omoo`06Ool00`1o0o`0O`07Ool20o`00g`AOomoo`05Ool00`7oJ1moo`07Ool00`1oJ1moo`06Ool0
0g`AOomoo`0=Ool00`:OOomoo`04Ool00`?oOomoo`06Ool00`?oOomoo`05Ool00`:OOomoo`0ROol2
0018Ool005Aoo`03001oogoo01moo`03001oogoo00Ioo`9d7`Qoo`8L7`Qoo`8L7`04Ooml7G`MO1d2
Ool3M1l2Ool2@1l7Ool00d0OOomoo`05Ool3O1d6Ool00`1o0Ymoo`07Ool00`7o0Ymoo`02Ool207l2
Ool00`1oOomoo`03Ool010:OOol1o`7o1goo00<2W`1o07l01goo00<3o7`AO1401goo0fPO1Woo00=X
7`1oJ1l01goo00=l4GooOol05Woo00<3ogooOol01Woo00<3ogooOol01Goo00<2WgooOol08Woo00<0
07ooOol0AWoo001DOol00`00Oomoo`0OOol00`00Oomoo`0MOol2O1d3Ool3M1l2Ool00d0O0Ol1o`06
Ool2@1l6Ool3O1dEOol207l8Ool20Yl20Ol6Ool010:O0o`0O`1o1Woo0P?l0W`A1Goo0P7o0fPO1Goo
00<0OfPOJ1l01Woo0g`A1Goo0WPO;7oo00<007ooOol067oo00<007ooOol0AWoo001DOol00`00Oomo
o`11Ool017`MOomoog@O1Goo0P7o1Woo0T0O0P?n1Goo0W`M00<3o7ooOol01Goo0P7o37oo00<0Ogoo
Ool01Woo0P:O1goo0`:O1Woo0P1o00=oog`AOol01Woo0P7o00=X7gooOol01Goo00<0OfPOJ1l01Woo
0g`A1Goo0WPO1goo00<L7gooOol08Woo00<007ooOol067oo00<007ooOol0AWoo001DOol00`00Oomo
o`0LOol00`:OOomoo`06Ool00`?oOomoo`07Ool00`?oOomoo`0@Ool00g`MOomoo`06Ool00`7oOomo
o`06Ool20oh7Ool20cl6Ool20OlOOol00`7oOomoo`05Ool207l00gooO1eoo`07Ool00d0OOomoo`05
Ool00d0OOomoo`07Ool3O145Ool2N1l7Ool271l6Ool371l5Ool2N1lCOol00`00Oomoo`0HOol00`00
Oomoo`16Ool005Aoo`03001oogoo01]oo`030Ymoogoo00Moo`030omoogoo00Moo`030omoogoo00Io
o`030Ymoogoo00Qoo`03O1eoogoo00Eoo`030Omoogoo00Moo`030oioogoo00Eoo`030cl3j@<o00Io
o`030Ol3k`?_00Eoo`030cl3oP<o0083?`Aoo`83?`9oo`030oioogoo00Qoo`030Omoogoo00Ioo`03
0oal7Goo00Ioo`030oaood0O00Moo`03@1moogoo00Ioo`03O1eoogoo00Qoo`03N1moogoo00Aoo`8L
7`Moo`8L7`Eoo`9h7a=oo`03001oogoo01Qoo`03001oogoo04Ioo`00L7oo0P:O17oo00@007ooOomo
o`83o`Qoo`83o`Uoo`030Ymoogoo00Yoo`987`Eoo`030Omoogoo00Moo`030oioogoo00Ioo`030o`3
jGoo00Eoo`030nl3j@?_00Aoo`83?`83k`Eoo`050cl3k`<o0oh3k`07Ool00`?_0nT1o`06Ool010<o
0nUoog`M1Woo00@3oWoo0oa07`Ioo`030Om07goo00Qoo`03O1eoogoo00Qoo`03N1moogoo00Ioo`03
71moogoo00Eoo`0371moogoo00Aoo`03N1moogoo015oo`03001oogoo01Qoo`03001oogoo04Ioo`00
L7oo0P:O17oo00@007ooOomoo`83o`Qoo`83o`Moo`82W`eoo`=87`Moo`0301moogoo00ioo`03B1mo
ogoo00Eoo`030Ol3jGoo00Aoo`040cmoogoo0nl5Ool010?_0oioo`<o1Goo00@3k`?Y0Ol1o`Eoo`83
?`03O1d3o7`M00Moo`03@1l3o40O00Moo`03@1moogoo00Moo`03O1eoogoo00Yoo`03N1moogoo00Io
o`0371moogoo00Eoo`0371moogoo00Aoo`03N1moogoo02]oo`03001oogoo04Ioo`00MWoo00<007oo
Ool057oo0P:O3Goo0TPO27oo0P0O1goo0P0O1Woo0TPO5Woo0P?n27oo00<3j@7o0Ol01Goo00@3?`?Y
O1el7@Ioo`83oP907`Ioo`030Om07d0O00Qoo`03O1eoogoo00aoo`03N1moogoo00Ioo`0371moogoo
00Eoo`0371moogoo00Aoo`03N1moogoo02Yoo`03001oogoo04Ioo`00E7oo00<007ooOol07goo00<0
07ooOol09Goo00=87gooOol01Goo00<07`?n0oh01Woo0P0O1Woo0TPO:Woo0g`M1Goo0P?n0T0O1Woo
00<1od0O@1l01Woo0g`M9goo00=h7gooOol0:Goo00<007ooOol0AWoo001DOol00`00Oomoo`0OOol0
0`00Oomh7`0UOol00dPOOomoo`06Ool00`?nOomoo`06Ool00`0O0nL3i`06Ool00dPO0nUoo`06Ool2
0ohNOol00dPOOomoo`0IOol2O1diOol00`00Oomoo`0HOol00`00Oomoo`16Ool005Aoo`03001oogoo
025oo`03N1moogoo00Moo`0371moogoo00Ioo`0371moogoo00Ioo`03N1moogoo00Qoo`03B1moogoo
00Eoo`0301l3oWoo00Moo`030nT3i`?W00Ioo`030nUoogoo00Eoo`030oioogoo00Moo`83i`Uoo`03
0oioogoo00Moo`030nU87goo00Moo`0301moogoo00Ioo`0301moogoo00Eoo`03B1moogoo025oo`03
0Ymoogoo01Ioo`03001oogoo01Moo`8004Qoo`00E7oo00<007ooOol087oo00=h7gooOol01goo00<L
7gooOol01goo00<L7gooOol01Woo00=h7gooOol04Goo00<07`?nOol01goo00<3jGoo0nL01Woo0S_P
1Woo00<3oWoo>n001Woo0P?W2Goo00<3oWooOol01goo00=87gooOol01Goo00<3jGoo01l01Woo00<3
oWoo01l01goo00=87gooOol08Goo0P:O1goo0P?o1Woo00<3ogooOol01Goo00<007ooOol067oo00<0
07ooOol0AWoo001DOol00`00Oomoo`0OOol00gPOOomoo`06Ool271l9Ool00a`OOomoo`06Ool00gPO
Oomoo`0=Ool00`1oOomoo`0GOol00c_POomoo`04Ool00`?n>n0kh004Ool20nL00goo0nMoo`04Ool0
0c_P0oh3oP06Ool2>n000`?YB1moo`04Ool20nL00goo0nT07`07Ool00`?n01moo`06Ool00dPOOomo
o`0ROol20Yl7Ool20ol6Ool20ol6Ool00`000Ymoo`0HOol00`00Oomoo`16Ool007Aoo`9h7`03001o
ogoo00Ioo`8L7`Moo`8L7`Moo`9h7`moo`<0O`Moo`030Ymoogoo00Eoo`030Ymoogoo00Ioo`80O`ao
o`83i`Moo`03>n03oP?n00Eoo`8kh003B1l3jDPO00Aoo`030nMoogoo00807`Ioo`030oh07`0O00Mo
o`03B1moogoo02Eoo`030Ymoogoo00Ioo`030omoogoo00=oo`83o`Ioo`030002Wgoo01Qoo`03001o
ogoo04Ioo`00M7oo0WPO00<007ooOol01Goo00<L7gooOol01goo0Q`O1goo0WPO47oo00<0OgooOol0
1Woo0P:O1Woo0P:O1goo00<0OgooOol05Goo00<3oWooOol01Woo0TPO17oo0P?W0Woo0P0O1Woo00<3
oP0O01l01Woo0dPO9goo00<2WgooOol01Woo00<3ogooOol017oo00<3ogooOol01Goo00<2WgooOol0
5Woo00<007ooOol0AWoo001fOol00`00Oomoo`0HOol2N1lAOol00`1oOomoo`05Ool00`:O0nMoo`06
Ool00`:OOomoo`06Ool00`1oOomoo`0MOol00dPOOomoo`0@Ool00`0OOomoo`05Ool3B1lhOol00`?o
Oomoo`05Ool00`:OOomoo`0EOol00`00Oomoo`16Ool005Aoo`03001oogoo015oo`030Ymoogoo00]o
o`03001oogoo02]oo`0307moogoo00Ioo`030nMoogoo00Ioo`030Ymoogoo00Ioo`0307moogoo00Eo
o`83ia=oo`0307moogoo00Moo`030Ymoogoo02moo`9`7cYoo`03001oogoo04Ioo`00E7oo00<007oo
Ool04Goo00<2WgooOol01goo00D3ogooOomoo`0000Eoo`030omoogoo00Ioo`030Ymoogoo01aoo`03
07moogoo00Ioo`030Yl3igoo00Ioo`8kh0Qoo`03>n1oogoo00Aoo`83i`Yoo`030nMoogoo00Ioo`03
07moogoo00Moo`030Ymoogoo00Eoo`030Ymoogoo00Ioo`0307moogoo01ioo`=`7`Ioo`8H7`Ioo`8H
7`Ioo`9`7`Ioo`03001oogoo01Qoo`03001oogoo04Ioo`00E7oo00<007ooOol047oo00<2WgooOol0
27oo00<3ogooOol01Woo00<3ogooOol01goo00<2WgooOol087oo00<3?gooOol00goo00<3igooOol0
1Woo00<kh7ooOol01Woo00<kh7oo0cl01Woo00<3igooOol01goo00<3igooOol01Goo00<0OgooOol0
1Woo00<kh0:OOol01Goo00<3igoo0Yl027oo00<0OgooOol07Woo0W0O1goo0aPO1Goo0aPO1Goo0W0O
1Woo00<007ooOol067oo00<007ooOol0AWoo001DOol00`00Oomoo`0?Ool20Yl8Ool20ol7Ool20ol8
Ool20YlSOol20cl7Ool00`?_Oomoo`04Ool00c_POol3k`06Ool00c_P0cl3?`0=Ool20nL6Ool207l0
0c_POomoo`05Ool20Yl7Ool00`?W0Ymoo`07Ool00`1oOomoo`0QOol00g0OOomoo`04Ool261l7Ool0
0aPOOomoo`04Ool2L1l6Ool00`00Oomoo`0HOol00`00Oomoo`16Ool005Aoo`03001oogoo00moo`03
0Ymoogoo00Moo`030omoogoo00Ioo`83o`Qoo`030Ymoogoo029oo`030cmoogoo00Ioo`83k`Moo`83
k`Moo`030cmoogoo00]oo`83i`Ioo`80O`Qoo`82W`Eoo`83i`82W`Moo`80ObAoo`03L1moogoo00Eo
o`0361moogoo00Eoo`0361moogoo00Eoo`03L1moogoo00=oo`03001oogoo01Qoo`03001oogoo04Io
o`00MWoo00<007ooOol0;goo00<3?gooOol01goo00<3kgooOol01Goo00<3kgooOol01Woo00<3?goo
Ool04goo00<0OgooOol01goo00<2WgooOol017oo00<3igoo0Yl027oo0P1o9Goo00=`7gooOol01Goo
00<H7gooOol01Goo00<H7gooOol01Goo00=`7gooOol00Woo00<007ooOol067oo00<007ooOol0AWoo
001fOol00`00Oomoo`0_Ool00`<oOomoo`07Ool00`?_Oomoo`06Ool00`?_Oomoo`06Ool00`<oOomo
o`0AOol00`<oOomoo`06Ool00`?_Oomoo`05Ool00`?_Oomoo`06Ool00`<oOomoo`0XOol00g0OOomo
o`05Ool00aPOOomoo`02Ool0107oOomooaPO1goo00=`7gooOol06goo0P00B7oo001DOol00`00Oomo
o`0FOol00g0OOomoo`06Ool00`0061moo`08Ool00aPOOomoo`06Ool00g0OOomoo`0^Ool00`?_Oomo
o`0JOol00`<oOomoo`06Ool00`?_Oomoo`05Ool00`?_Oomoo`06Ool00`<oOomoo`0]Ool2O1T6Ool2
0Ol7Ool00`=OOomoo`05Ool00`=OOomoo`04Ool20Ol@Ool00`00Oomoo`16Ool005Aoo`03001oogoo
01Ioo`03L1moogoo00Ioo`03000H7goo00Qoo`0361moogoo00Ioo`03L1moogoo04Yoo`030cmoogoo
00Ioo`030nmoogoo00Ioo`030nmoogoo00Ioo`030cmoogoo02eoo`=l6@Eoo`81o`03>1moogoo00=o
o`<3G`Ioo`83G`Eoo`81oa1oo`03001oogoo04Ioo`00E7oo00<007ooOol05Goo00=`7gooOol01goo
00<H7gooOol01goo00<H7gooOol01Woo00=`7gooOol0BWoo0P<o1goo0P?_27oo00<3kgooOol01Woo
0P<o;Woo0g`I1Woo00<1ocPO>1l01Goo00<h7`=O>1l00goo00@007ooO1T3G`Ioo`030Omoogoo00io
o`03001oogoo04Ioo`00E7oo00<007ooOol04goo0W0O27oo0QPO27oo0QPO1goo0W0OCGoo00<3?goo
Ool01Woo00<3kgooOol01goo00<3kgooOol01Woo00<3?gooOol0;Woo00=l6GooOol01Goo00<1ocPO
Ool01Goo00<h7`=OOol00goo00@007ooOol3G`Ioo`030Omoogoo00ioo`03001oogoo04Ioo`00E7oo
00<007ooOol04goo0W0O27oo0QPO27oo0QPO1goo0W0OVWoo00=l6GooOol01Woo00<1ogooOol017oo
00=nP3PO0el00goo00@007ooOommh0Ioo`030Omoogoo00Eoo`03OX1oogoo00Ioo`03001oogoo04Io
o`00HGoo00<1ogooOol01Woo00=`7`=OOol027oo00<3GgooOol01Woo00<1ogooOol01Goo0g0OVgoo
00Al6GooOomoo`9l6@=oo`03>1moogoo00Aoo`03OX0h7goo009oo`05001oogooON03G`02Ool2O1T2
Ool00ggPOomoo`04Ool2OX07Ool00`00Oomoo`16Ool005]oo`9nP0Aoo`040OmoogooOol2ON04Ool0
1@=OOomoogooON001Goo00<3G`00Ool00Wj017oo00<1ogooOol0Xgoo00=l6GooOol00g`I0goo00@h
7gooOolh7`Aoo`05>1moogoo>1l00003Ool00g`IOoml6@02O1TBOol00`00Oomoo`16Ool0065oo`03
0Omoogoo00Moo`030emoogoo00Ioo`030emoo`0000Moo`030Omoogoo0:=oo`03O1Uoogoo00=l6@=o
o`04>1moocPO>1l4Ool00cPOOolh7`02>1l3Ool00g`IOomoo`02O1TBOol00`00Oomoo`16Ool005Ao
o`03001oogoo00Uoo`030Omoogoo00=oo`05O1UoogooOol3G`05Ool00cPOOomoo`020el00goo001o
o`02Ool013POOomoo`7o1Goo00=l6GooOol0Wgoo00Al6GooOoml6@Eoo`04>1moocPO>1l4Ool013PO
Oolh7cPO17oo00=l6GooO1T04goo00<007ooOol01Goo0`005Goo1P008goo001DOol00`00Oomoo`09
Ool00`7oOomoo`03Ool017`IOomoogoo0P=O17oo00<h7gooOol00P=O00=oo`00Ool00Woo00<h7goo
Ool00P7o17oo00=l6GooOol0XGoo00=l6GooOol01Goo00<h7gooOol01Woo00<h7gooOol017oo00=l
6GooOol04Woo00<007ooOol017oo00D007ooOomoo`0001Eoo`05001oogooOol0000SOol005Aoo`03
001oogoo00ioo`03O1Uoogoo00Moo`03>1moogoo00Moo`03>1moogoo00Ioo`03O1Uoogoo0:9oo`03
O1Uoogoo00Eoo`03>1moogoo00Eoo`03>1moo`0000Eoo`03O1Uoogoo011oo`<000Ioo`05001oogoo
Ool0000EOol00`00Oomoo`0UOol005Aoo`03001oogoo00ioo`03O1Uoogoo00Moo`03>1moogoo00Mo
o`03>1moogoo00Ioo`03O1Uoogoo0:5oo`03O1Uoogoo00Aoo`81o`03>1moogoo00Aoo`040elh7goo
0005Ool00`=OOomoo`04Ool20Ol<Ool00`00Oomoo`04Ool01@00Oomoogoo00005Woo00<007ooOol0
97oo001DOol00`00Oomoo`0>Ool2O1T7Ool3>1l7Ool3>1l7Ool2O1VROol00g`IOomoo`05Ool20Ol5
Ool30el00goo001oo`03Ool20el6Ool20Ol<Ool00`00Oomoo`04Ool01@00Oomoogoo00005goo00<0
07ooOol08goo001TOol3O1T7Ool3>1l5Ool00`00Oolh7`02>1l6Ool3O1VQOol00g`IOomoo`05Ool0
0`7o>1moo`06Ool010=OOomoo`0017oo00<3GgooOol01Goo00<1ogooOol02goo00<007ooOol017oo
00D007ooOomoo`0001Qoo`03001oogoo029oo`00G7oo00=nP7ooOol01Goo00Al6GooON1l6@Moo`03
ON1oocPO00Aoo`06001oogooOX1oocPO1Goo00Al6GooOoml6JQoo`030Omoogoo00Aoo`03OX03Ggoo
00Ioo`03ON03Ggoo00Aoo`9mh0Ioo`9nP0Ioo`03001oogoo00Aoo`05001oogooOol0000DOol01@00
Oomoogoo000097oo001LOol00gj0Oomoo`02Ool00`7oOomoo`02Ool00ggPO1Uoo`02Ool00`=OOomo
o`02Ool00ggP>1moo`02Ool01`=O001oogooOX1oocPO009oo`030Omoogoo00=oo`03O1Uoogoo0:Io
o`030Omoogoo00Aoo`03OX03Ggoo00Eoo`9mh0030emoogoo00=oo`9mh0Ioo`03OX1oogoo00Eoo`03
001oogoo00Eoo`<001Eoo`H002=oo`00E7oo00<007ooOol02Woo00<1ogooOol017oo00Al6GooOol3
G`Eoo`<h7`03Ool3G`0000Aoo`8h7`03Ool1ogoo00Eoo`03O1Uoogoo09Qoo`9`7`Yoo`030Omoogoo
00Ioo`030emoogoo00=`7`9oo`030emoogoo01Aoo`03001oogoo04Ioo`00E7oo00<007ooOol02goo
00<1ogooOol00goo0W`I0Woo00<3GgooOol00Woo0cPO00=oo`=O000017oo0SPO0Woo00<1ogooOol0
0goo0W`I8Goo00<3?gooOol027oo00<3kgooOol01Woo00<3kgooOol01Woo0P<oFGoo0W0O1Woo0QPO
1Woo0QPO1goo00<0070OOol067oo00<007ooOol0AWoo001DOol00`00Oomoo`0;Ool20Ol4Ool2O1T2
Ool20el4Ool013POOomoogoo0P=O17oo00<h7gooOol00P7o17oo0W`I8Goo0P<o27oo0P?_27oo0P?_
1goo0P<oFGoo0W0O1Woo0QPO1Woo0QPO1Woo00=`7`00L1l06Goo00<007ooOol0AWoo001DOol00`00
Oomoo`0;Ool20Ol5Ool01G`IOomoogoo0el027oo00<3GgooOol01goo00<1ogooOol09Goo00<3?goo
Ool027oo00<3kgooOol01Woo00<3kgooOol01Woo00<3?gooOol0Egoo00=`7gooOol01Goo00<H7goo
Ool01Goo00<H7gooOol01Goo00=`7goo00006Woo00<007ooOol0AWoo001DOol00`00Oomoo`0FOol0
0g0OOomoo`07Ool00aPOOomoo`07Ool00aPOOomoo`06Ool00g0OOomoo`0KOol00`<oOomoo`07Ool0
0`?_Oomoo`06Ool00`?_Oomoo`07Ool00`<oOomoo`1FOol00g0OOomoo`05Ool00aPOOomoo`05Ool0
0aPOOomoo`05Ool0170OOomoo`006Woo00<007ooOol0AWoo001]Ool00g0OOomoo`06Ool00`0061mo
o`08Ool00aPOOomoo`07Ool00g0OOomoo`0JOol00`<oOomoo`07Ool00`?_Oomoo`06Ool00`?_Oomo
o`05Ool00`1o0cmoo`0KOol00`?_Oomoo`05Ool00`?_Oomoo`06Ool00`<oOomoo`0XOol00g0OOomo
o`05Ool00aPOOomoo`05Ool00aPOOomoo`05Ool01G0OOomoogoo00006Woo00<007ooOol0AWoo001^
Ool00g0OOomoo`05Ool00`00OolH7`09Ool00aPOOomoo`07Ool00g0OOomoo`0FOol00`1oOomoo`07
Ool00`:OOomoo`06Ool20Yl8Ool207l5Ool20nL=Ool00`<oOomoo`06Ool00`?_Oomoo`05Ool00`?_
Oomoo`06Ool00`<oOomoo`1NOol20018Ool006moo`03L1moog0O00Aoo`03001oogoo008H7`Qoo`8H
7`Moo`=`7aEoo`<0O`Moo`030Yl3i`?W00Moo`8kh0Moo`8kh00307moogoo00=oo`83i`eoo`030cmo
ogoo00Moo`030nmoogoo00Eoo`030nmoogoo00Eoo`030cmoogoo05moo`03001oogoo04Ioo`00E7oo
00<007ooOol06Goo0W0O17oo00<007ooOol00QPO27oo0QPO1goo0g0O5Woo00<0OgooOol01Woo00<2
W`?WOol01goo00<2Wc_POol01Woo00<kh7ooOol01Goo00<3igooOol03Goo00<3?gooOol01Goo0P?_
1goo00<3kgooOol01Goo0P<oH7oo00<007ooOol0AWoo001DOol00`00Oomoo`0IOol2L1l4Ool00`00
Oomoo`0[Ool00`1oOomoo`07Ool00`?WOomoo`07Ool00c_POomoo`06Ool00`1oOomoo`05Ool00`?W
Oomoo`0=Ool20cl00c_POomoo`06Ool00c_POomoo`05Ool00`?WOomoo`04Ool00`<oOomoo`0`Ool2
0Yl7Ool00`?oOomoo`04Ool20ol00goo001oo`03Ool20YlDOol00`00Oomoo`16Ool005Aoo`03001o
ogoo02Eoo`030omoogoo00Ioo`030Ymoogoo01aoo`0307moogoo00Ioo`030Ymoogoo00Moo`030Ymo
ogoo00Ioo`0307moogoo011oo`030nMoogoo00Aoo`030clkh3_P00Moo`8kh0Ioo`030nMoogoo00Qo
o`0307moogoo02]oo`<2W`Ioo`83o`Ioo`83o`03Ool007oo00=oo`82WaAoo`03001oogoo04Ioo`00
E7oo00<007ooOol04Goo00<2WgooOol01goo00<3ogooOol01goo00<3ogooOol01goo00<2WgooOol0
=7oo0TPO57oo00<3igooOol01Goo00<kh01oOol01goo00<kh0:OOol01Goo00<3i`:OOol01goo00<0
OgooOol0:goo0P:O1goo00<3ogooOol017oo00D3ogooOomoo`0000=oo`030Ymoogoo01Aoo`03001o
ogoo04Ioo`00E7oo00<007ooOol04Woo00<2WgooOol01goo0P?o27oo0P?o27oo00<2WgooOol05Woo
0TPO27oo0P0O27oo0P0O1goo0TPO1goo0P?n2goo0P?W1goo00<0OgooOol01goo00<2WgooOol01Goo
00<2WgooOol01goo00<0OgooOol0:Goo00<2WgooOol01Woo00<3ogooOol017oo00<3ogooOol00Woo
00@007ooOol2WaMoo`03001oogoo04Ioo`00JWoo0P:O1goo0P?o00=oo`00Ool01Goo0P?o27oo0P:O
5goo0dPO1goo00<3oP0OOol01goo00<3j@0OOol01Goo0P?Y27oo0P?n1goo0P?W37oo00<0OgooOol0
1goo00<2WgooOol01Goo00<2WgooOol01Woo00<0OgooOol0:7oo00<2WgooOol01Woo00<3ogooOol0
2Woo00<007ooOol067oo00<007ooOol0AWoo001ZOol20Yl:Ool00`00Oomoo`0WOol00dPOOomoo`07
Ool20oh7Ool20nT20nL5Ool014PO0nTkh3_P1Goo00<3oWoo>n001goo0P?W3Goo00<0Ogoo07l01Woo
0P:O1Woo0P:O1goo0P1o<Goo0gPO9Woo00<007ooOol0AWoo001fOol00`00Oomoo`0WOol00dPOOomo
o`06Ool00`?nOomoo`07Ool010?YOol3i`?W1Goo00<3jC_POol01Goo00<3oWoo>n001goo00<3igoo
Ool017oo00<kh7ooOol01Woo0`1o1Woo0P:O1goo00<2WgooOol01Woo00<0OgooOol05Woo0gPO3Woo
0Q`O1goo0WPO9Woo00<007ooOol0AWoo001DOol00`00Oomoo`0OOol00`00Oomoo`0WOol00dPOOomo
o`05Ool00`0O0oioo`07Ool00`?YOol3i`06Ool00`?YOomoo`0?Ool00`?WOomoo`06Ool2>n07Ool0
0c_P07moo`06Ool00`?W0nUoo`07Ool00`?nOomoo`0NOol2N1l6Ool271l6Ool271l6Ool00gPOOomh
7`0VOol00`00Oomoo`16Ool005Aoo`03001oogoo01moo`03001oogoo019oo`0371moogoo00Ioo`03
N1moogoo00Qoo`03B1moogoo00ioo`03@1moogoo00Eoo`=l7A=oo`83i`Ioo`03>n03oWoo00Qoo`03
0nUoogoo00Aoo`040nL3jGoo01l6Ool00`?nOol07`07Ool00dPOOomoo`0COol00gPOOomh7`06Ool2
71l6Ool271l5Ool00gPOOomoo`0<Ool00`00Oomoo`0GOol20018Ool005Aoo`03001oogoo025oo`03
N1moogoo00Moo`0371moogoo00Ioo`0371moogoo00Ioo`03N1moogoo00Eoo`9l7@Moo`=07`Moo`90
7`Qoo`9l7@Ioo`81o`Qoo`83oP03Ool3i`?W00Qoo`030oioogoo00Ioo`030nU87goo00Ioo`030nT0
7goo00Ioo`030oh07goo00Ioo`03B1moogoo019oo`03N1moogoo00Ioo`0371moogoo00Eoo`0371mo
ogoo00Aoo`03N1moogoo00eoo`03001oogoo01Qoo`03001oogoo04Ioo`00E7oo00<007ooOol08Goo
00=h7gooOol01goo00<L7gooOol01goo00<L7gooOol01Woo00=h7gooOol017oo0W`M1goo0P7o00=0
7gooOol017oo00<3o0?n0oh01goo00<3o7`MOol01Woo0P?Y27oo0P?n37oo0P?n1goo00=87gooOol0
1Goo0P?Y00<07gooOol017oo0P?n00<07gooOol01Goo00=87gooOol047oo00=h7gooOol01Woo00<L
7gooOol01Goo00<L7gooOol017oo00=h7gooOol03Woo00<007ooOol067oo00<007ooOol0AWoo001D
Ool00`00Oomoo`0ROol00gPOOomoo`07Ool00a`OOolL7`07Ool271l7Ool00gPOOomh7`03Ool00g`M
Oomoo`06Ool20Ol7Ool00`?l0oh3oP07Ool20nT6Ool00`7o0nT3j@07Ool00`?n0nmoo`08Ool20cl2
Ool20oh8Ool00dPOOomoo`07Ool00`0OOomoo`06Ool201l6Ool2B1l?Ool00gPOOomoo`06Ool00a`O
Oomoo`05Ool00a`OOomoo`0FOol00`00Oomoo`0HOol00`00Oomoo`16Ool007Ioo`04001oogooOol2
N1l8Ool271l7Ool271l8Ool2N1l2Ool00g`MOomoo`07Ool00`7oOomoo`06Ool00`?nOomoo`06Ool0
0`?l0cl3?`05Ool00`7o0nUoo`020nl5Ool010?nOol3k`?_1Woo0`<o3Woo00=87gooB1l01Woo0P0O
1goo0P0O1Woo0TPO>Goo00<007ooOol067oo00<007ooOol0AWoo001fOol01000Oomoogoo0gPO1goo
0Q`O4Woo00Ah7gooOoml7@Qoo`030Omoogoo00Ioo`030oioogoo00Eoo`03O143o0<o0083?`Ioo`<3
k`Ioo`83k`Moo`<3k`Ioo`030nl3j@?_00Ioo`030nU87dPO00Ioo`807`Qoo`0301moogoo00Aoo`98
7eAoo`03001oogoo04Ioo`00MWoo00@007ooOomoo`=h7a9oo`030Ymoogoo00Qoo`03O1eoogoo00Io
o`030Omoogoo00Eoo`03J1moogoo00Ioo`9l4@030cmoogoo011oo`<3?`Ioo`83oP83k`Ioo`030nT3
k`?_00Ioo`987`030cmoogoo00Eoo`030oaoogoo00Eoo`030Omoogoo00Qoo`03O1eoogoo02aoo`82
Wb5oo`03001oogoo04Ioo`00E7oo00<007ooOol077oo00@2WgooOol000Eoo`030omoogoo00Moo`03
0omoogoo00Ioo`030Ymoogoo00Eoo`=l4@Moo`9X7`Moo`9X7`Qoo`9l4@Ioo`80O`Qoo`81o`Aoo`83
?`=oo`80O`03Ool3oWoo00Moo`030Ol3jGoo00Ioo`030nT3o7oo00Ioo`030o`3oT0O00Ioo`030Om0
7goo00Moo`03O1eoogoo01Aoo`030Ymoogoo00Aoo`83o`Moo`83o`Ioo`82Wb5oo`03001oogoo04Io
o`00E7oo00<007ooOol077oo00@2WgooOol000Ioo`030omoogoo00Ioo`030omoogoo00Moo`030Ymo
o`:O00Aoo`=l4@Ioo`80O`03J1moogoo00Aoo`030_l1o`7o00Moo`030o`0O`1o00Ioo`0407l3o0:O
0Yl6Ool00`7o0Yl2W`03Ool00`<oOomoo`0307l3Ool00`?nOomoo`05Ool00`7o0nUoo`08Ool00g`M
0oaoo`05Ool00`?l@1moo`06Ool00d0O0Omoo`07Ool00g`MOomoo`0BOol20Yl6Ool20ol7Ool00`?o
Oomoo`05Ool00`:OOomoo`05Ool00`00Oomoo`0HOol00`00Oomoo`16Ool005Aoo`03001oogoo01eo
o`030Ymoogoo00Moo`83o`Moo`83o`Qoo`82W`Eoo`03O15oogoo00Eoo`80O`Moo`030_l1o`7o00Mo
o`030o`0O`1o00Eoo`0407l3o0:O0Yl6Ool0107o0Ymoo`:O1Goo00<0OgooOol017oo0P?n1goo00<1
ogoo0Ol01goo00<3o7`MOol01Goo0P?l00=07gooOol017oo00<1od0OOol027oo00=l7GooOol04Goo
0P:O1Woo00<3ogooOol01Goo00<3ogooOol01Goo00<2WgooOol01Woo00<007ooOol067oo00<007oo
Ool0AWoo001DOol00`00Oomoo`0MOol20Yl8Ool20ol8Ool00`?oOomoo`07Ool00`:OOomoo`02Ool0
0g`AOomoo`06Ool00`1oOomoo`06Ool00`7oOomoo`06Ool00`;o07moo`05Ool00`1o0o`2W`07Ool0
0`7o0Ymoo`06Ool00`1oOomoo`0?Ool20Ol7Ool00`1oOoml7@08Ool00d0OOomoo`05Ool00d0OOom0
7`06Ool3O1d@Ool00`:OOomoo`05Ool00`?oOomoo`05Ool00`?oOomoo`05Ool00`:OOomoo`07Ool0
0`00Oomoo`0HOol00`00Oomoo`16Ool005Aoo`03001oogoo01eoo`82Wb1oo`03O15oogoo00Ioo`03
07moogoo00Ioo`030Omoogoo00Eoo`03O0X2o`1o00Qoo`030Ymoogoo01Uoo`82W`Moo`030Ol2Wgoo
00Ioo`0307moog`M00Moo`=07`Ioo`907`Ioo`=l7@moo`030Ymoogoo00Eoo`030omoogoo01Qoo`03
001oogoo01Qoo`03001oogoo04Ioo`00MWoo00<007ooOol077oo00=l4GooOol01Woo00<0OgooOol0
1Goo0W`O1goo0W`:1goo00<<7gooOol01goo00<0OgooOol01goo0TPO0P1o2Goo00<2WgooOol01Goo
00<3o0:OOol01Woo00<3o7`MO1d01Woo0d0O1goo00=07gooOol017oo0g`M67oo0W@O67oo00<007oo
Ool05goo0P00B7oo001fOol00`00Oomoo`0IOol3O0X7Ool2O1l00gooM1moo`04Ool3O1l7Ool2B1l6
Ool010`O0_l07`0O1Woo00<0O`0O01l01goo0dPO0Woo00<0Ogoo07l01Goo0P7o00<2WgooOol01Goo
00<3o01oOol01Goo00@0Og`MO1el7@Ioo`030_l1ogoo00Ioo`0307moofPO00Eoo`=d7`Ioo`8L7`Io
o`8L7`Moo`9d7c=oo`03001oogoo04Ioo`00MWoo00<007ooOol04goo00<L7gooOol00goo0g`:00=o
oa`OOol00goo0P`O00=l7gooM1l01Goo0P1o1goo00<2odPOB1l01Woo00@<7`;o01l07`Ioo`0301l0
O`0O00Ioo`03B1moogoo00Aoo`80O`Ioo`030Yl1o`:O00Moo`0307l3o7oo00Ioo`030_ml4Goo00Eo
o`030Ol2ofPO00Moo`0307mX7goo00Eoo`9d7`Ioo`8L7`Ioo`8L7`Moo`03M1moogoo039oo`03001o
ogoo04Ioo`00E7oo00<007ooOol07goo00<007ooOol02Woo00=d7gooOol01Woo00<L7gooOol017oo
0W`:00=ooa`OOol00goo0P`O00Al7gooOomd7`Aoo`80O`Moo`030_m87dPO00Eoo`0431l2o`0O01l6
Ool00`0OOomoo`06Ool00dPOOomoo`05Ool207l8Ool00`7oOomoo`05Ool00`?l07moo`07Ool00g`A
0_moo`05Ool00`7o0_mX7`07Ool00`1oJ1moo`03Ool017@OOomd7g`A1Goo0Q`O1Woo00<L7gooOol0
1Goo00=d7gooOol0<goo00<007ooOol0AWoo001DOol00`00Oomoo`0OOol00`00Oomoo`0:Ool00g@O
Oomoo`07Ool00a`OOomoo`02Ool00g`:Oomoo`02Ool01A`OOomoogoo31l01Goo00Ed7gooM1l1o`1o
00Moo`030_m87goo00Eoo`0331moo`0O00Moo`0301moogoo00Ioo`03B1moogoo00moo`<1o`Qoo`80
O`Moo`03O15oogoo00Eoo`82o`03J1moogoo00Aoo`80O`04J1moogooM1l4Ool01G`AOomoogoo71l0
1goo00<L7gooOol01Goo00=d7gooOol06Goo00<007ooOol067oo00<007ooOol0AWoo001DOol00`00
Oomoo`0]Ool00g@OOomoo`07Ool011`OOolL7g`:1Woo0Q`O00<<7gooOol01Goo00=d7`7o07l01goo
00<2odPOOol01goo00<07gooOol03Goo0g`M77oo0P1o1goo00=87g`AOol027oo00=X7gooOol01Goo
00=X7gooM1l01Woo0W`A00<L7gooOol01Goo00<L7gooOol01Goo00=d7gooOol06Woo00<007ooOol0
67oo00<007ooOol0AWoo001DOol00`00Oomoo`0^Ool2M1l8Ool00a`OO0Yoo`06Ool00a`O31moo`07
Ool00g@O07moo`08Ool2O004Ool261l7Ool00``O@1m07`08Ool2O1d:Ool00dPOOomoo`06Ool00`0O
Oomoo`06Ool207l7Ool00dPO0_ml4@07Ool0101oJ1mX7fPO1Woo00=d7fPOOol01Goo00=l4A`OO140
;7oo00<007ooOol067oo00<007ooOol0AWoo001DOol00`00Oomoo`0^Ool2M1l9Ool00a`OO01oo`07
Ool2O1L7Ool3O1L4Ool3O1d2O003Ool011PO0Om07d0O1Woo00<<7d0O@1l01goo00=l7GooO1d02goo
00=87gooOol01Woo00<07`1oOol01goo00<2ogooOol01Goo00@2ogooO15l4@Eoo`0407mX7fPOJ1l6
Ool00``OJ1moo`07Ool00g`AO0Yoo`0ZOol00`00Oomoo`0HOol00`00Oomoo`16Ool007Ioo`03001o
ogoo00ioo`03M1moogoo00Ioo`=l00=oo`8H7`04Ooml5g`GO1L4Ool231l3O1L4Ool01P7oO1el07`M
Ooml00=oo`0461l1od0O@1l6Ool00d0O31m07`06Ool00g`MOomoo`0=Ool00dPOOomoo`06Ool00`1o
Ool07`06Ool00`0O31moo`06Ool00`;oO15l4@06Ool00`1o0Ol0O`07Ool00``OOoml7`07Ool00g`:
Oomoo`0DOol20WlCOol00`00Oomoo`0HOol00`00Oomoo`16Ool007Ioo`03001oogoo00Aoo`030Wmo
ogoo00Moo`030omoogoo00Eoo`Al00=oo`8H7`04O1Moo`9oO1L4Ool231l7Ool20Ol00g`MOomoo`03
Ool00aPOOom07`07Ool00d0OOomoo`06Ool00g`MOomoo`0?Ool00dPOOom87`06Ool00`1o01moo`06
Ool00``O0_l2o`05Ool014PO0Ol2og`:1Woo00<0O`7oO1l01goo00<<7g`O31l01goo00=l2WooOol0
2goo0P?o1Woo0P9o;Woo00<007ooOol0AWoo001fOol00`00Oomoo`04Ool00`9oOomoo`07Ool00`?o
Oomoo`03Ool2O003Ool017`00omoogoo0QPO0goo00H2OfPOJ1moog`G31l4Ool3O0d00`7oOoml7@05
Ool00aPOOom07`07Ool00d0OOomoo`06Ool00g`MOomoo`0AOol2B1l7Ool207l7Ool00``O0_moo`06
Ool00`7oO0X1o`06Ool00`1o0Oml7`07Ool00``OO1moo`03Ool20Wl2Ool017`:Oomoogoo0P?o1goo
00<3ogooOol01Goo0P9o;Woo00<007ooOol0AWoo001DOol00`00Oomoo`0OOol00`00Oomoo`05Ool0
0`9oOomoo`07Ool20ol2Ool00g`0Oomoo`03Ool01@?oJ1mX7aPOO1L01Goo00D2OgooJ1l<7fPO00Io
o`040Oml3G`MO0d6Ool00d0OOomoo`0=Ool3O14COol2B1l7Ool207l8Ool00``OOol<7`06Ool00`7o
O0Yoo`06Ool20Ol00g`OOomoo`04Ool231l017`OOomoogoo0P9o0goo00=l2WooOol00P?o17oo0W`=
00<3ogooOol01Goo00<2OgooOol0;Goo0P00B7oo001DOol00`00Oomoo`0OOol00`00Oomoo`06Ool2
0Wl8Ool3O0d8Ool011POJ1mX7fPO1Woo00@<7gooJ1mX7`Ioo`04O1el3G`=O0d;Ool00aPOJ1mX7`07
Ool3O14MOol00`1oOomoo`06Ool00d0O31l<7`06Ool00g`M0Oml2P07Ool010`OOoml7g`O1Woo00Al
7fPOJ1moo`82O`=oo`03O0YX7`?o00=oo`Al3@030oml3Goo00Eoo`030Wmoogoo01Aoo`03001oogoo
01Qoo`03001oogoo04Ioo`00E7oo00<007ooOol0:7oo0P9o2goo0g`=1goo0fPO1goo00EX7gooOomo
o`2o00=l4@9oo`03O0eoogoo0081O`9X7`Ioo`0361mX7fPO00Moo`03O15oogoo01Eoo`03O1eoogoo
00Ioo`03@1moogoo00Ioo`8<7`Moo`03O1d1og`:00Moo`0331ml7g`=009l3@Eoo`9X7`040Wmoogoo
Ool3J1l00`?oJ1moo`02O0d4Ool00g`=Oomoo`0LOol00`00Oomoo`0HOol00`00Oomoo`16Ool005Ao
o`03001oogoo03Ioo`=l3@03Ool/7b`O00Aoo`04J1moogooOol261l7Ool0105oO15l4G`A0goo0R`O
0P5o0VPO1Woo00=X7gooJ1l01Woo00=l4GooOol05goo00=l7GooOol01Woo00<<7gooOol01Woo00<1
od0OOol01Woo00@1ogooO0Yl2PAoo`Il3@=oo`=X7`030Wmoogoo009X7`=oo`04J1ml2W`0O00TOol0
0`00Oomoo`0HOol00`00Oomoo`16Ool008ioo`03O0eoogoo00</7`Ioo`030;lH7aPO00Eoo`80_`04
0Gml4GooO142Ool01B`OOomoogooJ1l01goo00=X7gooOol01Woo00=l4GooOol06Goo00=l7GooOol0
1Goo00@<7d0OOom07`Ioo`030OlH7goo00Ioo`030Oml07`:009oo`9l3@=oo`040Gml3G`GOol2J1l3
Ool00aPOO1Ml5`09Ool00g`0Ooml000QOol00`00Oomoo`0HOol00`00Oomoo`16Ool007Ioo`03001o
ogoo01Ioo`@/7`Ioo`030;mooaPO00Eoo`040;moo`5oO142Ool00`1OOomoo`03Ool00fPOOomoo`05
Ool00fPOOomoo`05Ool00g`:O15oo`0LOol2O1d6Ool00``O@1m07`06Ool00d0O61l1o`06Ool01G`M
0Gl1og`:O0001Goo00<<7`5oOol00g`G17oo00<H7gooO1L00W`G1goo0W`08Goo00<007ooOol067oo
00<007ooOol0AWoo001fOol00`00Oomoo`0EOol012`OOol27`8O1Woo00<0_goo61l00`8O17oo00<1
Og`AOol00`1O17oo00=X7gooOol03Goo0g`:7Goo0W`M1goo00<<7d0O31l01Woo00<1oaPOOol01goo
00H1Ogoo0Gml07ooO004Ool20Gl2O1L4Ool361l2O1L7Ool3O00kOol00`00Oomoo`16Ool005Aoo`03
001oogoo01moo`03001oogoo00ioo`80G`Uoo`<27`Aoo`0361moogoo00<27`9oo`03O0Yl4Goo009o
o`80G`9oo`9l7`Ioo`03;1ml7g`O00=oo`03O01oogoo009oo`9l2Qeoo`=l7@Moo`8<7`Qoo`0361mo
oaPO00Ioo`81O`03Ooml07`000Eoo`040Gml5g`GO1L5Ool00aPOO1Moo`0<Ool00`1OOomoo`0fOol0
0`00Oomoo`16Ool005Aoo`03001oogoo01moo`03001oogoo011oo`<0G`Moo`827`]oo`=l2PIoo`=l
7`Ioo`03;1ml7g`O009oo`9l00=oo`03O0Yoogoo02Qoo`0331moogoo00Ioo`03J1lH7aPO00Ioo`03
O141Ogoo00=l00Aoo`0361moogoo00Uoo`8/7`03Ool27goo00Ioo`<0GcMoo`03001oogoo00Aoo`@0
00=oo`<003Qoo`00E7oo00<007ooOol07goo00<007ooOol04Goo0P1O2Woo0R`O17oo00Al07ooOol0
_`=l2PEoo`80_`9l7`9oo`9l5`9oo`03O1moogoo009oo`9l009oo`03O0Yoogoo021oo`03O15oogoo
00Moo`03J1moogoo00Ioo`8H7`Moo`04O141Og`0Ool20;l4Ool011POOol0_`2o0Woo0P8O1Goo0`8O
0goo0`1O00=oo`1OOol077oo00<007ooOol067oo00<007ooOol027oo00<007oo00000goo00<007oo
Ool0=Goo001DOol00`00Oomoo`0nOol3;1l3Ool2O002Ool00`2oO0Yoo`02Ool3O1L017oo0;ml7gaP
0Woo0g`G00=oog`OOol017oo00Al07ooOoml2RAoo`03O15oogoo00Moo`0361moogoo00Ioo`030Gmo
ogoo008/7`Aoo`03O141Og`A009oo`030;l0G`1O009oo`0361moo`8O00<27`Aoo`827`03Ool27b`O
02Eoo`03001oogoo01Qoo`03001oogoo00Qoo`03001oo`0000=oo`03001oogoo03Eoo`00E7oo00<0
07ooOol0?goo00</7gooOol00Woo0g`000Aoog`:Ooml009oo`=l5`04Ooml7gooO603Ool2O1L017`O
;1moog`=0Woo00Al07ooOoml2RIoo`03O15oogoo00Ioo`0361mX7goo00Moo`050GmX7gooOol/7`04
Ool00g`A0Gl0G`0205l00`2o05moo`02Ool00`8OOomoo`020;l7Ool3;1lTOol00`00Oomoo`0GOol2
000:Ool00`00Ool00003Ool00`00Oomoo`0eOol007Ioo`03001oogoo01aoo`04;1moogooO002Ool0
1G`0Oomoog`:0;l017oo00El87`GOoml7`2o009oo`9lH004Ooml5goo;1l2Ool2O0d00gooO01oo`0Y
Ool00g`AOomoo`06Ool00aPOJ1moo`06Ool00fPO0Gl1O`02Ool2;1l2Ool00g`A05l1O`02Ool20;l2
Ool361l017oo0;l0_`2o;Goo00<007ooOol05Woo00<007oo00002Woo00<007oo00000goo00<007oo
Ool0=Goo001fOol00`00Oomoo`0EOol00gaPOomoo`04Ool00b`OOoml3@03Ool01G`0Ooml2Woo0;l0
0Woo00Il07ooO21l5goo0;l2Ool016POOomoog`G1Goo00Al3GooOoml02]oo`9l4@Ioo`04J1lH7fPO
61l6Ool20Gl2Ool2;1l4Ool017`:Oomoo`2o=goo00<007ooOol067oo00<007ooOol017oo10000Woo
00D007ooOomoo`0003Moo`00MWoo00<007ooOol05Woo00IlH7ooOoml07oo;1l2Ool017`=Ooml07`0
0goo00@0_gooOomX7`9oo`03O1Moogoo00=oo`9X7`03Ooml5goo00Eoo`03O0el07oo02]oo`9l4@Mo
o`<H7`Qoo`03O1moogoo008/7`=oo`03O0Yoogoo00ioo`03O61oogoo049oo`03001oogoo00Eoo`03
001oogoo009oo`05001oogooOol0000gOol005Aoo`03001oogoo01moo`03001oogoo00moo`03O21o
ogoo00Aoo`03O61oogoo00Aoo`=l3@03Ooml07oo00Aoo`=X7`03Ooml5goo00Eoo`03J1ml5goo00Io
o`03O0eoogoo02eoo`03O15oogoo00Ioo`0361moogoo00Ioo`03O1moogoo00Ioo`03O0Yoogoo00Eo
o`03O01oogoo04Yoo`03001oogoo00Eoo`@0009oo`<003Qoo`00E7oo00<007ooOol07goo00<007oo
Ool07goo00=l3GooO0001Woo00=X7gooO1L01goo00AX7gooOol0G`Eoo`03O0eoogoo02eoo`03O0Yo
ogoo00Ioo`03O1moogoo00Moo`03O1moogoo00Aoo`03O000_g`:00Moo`03;1moogoo009oo`03O61o
ogoo02Uoo`03001oogoo01Qoo`03001oogoo04Ioo`00E7oo00<007ooOol0@Goo00=l3G`0Ool01Woo
00=X7gooOol00Woo00<27gooOol00Woo00=X7gooOol00P1O1Goo00=l3GooOol0;7oo00=l2WooOol0
1goo00=l7gooOol017oo00AlH7oo0;ml7`Ioo`030;moog`:009l2P05Ooml07ooOol/7`0=Ool00g`P
Oomoo`0POol00`00Oomoo`0HOol00`00Oomoo`16Ool005Aoo`03001oogoo03]oo`0305moogoo00=o
o`05O0eoogooOol27`05Ool00fPOOomoo`020Ql5Ool016POOomoo`1O1Goo00=l3GooOol0;Goo00=l
2WooOol01Woo00</7g`OOol01Woo00@0_g`OO1ml7`9oo`04O01oogoo0;l3O0X5Ool00b`OOomoo`02
Ool00g`0Oomoo`0XOol00`00Oomoo`0HOol00`00Oomoo`16Ool005Aoo`03001oogoo03]oo`80G`Ao
o`04O0eoogooOol20Ql4Ool01FPOOomoogoo0Ql00goo00=l87ooJ1l00Woo00<0GgooOol0=7oo00=l
2WooOol01Goo00@/7gooO1ml7`9oo`07O61oogooOol0_g`OO1L01Woo00D0_g`:O0Yoog`000=oo`03
;1moogoo02eoo`03001oogoo01Qoo`03001oogoo04Ioo`00MWoo00<007ooOol06Goo0P1O1Goo00Al
3GooOol27`=oo`03O01oofPO00Aoo`030Qmoog`P00Eoo`0305moogoo03Eoo`=l2PEoo`03;1ml7g`G
00Ioo`040;moog`OOol2O203Ool20;l00gooO01oo`03Ool3;1l]Ool00`00Oomoo`0HOol00`00Oomo
o`16Ool007Ioo`03001oogoo01Yoo`0705moogooOoml07ooO0d00goo00<27gooOol01goo00<27goo
Ool01Woo00<0GgooOol0=7oo0g`:1Goo00</7gooO1L01Woo0P2o00=oog`GOol017oo0P2o00=oog`0
Ool00goo0R`OBGoo00<007ooOol0AWoo001fOol00`00Oomoo`0DOol00g`POomoo`03Ool00`1OOomo
o`07Ool00`8OOomoo`07Ool00`8OOomoo`0>Ool2M1l]Ool3O0X5Ool012`OOomoog`G1Goo0P2o00=o
og`GOol01Woo00=l3G`0Ool0CWoo00<007ooOol0AWoo001DOol00`00Oomoo`0OOol00`00Oomoo`0K
Ool00`1OOomoo`06Ool00`8OOomoo`0?Ool00a`OOomoo`06Ool2M1l_Ool00g`0Oomoo`03Ool3;1l0
0g`GOomoo`05Ool00fPOOoml5`06Ool00g`=Ooml001=Ool20018Ool005Aoo`03001oogoo01moo`03
001oogoo01]oo`0305moogoo00Eoo`03M1moogoo00Moo`8L7`Moo`8L7`Qoo`03M1moogoo02ioo`03
O01oogoo00=oo`04;1moofPOO1L6Ool016POOoml5g`G1Goo00Al3GooO01l00Uoo`03O21oogoo02Io
o`03001oogoo01Qoo`03001oogoo04Ioo`00E7oo00<007ooOol0AGoo0W@O27oo0Q`O1goo0Q`O2Goo
00=d7gooOol0;7oo00=l3G`0Ool01Woo00AX7g`GO1Ml5`Aoo`04J1moog`GO1L4Ool00g`=Ooml0004
O0000`1OOomoo`0]Ool00`00Oomoo`0HOol00`00Oomoo`16Ool005Aoo`03001oogoo04Eoo`9d7`Qo
o`8L7`Uoo`0371moogoo00Moo`03M1moogoo02]oo`03O0el07oo00Ioo`04J1ml5g`GO1L4Ool02FPO
Oomoog`GOoml008OOoml3@03Ool017`0Oomoo`1O;goo00<007ooOol067oo00<007ooOol0AWoo001D
Ool00`00Oomoo`17Ool00g@OOomoo`07Ool00a`OOomoo`07Ool00a`OOomoo`07Ool00g@OOomoo`0Z
Ool017`=O01l07`017oo00UX7gooOoml5gooO21oo`8OJ1l01Woo00<27gooO0d01Goo00<0GgooOol0
;Woo00<007ooOol067oo00<007ooOol0AWoo001fOol00`00Oomoo`0UOol00g@OOomoo`07Ool00a`O
Oomoo`08Ool00a`OOomoo`0bOol00g`=Ooml0002O002Ool00`1OOomX7`06Ool00`8OJ1mX7`05Ool0
0`8OO0el3@05Ool00`1OOomoo`0^Ool00`00Oomoo`0HOol00`00Oomoo`16Ool007Ioo`03001oogoo
02Ioo`03M1moogoo00Moo`0371moogoo00Qoo`030Wmoogoo035oo`05O0eoogooOoml0002Ool00`1O
J1mX7`05Ool0108OJ1mX7fPO17oo00@27g`=O0el3@Aoo`80Gd]oo`03001oogoo04Ioo`00MWoo00<0
07ooOol09goo00=d7gooOol04Goo00<2OgooOol0<Goo00=l3GooOol00goo00@0GgooJ1mX7`Eoo`05
0QmoofPOOomd7`03Ool20Ql00g`=Oomoo`03Ool205m;Ool00`00Oomoo`16Ool005Aoo`03001oogoo
01moo`03001oogoo039oo`83o`Moo`82Oc1oo`=l3@Eoo`0305moofPO009oo`0371moogoo00827`=o
o`05M1moogooOol27`07Ool00`1OOomoo`1:Ool00`00Oomoo`16Ool005Aoo`03001oogoo01moo`03
001oogoo02Qoo`83o`Qoo`030omoogoo00Moo`030Wmoogoo02ioo`=l3@03OolL7goo009oo`0505mo
ogooOolL7`03Ool01@8OOomoogooM1l0?Woo00<007ooOol067oo00<007ooOol0AWoo001DOol00`00
Oomoo`11Ool20Wl8Ool00`?oOomoo`07Ool00`?oOomoo`07Ool00`9oOomoo`0XOol00g@OOomoo`03
Ool00g`=OolL7`03Ool205l2Ool00a`OOomoo`03Ool00g@OOomd7`0oOol00`00Oomoo`0HOol00`00
Oomoo`16Ool005Aoo`03001oogoo045oo`030Wmoogoo00Qoo`030omoogoo00Moo`030omoogoo035o
o`03M1moogoo00Aoo`0371moogoo009oo`0405mooa`O71l6Ool2M1m0Ool00`00Oomoo`0GOol20018
Ool005Aoo`03001oogoo049oo`030Wmoogoo00Qoo`030omoogoo03Uoo`03M1moogoo00=oo`8L7`Mo
o`8L7`Ioo`03M1moogoo03moo`03001oogoo01Qoo`03001oogoo04Ioo`00MWoo00<007ooOol08Goo
00<2OgooOol09Woo0WPO67oo00=d7gooM1l01Woo0Q`ODGoo00<007ooOol067oo00<007ooOol0AWoo
001fOol00`00Oomoo`1:Ool2N1lHOol2M1lROol00`9oOomoo`1@Ool00`00Oomoo`16Ool007Ioo`03
001oogoo045oo`<L7`Moo`03N1moogoo01Ioo`9d7aYoo`030omoogoo00Aoo`030Wmoogoo055oo`03
001oogoo04Ioo`00E7oo00<007ooOol07goo00<007ooOol0;Woo0gPO1goo0Q`O27oo00<L7gooOol0
1goo00=h7gooOol0:7oo00<3ogooOol01Goo00<3ogooOol00goo0P9oE7oo00<007ooOol0AWoo001D
Ool00`00Oomoo`0OOol00`00Oomoo`0^Ool3N1l7Ool271l9Ool00a`OOomoo`07Ool00gPOOomoo`0W
Ool00`?oOomoo`03Ool20ol6Ool20WliOol00`00Oomoo`0HOol00`00Oomoo`16Ool005Aoo`03001o
ogoo051oo`9h7`Yoo`0371moogoo00Moo`0371moogoo00Moo`03N1moogoo01eoo`030Wmoogoo00=o
o`030omoo`?o00Ioo`83od5oo`03001oogoo01Qoo`03001oogoo04Ioo`00E7oo00<007ooOol0DWoo
00=h7gooOol027oo00<L7gooOol01goo00<L7gooOol09Goo00<2OgooOol017oo0P?oBWoo00<007oo
Ool067oo00<007ooOol0AWoo001DOol00`00Oomoo`1COol00gPOOomoo`08Ool00a`OOomoo`0/Ool2
0Wl7Ool00`?oOomh7`19Ool00`00Oomoo`0HOol00`00Oomoo`16Ool007Ioo`03001oogoo039oo`03
N1moogoo015oo`82Wb=oo`82O`03OolL7goo00Ioo`03N1moogoo04Moo`03001oogoo01Qoo`03001o
ogoo04Ioo`00MWoo00<007ooOol0?Goo0P?o1goo00<2WgooOol09Goo00<L7gooOol017oo00=h7goo
Ool0Hgoo00<007ooOol0AWoo001fOol00`00Oomoo`0dOol00`?oOomoo`06Ool20ol8Ool00`:OOomo
o`0KOol00a`OOomoo`05Ool00a`OOomoo`02Ool00gPOOomh7`1UOol20018Ool005Aoo`03001oogoo
01moo`03001oogoo02Yoo`030Ymoogoo00Moo`83o`Qoo`030omoogoo00Moo`030Ymoogoo015oo`03
N1moogoo00Eoo`0371moogoo00=oo`0371mooa`O00Eoo`9h7fMoo`03001oogoo04Ioo`00E7oo00<0
07ooOol07goo00<007ooOol0:Woo0P:O2Goo00<3ogooOol01goo00<3ogooOol06Goo00=h7gooOol0
0goo00<L7goo71l01Woo0Q`O1Woo0WPOC7oo00<007ooOol067oo00<007ooOol0AWoo001DOol00`00
Oomoo`1<Ool20Yl9Ool00`?oOomoo`0ROol00gPOOomoo`04Ool271l7Ool00a`OOomoo`1COol00`00
Oomoo`0HOol00`00Oomoo`16Ool005Aoo`03001oogoo04ioo`030Ymoogoo00Moo`030omoogoo01ao
o`=`7`9h7`Moo`8L7aUoo`030Ymoogoo045oo`03001oogoo01Qoo`03001oogoo04Ioo`00E7oo00<0
07ooOol0Cgoo00<2WgooOol09Goo0W0O00=oogPON1l08Woo00<2WgooOol0@Goo00<007ooOol067oo
00<007ooOol0AWoo001fOol00`00Oomoo`1=Ool261l6Ool2L1l3N1lJOol00`?oOomoo`02Ool00`:O
Ool2W`14Ool00`00Oomoo`0HOol00`00Oomoo`16Ool007Ioo`03001oogoo04Aoo`0361moogoo00Io
o`8H7`Qoo`03L1moogoo015oo`030omoogoo00Eoo`030omoogoo00=oo`82Wf1oo`03001oogoo04Io
o`00MWoo00<007ooOol0>Woo0W0O27oo0QPO1goo0QPO2Goo00=`7gooOol03goo00<3ogooOol017oo
0P?o1Woo0P:OH7oo00<007ooOol0AWoo001DOol00`00Oomoo`0OOol00`00Oomoo`0jOol2L1l8Ool2
61l9Ool00aPOOomoo`07Ool00g0OOomoo`06Ool00`:OOomoo`03Ool20ol7Ool20omXOol00`00Oomo
o`16Ool005Aoo`03001oogoo01moo`03001oogoo03Yoo`9`7`Yoo`0361moogoo00Ioo`0361moogoo
00moo`030Ymoogoo00Aoo`83o`03L1moogoo05=oo`03001oogoo01Qoo`03001oogoo04Ioo`00E7oo
00<007ooOol0GWoo00=`7gooOol01goo00<H7gooOol01goo00<H7gooOol037oo0P:O2Goo00=`7goo
Ool0Dgoo00<007ooOol05goo0P00B7oo001DOol00`00Oomoo`1OOol00g0OOomoo`07Ool00aPOOomo
o`07Ool20Yl<Ool20Yl00goo61moo`05Ool00g0OOomoo`1DOol00`00Oomoo`0HOol00`00Oomoo`16
Ool00;Moo`03L1moogoo011oo`82W`Ioo`0361moogoo00Eoo`0361moogoo00=oo`9`7eMoo`03001o
ogoo01Qoo`03001oogoo04Ioo`00MWoo00<007ooOol0B7oo0P?o2Goo00<2WgooOol00Woo00<H7goo
Ool00goo00<H7goo61l01Woo0W0OEgoo00<007ooOol067oo00<007ooOol0AWoo001fOol00`00Oomo
o`0oOol20ol7Ool20ol6Ool01G0OOomoogoo0Yl00Woo00<H7gooOol00g`I00=ooaPO61l01Woo0g0O
LWoo00<007ooOol0AWoo001DOol00`00Oomoo`0OOol00`00Oomoo`0eOol00`:OOomoo`07Ool20ol9
Ool00`?oOomoo`02Ool00g0OOomoo`03Ool261l3Ool3O1T00goo61lH7`1kOol00`00Oomoo`16Ool0
05Aoo`03001oogoo01moo`03001oogoo03Eoo`82W`Yoo`030omoogoo00Moo`040omoogooL1l3Ool3
>1l261l4Ool017`IOoml6G`IO7oo00<007ooOol0AWoo001DOol00`00Oomoo`0OOol00`00Oomoo`0f
Ool00`:OOomoo`09Ool00`?oOomoo`05Ool013POOom`7g0O1Goo0cPO2Goo00=l6GooOol03Woo00<2
WgooOol0CGoo00<007ooOol067oo00<007ooOol01Woo0`000Woo0`000goo0`00<Woo001DOol00`00
Oomoo`1IOol00`:OOomoo`06Ool2O1T7Ool3>1l2L1l8Ool00cPOOomoo`07Ool00g`IOomoo`02O1T3
Ool00`?oOomoo`04Ool00`:OOomoo`1>Ool00`00Oomoo`0HOol00`00Oomoo`07Ool01000Oomoo`00
0goo00<007oo00000goo00<007ooOol0;goo001DOol00`00Oomoo`1JOol00`:OOomoo`04Ool3O1T8
Ool00cPOL1lh7`0:Ool00cPOOomoo`02>1l3Ool017`IOoml6G`I17oo00<3ogooOol017oo00<2Wgoo
Ool0Cgoo00<007ooOol067oo00<007ooOol01goo00@007ooOol000=oo`03001oo`0000=oo`03001o
ogoo02moo`00MWoo00<007ooOol0@7oo0g`I2Woo00<h7gooOol01goo0cPO1Goo00<3og`IOol00goo
0P?o1Woo0P:ODGoo00<007ooOol067oo00<007ooOol01goo00@007ooOol000=oo`03001oo`0000=o
o`03001oogoo02moo`00MWoo00<007ooOol0@goo0W`I2Goo00<h7gooOol00SPO0Woo00@2Wgoo>1lh
7`Eoo`030oml6G`I00Aoo`83oeUoo`03001oogoo01Qoo`03001oogoo00Moo`04001oogoo0003Ool0
0`00Ool00003Ool00`00Oomoo`0_Ool007Ioo`03001oogoo04Eoo`03O1Uoogoo00Ioo`<h7`Aoo`03
0Ylh7cPO009oo`81o`83og]oo`<000Uoo`04001oogoo0003Ool00`00Ool00003Ool00`00Oomoo`0_
Ool005Aoo`03001oogoo01moo`03001oogoo04Qoo`9l6@=oo`8h7`9oo`83G`82W`Eoo`040Omoo`?o
0OmmOol00`00Oomoo`07Ool01000Oomoo`000goo00<007oo00000goo00<007ooOol0;goo001DOol0
0`00Oomoo`0OOol00`00Oomoo`14Ool4O1T6Ool00cPOOomoo`020el20Yl9Ool00`7oOomoo`1OOol0
0`00Oomoo`0HOol00`00Oomoo`06Ool20003Ool30003Ool3000bOol005Aoo`03001oogoo06Eoo`=l
6@9oo`83G`Qoo`030el2W`=O011oo`81oeUoo`03001oogoo01Qoo`03001oogoo04Ioo`00E7oo00<0
07ooOol0HGoo0P7o0goo00=l6GooOol00Woo0`=O2Goo00<3GgooOol017oo0P=O1Goo0P7oFgoo00<0
07ooOol067oo00<007ooOol0AWoo001DOol00`00Oomoo`1QOol20Ol;Ool00`=OOomoo`0;Ool20el6
Ool20OmLOol00`00Oomoo`0HOol00`00Oomoo`16Ool007Ioo`03001oogoo03moo`030Omoo`7o015o
o`83G`Eoo`83GfAoo`03001oogoo01Qoo`03001oogoo04Ioo`00MWoo00<007ooOol0@Woo00<1ogoo
Ool037oo0P=OR7oo00<007ooOol0AWoo001bOol80003Ool30013Ool20Ol5Ool20en8Ool00`00Oomo
o`16Ool005Aoo`03001oogoo01=oo`D0015oo`8000=oo`D003Moo`81oa=oo`9nP7aoo`03001oogoo
04Ioo`00E7oo00<007ooOol03Goo0`009Woo1@000goo0`00:7oo0P7o5Goo00=nP7ooOol01Goo00=n
P7ooOol0Egoo00<007ooOol067oo00<007ooOol0AWoo001DOol00`00Oomoo`05Ool30003Ool2000d
Ool20003Ool5000/Ool00ggPOomoo`0=Ool00gj0Oomoo`1HOol00`00Oomoo`0GOol20018Ool005Ao
o`03001oogoo00=oo`8004Uoo`@000=oo`<001moo`03ON1oogoo00Aoo`9mh69oo`03001oogoo01Qo
o`03001oogoo04Ioo`00E7oo1000Egoo0P000goo0`003Woo00=mh7ooOol03Goo0WgPHWoo00<007oo
Ool067oo00<007ooOol0AWoo001JOol50003Ool3001BOol20002Ool00gj000000003000;Ool2ON1[
Ool00`00Oomoo`0HOol00`00Oomoo`16Ool006Eoo`8000=oo`D004aoo`9nP0Moo`D000=oo`<008Eo
o`03001oogoo04Ioo`00LWoo1000CGoo0Wj02Woo0P000goo1000O7oo00<007ooOol0AWoo001iOol5
0003Ool3001GOol50003Ool3001^Ool00`00Oomoo`16Ool008Aoo`8000=oo`D005Qoo`8000=oo`D0
04Uoo`03001oogoo01Qoo`03001oogoo04Ioo`00TGoo1@00GGoo1@000goo0`00>goo00<007ooOol0
67oo00<007ooOol0AWoo002IOol50002Ool3001KOol20003Ool4000bOol00`00Oomoo`0HOol00`00
Oomoo`16Ool00:=oo`8000=oo`D005eoo`D002Yoo`03001oogoo01Qoo`03001oogoo04Ioo`00/7oo
1@00GGoo1@000goo0`0077oo00<007ooOol067oo00<007ooOol0AWoo002hOol50003Ool3001JOol2
0003Ool5000/Ool20018Ool00<=oo`8000=oo`D005eoo`D0009oo`<0021oo`03001oogoo04Ioo`00
cgoo1@00H7oo0P000goo1@005Woo00<007ooOol0AWoo003GOol50003Ool3001GOol00`00Oomoo`05
Ool50003Ool30008Ool00`00Oomoo`16Ool00>9oo`8000=oo`D004eoo`03001oogoo011oo`8000=o
o`@004Qoo`00kgoo1@00AGoo00<007ooOol05Woo0`00B7oo003gOol40003Ool3000hOol00`00Oomo
o`0DOol2001;Ool00?moo`9oo`8000=oo`D002ioo`03001oogoo00ioo`<0051oo`00ogoo3goo1@00
=Goo0P00Dgoo003oOolGOol50003Ool3000ROol2001HOol00?moob9oo`80009oo`D001Moo`8005Yo
o`00ogoo;Woo1@001goo00<007oo00000P00Ggoo003oOolfOol6001ROol00?mooiioo`00ogooWWoo
003oOonNOol00?mooiioo`00ogooWWoo003oOonNOol00?mooiioo`00ogooWWoo003oOonNOol00?mo
oiioo`00ogooWWoo003oOonNOol00?mooiioo`00ogooWWoo003oOonNOol00?mooiioo`00ogooWWoo
003oOonNOol00?mooiioo`00ogooWWoo003oOonNOol00?mooiioo`00ogooWWoo003oOonNOol00?mo
oiioo`00ogooWWoo003oOonNOol00?mooiioo`00ogooWWoo003oOonNOol00?mooiioo`00ogooWWoo
003oOonNOol00?mooiioo`00ogooWWoo003oOonNOol00?mooiioo`00ogooWWoo003oOonNOol00?mo
oiioo`00ogooWWoo003oOonNOol00?mooiioo`00ogooWWoo003oOonNOol00?mooiioo`00ogooWWoo
003oOonNOol00?mooiioo`00ogooWWoo003oOonNOol00?mooiioo`00TGoo1000ogoo2Goo002@Ool0
0`00Oomoo`02Ool00`00Oomoo`3oOol6Ool0091oo`03001oogoo009oo`03001oogoo0?moo`Ioo`00
P7oo0`000Woo00<007oo00000P000Woo100000=oo`0000000P0000Eoo`00000007oo00800003Ool0
000000Aoo`03001oo`0000L00003Ool00000008000=oo`@00004Ool000000002Ool300000goo0000
0003Ool600000goo00000004Ool6000017oo000000000Woo0P000Woo0`0000Aoo`00001oo`800003
Ool0000000=oo`<00003Ool00000009oo`03001oogoo009oo`03001oo`0000Moo`<0009oo`<0009o
o`8008Ioo`00PGoo00<007ooOol00P000Woo00@007ooOol0009oo`03001oo`0000Ioo`06001oogoo
001oo`000Woo00@007ooOol000=oo`04001oogoo0002Ool20002Ool01@00Oomoogoo00000Woo00<0
07oo00000goo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0002Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`00Ool00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oo`00009o
o`05001oogooOol00002Ool01000Oomoo`001Goo00<007oo000027oo00@007ooOol000=oo`04001o
ogooOol20024Ool0085oo`08001oogoo001oo`00Ool0009oo`04001oogoo0002Ool30003Ool01P00
Oomoo`00Ool000Eoo`05001oogooOol00003Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03
001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`000Woo00<007ooOol017oo
00<007ooOol017oo00@007ooOol000Eoo`04001oogoo0002Ool00`00Ool00006Ool01000Oomoo`00
0Woo00<007ooOol00goo00<007oo000027oo00@007ooOol000=oo`03001oogoo009oo`03001oogoo
089oo`00PGoo00<007oo00000Woo00<007oo00000goo0`0000=oo`00Ool00Woo00@007ooOol0009o
o`03001oo`0000<0009oo`05001oogooOol00003Ool01000Oomoogoo0`000goo00H007ooOol007oo
0003Ool01000Oomoo`000Woo00<007ooOol00goo00@007ooOol0009oo`03001oogoo00Aoo`04001o
ogoo0003Ool00`00Oomoo`040002Ool01000Oomoo`000Woo00<007oo00000`000goo00@007ooOol0
009oo`03001oogoo009oo`D000Moo`04001oogoo0003Ool00`00Oomoo`040023Ool0085oo`03001o
o`00009oo`03001oo`0000Eoo`03001oo`0000=oo`03001oogoo00800004Ool007oo0002Ool01000
Oomoo`000goo00<007oo00000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oo`0000=o
o`03001oogoo00800003Ool007oo00Aoo`03001oogoo00800003Ool007oo00Eoo`@000=oo`04001o
ogoo0002Ool00`00Oomoo`0200001goo000007oo001oo`00009oo`04001oogooOol200001Goo001o
ogoo00001Woo00<007oo00001goo00@007ooOol000=oo`03001oo`0000=oo`03001oogoo085oo`00
PGoo0P0017oo0P000Woo0`000goo0`000Woo0P0000=oo`00Ool00Woo0P000Woo0`0000Aoo`00001o
o`P000=oo`D0009oo`<0009oo`800003Ool007oo00Aoo`800005Ool00000Ool00007Ool01000Oomo
o`000goo00@007ooOomoo`80009oo`800005Ool007ooOol00003Ool20003Ool2000017oo001oogoo
0`0017oo1@001Woo00@007ooOol000=oo`03001oo`0000=oo`03001oogoo085oo`00PGoo0P0017oo
0P006Goo00<007ooOol03goo00<007ooOol07goo00D007ooOomoo`00009oo`03001oogoo01]oo`03
001oogoo00Aoo`03001oo`0000Moo`04001oogoo0003Ool00`00Ool00003Ool00`00Oomoo`21Ool0
081oo`8000Ioo`8001Qoo`05001oogooOol0000=Ool01000Oomoo`004Goo00<007ooOol02Goo1P00
00=oo`0000007Goo00<007ooOol017oo00<007oo00001Woo0P000goo0`000goo0`00Q7oo003oOonN
Ool00?mooiioo`00\
\>"],
  ImageRangeCache->{{{0, 412}, {412, 0}} -> {-0.024063, -5.06255*^-6, 
  0.002544, 0.002544}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\( (*\ settings\ of\ the\ plot\ *) \n\nobj = g; \nny = 6; ymin = 1; 
    ymax = 25; \nnz = 40; zmin = 10; zmax = 90; \nnm = 11; mmin = 0.0; 
    mmax = 2; \nx = 5; \n\n (*\ Prepare\ the\ Plot\ *) \n\n
    t0 = AbsoluteTime[]; \n
    t1 = Table[
        radFldLst[obj, "\<M\>", {x, ymin, z}, {x, ymax, z}, ny], {z, zmin, 
          zmax, \((zmax - zmin)\)/\((nz - 1)\)}]; \n
    Print[AbsoluteTime[] - t0, "\< sec\>"]; \n
    f[x_, y_, z_] := Sqrt[x^2 + y^2 + z^2]; \ntt = Apply[f, t1, {2}]\ ; \n
    ct = Table[w, {w, mmin, mmax, \((mmax - mmin)\)/\((nm - 1)\)}]\ ; \n
    \n (*\ Plot\ *) \n\n
    ListContourPlot[tt\n, Axes -> True\n, PlotLabel -> "\< X = 5 mm\>"\n, 
      Contours -> ct\n, ColorFunction -> \ Hue\n, 
      AspectRatio -> Abs[\((zmax - zmin)\)/\((ymax - ymin)\)]\n, 
      MeshRange \[Rule] {{ymin, ymax}, {zmin, zmax}}\n]; \)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(16.`6.9237\[InvisibleSpace]" sec"\),
      SequenceForm[ 16., " sec"],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 3.33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
-0.0208333 0.0400641 -0.336538 0.0400641 [
[.17949 -0.0125 -5 -14 ]
[.17949 -0.0125 5 0 ]
[.37981 -0.0125 -8 -14 ]
[.37981 -0.0125 8 0 ]
[.58013 -0.0125 -8 -14 ]
[.58013 -0.0125 8 0 ]
[.78045 -0.0125 -8 -14 ]
[.78045 -0.0125 8 0 ]
[.98077 -0.0125 -8 -14 ]
[.98077 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .46474 -16 -7 ]
[-0.0125 .46474 0 7 ]
[-0.0125 1.26603 -16 -7 ]
[-0.0125 1.26603 0 7 ]
[-0.0125 2.06731 -16 -7 ]
[-0.0125 2.06731 0 7 ]
[-0.0125 2.86859 -16 -7 ]
[-0.0125 2.86859 0 7 ]
[ 0 0 -0.125 0 ]
[ 0 3.33333 .125 0 ]
[ 1 0 .125 0 ]
[.5 3.34583 -28.4688 0 ]
[.5 3.34583 28.4688 14 ]
[ 0 0 0 0 ]
[ 1 3.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17949 0 m
.17949 .00625 L
s
gsave
.17949 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.37981 0 m
.37981 .00625 L
s
gsave
.37981 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.58013 0 m
.58013 .00625 L
s
gsave
.58013 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.78045 0 m
.78045 .00625 L
s
gsave
.78045 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98077 0 m
.98077 .00625 L
s
gsave
.98077 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(25) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.21955 0 m
.21955 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.29968 0 m
.29968 .00375 L
s
.33974 0 m
.33974 .00375 L
s
.41987 0 m
.41987 .00375 L
s
.45994 0 m
.45994 .00375 L
s
.5 0 m
.5 .00375 L
s
.54006 0 m
.54006 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.66026 0 m
.66026 .00375 L
s
.70032 0 m
.70032 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.90064 0 m
.90064 .00375 L
s
.94071 0 m
.94071 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.09936 0 m
.09936 .00375 L
s
.05929 0 m
.05929 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .46474 m
.00625 .46474 L
s
gsave
-0.0125 .46474 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 1.26603 m
.00625 1.26603 L
s
gsave
-0.0125 1.26603 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 2.06731 m
.00625 2.06731 L
s
gsave
-0.0125 2.06731 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 2.86859 m
.00625 2.86859 L
s
gsave
-0.0125 2.86859 -77 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(80) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .66506 m
.00375 .66506 L
s
0 .86538 m
.00375 .86538 L
s
0 1.06571 m
.00375 1.06571 L
s
0 1.46635 m
.00375 1.46635 L
s
0 1.66667 m
.00375 1.66667 L
s
0 1.86699 m
.00375 1.86699 L
s
0 2.26763 m
.00375 2.26763 L
s
0 2.46795 m
.00375 2.46795 L
s
0 2.66827 m
.00375 2.66827 L
s
0 .26442 m
.00375 .26442 L
s
0 .0641 m
.00375 .0641 L
s
0 3.06891 m
.00375 3.06891 L
s
0 3.26923 m
.00375 3.26923 L
s
.25 Mabswid
0 0 m
0 3.33333 L
s
.17949 3.32708 m
.17949 3.33333 L
s
.37981 3.32708 m
.37981 3.33333 L
s
.58013 3.32708 m
.58013 3.33333 L
s
.78045 3.32708 m
.78045 3.33333 L
s
.98077 3.32708 m
.98077 3.33333 L
s
.125 Mabswid
.21955 3.32958 m
.21955 3.33333 L
s
.25962 3.32958 m
.25962 3.33333 L
s
.29968 3.32958 m
.29968 3.33333 L
s
.33974 3.32958 m
.33974 3.33333 L
s
.41987 3.32958 m
.41987 3.33333 L
s
.45994 3.32958 m
.45994 3.33333 L
s
.5 3.32958 m
.5 3.33333 L
s
.54006 3.32958 m
.54006 3.33333 L
s
.62019 3.32958 m
.62019 3.33333 L
s
.66026 3.32958 m
.66026 3.33333 L
s
.70032 3.32958 m
.70032 3.33333 L
s
.74038 3.32958 m
.74038 3.33333 L
s
.82051 3.32958 m
.82051 3.33333 L
s
.86058 3.32958 m
.86058 3.33333 L
s
.90064 3.32958 m
.90064 3.33333 L
s
.94071 3.32958 m
.94071 3.33333 L
s
.13942 3.32958 m
.13942 3.33333 L
s
.09936 3.32958 m
.09936 3.33333 L
s
.05929 3.32958 m
.05929 3.33333 L
s
.01923 3.32958 m
.01923 3.33333 L
s
.25 Mabswid
0 3.33333 m
1 3.33333 L
s
.99375 .46474 m
1 .46474 L
s
.99375 1.26603 m
1 1.26603 L
s
.99375 2.06731 m
1 2.06731 L
s
.99375 2.86859 m
1 2.86859 L
s
.125 Mabswid
.99625 .66506 m
1 .66506 L
s
.99625 .86538 m
1 .86538 L
s
.99625 1.06571 m
1 1.06571 L
s
.99625 1.46635 m
1 1.46635 L
s
.99625 1.66667 m
1 1.66667 L
s
.99625 1.86699 m
1 1.86699 L
s
.99625 2.26763 m
1 2.26763 L
s
.99625 2.46795 m
1 2.46795 L
s
.99625 2.66827 m
1 2.66827 L
s
.99625 .26442 m
1 .26442 L
s
.99625 .0641 m
1 .0641 L
s
.99625 3.06891 m
1 3.06891 L
s
.99625 3.26923 m
1 3.26923 L
s
.25 Mabswid
1 0 m
1 3.33333 L
s
0 0 m
1 0 L
s
0 0 m
0 3.33333 L
s
gsave
.5 3.34583 -89.4688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
66.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
77.625000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
88.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
97.312500 14.000000 moveto
(mm) show
115.937500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 m
1 0 L
1 3.33333 L
0 3.33333 L
closepath
clip
newpath
1 .624 0 r
.01923 3.26923 m
.98077 3.26923 L
.98077 .0641 L
.01923 .0641 L
F
0 g
.5 Mabswid
.284 1 0 r
.01923 .44136 m
.06785 .47502 L
.21154 .52354 L
.2903 .5572 L
.40385 .58857 L
.52631 .63938 L
.52631 .72156 L
.54307 .80375 L
.54307 .88593 L
.54307 .96811 L
.54307 1.0503 L
.54307 1.13248 L
.55107 1.21466 L
.55107 1.29684 L
.55107 1.37903 L
.55107 1.46121 L
.55553 1.54339 L
.55553 1.62558 L
.55553 1.70776 L
.55553 1.78994 L
.55799 1.87212 L
.55799 1.95431 L
.55799 2.03649 L
.55799 2.11867 L
.55919 2.20085 L
.55919 2.28304 L
.55919 2.36522 L
.55919 2.4474 L
.59615 2.46662 L
.78846 2.46662 L
.98077 2.46662 L
.98077 3.26923 L
.01923 3.26923 L
F
0 g
.01923 .44136 m
.06785 .47502 L
.21154 .52354 L
.2903 .5572 L
.40385 .58857 L
.52631 .63938 L
.52631 .72156 L
.54307 .80375 L
.54307 .88593 L
.54307 .96811 L
.54307 1.0503 L
.54307 1.13248 L
.55107 1.21466 L
.55107 1.29684 L
.55107 1.37903 L
.55107 1.46121 L
.55553 1.54339 L
.55553 1.62558 L
.55553 1.70776 L
.55553 1.78994 L
.55799 1.87212 L
.55799 1.95431 L
.55799 2.03649 L
.55799 2.11867 L
.55919 2.20085 L
.55919 2.28304 L
.55919 2.36522 L
.55919 2.4474 L
.59615 2.46662 L
.78846 2.46662 L
.98077 2.46662 L
s
0 1 .808 r
.01923 .75525 m
.21154 .75525 L
.25754 .72156 L
.25754 .63938 L
.40385 .61717 L
.45993 .63938 L
.45993 .72156 L
.49484 .80375 L
.49484 .88593 L
.49484 .96811 L
.49484 1.0503 L
.49484 1.13248 L
.51046 1.21466 L
.51046 1.29684 L
.51046 1.37903 L
.51046 1.46121 L
.51897 1.54339 L
.51897 1.62558 L
.51897 1.70776 L
.51897 1.78994 L
.52363 1.87212 L
.52363 1.95431 L
.52363 2.03649 L
.52363 2.11867 L
.52588 2.20085 L
.52588 2.28304 L
.52588 2.36522 L
.52588 2.4474 L
.59615 2.48363 L
.78846 2.48363 L
.98077 2.48363 L
.98077 3.26923 L
.01923 3.26923 L
F
0 g
.01923 .75525 m
.21154 .75525 L
.25754 .72156 L
.25754 .63938 L
.40385 .61717 L
.45993 .63938 L
.45993 .72156 L
.49484 .80375 L
.49484 .88593 L
.49484 .96811 L
.49484 1.0503 L
.49484 1.13248 L
.51046 1.21466 L
.51046 1.29684 L
.51046 1.37903 L
.51046 1.46121 L
.51897 1.54339 L
.51897 1.62558 L
.51897 1.70776 L
.51897 1.78994 L
.52363 1.87212 L
.52363 1.95431 L
.52363 2.03649 L
.52363 2.11867 L
.52588 2.20085 L
.52588 2.28304 L
.52588 2.36522 L
.52588 2.4474 L
.59615 2.48363 L
.78846 2.48363 L
.98077 2.48363 L
s
0 .099 1 r
.01923 1.19673 m
.21154 1.19673 L
.27139 1.13248 L
.27139 1.0503 L
.27139 .96811 L
.27139 .88593 L
.27139 .80375 L
.40385 .7496 L
.44381 .80375 L
.44381 .88593 L
.44381 .96811 L
.44381 1.0503 L
.44381 1.13248 L
.46971 1.21466 L
.46971 1.29684 L
.46971 1.37903 L
.46971 1.46121 L
.48298 1.54339 L
.48298 1.62558 L
.48298 1.70776 L
.48298 1.78994 L
.49008 1.87212 L
.49008 1.95431 L
.49008 2.03649 L
.49008 2.11867 L
.49347 2.20085 L
.49347 2.28304 L
.49347 2.36522 L
.49347 2.4474 L
.59615 2.50024 L
.78846 2.50024 L
.98077 2.50024 L
.98077 3.26923 L
.01923 3.26923 L
F
0 g
.01923 1.19673 m
.21154 1.19673 L
.27139 1.13248 L
.27139 1.0503 L
.27139 .96811 L
.27139 .88593 L
.27139 .80375 L
.40385 .7496 L
.44381 .80375 L
.44381 .88593 L
.44381 .96811 L
.44381 1.0503 L
.44381 1.13248 L
.46971 1.21466 L
.46971 1.29684 L
.46971 1.37903 L
.46971 1.46121 L
.48298 1.54339 L
.48298 1.62558 L
.48298 1.70776 L
.48298 1.78994 L
.49008 1.87212 L
.49008 1.95431 L
.49008 2.03649 L
.49008 2.11867 L
.49347 2.20085 L
.49347 2.28304 L
.49347 2.36522 L
.49347 2.4474 L
.59615 2.50024 L
.78846 2.50024 L
.98077 2.50024 L
s
.993 0 1 r
.01923 2.45274 m
.21154 2.4717 L
.21653 2.4474 L
.21653 2.36522 L
.21653 2.28304 L
.21653 2.20085 L
.2281 2.11867 L
.2281 2.03649 L
.2281 1.95431 L
.2281 1.87212 L
.25401 1.78994 L
.25401 1.70776 L
.25401 1.62558 L
.25401 1.54339 L
.30497 1.46121 L
.30497 1.37903 L
.30497 1.29684 L
.30497 1.21466 L
.40385 1.17312 L
.42401 1.21466 L
.42401 1.29684 L
.42401 1.37903 L
.42401 1.46121 L
.44463 1.54339 L
.44463 1.62558 L
.44463 1.70776 L
.44463 1.78994 L
.45506 1.87212 L
.45506 1.95431 L
.45506 2.03649 L
.45506 2.11867 L
.45992 2.20085 L
.45992 2.28304 L
.45992 2.36522 L
.45992 2.4474 L
.59615 2.51785 L
.78846 2.51785 L
.98077 2.51785 L
.98077 3.26923 L
.01923 3.26923 L
F
0 g
.01923 2.45274 m
.21154 2.4717 L
.21653 2.4474 L
.21653 2.36522 L
.21653 2.28304 L
.21653 2.20085 L
.2281 2.11867 L
.2281 2.03649 L
.2281 1.95431 L
.2281 1.87212 L
.25401 1.78994 L
.25401 1.70776 L
.25401 1.62558 L
.25401 1.54339 L
.30497 1.46121 L
.30497 1.37903 L
.30497 1.29684 L
.30497 1.21466 L
.40385 1.17312 L
.42401 1.21466 L
.42401 1.29684 L
.42401 1.37903 L
.42401 1.46121 L
.44463 1.54339 L
.44463 1.62558 L
.44463 1.70776 L
.44463 1.78994 L
.45506 1.87212 L
.45506 1.95431 L
.45506 2.03649 L
.45506 2.11867 L
.45992 2.20085 L
.45992 2.28304 L
.45992 2.36522 L
.45992 2.4474 L
.59615 2.51785 L
.78846 2.51785 L
.98077 2.51785 L
s
0 .099 1 r
.01923 2.53296 m
.20219 2.61177 L
.20055 2.69395 L
.189 2.77613 L
.21154 2.80856 L
.35057 2.77613 L
.40385 2.7614 L
.46506 2.77613 L
.59615 2.81374 L
.78846 2.81374 L
.98077 2.81374 L
.98077 3.26923 L
.01923 3.26923 L
F
0 g
.01923 2.53296 m
.20219 2.61177 L
.20055 2.69395 L
.189 2.77613 L
.21154 2.80856 L
.35057 2.77613 L
.40385 2.7614 L
.46506 2.77613 L
.59615 2.81374 L
.78846 2.81374 L
.98077 2.81374 L
s
0 1 .808 r
.01923 2.55368 m
.14512 2.61177 L
.13854 2.69395 L
.11576 2.77613 L
.14079 2.85832 L
.14079 2.9405 L
.21154 2.95872 L
.35994 3.02268 L
.40385 3.0409 L
.57667 3.10487 L
.57667 3.18705 L
.59615 3.20362 L
.78846 3.20362 L
.98077 3.20362 L
.98077 3.26923 L
.01923 3.26923 L
F
0 g
.01923 2.55368 m
.14512 2.61177 L
.13854 2.69395 L
.11576 2.77613 L
.14079 2.85832 L
.14079 2.9405 L
.21154 2.95872 L
.35994 3.02268 L
.40385 3.0409 L
.57667 3.10487 L
.57667 3.18705 L
.59615 3.20362 L
.78846 3.20362 L
.98077 3.20362 L
s
.284 1 0 r
.01923 2.57225 m
.09777 2.61177 L
.09155 2.69395 L
.07491 2.77613 L
.08832 2.85832 L
.08832 2.9405 L
.21154 2.97942 L
.31132 3.02268 L
.40385 3.0616 L
.51889 3.10487 L
.51889 3.18705 L
.59615 3.2346 L
.78846 3.2346 L
.98077 3.2346 L
.98077 3.26923 L
.01923 3.26923 L
F
0 g
.01923 2.57225 m
.09777 2.61177 L
.09155 2.69395 L
.07491 2.77613 L
.08832 2.85832 L
.08832 2.9405 L
.21154 2.97942 L
.31132 3.02268 L
.40385 3.0616 L
.51889 3.10487 L
.51889 3.18705 L
.59615 3.2346 L
.78846 3.2346 L
.98077 3.2346 L
s
1 .624 0 r
.01923 2.59089 m
.05635 2.61177 L
.05268 2.69395 L
.04428 2.77613 L
.0501 2.85832 L
.0501 2.9405 L
.21154 2.99986 L
.26393 3.02268 L
.40385 3.08204 L
.46437 3.10487 L
.46437 3.18705 L
.59615 3.25415 L
.78846 3.25415 L
.98077 3.25415 L
.98077 3.26923 L
.01923 3.26923 L
F
0 g
.01923 2.59089 m
.05635 2.61177 L
.05268 2.69395 L
.04428 2.77613 L
.0501 2.85832 L
.0501 2.9405 L
.21154 2.99986 L
.26393 3.02268 L
.40385 3.08204 L
.46437 3.10487 L
.46437 3.18705 L
.59615 3.25415 L
.78846 3.25415 L
.98077 3.25415 L
s
1 0 0 r
.40385 1.81684 m
.4149 1.87212 L
.4149 1.95431 L
.4149 2.03649 L
.4149 2.11867 L
.42225 2.20085 L
.42225 2.28304 L
.42225 2.36522 L
.42225 2.4474 L
.53529 2.52959 L
.53529 2.61177 L
.49529 2.69395 L
.40385 2.7075 L
.30965 2.69395 L
.28021 2.61177 L
.30861 2.52959 L
.30581 2.4474 L
.30581 2.36522 L
.30581 2.28304 L
.30581 2.20085 L
.32503 2.11867 L
.32503 2.03649 L
.32503 1.95431 L
.32503 1.87212 L
F
0 g
.40385 1.81684 m
.4149 1.87212 L
.4149 1.95431 L
.4149 2.03649 L
.4149 2.11867 L
.42225 2.20085 L
.42225 2.28304 L
.42225 2.36522 L
.42225 2.4474 L
.53529 2.52959 L
.53529 2.61177 L
.49529 2.69395 L
.40385 2.7075 L
.30965 2.69395 L
.28021 2.61177 L
.30861 2.52959 L
.30581 2.4474 L
.30581 2.36522 L
.30581 2.28304 L
.30581 2.20085 L
.32503 2.11867 L
.32503 2.03649 L
.32503 1.95431 L
.32503 1.87212 L
.40385 1.81684 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{173.375, 577.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002]0002@A000`40O003h00O[Goo002]Ool00:eo
o`00[Goo002]Ool00:eoo`00[Goo002]Ool00:eoo`00[Goo002]Ool00:eoo`00[Goo002]Ool00:eo
o`00[Goo002]Ool00:eoo`00[Goo002]Ool00:eoo`00[Goo002]Ool00:eoo`00[Goo002]Ool00:eo
o`00[Goo000YOol4000IOol30002Ool3000FOol300000goo00000002000DOol40003Ool3000DOol4
0002Ool40005Ool002eoo`03001oogoo01Moo`04001oogoo0003Ool00`00Oomoo`0DOol00`00Oomo
o`04Ool00`00Oomoo`0AOol01`00Oomoogoo001oo`0000=oo`03001oogoo015oo`05001oogooOol0
0005Ool00`00Oomoo`02Ool002eoo`03001oogoo01Moo`04001oogoo0003Ool00`00Oomoo`0DOol0
0`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`02Ool01@00Oomoogoo000057oo00<007ooOol0
1Woo00<007ooOol00Woo000]Ool00`00Oomoo`0GOol01000Oomoo`000goo00<007ooOol057oo00<0
07ooOol017oo00<007ooOol04goo00D007ooOomoo`0000=oo`03001oogoo01=oo`03001oogoo00Eo
o`03001oogoo009oo`00;Goo00<007ooOol05goo00@007ooOol000=oo`03001oogoo01Aoo`03001o
ogoo00Aoo`03001oogoo01Aoo`04001oogoo0003Ool00`00Oomoo`0DOol00`00Oomoo`04Ool00`00
Oomoo`02Ool002Uoo`@001Yoo`04001oogoo0003Ool00`00Oomoo`0DOol00`00Oomoo`04000GOol0
1000Oomoo`000goo00<007ooOol057oo00<007ooOol010001Goo000ZOol00`00Oomoo`0JOol01000
Oomoo`000goo00<007ooOol057oo00D007ooOomoo`0001Ioo`04001oogoo0002Ool01@00Oomoogoo
00004goo00@007ooOol000=oo`03001oogoo00Eoo`00:Woo100067oo0P000goo0`005Woo0P000goo
100057oo0P0017oo0`005Goo0P0017oo100017oo002]Ool00:eoo`00[Goo000AOonG0005Ool0015o
o`04001oogoo0005Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoo`00
1Goo000AOol00`00Oomoo`2COol00`00Oomoo`03Ool0015oo`03001oogoo09=oo`03001oogoo00=o
o`004Goo00<007ooOol0Tgoo00<007ooOol00goo000AOol00`00Oomoo`2COol00`00Oomoo`03Ool0
015oo`03001oogoo09=oo`03001oogoo00=oo`004Goo00<007ooOol0Tgoo00<007ooOol00goo000A
Ool00`00Oomoo`2COol00`00Oomoo`03Ool0015oo`03001oogoo09=oo`03001oogoo00=oo`004Goo
0P00Tgoo0P001Goo000AOol00`00Oomoo`2@OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo091n
H0=oo`03001oogoo00=oo`004Goo00<007ooOol0T7iP0goo00<007ooOol00goo000AOol00`00Oomo
o`2@OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo091nH0=oo`03001oogoo00=oo`004Goo00<0
07ooOol0T7iP0goo00<007ooOol00goo000AOol00`00Oomoo`2@OV03Ool00`00Oomoo`03Ool0015o
o`03001oogoo091nH0=oo`03001oogoo00=oo`004Goo00<007ooOol0T7iP0goo00<007ooOol00goo
000AOol00`00Oomoo`2@OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo091nH0=oo`03001oogoo
00=oo`004Goo00<007ooOol0T7iP0goo00<007ooOol00goo000AOol00`00Oomoo`2@OV03Ool00`00
Oomoo`03Ool0015oo`03001oogoo091nH0=oo`03001oogoo00=oo`004Goo00<007ooOol0T7iP0goo
00<007ooOol00goo000AOol00`00Oomoo`2@OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo091n
H0=oo`03001oogoo00=oo`004Goo00<007ooOol0T7iP0goo00<007ooOol00goo000AOol00`00Oomo
o`2@OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo091nH0=oo`03001oogoo00=oo`004Goo00<0
07ooOol0T7iP0goo00<007ooOol00goo000AOol00`00Oomoo`2@OV03Ool00`00Oomoo`03Ool0015o
o`03001oogoo091nH0=oo`03001oogoo00=oo`004Goo00<007ooOol0T7iP0goo00<007ooOol00goo
000AOol00`00Oomoo`2@OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo091nH0=oo`03001oogoo
00=oo`004Goo00<007ooOol0T7iP0goo00<007ooOol00goo000AOol00`00Oomoo`2@OV03Ool00`00
Oomoo`03Ool0015oo`03001oogoo091nH0=oo`03001oogoo00=oo`004Goo0P0000=oogiPOV00SWiP
0Woo0P001Goo000AOol00`00Oomoo`2@OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo091nH0=o
o`03001oogoo00=oo`004Goo00<007ooOol0T7iP0goo00<007ooOol00goo000AOol00`00Oomoo`2@
OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo091nH0=oo`03001oogoo00=oo`004Goo00<007oo
Ool0T7iP0goo00<007ooOol00goo000AOol00`00Oomoo`2@OV03Ool00`00Oomoo`03Ool0015oo`03
001oogoo091nH0=oo`03001oogoo00=oo`004Goo00<007ooOol0T7iP0goo00<007ooOol00goo000A
Ool00`00Oomoo`2@OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo091nH0=oo`03001oogoo00=o
o`004Goo00<007ooOol0T7iP0goo00<007ooOol00goo000AOol00`00Oomoo`2@OV03Ool00`00Oomo
o`03Ool0015oo`03001oogoo091nH0=oo`03001oogoo00=oo`004Goo00<007ooOol0T7iP0goo00<0
07ooOol00goo000AOol00`00Oomoo`2@OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo091nH0=o
o`03001oogoo00=oo`004Goo00<007ooOol0T7iP0goo00<007ooOol00goo000AOol00`00Oomoo`2@
OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo091nH0=oo`03001oogoo00=oo`004Goo00<007oo
Ool0T7iP0goo00<007ooOol00goo000AOol00`00Oomoo`2@OV03Ool00`00Oomoo`03Ool0015oo`03
001oogoo091nH0=oo`03001oogoo00=oo`004Goo00<007ooOol0T7iP0goo00<007ooOol00goo000A
Ool00`00Oomoo`2@OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo008008inH0=oo`03001oogoo
00=oo`004Goo00<007ooOol00ROP00<007iPOV00RgiP0goo00<007ooOol00goo0002Ool40003Ool3
0005Ool00`00Oomoo`039n02002;OV03Ool00`00Oomoo`03Ool0009oo`07001oogooOol007oo0000
0goo00<007ooOol00Woo00<007ooOol01BOP0P00RGiP0goo00<007ooOol00goo0003Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo0P0000=oobOP9n001BOP00<007iPOV00QWiP0Woo0P001Goo0004
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol022OP0`00QGiP0goo00<007ooOol0
0goo0005Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol02bOP0`00PWiP0goo00<007oo
Ool00goo0005Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol03ROP0`00OgiP0goo00<0
07ooOol00goo0002Ool01000Oomoo`000Woo00D007ooOomoo`0000Aoo`03001oogoo014Wh0<007an
H0=oo`03001oogoo00=oo`000goo0P0017oo0`001Goo00<007ooOol052OP0`00NGiP0goo00<007oo
Ool00goo000AOol00`00Oomoo`0G9n03001fOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo01XW
h0<007=nH0=oo`03001oogoo00=oo`004Goo00<007ooOol07BOP0P00LGiP0goo00<007ooOol00goo
000AOol00`00Oomoo`0O9n03001^OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo028Wh08006an
H0=oo`03001oogoo00=oo`004Goo00<007ooOol092OP0P00JWiP0goo00<007ooOol00goo000AOol0
0`00Oomoo`0V9n03001WOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02TWh0<006AnH0=oo`03
001oogoo00=oo`004Goo00<007ooOol0;2OP0`00HGiP0goo00<007ooOol00goo000AOol00`00Oomo
o`0_9n04001MOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo03<Wh0<005YnH0=oo`03001oogoo
00=oo`004Goo00<007ooOol0=ROP0`00EgiP0goo00<007ooOol00goo000AOol00`00Oomoo`0i9n03
001DOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo03`Wh080059nH0=oo`03001oogoo00=oo`00
4Goo00<007ooOol0?ROP0`00CgiP0goo00<007ooOol00goo000AOol00`00Oomoo`119n02001=OV03
Ool00`00Oomoo`03Ool0015oo`03001oogoo03LWh0D000LWh08004]nH0=oo`03001oogoo00=oo`00
4Goo00<007ooOol0<ROP1@001@?i0P001bOP0P00BGiP0goo00<007ooOol00goo000AOol00`00Oomo
o`0/9n06000<0oT200079n030016OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02LWh0D001@3
n@8000PWh08004AnH0=oo`03001oogoo00=oo`004Goo00<007ooOol092OP0`006`?i00<002OP9n00
1bOP00<007iPOV00@GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0T9n000`000oT3n@0K0oT0
0`009n0Wh0079n000`00OV1nH011OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02@Wh0030003
n@?i01/3n@03000Wh2OP00LWh003001nH7iP045nH0=oo`03001oogoo00=oo`004Goo0P0000=oobOP
9n008ROP00<000?i0oT06`?i00<002OP9n001bOP00<007iPOV00@GiP0Woo0P001Goo000AOol00`00
Oomoo`0T9n000`000oT3n@0K0oT00`009n0Wh0079n000`00OV1nH011OV03Ool00`00Oomoo`03Ool0
015oo`03001oogoo02@Wh0030003n@?i01/3n@03000Wh2OP00LWh003001nH7iP045nH0=oo`03001o
ogoo00=oo`004Goo00<007ooOol092OP00<000?i0oT06`?i00<002OP9n001bOP00<007iPOV00@GiP
0goo00<007ooOol00goo000AOol00`00Oomoo`0T9n000`000oT3n@0K0oT00`009n0Wh0079n000`00
OV1nH011OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02@Wh0030003n@?i01/3n@03000Wh2OP
00LWh003001nH7iP045nH0=oo`03001oogoo00=oo`004Goo00<007ooOol092OP00<000?i0oT06`?i
00<002OP9n001bOP00<007iPOV00@GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0T9n000`00
0oT3n@0K0oT00`009n0Wh0079n000`00OV1nH011OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo
02@Wh0030003n@?i01/3n@03000Wh2OP00LWh003001nH7iP045nH0=oo`03001oogoo00=oo`004Goo
00<007ooOol08bOP0P007@?i00<002OP9n001bOP00<007iPOV00@GiP0goo00<007ooOol00goo000A
Ool00`00Oomoo`0R9n000`000oT3n@0M0oT00`009n0Wh0079n000`00OV1nH011OV03Ool00`00Oomo
o`03Ool0015oo`03001oogoo020Wh0800243n@03000Wh2OP00HWh003001nH7iP045nH0=oo`03001o
ogoo00=oo`004Goo00<007ooOol07bOP00<000?i0oT08@?i00<002OP9n001ROP00<007iPOV00@GiP
0goo00<007ooOol00goo000AOol00`00Oomoo`0N9n000`000oT3n@0H0oT200080oT00`009n0Wh007
9n000`00OV1nH010OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo01h001P3n@<0000307l000?i
00P3n@03000Wh2OP00HWh003001nH7iP041nH0=oo`03001oogoo00=oo`004Goo00<007ooOol0=0?i
0P001@1o00<000?i0oT01P?i00<002OP9n001ROP00<007iPOV00@7iP0goo00<007ooOol00goo000A
Ool00`00Oomoo`0a0oT3000807l00`000oT3n@060oT00`009n0Wh0059n000`00OV1nH010OV03Ool0
0`00Oomoo`03Ool0015oo`03001oogoo02l3n@8000`0O`030003n@?i00D3n@03000Wh2OP00DWh003
001nH7iP041nH0=oo`03001oogoo00=oo`004Goo00<007ooOol0;0?i0`003P1o00<000?i0oT01P?i
00<002OP9n0012OP00<007iPOV00@7iP0goo00<007ooOol00goo000AOol00`00Oomoo`0Z0oT2000B
07l00`000oT3n@050oT00`009n0Wh0059n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03
001oogoo02L3n@<001D0O`030003n@?i00@3n@03000Wh2OP00DWh003001nH7iP03mnH0=oo`03001o
ogoo00=oo`004Goo00<007ooOol09P?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n0012OP
00<007iPOV00?giP0goo00<007ooOol00goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`00
0oT3n@040oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo
02H3n@030000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001o
ogoo00=oo`004Goo00<007ooOol09P?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n0012OP
00<007iPOV00?giP0goo00<007ooOol00goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`00
0oT3n@040oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo
02H3n@030000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001o
ogoo00=oo`004Goo00<007ooOol09P?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n0012OP
00<007iPOV00?giP0goo00<007ooOol00goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`00
0oT3n@040oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo
02H3n@030000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001o
ogoo00=oo`004Goo0P0000=oo`?i0oT090?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n00
12OP00<007iPOV00?giP0Woo0P001Goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`000oT3
n@040oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02H3
n@030000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001oogoo
00=oo`004Goo00<007ooOol09P?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n0012OP00<0
07iPOV00?giP0goo00<007ooOol00goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`000oT3
n@040oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02H3
n@030000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001oogoo
00=oo`004Goo00<007ooOol09P?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n0012OP00<0
07iPOV00?giP0goo00<007ooOol00goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`000oT3
n@040oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02H3
n@030000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001oogoo
00=oo`004Goo00<007ooOol09P?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n0012OP00<0
07iPOV00?giP0goo00<007ooOol00goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`000oT3
n@040oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02H3
n@030000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001oogoo
00=oo`004Goo00<007ooOol09P?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n0012OP00<0
07iPOV00?giP0goo00<007ooOol00goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`000oT3
n@040oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02H3
n@030000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001oogoo
00=oo`004Goo00<007ooOol09P?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n0012OP00<0
07iPOV00?giP0goo00<007ooOol00goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`000oT3
n@040oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02H3
n@030000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001oogoo
00=oo`004Goo00<007ooOol09P?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n0012OP00<0
07iPOV00?giP0goo00<007ooOol00goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`000oT3
n@040oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02H3
n@030000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001oogoo
00=oo`004Goo00<007ooOol09P?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n0012OP00<0
07iPOV00?giP0goo00<007ooOol00goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`000oT3
n@040oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02H3
n@030000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001oogoo
00=oo`004Goo00<007ooOol09P?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n0012OP00<0
07iPOV00?giP0goo00<007ooOol00goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`000oT3
n@040oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02H3
n@030000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001oogoo
00=oo`004Goo00<007ooOol09P?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n0012OP00<0
07iPOV00?giP0goo00<007ooOol00goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`000oT3
n@040oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02H3
n@030000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001oogoo
00=oo`004Goo0P0000=oo`?i0oT090?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n0012OP
00<007iPOV00?giP0Woo0P001Goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`000oT3n@04
0oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02H3n@03
0000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001oogoo00=o
o`004Goo00<007ooOol09P?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n0012OP00<007iP
OV00?giP0goo00<007ooOol00goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`000oT3n@04
0oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02H3n@03
0000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001oogoo00=o
o`004Goo00<007ooOol09P?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n0012OP00<007iP
OV00?giP0goo00<007ooOol00goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`000oT3n@04
0oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02H3n@03
0000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001oogoo00=o
o`004Goo00<007ooOol09P?i00<0001o07l05`1o00<000?i0oT010?i00<002OP9n0012OP00<007iP
OV00?giP0goo00<007ooOol00goo000AOol00`00Oomoo`0V0oT00`0007l0O`0G07l00`000oT3n@04
0oT00`009n0Wh0049n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02H3n@03
0000O`1o01L0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03mnH0=oo`03001oogoo00=o
o`004Goo00<007ooOol09@?i00<0001o07l0601o00<000?i0oT010?i00<002OP9n0012OP00<007iP
OV00?giP0goo00<007ooOol00goo000AOol00`00Oomoo`0T0oT00`0007l0O`0J07l00`000oT3n@04
0oT00`009n0Wh0039n000`00OV1nH00oOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02<3n@03
0000O`1o01/0O`030003n@?i00@3n@03000Wh2OP00@Wh003001nH7iP03inH0=oo`03001oogoo00=o
o`004Goo00<007ooOol08P?i00<0001o07l0701o00<000?i0oT010?i00<002OP9n0012OP00<007iP
OV00?WiP0goo00<007ooOol00goo000AOol00`00Oomoo`0Q0oT00`0007l0O`0E07l2000707l00`00
0oT3n@030oT00`009n0Wh0049n000`00OV1nH00nOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo
0203n@030000O`1o01@0O`800003O1l0001o00H0O`030003n@?i00@3n@03000Wh2OP00<Wh003001n
H7iP03inH0=oo`03001oogoo00=oo`004Goo00<007ooOol07`?i00<0001o07l04`1o0P0017`O00<0
001o07l0101o00<000?i0oT010?i00<002OP9n000bOP00<007iPOV00?WiP0goo00<007ooOol00goo
000AOol00`00Oomoo`0N0oT00`0007l0O`0A07l30006O1l00`0007l0O`0507l00`000oT3n@030oT0
0`009n0Wh0039n000`00OV1nH00nOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo01h00180O`80
00Yl7`030000O`1o00@0O`030003n@?i00<3n@03000Wh2OP00<Wh003001nH7iP03inH0=oo`03001o
ogoo00=oo`004Goo00<007ooOol0;P1o0P0037`O00<0001o07l0101o00<000?i0oT00`?i00<002OP
9n0012OP00<007iPOV00?GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0/07l2000>O1l00`00
07l0O`0507l00`000oT3n@030oT00`009n0Wh0039n000`00OV1nH00mOV03Ool00`00Oomoo`03Ool0
015oo`03001oogoo02/0O`03001l7g`O00ml7`030000O`1o00@0O`030003n@?i00<3n@03000Wh2OP
00<Wh003001nH7iP03enH0=oo`03001oogoo00=oo`004Goo00<007ooOol0:`1o00<007`OO1l03g`O
00<0001o07l0101o00<000?i0oT00`?i00<002OP9n000bOP00<007iPOV00?GiP0goo00<007ooOol0
0goo000AOol00`00Oomoo`0[07l00`00O1ml7`0?O1l00`0007l0O`0407l00`000oT3n@030oT00`00
9n0Wh0039n000`00OV1nH00mOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02/0O`03001l7g`O
00ml7`030000O`1o00@0O`030003n@?i00<3n@03000Wh2OP00<Wh003001nH7iP03enH0=oo`03001o
ogoo00=oo`004Goo00<007ooOol0:`1o00<007`OO1l03g`O00<0001o07l0101o00<000?i0oT00`?i
00<002OP9n000bOP00<007iPOV00?GiP0goo00<007ooOol00goo0005Ool01000Oomoogoo0`001Goo
00<007ooOol0:`1o00<007`OO1l03g`O00<0001o07l0101o00<000?i0oT00`?i00<002OP9n000bOP
00<007iPOV00?GiP0goo00<007ooOol00goo0005Ool01000Oomoo`000goo00<007ooOol00Woo00<0
07ooOol0:`1o00<007`OO1l03g`O00<0001o07l0101o00<000?i0oT00`?i00<002OP9n000bOP00<0
07iPOV00?GiP0goo00<007ooOol00goo0002Ool70003Ool00`00Oomoo`02Ool200000goo07l0O`0Y
07l00`00O1ml7`0?O1l00`0007l0O`0407l00`000oT3n@030oT00`009n0Wh0039n000`00OV1nH00m
OV02Ool20005Ool0009oo`04001oogoo0002Ool01@00Oomoogoo000017oo00<007ooOol0:`1o00<0
07`OO1l03g`O00<0001o07l0101o00<000?i0oT00`?i00<002OP9n000bOP00<007iPOV00?GiP0goo
00<007ooOol00goo0003Ool00`00Ool00002Ool01@00Oomoogoo000017oo00<007ooOol0:`1o00<0
07`OO1l03g`O00<0001o07l0101o00<000?i0oT00`?i00<002OP9n000bOP00<007iPOV00?GiP0goo
00<007ooOol00goo0004Ool20002Ool01@00Oomoogoo000017oo00<007ooOol0:`1o00<007`OO1l0
3g`O00<0001o07l0101o00<000?i0oT00`?i00<002OP9n000bOP00<007iPOV00?GiP0goo00<007oo
Ool00goo0004Ool20002Ool01@00Oomoogoo000017oo00<007ooOol0:`1o00<007`OO1l03g`O00<0
001o07l0101o00<000?i0oT00`?i00<002OP9n000bOP00<007iPOV00?GiP0goo00<007ooOol00goo
0005Ool01000Oomoogoo0`001Goo00<007ooOol0:`1o00<007`OO1l03g`O00<0001o07l0101o00<0
00?i0oT00`?i00<002OP9n000bOP00<007iPOV00?GiP0goo00<007ooOol00goo000AOol00`00Oomo
o`0[07l00`00O1ml7`0?O1l00`0007l0O`0407l00`000oT3n@030oT00`009n0Wh0039n000`00OV1n
H00mOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02/0O`03001l7g`O00ml7`030000O`1o00@0
O`030003n@?i00<3n@03000Wh2OP00<Wh003001nH7iP03enH0=oo`03001oogoo00=oo`004Goo00<0
07ooOol0:`1o00<007`OO1l03g`O00<0001o07l0101o00<000?i0oT00`?i00<002OP9n000bOP00<0
07iPOV00?GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0[07l00`00O1ml7`0?O1l00`0007l0
O`0407l00`000oT3n@030oT00`009n0Wh0039n000`00OV1nH00mOV03Ool00`00Oomoo`03Ool0015o
o`03001oogoo02/0O`03001l7g`O00ml7`030000O`1o00@0O`030003n@?i00<3n@03000Wh2OP00<W
h003001nH7iP03enH0=oo`03001oogoo00=oo`004Goo00<007ooOol0:`1o00<007`OO1l03g`O00<0
001o07l0101o00<000?i0oT00`?i00<002OP9n000bOP00<007iPOV00?GiP0goo00<007ooOol00goo
000AOol00`00Oomoo`0[07l00`00O1ml7`0?O1l00`0007l0O`0407l00`000oT3n@030oT00`009n0W
h0039n000`00OV1nH00mOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02/0O`03001l7g`O00ml
7`030000O`1o00@0O`030003n@?i00<3n@03000Wh2OP00<Wh003001nH7iP03enH0=oo`03001oogoo
00=oo`004Goo00<007ooOol0:`1o00<007`OO1l03g`O00<0001o07l0101o00<000?i0oT00`?i00<0
02OP9n000bOP00<007iPOV00?GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0[07l00`00O1ml
7`0?O1l00`0007l0O`0407l00`000oT3n@030oT00`009n0Wh0039n000`00OV1nH00mOV03Ool00`00
Oomoo`03Ool0015oo`03001oogoo02/0O`03001l7g`O00ml7`030000O`1o00@0O`030003n@?i00<3
n@03000Wh2OP00<Wh003001nH7iP03enH0=oo`03001oogoo00=oo`004Goo00<007ooOol0:`1o00<0
07`OO1l03g`O00<0001o07l0101o00<000?i0oT00`?i00<002OP9n000bOP00<007iPOV00?GiP0goo
00<007ooOol00goo000AOol00`00Oomoo`0[07l00`00O1ml7`0?O1l00`0007l0O`0407l00`000oT3
n@030oT00`009n0Wh0039n000`00OV1nH00mOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02/0
O`03001l7g`O00ml7`030000O`1o00@0O`030003n@?i00<3n@03000Wh2OP00<Wh003001nH7iP03en
H0=oo`03001oogoo00=oo`004Goo00<007ooOol0:`1o00<007`OO1l03g`O00<0001o07l0101o00<0
00?i0oT00`?i00<002OP9n000bOP00<007iPOV00?GiP0goo00<007ooOol00goo000AOol00`00Oomo
o`0[07l00`00O1ml7`0?O1l00`0007l0O`0407l00`000oT3n@030oT00`009n0Wh0039n000`00OV1n
H00mOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02/0O`03001l7g`O00ml7`030000O`1o00@0
O`030003n@?i00<3n@03000Wh2OP00<Wh003001nH7iP03enH0=oo`03001oogoo00=oo`004Goo00<0
07ooOol0:`1o00<007`OO1l03g`O00<0001o07l0101o00<000?i0oT00`?i00<002OP9n000bOP00<0
07iPOV00?GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0[07l00`00O1ml7`0?O1l00`0007l0
O`0407l00`000oT3n@030oT00`009n0Wh0039n000`00OV1nH00mOV03Ool00`00Oomoo`03Ool0015o
o`03001oogoo02/0O`03001l7g`O00ml7`030000O`1o00@0O`030003n@?i00<3n@03000Wh2OP00<W
h003001nH7iP03enH0=oo`03001oogoo00=oo`004Goo00<007ooOol0:`1o00<007`OO1l03g`O00<0
001o07l0101o00<000?i0oT00`?i00<002OP9n000bOP00<007iPOV00?GiP0goo00<007ooOol00goo
000AOol00`00Oomoo`0[07l00`00O1ml7`0?O1l00`0007l0O`0407l00`000oT3n@030oT00`009n0W
h0039n000`00OV1nH00mOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02/0O`03001l7g`O00ml
7`030000O`1o00@0O`030003n@?i00<3n@03000Wh2OP00<Wh003001nH7iP03enH0=oo`03001oogoo
00=oo`004Goo00<007ooOol0:`1o00<007`OO1l03g`O00<0001o07l0101o00<000?i0oT00`?i00<0
02OP9n000bOP00<007iPOV00?GiP0goo00<007ooOol00goo000AOol200000goo07l0O`0Y07l00`00
O1ml7`0?O1l00`0007l0O`0407l00`000oT3n@030oT00`009n0Wh0039n000`00OV1nH00mOV02Ool2
0005Ool0015oo`03001oogoo02X0O`03001l7g`O011l7`030000O`1o00@0O`030003n@?i00<3n@03
000Wh2OP00<Wh003001nH7iP03enH0=oo`03001oogoo00=oo`004Goo00<007ooOol0:@1o00<007`O
O1l04W`O00<0001o07l00`1o00<000?i0oT00`?i00<002OP9n000bOP00<007iPOV00?GiP0goo00<0
07ooOol00goo000AOol00`00Oomoo`0Y07l00`00O1ml7`0BO1l00`0007l0O`0407l00`000oT3n@02
0oT00`009n0Wh0039n000`00OV1nH00mOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02P0O`03
001l7g`O01=l7`030000O`1o00@0O`030003n@?i0083n@03000Wh2OP00<Wh003001nH7iP03enH0=o
o`03001oogoo00=oo`004Goo00<007ooOol0:01o00<007`OO1l04g`O00<0001o07l0101o00<000?i
0oT00P?i00<002OP9n000bOP00<007iPOV00?GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0W
07l00`00O1ml7`0EO1l00`0007l0O`0307l00`000oT3n@030oT00`009n0Wh0029n000`00OV1nH00m
OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02H0O`03001l7g`O01Il7`030000O`1o00<0O`03
0003n@?i00<3n@03000Wh2OP008Wh003001nH7iP03enH0=oo`03001oogoo00=oo`004Goo00<007oo
Ool09P1o00<007`OO1l05W`O00<0001o07l00`1o00<000?i0oT00`?i00<002OP9n000ROP00<007iP
OV00?GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0U07l00`00O1ml7`0GO1l00`0007l0O`03
07l00`000oT3n@030oT00`009n0Wh0029n000`00OV1nH00mOV03Ool00`00Oomoo`03Ool0015oo`03
001oogoo02D0O`03001l7g`O01Ml7`030000O`1o00@0O`030003n@?i0083n@03000Wh2OP008Wh003
001nH7iP03enH0=oo`03001oogoo00=oo`004Goo00<007ooOol0901o00<007`OO1l06G`O00<0001o
07l00`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?GiP0goo00<007ooOol00goo000A
Ool00`00Oomoo`0S07l00`00O1ml7`0JO1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh002
9n000`00OV1nH00mOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02<0O`03001l7g`O01Yl7`03
0000O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03enH0=oo`03001oogoo00=o
o`004Goo00<007ooOol08`1o00<007`OO1l06W`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP
9n000ROP00<007iPOV00?GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0S07l00`00O1ml7`0J
O1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00mOV03Ool00`00Oomo
o`03Ool0015oo`03001oogoo02<0O`03001l7g`O01Yl7`030000O`1o00<0O`030003n@?i0083n@03
000Wh2OP008Wh003001nH7iP03enH0=oo`03001oogoo00=oo`004Goo00<007ooOol08`1o00<007`O
O1l06W`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?GiP0goo00<0
07ooOol00goo000AOol00`00Oomoo`0S07l00`00O1ml7`0JO1l00`0007l0O`0307l00`000oT3n@02
0oT00`009n0Wh0029n000`00OV1nH00mOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02<0O`03
001l7g`O01Yl7`030000O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03enH0=o
o`03001oogoo00=oo`004Goo00<007ooOol08`1o00<007`OO1l06W`O00<0001o07l00`1o00<000?i
0oT00P?i00<002OP9n000ROP00<007iPOV00?GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0S
07l00`00O1ml7`0JO1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00m
OV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02<0O`03001l7g`O01Yl7`030000O`1o00<0O`03
0003n@?i0083n@03000Wh2OP008Wh003001nH7iP03enH0=oo`03001oogoo00=oo`004Goo00<007oo
Ool08`1o00<007`OO1l06W`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iP
OV00?GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0S07l00`00O1ml7`0JO1l00`0007l0O`03
07l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00mOV03Ool00`00Oomoo`03Ool0015oo`03
001oogoo02<0O`03001l7g`O01Yl7`030000O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003
001nH7iP03enH0=oo`03001oogoo00=oo`004Goo00<007ooOol08`1o00<007`OO1l06W`O00<0001o
07l00`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?GiP0goo00<007ooOol00goo000A
Ool00`00Oomoo`0S07l00`00O1ml7`0JO1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh002
9n000`00OV1nH00mOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02<0O`03001l7g`O01Yl7`03
0000O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03enH0=oo`03001oogoo00=o
o`004Goo00<007ooOol08`1o00<007`OO1l06W`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP
9n000ROP00<007iPOV00?GiP0goo00<007ooOol00goo000AOol200000goo07l0O`0Q07l00`00O1ml
7`0JO1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00mOV02Ool20005
Ool0015oo`03001oogoo02<0O`03001l7g`O01Yl7`030000O`1o00<0O`030003n@?i0083n@03000W
h2OP008Wh003001nH7iP03enH0=oo`03001oogoo00=oo`004Goo00<007ooOol08`1o00<007`OO1l0
6W`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?GiP0goo00<007oo
Ool00goo000AOol00`00Oomoo`0S07l00`00O1ml7`0JO1l00`0007l0O`0307l00`000oT3n@020oT0
0`009n0Wh0029n000`00OV1nH00mOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02<0O`03001l
7g`O01Yl7`030000O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03enH0=oo`03
001oogoo00=oo`004Goo00<007ooOol08`1o00<007`OO1l06W`O00<0001o07l00`1o00<000?i0oT0
0P?i00<002OP9n000ROP00<007iPOV00?GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0S07l0
0`00O1ml7`0JO1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00mOV03
Ool00`00Oomoo`03Ool0015oo`03001oogoo02<0O`03001l7g`O01Yl7`030000O`1o00<0O`030003
n@?i0083n@03000Wh2OP008Wh003001nH7iP03enH0=oo`03001oogoo00=oo`004Goo00<007ooOol0
8`1o00<007`OO1l06W`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00
?GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0S07l00`00O1ml7`0JO1l00`0007l0O`0307l0
0`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00mOV03Ool00`00Oomoo`03Ool0015oo`03001o
ogoo02<0O`03001l7g`O01Yl7`030000O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001n
H7iP03enH0=oo`03001oogoo00=oo`004Goo00<007ooOol08`1o00<007`OO1l06W`O00<0001o07l0
0`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?GiP0goo00<007ooOol00goo000AOol0
0`00Oomoo`0S07l00`00O1ml7`0JO1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n00
0`00OV1nH00mOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02<0O`03001l7g`O01Yl7`030000
O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03enH0=oo`03001oogoo00=oo`00
4Goo00<007ooOol08`1o00<007`OO1l06W`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n00
0ROP00<007iPOV00?GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0S07l00`00O1ml7`0JO1l0
0`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00mOV03Ool00`00Oomoo`03
Ool0015oo`03001oogoo02<0O`03001l7g`O01Yl7`030000O`1o00<0O`030003n@?i0083n@03000W
h2OP008Wh003001nH7iP03enH0=oo`03001oogoo00=oo`004Goo00<007ooOol08`1o00<007`OO1l0
6W`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?GiP0goo00<007oo
Ool00goo000AOol00`00Oomoo`0S07l00`00O1ml7`0JO1l00`0007l0O`0307l00`000oT3n@020oT0
0`009n0Wh0029n000`00OV1nH00mOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo02<0O`03001l
7g`O01Yl7`030000O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03enH0=oo`03
001oogoo00=oo`004Goo00<007ooOol08`1o00<007`OO1l06W`O00<0001o07l00`1o00<000?i0oT0
0P?i00<002OP9n000ROP00<007iPOV00?GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0R07l0
0`00O1ml7`0KO1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00mOV03
Ool00`00Oomoo`03Ool0015oo`03001oogoo0280O`03001l7g`O01Al7`8000El7`030000O`1o00<0
O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03enH0=oo`03001oogoo00=oo`004Goo00<0
07ooOol08P1o00<007`OO1l04g`O00<007`000001G`O00<0001o07l00`1o00<000?i0oT00P?i00<0
02OP9n000ROP00<007iPOV00?GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0Q07l00`00O1ml
7`0CO1l01000O01l00001G`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iP
OV00?GiP0goo00<007ooOol00goo000AOol00`00Oomoo`0Q07l00`00O1ml7`0AO1l20003O0000`00
O1ml7`04O1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool0
0`00Oomoo`03Ool0015oo`03001oogoo0240O`03001l7g`O011l7`03001l07`000=l0003001l7g`O
00Al7`030000O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03001o
ogoo00=oo`004Goo00<007ooOol0801o00<007`OO1l047`O00<007`0O0001G`000<007`OO1l00g`O
00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?7iP0goo00<007ooOol0
0goo000AOol00`00Oomoo`0P07l00`00O1ml7`0>O1l20008O0000`00O1ml7`03O1l00`0007l0O`03
07l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool00`00Oomoo`03Ool0015oo`03
001oogoo0200O`03001l7g`O00el7`03001l07`000Ql0003001l7g`O00=l7`030000O`1o00<0O`03
0003n@?i0083n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03001oogoo00=oo`004Goo0P0000=o
o`1o07l07@1o00<007`OO1l03G`O00<007`0O0002G`000<007`OO1l00g`O00<0001o07l00`1o00<0
00?i0oT00P?i00<002OP9n000ROP00<007iPOV00?7iP0Woo0P001Goo000AOol00`00Oomoo`0O07l0
0`00O1ml7`0<O1l00`00O01l000:O0000`00O1ml7`03O1l00`0007l0O`0307l00`000oT3n@020oT0
0`009n0Wh0029n000`00OV1nH00lOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo01l0O`03001l
7g`O00al7`03001l07`000Yl0003001l7g`O00=l7`030000O`1o00<0O`030003n@?i0083n@03000W
h2OP008Wh003001nH7iP03anH0=oo`03001oogoo00=oo`004Goo00<007ooOol07`1o00<007`OO1l0
37`O00<007`0O0002W`000<007`OO1l00g`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n00
0ROP00<007iPOV00?7iP0goo00<007ooOol00goo000AOol00`00Oomoo`0O07l00`00O1ml7`0<O1l0
0`00O01l000:O0000`00O1ml7`03O1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n00
0`00OV1nH00lOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo01l0O`03001l7g`O00al7`03001l
07`000Yl0003001l7g`O00=l7`030000O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001n
H7iP03anH0=oo`03001oogoo00=oo`004Goo00<007ooOol07`1o00<007`OO1l037`O00<007`0O000
2W`000<007`OO1l00g`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00
?7iP0goo00<007ooOol00goo000AOol00`00Oomoo`0O07l00`00O1ml7`0<O1l00`00O01l000:O000
0`00O1ml7`03O1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03
Ool00`00Oomoo`03Ool0015oo`03001oogoo01l0O`03001l7g`O00al7`03001l07`000Yl0003001l
7g`O00=l7`030000O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03
001oogoo00=oo`004Goo00<007ooOol07`1o00<007`OO1l037`O00<007`0O0002W`000<007`OO1l0
0g`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?7iP0goo00<007oo
Ool00goo000AOol00`00Oomoo`0O07l00`00O1ml7`0<O1l00`00O01l000:O0000`00O1ml7`03O1l0
0`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool00`00Oomoo`03
Ool0015oo`03001oogoo01l0O`03001l7g`O00al7`03001l07`000Yl0003001l7g`O00=l7`030000
O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03001oogoo00=oo`00
4Goo00<007ooOol07`1o00<007`OO1l037`O00<007`0O0002W`000<007`OO1l00g`O00<0001o07l0
0`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?7iP0goo00<007ooOol00goo000AOol0
0`00Oomoo`0O07l00`00O1ml7`0<O1l00`00O01l000:O0000`00O1ml7`03O1l00`0007l0O`0307l0
0`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool00`00Oomoo`03Ool0015oo`03001o
ogoo01l0O`03001l7g`O00al7`03001l07`000Yl0003001l7g`O00=l7`030000O`1o00<0O`030003
n@?i0083n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03001oogoo00=oo`004Goo00<007ooOol0
7`1o00<007`OO1l037`O00<007`0O0002W`000<007`OO1l00g`O00<0001o07l00`1o00<000?i0oT0
0P?i00<002OP9n000ROP00<007iPOV00?7iP0goo00<007ooOol00goo000AOol00`00Oomoo`0O07l0
0`00O1ml7`0<O1l00`00O01l000:O0000`00O1ml7`03O1l00`0007l0O`0307l00`000oT3n@020oT0
0`009n0Wh0029n000`00OV1nH00lOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo01l0O`03001l
7g`O00al7`03001l07`000Yl0003001l7g`O00=l7`030000O`1o00<0O`030003n@?i0083n@03000W
h2OP008Wh003001nH7iP03anH0=oo`03001oogoo00=oo`004Goo00<007ooOol07`1o00<007`OO1l0
37`O00<007`0O0002W`000<007`OO1l00g`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n00
0ROP00<007iPOV00?7iP0goo00<007ooOol00goo000AOol00`00Oomoo`0O07l00`00O1ml7`0<O1l0
0`00O01l000:O0000`00O1ml7`03O1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n00
0`00OV1nH00lOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo01l0O`03001l7g`O00al7`03001l
07`000Yl0003001l7g`O00=l7`030000O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001n
H7iP03anH0=oo`03001oogoo00=oo`004Goo00<007ooOol07`1o00<007`OO1l037`O00<007`0O000
2W`000<007`OO1l00g`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00
?7iP0goo00<007ooOol00goo000AOol00`00Oomoo`0O07l00`00O1ml7`0<O1l00`00O01l000:O000
0`00O1ml7`03O1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03
Ool00`00Oomoo`03Ool0015oo`03001oogoo01l0O`03001l7g`O00al7`03001l07`000Yl0003001l
7g`O00=l7`030000O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03
001oogoo00=oo`004Goo00<007ooOol07`1o00<007`OO1l037`O00<007`0O0002W`000<007`OO1l0
0g`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?7iP0goo00<007oo
Ool00goo000AOol00`00Oomoo`0O07l00`00O1ml7`0<O1l00`00O01l000:O0000`00O1ml7`03O1l0
0`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool00`00Oomoo`03
Ool0015oo`03001oogoo01l0O`03001l7g`O00al7`03001l07`000Yl0003001l7g`O00=l7`030000
O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03001oogoo00=oo`00
4Goo00<007ooOol07`1o00<007`OO1l037`O00<007`0O0002W`000<007`OO1l00g`O00<0001o07l0
0`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?7iP0goo00<007ooOol00goo0003Ool3
0003Ool30005Ool00`00Oomoo`0O07l00`00O1ml7`0<O1l00`00O01l000:O0000`00O1ml7`03O1l0
0`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool00`00Oomoo`03
Ool0009oo`07001oogooOol007oo00000goo00<007ooOol00Woo00<007ooOol07`1o00<007`OO1l0
37`O00<007`0O0002W`000<007`OO1l00g`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n00
0ROP00<007iPOV00?7iP0goo00<007ooOol00goo0002Ool01`00Oomoogoo001oo`0000=oo`03001o
ogoo009oo`800003Ool0O`1o01d0O`03001l7g`O00al7`03001l07`000Yl0003001l7g`O00=l7`03
0000O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03anH09oo`8000Eoo`000Woo
00L007ooOomoo`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`0O07l00`00O1ml7`0<O1l00`00
O01l000:O0000`00O1ml7`03O1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00
OV1nH00lOV03Ool00`00Oomoo`03Ool0009oo`@0009oo`05001oogooOol00004Ool00`00Oomoo`0O
07l00`00O1ml7`0<O1l00`00O01l000:O0000`00O1ml7`03O1l00`0007l0O`0307l00`000oT3n@02
0oT00`009n0Wh0029n000`00OV1nH00lOV03Ool00`00Oomoo`03Ool000=oo`03001oogoo009oo`05
001oogooOol00004Ool00`00Oomoo`0O07l00`00O1ml7`0<O1l00`00O01l000:O0000`00O1ml7`03
O1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool00`00Oomo
o`03Ool000=oo`8000=oo`05001oogooOol00004Ool00`00Oomoo`0O07l00`00O1ml7`0<O1l00`00
O01l000:O0000`00O1ml7`03O1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00
OV1nH00lOV03Ool00`00Oomoo`03Ool000Eoo`80009oo`<000Eoo`03001oogoo01l0O`03001l7g`O
00al7`03001l07`000Yl0003001l7g`O00=l7`030000O`1o00<0O`030003n@?i0083n@03000Wh2OP
008Wh003001nH7iP03anH0=oo`03001oogoo00=oo`004Goo00<007ooOol07`1o00<007`OO1l037`O
00<007`0O0002W`000<007`OO1l00g`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n000ROP
00<007iPOV00?7iP0goo00<007ooOol00goo000AOol00`00Oomoo`0O07l00`00O1ml7`0<O1l00`00
O01l000:O0000`00O1ml7`03O1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00
OV1nH00lOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo01l0O`03001l7g`O00al7`03001l07`0
00Yl0003001l7g`O00=l7`030000O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP
03anH0=oo`03001oogoo00=oo`004Goo00<007ooOol07`1o00<007`OO1l037`O00<007`0O0002W`0
00<007`OO1l00g`O00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?7iP
0goo00<007ooOol00goo000AOol00`00Oomoo`0O07l00`00O1ml7`0<O1l00`00O01l000:O0000`00
O1ml7`03O1l00`0007l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool0
0`00Oomoo`03Ool0015oo`03001oogoo01l0O`03001l7g`O00]l7`03001l07`000]l0003001l7g`O
00=l7`030000O`1o00<0O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03001o
ogoo00=oo`004Goo00<007ooOol07`1o00<007`OO1l02g`O00<007`0O0002g`000<007`OO1l00g`O
00<0001o07l00`1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?7iP0goo00<007ooOol0
0goo000AOol00`00Oomoo`0O07l00`00O1ml7`0;O1l00`00O01l000;O0000`00O1ml7`03O1l00`00
07l0O`0307l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool00`00Oomoo`03Ool0
015oo`03001oogoo01l0O`03001l7g`O00]l7`03001l07`000]l0003001l7g`O00=l7`030000O`1o
00<0O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03001oogoo00=oo`004Goo
00<007ooOol07P1o00<007`OO1l02g`O00<007`0O0003G`000<007`OO1l00g`O00<0001o07l00P1o
00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?7iP0goo00<007ooOol00goo000AOol00`00
Oomoo`0N07l00`00O1ml7`0;O1l00`00O01l000=O0000`00O1ml7`03O1l00`0007l0O`0207l00`00
0oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo
01h0O`03001l7g`O00]l7`03001l07`000el0003001l7g`O00=l7`030000O`1o0080O`030003n@?i
0083n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03001oogoo00=oo`004Goo00<007ooOol07P1o
00<007`OO1l02g`O00<007`0O0003G`000<007`OO1l00g`O00<0001o07l00P1o00<000?i0oT00P?i
00<002OP9n000ROP00<007iPOV00?7iP0goo00<007ooOol00goo000AOol00`00Oomoo`0N07l00`00
O1ml7`0:O1l00`00O01l000>O0000`00O1ml7`03O1l00`0007l0O`0207l00`000oT3n@020oT00`00
9n0Wh0029n000`00OV1nH00lOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo01h0O`03001l7g`O
00Yl7`03001l07`000il0003001l7g`O00=l7`030000O`1o0080O`030003n@?i0083n@03000Wh2OP
008Wh003001nH7iP03anH0=oo`03001oogoo00=oo`004Goo00<007ooOol07P1o00<007`OO1l02W`O
00<007`0O0003W`000<007`OO1l00g`O00<0001o07l00P1o00<000?i0oT00P?i00<002OP9n000ROP
00<007iPOV00?7iP0goo00<007ooOol00goo000AOol00`00Oomoo`0N07l00`00O1ml7`0:O1l00`00
O01l000>O0000`00O1ml7`03O1l00`0007l0O`0207l00`000oT3n@020oT00`009n0Wh0029n000`00
OV1nH00lOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo01h0O`03001l7g`O00Yl7`03001l07`0
00il0003001l7g`O00=l7`030000O`1o0080O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP
03anH0=oo`03001oogoo00=oo`004Goo00<007ooOol07P1o00<007`OO1l02W`O00<007`0O0003W`0
00<007`OO1l00g`O00<0001o07l00P1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?7iP
0goo00<007ooOol00goo000AOol00`00Oomoo`0N07l00`00O1ml7`0:O1l00`00O01l000>O0000`00
O1ml7`03O1l00`0007l0O`0207l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool0
0`00Oomoo`03Ool0015oo`03001oogoo01h0O`03001l7g`O00Yl7`03001l07`000il0003001l7g`O
00=l7`030000O`1o0080O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03001o
ogoo00=oo`004Goo00<007ooOol07P1o00<007`OO1l02W`O00<007`0O0003W`000<007`OO1l00g`O
00<0001o07l00P1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?7iP0goo00<007ooOol0
0goo000AOol00`00Oomoo`0N07l00`00O1ml7`0:O1l00`00O01l000>O0000`00O1ml7`03O1l00`00
07l0O`0207l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool00`00Oomoo`03Ool0
015oo`03001oogoo01h0O`03001l7g`O00Yl7`03001l07`000il0003001l7g`O00=l7`030000O`1o
0080O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03001oogoo00=oo`004Goo
0P0000=oo`1o07l0701o00<007`OO1l02W`O00<007`0O0003W`000<007`OO1l00g`O00<0001o07l0
0P1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?7iP0Woo0P001Goo000AOol00`00Oomo
o`0N07l00`00O1ml7`0:O1l00`00O01l000>O0000`00O1ml7`03O1l00`0007l0O`0207l00`000oT3
n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo01h0
O`03001l7g`O00Yl7`03001l07`000il0003001l7g`O00=l7`030000O`1o0080O`030003n@?i0083
n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03001oogoo00=oo`004Goo00<007ooOol07P1o00<0
07`OO1l02W`O00<007`0O0003W`000<007`OO1l00g`O00<0001o07l00P1o00<000?i0oT00P?i00<0
02OP9n000ROP00<007iPOV00?7iP0goo00<007ooOol00goo000AOol00`00Oomoo`0N07l00`00O1ml
7`0:O1l00`00O01l000>O0000`00O1ml7`03O1l00`0007l0O`0207l00`000oT3n@020oT00`009n0W
h0029n000`00OV1nH00lOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo01h0O`03001l7g`O00Yl
7`03001l07`000il0003001l7g`O00=l7`030000O`1o0080O`030003n@?i0083n@03000Wh2OP008W
h003001nH7iP03anH0=oo`03001oogoo00=oo`004Goo00<007ooOol07P1o00<007`OO1l02W`O00<0
07`0O0003W`000<007`OO1l00g`O00<0001o07l00P1o00<000?i0oT00P?i00<002OP9n000ROP00<0
07iPOV00?7iP0goo00<007ooOol00goo000AOol00`00Oomoo`0N07l00`00O1ml7`0:O1l00`00O01l
000>O0000`00O1ml7`03O1l00`0007l0O`0207l00`000oT3n@020oT00`009n0Wh0029n000`00OV1n
H00lOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo01h0O`03001l7g`O00Yl7`03001l07`000il
0003001l7g`O00=l7`030000O`1o0080O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03an
H0=oo`03001oogoo00=oo`004Goo00<007ooOol07P1o00<007`OO1l02W`O00<007`0O0003W`000<0
07`OO1l00g`O00<0001o07l00P1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?7iP0goo
00<007ooOol00goo000AOol00`00Oomoo`0N07l00`00O1ml7`0:O1l00`00O01l000>O0000`00O1ml
7`03O1l00`0007l0O`0207l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool00`00
Oomoo`03Ool0015oo`03001oogoo01h0O`03001l7g`O00Yl7`03001l07`000il0003001l7g`O00=l
7`030000O`1o0080O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03001oogoo
00=oo`004Goo00<007ooOol07P1o00<007`OO1l02W`O00<007`0O0003W`000<007`OO1l00g`O00<0
001o07l00P1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?7iP0goo00<007ooOol00goo
000AOol00`00Oomoo`0N07l00`00O1ml7`0:O1l00`00O01l000>O0000`00O1ml7`03O1l00`0007l0
O`0207l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool00`00Oomoo`03Ool0015o
o`03001oogoo01h0O`03001l7g`O00Yl7`03001l07`000il0003001l7g`O00=l7`030000O`1o0080
O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03001oogoo00=oo`004Goo00<0
07ooOol07P1o00<007`OO1l02W`O00<007`0O0003W`000<007`OO1l00g`O00<0001o07l00P1o00<0
00?i0oT00P?i00<002OP9n000ROP00<007iPOV00?7iP0goo00<007ooOol00goo000AOol00`00Oomo
o`0N07l00`00O1ml7`0:O1l00`00O01l000>O0000`00O1ml7`03O1l00`0007l0O`0207l00`000oT3
n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo01h0
O`03001l7g`O00Yl7`03001l07`000il0003001l7g`O00=l7`030000O`1o0080O`030003n@?i0083
n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03001oogoo00=oo`004Goo00<007ooOol07P1o00<0
07`OO1l02W`O00<007`0O0003W`000<007`OO1l00g`O00<0001o07l00P1o00<000?i0oT00P?i00<0
02OP9n000ROP00<007iPOV00?7iP0goo00<007ooOol00goo000AOol00`00Oomoo`0N07l00`00O1ml
7`0:O1l00`00O01l000>O0000`00O1ml7`03O1l00`0007l0O`0207l00`000oT3n@020oT00`009n0W
h0029n000`00OV1nH00lOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo01h0O`03001l7g`O00Yl
7`03001l07`000il0003001l7g`O00=l7`030000O`1o0080O`030003n@?i0083n@03000Wh2OP008W
h003001nH7iP03anH0=oo`03001oogoo00=oo`004Goo00<007ooOol07P1o00<007`OO1l02W`O00<0
07`0O0003W`000<007`OO1l00g`O00<0001o07l00P1o00<000?i0oT00P?i00<002OP9n000ROP00<0
07iPOV00?7iP0goo00<007ooOol00goo000AOol00`00Oomoo`0N07l00`00O1ml7`0:O1l00`00O01l
000>O0000`00O1ml7`03O1l00`0007l0O`0207l00`000oT3n@020oT00`009n0Wh0029n000`00OV1n
H00lOV03Ool00`00Oomoo`03Ool0015oo`03001oogoo01h0O`03001l7g`O00Yl7`03001l07`000il
0003001l7g`O00=l7`030000O`1o0080O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03an
H0=oo`03001oogoo00=oo`004Goo00<007ooOol07P1o00<007`OO1l02W`O00<007`0O0003W`000<0
07`OO1l00g`O00<0001o07l00P1o00<000?i0oT00P?i00<002OP9n000ROP00<007iPOV00?7iP0goo
00<007ooOol00goo000AOol00`00Oomoo`0N07l00`00O1ml7`0:O1l00`00O01l000>O0000`00O1ml
7`03O1l00`0007l0O`0207l00`000oT3n@020oT00`009n0Wh0029n000`00OV1nH00lOV03Ool00`00
Oomoo`03Ool0015oo`03001oogoo01h0O`03001l7g`O00Yl7`03001l07`000il0003001l7g`O00=l
7`030000O`1o0080O`030003n@?i0083n@03000Wh2OP008Wh003001nH7iP03anH0=oo`03001oogoo
00=oo`004Goo00<007ooOol01P00601o00<007`OO1l02W`O00<007`0O0003W`00P0017`O0P000`1o
0P000`?i0P000bOP0P00?GiP0goo00<007ooOol00goo000AOol00`00Oomoo`06O1l:000>07l00`00
O1ml7`0:O1l00`00O01l000@O0000`00O1ml7`03O1l2000307l200030oT200039n02000kOV03Ool0
0`00Oomoo`03Ool0015oo`03001oogoo011l7`T000@0O`03001l7g`O00]l7`03001l07`0015l0080
00El7`8000<0O`8000<3n@8000<Wh003001nH7iP03QnH0=oo`03001oogoo00=oo`004Goo0P0000=o
og`OO1l05g`O1@003G`O00<007`0O0004g`000<007`OO1l017`O0P000`1o0P000`?i0P000ROP>`00
00=oo`0000001Goo000AOol00`00Oomoo`0[O1l00`00O01l000DO0000`00O1ml7`05O1l2000307l0
0`000oT3n@020oT2000j9n03Ool00`00Oomoo`03Ool0015oo`03001oogoo02]l7`03001l07`001El
008000Ml7`800080O`8000@3nC/0009oo`03001oogoo00=oo`004Goo00<007ooOol0:g`O00<007`0
O0005g`000<007`OO1l01W`O0P000P1o0P00?0?i0goo00<007ooOol00goo000AOol00`00Oomoo`0[
O1l00`00O01l000HO0020008O1l2000207l2000j0oT3Ool00`00Oomoo`03Ool0015oo`03001oogoo
02]l7`03001l07`001Yl0003001l7g`O00Ml7`800080Oc/0009oo`03001oogoo00=oo`004Goo00<0
07ooOol0:g`O00<007`0O0006g`000<007`OO1l027`O0P00>P1o0goo00<007ooOol00goo000AOol0
0`00Oomoo`0[O1l00`00O01l000LO002000:O1lk0002Ool00`00Oomoo`03Ool0015oo`03001oogoo
02]l7`03001l07`001il0003001l7g`O045l7`=oo`03001oogoo00=oo`004Goo00<007ooOol00P00
:G`O00<007`0O0007g`000<007`OO1l0@7`O0goo00<007ooOol00goo000AOol00`00Oomoo`0207l3
000VO1l00`00O01l000OO0000`00O1ml7`10O1l3Ool00`00Oomoo`03Ool0015oo`03001oogoo00D0
O`8002=l7`03001l07`0021l0003001l7g`O041l7`=oo`03001oogoo00=oo`004Goo00<007ooOol0
1`1o0P008G`O00<007`0O00087`000<007`OO1l0@7`O0goo00<007ooOol00goo000AOol00`00Oomo
o`02000707l3000NO1l00`00O01l000PO0000`00O1ml7`10O1l3Ool00`00Oomoo`03Ool0015oo`03
001oogoo0083n@<000L0O`8001]l7`03001l07`0025l0003001l7g`O041l7`=oo`03001oogoo00=o
o`004Goo00<007ooOol00P000`?i0P001`1o0P006G`O00<007`0O0008G`000<007`OO1l0@7`O0goo
00<007ooOol00goo000AOol00`00Oomoo`029n0200030oT2000707l3000FO1l00`00O01l000QO000
0`00O1ml7`10O1l3Ool00`00Oomoo`03Ool0015oo`03001oogoo00@Wh08000<3n@<000L0O`8001=l
7`03001l07`0029l0003001l7g`O041l7`=oo`03001oogoo00=oo`004Goo00<007ooOol00P0012OP
0P0010?i0P001`1o0P004G`O00<007`0O0008W`000<007`OO1l0@7`O0goo00<007ooOol00goo000A
Ool00`00Oomoo`02OV0200049n0200040oT2000707l3000>O1l00`00O01l000RO0000`00O1ml7`10
O1l3Ool00`00Oomoo`03Ool0015oo`03001oogoo00AnH08000@Wh08000@3n@<000L0O`8000]l7`03
001l07`002=l0003001l7g`O041l7`=oo`03001oogoo00=oo`004Goo00<007ooOol01WiP00<002OP
9n000bOP00<000?i0oT010?i00<0001o07l01P1o00<007`OO1l027`O00<007`0O0008g`000<007`O
O1l0@7`O0goo00<007ooOol00goo000AOol00`00Oomoo`06OV000`009n0Wh0039n000`000oT3n@04
0oT00`0007l0O`0607l00`00O1ml7`08O1l00`00O01l000SO0000`00O1ml7`10O1l3Ool00`00Oomo
o`03Ool0015oo`03001oogoo00InH003000Wh2OP00<Wh0030003n@?i00@3n@030000O`1o00H0O`03
001l7g`O00Ul7`03001l07`0025l0003001l7g`O045l7`=oo`03001oogoo00=oo`004Goo00<007oo
Ool01WiP00<002OP9n000bOP00<000?i0oT010?i00<0001o07l01P1o00<007`OO1l02G`O00<007`0
O0008G`000<007`OO1l0@G`O0goo00<007ooOol00goo000AOol00`00Oomoo`06OV000`009n0Wh003
9n000`000oT3n@040oT00`0007l0O`0607l00`00O1ml7`09O1l00`00O01l000PO0000`00O1ml7`12
O1l3Ool00`00Oomoo`03Ool0015oo`03001oogoo00InH003000Wh2OP00<Wh0030003n@?i00@3n@03
0000O`1o00H0O`03001l7g`O00Yl7`03001l07`001ml0003001l7g`O049l7`=oo`03001oogoo00=o
o`004Goo00<007ooOol01WiP00<002OP9n000bOP00<000?i0oT010?i00<0001o07l01P1o00<007`O
O1l02W`O00<007`0O0007W`000<007`OO1l0@g`O0goo00<007ooOol00goo000AOol00`00Oomoo`05
OV000`009n0Wh0039n000`000oT3n@040oT00`0007l0O`0607l00`00O1ml7`0<O1l00`00O01l000M
O0000`00O1ml7`13O1l3Ool00`00Oomoo`03Ool0015oo`03001oogoo00EnH003000Wh2OP00<Wh003
0003n@?i00@3n@030000O`1o00H0O`03001l7g`O00al7`03001l07`001el0003001l7g`O04=l7`=o
o`03001oogoo00=oo`004Goo0P0000=oogiPOV000giP00<002OP9n000bOP00<000?i0oT010?i00<0
001o07l01P1o00<007`OO1l037`O00<007`0O00077`000<007`OO1l0A7`O0Woo0P001Goo000AOol0
0`00Oomoo`05OV000`009n0Wh0039n000`000oT3n@040oT00`0007l0O`0607l00`00O1ml7`0=O1l0
0`00O01l000KO0000`00O1ml7`14O1l3Ool00`00Oomoo`03Ool0015oo`03001oogoo00EnH003000W
h2OP00<Wh0030003n@?i00@3n@030000O`1o00H0O`03001l7g`O00el7`03001l07`001Yl0003001l
7g`O04El7`=oo`03001oogoo00=oo`004Goo00<007ooOol01GiP00<002OP9n000bOP00<000?i0oT0
10?i00<0001o07l01P1o00<007`OO1l03G`O00<007`0O0006W`000<007`OO1l0AG`O0goo00<007oo
Ool00goo000AOol00`00Oomoo`05OV000`009n0Wh0039n000`000oT3n@040oT00`0007l0O`0607l0
0`00O1ml7`0>O1l5000CO0040018O1l3Ool00`00Oomoo`03Ool0015oo`03001oogoo00EnH003000W
h2OP00<Wh0030003n@?i00@3n@030000O`1o00H0O`03001l7g`O01=l7`L000El00L004al7`=oo`03
001oogoo00=oo`004Goo00<007ooOol01GiP00<002OP9n000bOP00<000?i0oT010?i00<0001o07l0
1P1o00<007`OO1l06W`O1@00Dg`O0goo00<007ooOol00goo000AOol00`00Oomoo`05OV000`009n0W
h0039n000`000oT3n@030oT00`0007l0O`0707l00`00O1ml7`1bO1l3Ool00`00Oomoo`03Ool0015o
o`03001oogoo00EnH003000Wh2OP008Wh0030003n@?i00@3n@030000O`1o00L0O`03001l7g`O079l
7`=oo`03001oogoo00=oo`004Goo00<007ooOol01GiP00<002OP9n000ROP00<000?i0oT010?i00<0
001o07l01`1o00<007`OO1l0LW`O0goo00<007ooOol00goo000AOol00`00Oomoo`05OV000`009n0W
h0029n000`000oT3n@040oT00`0007l0O`0707l00`00O1ml7`1bO1l3Ool00`00Oomoo`03Ool0015o
o`03001oogoo00AnH003000Wh2OP00<Wh0030003n@?i00<3n@030000O`1o00L0O`03001l7g`O07=l
7`=oo`03001oogoo00=oo`004Goo00<007ooOol017iP00<002OP9n000bOP00<000?i0oT00`?i00<0
001o07l01`1o00<007`OO1l0Lg`O0goo00<007ooOol00goo000AOol00`00Oomoo`04OV000`009n0W
h0039n000`000oT3n@030oT00`0007l0O`0707l00`00O1ml7`1cO1l3Ool00`00Oomoo`03Ool0015o
o`03001oogoo00AnH003000Wh2OP008Wh0030003n@?i00@3n@030000O`1o00L0O`03001l7g`O01]l
7`D005=l7`=oo`03001oogoo00=oo`004Goo00<007ooOol017iP00<002OP9n000ROP00<000?i0oT0
0`?i00<0001o07l0201o00<007`OO1l05g`O10001@1o1@00CW`O0goo00<007ooOol00goo000AOol0
0`00Oomoo`04OV000`009n0Wh0029n000`000oT3n@030oT00`0007l0O`0807l00`00O1ml7`0CO1l4
000>07l4001:O1l3Ool00`00Oomoo`03Ool0015oo`03001oogoo00AnH003000Wh2OP008Wh0030003
n@?i00<3n@030000O`1o00P0O`03001l7g`O00ml7`@001H0O`@004Il7`=oo`03001oogoo00=oo`00
4Goo00<007ooOol017iP00<002OP9n000ROP00<000?i0oT00`?i00<0001o07l02@1o00<007`OO1l0
2G`O1@007P1o1000@W`O0goo00<007ooOol00goo000AOol00`00Oomoo`04OV000`009n0Wh0029n00
0`000oT3n@040oT00`0007l0O`0907l00`00O1ml7`04O1l4000W07l3000oO1l3Ool00`00Oomoo`03
Ool0015oo`03001oogoo00AnH003000Wh2OP00<Wh0030003n@?i00<3n@030000O`1o00T0O`03001l
7g`O00@002h0O`@003]l7`=oo`03001oogoo00=oo`004Goo00<007ooOol017iP00<002OP9n000bOP
00<000?i0oT00`?i00<0001o07l02P1o0P00=P1o?0000Woo00<007ooOol00goo000AOol00`00Oomo
o`04OV000`009n0Wh0039n000`000oT3n@030oT00`0007l0O`1m07l3Ool00`00Oomoo`03Ool0015o
o`03001oogoo00EnH003000Wh2OP008Wh0030003n@?i00@3n@030000O`1o07`0O`=oo`03001oogoo
00=oo`004Goo00<007ooOol01GiP00<002OP9n000ROP00<000?i0oT010?i00<0001o07l0O01o0goo
00<007ooOol00goo000AOol00`00Oomoo`05OV000`009n0Wh0029n000`000oT3n@040oT00`0007l0
O`1l07l3Ool00`00Oomoo`03Ool0015oo`03001oogoo00EnH003000Wh2OP00<Wh0030003n@?i00<3
n@030000O`1o07`0O`=oo`03001oogoo00=oo`004Goo00<007ooOol01GiP00<002OP9n000bOP00<0
00?i0oT010?i00<0001o07l0N`1o0goo00<007ooOol00goo0003Ool30003Ool30005Ool00`00Oomo
o`05OV000`009n0Wh0039n000`000oT3n@040oT00`0007l0O`1k07l3Ool00`00Oomoo`03Ool0009o
o`07001oogooOol007oo00000goo00<007ooOol00Woo00<007ooOol01GiP00<002OP9n000bOP00<0
00?i0oT010?i00<0001o07l0N`1o0goo00<007ooOol00goo0002Ool01`00Oomoogoo001oo`0000=o
o`03001oogoo009oo`800003OomnH7iP00=nH003000Wh2OP00<Wh0030003n@?i00@3n@030000O`1o
07/0O`9oo`8000Eoo`000Woo00L007ooOomoo`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`05
OV000`009n0Wh0039n000`000oT3n@040oT00`0007l0O`1k07l3Ool00`00Oomoo`03Ool000=oo`<0
009oo`05001oogooOol00004Ool00`00Oomoo`05OV000`009n0Wh0039n000`000oT3n@040oT00`00
07l0O`1k07l3Ool00`00Oomoo`03Ool0009oo`07001oogooOol007oo00000goo00<007ooOol00Woo
00<007ooOol01GiP00<002OP9n000bOP00<000?i0oT010?i00<0001o07l0N`1o0goo00<007ooOol0
0goo0002Ool01`00Oomoogoo001oo`0000=oo`03001oogoo009oo`03001oogoo00EnH003000Wh2OP
00<Wh0030003n@?i00@3n@030000O`1o07/0O`=oo`03001oogoo00=oo`000goo0`000goo0`001Goo
00<007ooOol01GiP00<002OP9n000bOP00<000?i0oT010?i00<0001o07l0N`1o0goo00<007ooOol0
0goo000AOol00`00Oomoo`05OV000`009n0Wh0039n000`000oT3n@040oT00`0007l0O`1k07l3Ool0
0`00Oomoo`03Ool0015oo`03001oogoo00EnH003000Wh2OP00<Wh0030003n@?i00@3n@030000O`1o
07/0O`=oo`03001oogoo00=oo`004Goo00<007ooOol01GiP00<002OP9n000bOP00<000?i0oT010?i
00<0001o07l0N`1o0goo00<007ooOol00goo000AOol00`00Oomoo`05OV000`009n0Wh0039n000`00
0oT3n@040oT00`0007l0O`1k07l3Ool00`00Oomoo`03Ool0015oo`03001oogoo00EnH08000@Wh0<0
00@3n@<007/0O`=oo`03001oogoo00=oo`004Goo00<007ooOol01giP0`0012OP0`0010?i1000M`1o
0goo00<007ooOol00goo000AOol00`00Oomoo`0:OV0300049n0300050oT3001d07l3Ool00`00Oomo
o`03Ool0015oo`03001oogoo00enH08000DWh0<000D3n@<00740O`=oo`03001oogoo00=oo`004Goo
00<007ooOol03giP0`001BOP0`001@?i0P00K`1o0goo00<007ooOol00goo000AOol00`00Oomoo`0B
OV0300059n0300040oT3001/07l3Ool00`00Oomoo`03Ool0015oo`03001oogoo01EnH08000HWh080
00D3n@8006X0O`=oo`03001oogoo00=oo`004Goo00<007ooOol05giP0`001BOP0P001@?i0P00J01o
0goo00<007ooOol00goo000AOol00`00Oomoo`0JOV0300049n0200050oT2001V07l3Ool00`00Oomo
o`03Ool0015oo`03001oogoo01enH08000@Wh0<000@3n@8006@0O`=oo`03001oogoo00=oo`004Goo
00<007ooOol07giP0P001BOP0P0010?i0`00H@1o0goo00<007ooOol00goo000AOol00`00Oomoo`0Q
OV0200059n0200050oT2001O07l3Ool00`00Oomoo`03Ool0015oo`03001oogoo02=nH08000DWh080
00D3n@8005d0O`=oo`03001oogoo00=oo`004Goo00<007ooOol09GiP0P001BOP0P001@?i0`00FP1o
0goo00<007ooOol00goo000AOol00`00Oomoo`0WOV0300049n0300050oT3001G07l3Ool00`00Oomo
o`03Ool0015oo`03001oogoo02YnH0<000@Wh0<000D3n@<005@0O`=oo`03001oogoo00=oo`004Goo
00<007ooOol0;GiP0P001BOP0`001@?i0`00D@1o0goo00<007ooOol00goo000AOol00`00Oomoo`0_
OV0300059n0300050oT3001>07l3Ool00`00Oomoo`03Ool0015oo`03001oogoo039nH08000HWh080
00H3n@8004`0O`=oo`03001oogoo00=oo`004Goo00<007ooOol0=7iP0`001BOP0`001@?i0`00B@1o
0goo00<007ooOol00goo000AOol200000gooOV1nH00eOV0300059n0200060oT2001707l2Ool20005
Ool0015oo`03001oogoo03YnH08000DWh0<000D3n@<004@0O`=oo`03001oogoo00=oo`004Goo00<0
07ooOol0?7iP0P001ROP0P001P?i0`00@@1o0goo00<007ooOol00goo000AOol00`00Oomoo`0nOV03
00059n0200070oT2000o07l3Ool00`00Oomoo`03Ool0015oo`03001oogoo045nH08000DWh0<000H3
n@<003`0O`=oo`03001oogoo00=oo`004Goo00<007ooOol0@giP00<002OP9n001BOP00<000?i0oT0
1P?i00<0001o07l0>@1o0goo00<007ooOol00goo000AOol00`00Oomoo`13OV000`009n0Wh0059n00
0`000oT3n@060oT00`0007l0O`0i07l3Ool00`00Oomoo`03Ool0015oo`03001oogoo04=nH003000W
h2OP00DWh0030003n@?i00H3n@030000O`1o03T0O`=oo`03001oogoo00=oo`004Goo00<007ooOol0
@giP00<002OP9n001BOP00<000?i0oT01P?i00<0001o07l0>@1o0goo00<007ooOol00goo000AOol0
0`00Oomoo`13OV000`009n0Wh0059n000`000oT3n@060oT00`0007l0O`0i07l3Ool00`00Oomoo`03
Ool0015oo`03001oogoo04=nH003000Wh2OP00DWh0030003n@?i00H3n@030000O`1o03T0O`=oo`03
001oogoo00=oo`004Goo00<007ooOol0@giP00<002OP9n001BOP00<000?i0oT01P?i00<0001o07l0
>@1o0goo00<007ooOol00goo000AOol00`00Oomoo`13OV000`009n0Wh0059n000`000oT3n@060oT0
0`0007l0O`0i07l3Ool00`00Oomoo`03Ool0015oo`03001oogoo04=nH003000Wh2OP00DWh0030003
n@?i00H3n@030000O`1o03T0O`=oo`03001oogoo00=oo`004Goo00<007ooOol0@giP00<002OP9n00
1BOP00<000?i0oT01P?i00<0001o07l0>@1o0goo00<007ooOol00goo000AOol00`00Oomoo`13OV00
0`009n0Wh0059n000`000oT3n@060oT00`0007l0O`0i07l3Ool00`00Oomoo`03Ool0015oo`03001o
ogoo04=nH003000Wh2OP00DWh0030003n@?i00H3n@030000O`1o03T0O`=oo`03001oogoo00=oo`00
4Goo00<007ooOol0@giP0P001ROP0P001`?i00<0001o07l0>@1o0goo00<007ooOol00goo000AOol0
0`00Oomoo`15OV0200069n000`000oT3n@040oT00`0007l0O`0i07l3Ool00`00Oomoo`03Ool0015o
o`03001oogoo04MnH08000DWh08000D3n@030000O`1o03P0O`=oo`03001oogoo00=oo`004Goo00<0
07ooOol0BGiP0P001BOP0P0010?i>`000Woo00<007ooOol00goo000AOol00`00Oomoo`1;OV020005
9n000`000oT3n@0k0oT3Ool00`00Oomoo`03Ool0015oo`03001oogoo04enH003000Wh2OP00<Wh080
03/3n@=oo`03001oogoo00=oo`004Goo00<007ooOol0CWiP0P001BOP00<000?i0oT0>0?i0goo00<0
07ooOol00goo000AOol00`00Oomoo`1@OV0200049n0k0002Ool00`00Oomoo`03Ool0015oo`03001o
ogoo059nH08003`Wh0=oo`03001oogoo00=oo`004Goo00<007ooOol0E7iP0P00>ROP0goo00<007oo
Ool00goo000AOol00`00Oomoo`1FOV0k0002Ool00`00Oomoo`03Ool0015oo`03001oogoo091nH0=o
o`03001oogoo00=oo`004Goo0P0000=oogiPOV00SWiP0Woo0P001Goo000AOol00`00Oomoo`2COol0
0`00Oomoo`03Ool0015oo`03001oogoo09=oo`03001oogoo00=oo`004Goo00<007ooOol0Tgoo00<0
07ooOol00goo000AOol00`00Oomoo`2COol00`00Oomoo`03Ool0015oo`03001oogoo09=oo`03001o
ogoo00=oo`004Goo00<007ooOol0Tgoo00<007ooOol00goo000AOol00`00Oomoo`2COol00`00Oomo
o`03Ool0015oo`03001oogoo09=oo`03001oogoo00=oo`004Goo00@007ooOol000Eoo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo00=oo`04001oogoo0005Ool0015ooiL000Eoo`00[Goo002]
Ool00:eoo`00[Goo002]Ool00:eoo`00AGoo0`000Woo0`003Woo10001Goo0`0000Aoo`00001oo`D0
0004Ool00000Ool2000gOol004Moo`04001oogoo0006Ool70007Ool00`00Oomoo`03Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo000hOol004Moo`04001oogoo000DOol00`00Oomoo`03
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000hOol004Qoo`8001Eoo`03001oogoo
00=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol003Qoo`00B7oo0P001goo1`001goo
00<007ooOol00goo0P0000Eoo`00001oo`00009oo`800005Ool00000Ool0000hOol004Moo`04001o
ogoo000@Ool40005Ool200001Goo001oogoo00000Woo0P0000Eoo`00Oomoo`0003Uoo`00Agoo00@0
07ooOol0015oo`03001oogoo04ioo`00AGoo0`000Woo0`003goo1000CGoo002]Ool00:eoo`00[Goo
002]Ool00:eoo`00[Goo002]Ool00:eoo`00[Goo002]Ool00:eoo`00[Goo002]Ool00:eoo`00[Goo
002]Ool00:eoo`00[Goo002]Ool00:eoo`00[Goo002]Ool00:eoo`00[Goo002]Ool00001\
\>"],
  ImageRangeCache->{{{0, 172.375}, {576.875, 0}} -> {-2.4656, 1.80436, 
  0.167092, 0.167092}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["QuickDraw 3D  Graphics", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Here are instructions to plot using QuickDraw3D the whole quadrupole or \
the periodic part of the iron structure. One can save the geometry with \
colors in a 3dmf format using the menu \"File->Save As\"  in Radia.exe before \
returning to ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  ". A 3dmf file can be read by a number of CAD and RayTracing Packages. ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\( (*\ The\ whole\ geometry\ *) \n\(radObjDrwQD3D[t]; \)\)\)], "Input"],

Cell[BoxData[
    \(\( (*\ The\ Periodic\ part\ of\ the\ Iron\ \ *) \n\(radObjDrwQD3D[g]; 
    \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Graphics"
}], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "The plot of the whole quadrupole requires significant memory for the \
Kernel. Depending on your memory  you may or may not be capable of plotting \
it. However, one may just want to plot the periodic part of the iron \
structure to see  its  segmentation. To plot the whole quadrupole replace \"",
    
    Evaluatable->False,
    AspectRatioFixed->True],
  "radObjDrw[g]\" by \"radObjDrw[t]\" and be preapred to wait for some time. \
This time can be minimized if you only plot loosely segmented structures. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"draw", "=", 
        RowBox[{
          StyleBox["radObjDrw",
            FontColor->RGBColor[1, 0, 0]], "[", "t", "]"}]}], ";", "\n", 
      RowBox[{
        StyleBox["RadPlot3DOptions",
          FontColor->RGBColor[1, 0, 0]], "[", "]"}], ";", "\n", 
      \(Show[Graphics3D[draw]\n, ViewPoint -> {5, \(-2\), 1}\n, 
        PlotRange -> All\n, AmbientLight\  -> \ GrayLevel[0.1]]\), ";"}]], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.74834 .86467 -12.3439 0 ]
[.74834 .86467 12.6561 15 ]
[.80241 .8546 -4.92393 0 ]
[.80241 .8546 5.07607 15 ]
[.85998 .84388 -7.85503 0 ]
[.85998 .84388 8.14497 15 ]
[.80336 .91709 -7.87828 0 ]
[.80336 .91709 8.12172 15 ]
[.31608 .09812 -15.3509 -15 ]
[.31608 .09812 15.6491 0 ]
[.56169 .1259 -5.01611 -15 ]
[.56169 .1259 4.98389 0 ]
[.79479 .15226 -11.1691 -15 ]
[.79479 .15226 10.8309 0 ]
[.56149 .0634 -8.02578 -15 ]
[.56149 .0634 7.97422 0 ]
[.87801 .24858 0 -6.71554 ]
[.87801 .24858 31 8.28446 ]
[.88274 .49586 0 -6.92503 ]
[.88274 .49586 10 8.07497 ]
[.88759 .74958 0 -7.14022 ]
[.88759 .74958 22 7.85978 ]
[.94506 .50064 0 -6.92503 ]
[.94506 .50064 15 8.07497 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
.73358 .85489 m
.8766 .82824 L
s
.25 Mabswid
.74818 .85217 m
.7481 .84592 L
s
gsave
.74834 .86467 -73.3439 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.80222 .8421 m
.80212 .83585 L
s
gsave
.80241 .8546 -65.9239 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.85976 .83138 m
.85964 .82513 L
s
gsave
.85998 .84388 -68.855 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.75872 .8502 m
.75867 .84645 L
s
.7694 .84821 m
.76935 .84447 L
s
.7802 .8462 m
.78015 .84245 L
s
.79114 .84416 m
.79109 .84041 L
s
.81344 .84001 m
.81338 .83626 L
s
.8248 .83789 m
.82473 .83414 L
s
.8363 .83575 m
.83624 .832 L
s
.84795 .83358 m
.84789 .82983 L
s
.73776 .85411 m
.73772 .85036 L
s
.87172 .82915 m
.87165 .8254 L
s
gsave
.80336 .91709 -68.8783 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.003 w
.23791 .1018 m
.86416 .17258 L
s
.25 Mabswid
.31596 .11062 m
.3159 .11687 L
s
gsave
.31608 .09812 -76.3509 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.56173 .1384 m
.56175 .14465 L
s
gsave
.56169 .1259 -66.0161 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.79498 .16476 m
.79508 .17101 L
s
gsave
.79479 .15226 -72.1691 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.36617 .1163 m
.36614 .12005 L
s
.41584 .12191 m
.41582 .12566 L
s
.46498 .12746 m
.46498 .13121 L
s
.51361 .13296 m
.51362 .13671 L
s
.60935 .14378 m
.60938 .14753 L
s
.65648 .14911 m
.65651 .15286 L
s
.70312 .15438 m
.70316 .15813 L
s
.74929 .15959 m
.74934 .16334 L
s
.26522 .10489 m
.26517 .10864 L
s
.84021 .16987 m
.84028 .17362 L
s
gsave
.56149 .0634 -69.0258 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.003 w
.86416 .17258 m
.8766 .82824 L
s
.25 Mabswid
.86558 .24728 m
.85936 .24663 L
s
gsave
.87801 .24858 -61 -10.7155 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.87028 .4949 m
.86405 .49443 L
s
gsave
.88274 .49586 -61 -10.925 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.8751 .74898 m
.86886 .74868 L
s
gsave
.88759 .74958 -61 -11.1402 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.86651 .2963 m
.86278 .29593 L
s
.86745 .34557 m
.86371 .34522 L
s
.86839 .39509 m
.86465 .39477 L
s
.86933 .44487 m
.86559 .44456 L
s
.87123 .5452 m
.86749 .54493 L
s
.87219 .59575 m
.86845 .5955 L
s
.87316 .64656 m
.86941 .64634 L
s
.87413 .69764 m
.87038 .69743 L
s
.86466 .1985 m
.86093 .19809 L
s
.87608 .80059 m
.87233 .80043 L
s
gsave
.94506 .50064 -61 -10.925 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.187500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.14118 .18726 m
.12911 .83347 L
s
.12911 .83347 m
.73358 .85489 L
s
.73358 .85489 m
.72644 .24751 L
s
.72644 .24751 m
.14118 .18726 L
s
.23791 .1018 m
.86416 .17258 L
s
.86416 .17258 m
.8766 .82824 L
s
.8766 .82824 m
.2283 .80295 L
s
.2283 .80295 m
.23791 .1018 L
s
.14118 .18726 m
.12911 .83347 L
s
.12911 .83347 m
.2283 .80295 L
s
.2283 .80295 m
.23791 .1018 L
s
.23791 .1018 m
.14118 .18726 L
s
.72644 .24751 m
.86416 .17258 L
s
.86416 .17258 m
.8766 .82824 L
s
.8766 .82824 m
.73358 .85489 L
s
.73358 .85489 m
.72644 .24751 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
[ ] 0 setdash
.55012 .38543 m .53539 .39304 L .57613 .43948 L p .578 0 0 r
F P
0 g
s
.57613 .43948 m .59122 .43234 L .55012 .38543 L p .578 0 0 r
F P
0 g
s
.54496 .47029 m .57613 .43948 L .53539 .39304 L p .855 0 0 r
F P
0 g
s
.54496 .47029 m .60428 .4653 L .57613 .43948 L .83 0 0 r
F
.59122 .43234 m .57613 .43948 L .60428 .4653 L .578 0 0 r
F
.59122 .43234 m .57613 .43948 L .54496 .47029 L p .157 0 0 r
F P
0 g
s
.55983 .46341 m .57613 .43948 L .59122 .43234 L .157 0 0 r
F
.55983 .46341 m .54496 .47029 L .57613 .43948 L F
.57322 .49628 m .63299 .48077 L .60428 .4653 L .765 0 0 r
F
.60497 .44495 m .60428 .4653 L .63299 .48077 L .578 0 0 r
F
.54496 .47029 m .57322 .49628 L .60428 .4653 L .83 0 0 r
F
.59122 .43234 m .60428 .4653 L .60497 .44495 L .578 0 0 r
F
0 g
.58022 .44323 m
.60428 .4653 L
s
.53539 .39304 m .50394 .42367 L .54496 .47029 L p .855 0 0 r
F P
0 g
s
.51844 .41633 m .53539 .39304 L .50394 .42367 L .1 0 0 r
F
.51844 .41633 m .55012 .38543 L .53539 .39304 L F
.48308 .39382 m .53539 .39304 L .51476 .36322 L .879 0 0 r
F
.48308 .39382 m .50394 .42367 L .53539 .39304 L F
.54008 .37088 m .53539 .39304 L .55012 .38543 L .578 0 0 r
F
.54008 .37088 m .51476 .36322 L .53539 .39304 L F
.50394 .42367 m .53539 .39304 L .55012 .38543 L p .1 0 0 r
F P
0 g
s
.54496 .47029 m .55983 .46341 L .59122 .43234 L p .157 0 0 r
F P
0 g
s
.51844 .41633 m .55983 .46341 L .54496 .47029 L p .57 0 0 r
F P
0 g
s
.55615 .45923 m
.57613 .43948 L
s
.54496 .47029 m .50394 .42367 L .51844 .41633 L p .57 0 0 r
F P
0 g
s
.55469 .46579 m .57322 .49628 L .54496 .47029 L .57 0 0 r
F
.55983 .46341 m .56253 .47006 L .55469 .46579 L F
.56253 .47006 m .57322 .49628 L .55469 .46579 L F
.60497 .44495 m .63299 .48077 L .61895 .45242 L .578 0 0 r
F
.57363 .4761 m .61895 .45242 L .60497 .44495 L .765 0 0 r
F
.57322 .49628 m .60189 .51201 L .63299 .48077 L F
.57349 .48307 m .60189 .51201 L .57322 .49628 L .57 0 0 r
F
.57363 .4761 m .57932 .48333 L .57349 .48307 L F
.57932 .48333 m .60189 .51201 L .57349 .48307 L F
.61895 .45242 m .63299 .48077 L .65482 .48171 L .578 0 0 r
F
.61895 .45242 m .65482 .48171 L .62947 .45275 L F
.58759 .4837 m .62947 .45275 L .61895 .45242 L .582 0 0 r
F
.60189 .51201 m .65482 .48171 L .63299 .48077 L .589 0 0 r
F
.60189 .51201 m .62355 .51324 L .65482 .48171 L F
.58967 .48783 m .62355 .51324 L .60189 .51201 L .57 0 0 r
F
.58759 .4837 m .59159 .48699 L .58967 .48783 L F
.59159 .48699 m .62355 .51324 L .58967 .48783 L F
.69473 .46742 m .6659 .43438 L .65194 .44836 L p 0 .349 .782 r
F P
0 g
s
.65194 .44836 m .68087 .48146 L .69473 .46742 L p 0 .349 .782 r
F P
0 g
s
.69473 .46742 m .71012 .46092 L .68104 .42756 L p 0 .319 .936 r
F P
0 g
s
.68104 .42756 m .6659 .43438 L .69473 .46742 L p 0 .319 .936 r
F P
0 g
s
.62293 .41516 m .65194 .44836 L .6659 .43438 L p 0 .349 .782 r
F P
0 g
s
.68087 .48146 m .65194 .44836 L .63792 .46241 L p 0 .349 .782 r
F P
0 g
s
.65194 .44836 m .62293 .41516 L .60882 .42916 L p 0 .349 .782 r
F P
0 g
s
.60882 .42916 m .63792 .46241 L .65194 .44836 L p 0 .349 .782 r
F P
0 g
s
.59802 .48417 m .62947 .45275 L .65482 .48171 L .856 0 0 r
F
.63792 .46241 m .66694 .49556 L .68087 .48146 L p 0 .349 .782 r
F P
0 g
s
.69647 .42061 m .68104 .42756 L .71012 .46092 L p 0 .319 .936 r
F P
0 g
s
.71012 .46092 m .72579 .45429 L .69647 .42061 L p 0 .319 .936 r
F P
0 g
s
.72579 .45429 m .69647 .42061 L .68232 .43483 L p 0 .349 .781 r
F P
0 g
s
.72347 .50035 m .7391 .49416 L .71012 .46092 L p 0 .319 .936 r
F P
0 g
s
.71012 .46092 m .69473 .46742 L .72347 .50035 L p 0 .319 .936 r
F P
0 g
s
.72579 .45429 m .71012 .46092 L .7391 .49416 L p 0 .319 .936 r
F P
0 g
s
.71174 .46856 m .72579 .45429 L p .70765 .44617 L 0 .349 .781 r
F P
0 g
s
.68232 .43483 m .69945 .45447 L p .70765 .44617 L 0 .349 .781 r
F P
0 g
s
.69945 .45447 m .71174 .46856 L p .70765 .44617 L 0 .349 .781 r
F P
0 g
s
.66694 .49556 m .63792 .46241 L .65288 .45582 L p 0 .318 .938 r
F P
0 g
s
.7097 .51445 m .68087 .48146 L .66694 .49556 L p 0 .349 .782 r
F P
0 g
s
.65288 .45582 m .68214 .48929 L .66694 .49556 L p 0 .318 .938 r
F P
0 g
s
.65482 .48171 m .62355 .51324 L p .66949 .48477 L .217 0 0 r
F P
0 g
s
.72347 .50035 m .69473 .46742 L .68087 .48146 L p 0 .349 .782 r
F P
0 g
s
.68214 .48929 m .65288 .45582 L .66812 .44911 L p 0 .318 .938 r
F P
0 g
s
.68087 .48146 m .7097 .51445 L .72347 .50035 L p 0 .349 .782 r
F P
0 g
s
.66812 .44911 m .69762 .4829 L .68214 .48929 L p 0 .318 .938 r
F P
0 g
s
.72579 .45429 m .71174 .46856 L .69945 .45447 L p 0 .349 .781 r
F P
0 g
s
.69945 .45447 m .68232 .43483 L p .70765 .44617 L 0 .349 .781 r
F P
0 g
s
.70765 .44617 m .72579 .45429 L .69945 .45447 L 0 .349 .781 r
F
.71174 .46856 m .68232 .43483 L .66812 .44911 L p F P
0 g
s
.66812 .44911 m .69762 .4829 L .71174 .46856 L p 0 .349 .781 r
F P
0 g
s
.71174 .46856 m .69762 .4829 L .66812 .44911 L p 0 .349 .781 r
F P
0 g
s
.66812 .44911 m .68232 .43483 L .71174 .46856 L p 0 .349 .781 r
F P
0 g
s
.7391 .49416 m .72347 .50035 L .75161 .53259 L p 0 .319 .936 r
F P
0 g
s
.73535 .53143 m .75161 .53259 L .72347 .50035 L closepath p 0 .349 .782 r
F P
0 g
s
.71565 .53002 m .73535 .53143 L .72347 .50035 L p 0 .349 .782 r
F P
0 g
s
.72347 .50035 m .7391 .49416 L .72523 .50837 L p 0 .05 .218 r
F P
0 g
s
.72523 .50837 m .7391 .49416 L .72347 .50035 L p 0 .05 .218 r
F P
0 g
s
.75161 .53259 m .76747 .52671 L .7391 .49416 L p 0 .319 .936 r
F P
0 g
s
.7391 .49416 m .76747 .52671 L .78362 .52071 L p 0 .319 .936 r
F P
0 g
s
.78362 .52071 m .75502 .48786 L .7391 .49416 L p 0 .319 .936 r
F P
0 g
s
.72523 .50837 m .7391 .49416 L .75502 .48786 L p 0 .05 .218 r
F P
0 g
s
.7391 .49416 m .72523 .50837 L .74106 .50219 L p 0 .05 .218 r
F P
0 g
s
.75502 .48786 m .74106 .50219 L .72523 .50837 L p 0 .05 .218 r
F P
0 g
s
.74106 .50219 m .71174 .46856 L .69762 .4829 L p 0 .349 .781 r
F P
0 g
s
.69762 .4829 m .71174 .46856 L .74106 .50219 L p 0 .349 .781 r
F P
0 g
s
.7134 .47639 m .69762 .4829 L .66812 .44911 L p 0 .318 .938 r
F P
0 g
s
.66812 .44911 m .68364 .44227 L .7134 .47639 L p 0 .318 .938 r
F P
0 g
s
.7391 .49416 m .75502 .48786 L .72579 .45429 L p 0 .319 .936 r
F P
0 g
s
.75502 .48786 m .72579 .45429 L .71174 .46856 L p 0 .349 .781 r
F P
0 g
s
.74106 .50219 m .75502 .48786 L .7391 .49416 L p 0 .05 .218 r
F P
0 g
s
.71174 .46856 m .74106 .50219 L .75502 .48786 L p 0 .349 .781 r
F P
0 g
s
.75502 .48786 m .74106 .50219 L .71174 .46856 L p 0 .349 .781 r
F P
0 g
s
.71174 .46856 m .72579 .45429 L .75502 .48786 L p 0 .349 .781 r
F P
0 g
s
.72948 .46975 m .7134 .47639 L .68364 .44227 L p 0 .318 .938 r
F P
0 g
s
.68232 .43483 m .69647 .42061 L .72579 .45429 L p 0 .349 .781 r
F P
0 g
s
.68364 .44227 m .69946 .43529 L .72948 .46975 L p 0 .318 .938 r
F P
0 g
s
.68481 .48795 m .71694 .45536 L p .66949 .48477 L .217 0 0 r
F P
0 g
s
.62355 .51324 m .6536 .50084 L p .66949 .48477 L .217 0 0 r
F P
0 g
s
.6536 .50084 m .68481 .48795 L p .66949 .48477 L .217 0 0 r
F P
0 g
s
.71694 .45536 m .6853 .46878 L p .66949 .48477 L .217 0 0 r
F P
0 g
s
.6853 .46878 m .65482 .48171 L p .66949 .48477 L .217 0 0 r
F P
0 g
s
.68104 .42756 m .69647 .42061 L .66705 .38683 L p 0 .319 .936 r
F P
0 g
s
.68232 .43483 m .69647 .42061 L p .6838 .41492 L 0 .349 .781 r
F P
0 g
s
.6659 .43438 m .68104 .42756 L .65187 .3941 L p 0 .319 .936 r
F P
0 g
s
.65187 .3941 m .63697 .40123 L .6659 .43438 L p 0 .319 .936 r
F P
0 g
s
.66705 .38683 m .65187 .3941 L .68104 .42756 L p 0 .319 .936 r
F P
0 g
s
.65282 .40098 m .67375 .42499 L p .6838 .41492 L 0 .349 .781 r
F P
0 g
s
.67375 .42499 m .68232 .43483 L p .6838 .41492 L 0 .349 .781 r
F P
0 g
s
.69647 .42061 m .68232 .43483 L .67375 .42499 L p 0 .349 .781 r
F P
0 g
s
.67375 .42499 m .65282 .40098 L p .6838 .41492 L 0 .349 .781 r
F P
0 g
s
.6838 .41492 m .69647 .42061 L .67375 .42499 L 0 .349 .781 r
F
.6659 .43438 m .63697 .40123 L .62293 .41516 L p 0 .349 .782 r
F P
0 g
s
.65282 .40098 m .63851 .41521 L p .66962 .42914 L 0 .349 .781 r
F P
0 g
s
.68232 .43483 m .67375 .42499 L p .66962 .42914 L 0 .349 .781 r
F P
0 g
s
.66812 .44911 m .68232 .43483 L p .66962 .42914 L 0 .349 .781 r
F P
0 g
s
.63851 .41521 m .65951 .43926 L p .66962 .42914 L 0 .349 .781 r
F P
0 g
s
.65951 .43926 m .66812 .44911 L p .66962 .42914 L 0 .349 .781 r
F P
0 g
s
.68232 .43483 m .66812 .44911 L .63851 .41521 L p 0 .349 .781 r
F P
0 g
s
.63851 .41521 m .65282 .40098 L .68232 .43483 L p 0 .349 .781 r
F P
0 g
s
.69071 .42525 m .62947 .45275 L .64532 .47086 L p .578 0 0 r
F P
0 g
s
.59802 .48417 m .65482 .48171 L .62355 .51324 L .856 0 0 r
F
.62355 .51324 m .65482 .48171 L .62947 .45275 L p F P
0 g
s
.62353 .42225 m .65288 .45582 L .63792 .46241 L p 0 .318 .938 r
F P
0 g
s
.62947 .45275 m .59802 .48417 L .62355 .51324 L p .856 0 0 r
F P
0 g
s
.64532 .47086 m .65482 .48171 L p .69071 .42525 L .578 0 0 r
F P
0 g
s
.62355 .51324 m .59802 .48417 L .65839 .45773 L p .57 0 0 r
F P
0 g
s
.62572 .49056 m .65839 .45773 L p .62764 .4712 L .187 0 0 r
F P
0 g
s
.65288 .45582 m .62353 .42225 L .63851 .41521 L p 0 .318 .938 r
F P
0 g
s
.63851 .41521 m .66812 .44911 L .65288 .45582 L p 0 .318 .938 r
F P
0 g
s
.68364 .44227 m .66812 .44911 L .63851 .41521 L p 0 .318 .938 r
F P
0 g
s
.67375 .42499 m .65282 .40098 L p .66962 .42914 L 0 .349 .781 r
F P
0 g
s
.63851 .41521 m .65378 .40803 L .68364 .44227 L p 0 .318 .938 r
F P
0 g
s
.69946 .43529 m .68364 .44227 L .65378 .40803 L p 0 .318 .938 r
F P
0 g
s
.69647 .42061 m .66705 .38683 L .65282 .40098 L p 0 .349 .781 r
F P
0 g
s
.65282 .40098 m .66705 .38683 L .69647 .42061 L p 0 .349 .781 r
F P
0 g
s
.65378 .40803 m .66934 .40072 L .69946 .43529 L p 0 .318 .938 r
F P
0 g
s
.65839 .45773 m .69071 .42525 L p .62764 .4712 L .187 0 0 r
F P
0 g
s
.69071 .42525 m .65839 .45773 L .62764 .4712 L p .187 0 0 r
F P
0 g
s
.63792 .46241 m .60882 .42916 L .62353 .42225 L p 0 .318 .938 r
F P
0 g
s
.62764 .4712 m .64362 .45519 L .59802 .48417 L .187 0 0 r
F
.62764 .4712 m .59802 .48417 L p .64362 .45519 L F P
0 g
s
.62764 .4712 m .69071 .42525 L .64362 .45519 L .187 0 0 r
F
.64362 .45519 m .69071 .42525 L .62764 .4712 L F
.57932 .48333 m .58759 .4837 L .60189 .51201 L .57 0 0 r
F
.57363 .4761 m .58759 .4837 L .57932 .48333 L F
.58759 .4837 m .59802 .48417 L .62355 .51324 L F
.5559 .51531 m .56624 .51593 L .59802 .48417 L .582 0 0 r
F
.59279 .48394 m .59802 .48417 L .62947 .45275 L F
.5559 .51531 m .59802 .48417 L .59279 .48394 L F
.56624 .51593 m .59542 .50348 L p .62764 .4712 L .187 0 0 r
F P
0 g
s
.59542 .50348 m .62572 .49056 L p .62764 .4712 L .187 0 0 r
F P
0 g
s
.62947 .45275 m .59802 .48417 L p .64362 .45519 L .187 0 0 r
F P
0 g
s
.65951 .43926 m .62947 .45275 L p .64362 .45519 L .187 0 0 r
F P
0 g
s
.59802 .48417 m .62947 .45275 L .65951 .43926 L p .187 0 0 r
F P
0 g
s
.69071 .42525 m .65951 .43926 L p .64362 .45519 L .187 0 0 r
F P
0 g
s
.65951 .43926 m .69071 .42525 L p .64362 .45519 L .187 0 0 r
F P
0 g
s
.59802 .48417 m .65951 .43926 L .64362 .45519 L .187 0 0 r
F
.59802 .48417 m .56624 .51593 L p .62764 .4712 L F P
0 g
s
.5559 .51531 m .59279 .48394 L .58759 .4837 L .582 0 0 r
F
.59279 .48394 m .62947 .45275 L .58759 .4837 L F
.56253 .47006 m .57363 .4761 L .57322 .49628 L .57 0 0 r
F
.54196 .50758 m .5559 .51531 L .58759 .4837 L .765 0 0 r
F
.5806 .4799 m .58759 .4837 L .61895 .45242 L F
.54196 .50758 m .58759 .4837 L .5806 .4799 L F
.55983 .46341 m .57363 .4761 L .56253 .47006 L .57 0 0 r
F
.5281 .49481 m .60497 .44495 L .59122 .43234 L .831 0 0 r
F
.55983 .46341 m .59122 .43234 L .60497 .44495 L F
.57212 .45773 m .59122 .43234 L .59461 .43545 L .157 0 0 r
F
.6037 .42644 m .59122 .43234 L .60497 .44495 L .578 0 0 r
F
.59461 .43545 m .59122 .43234 L .6037 .42644 L .157 0 0 r
F
.5281 .49481 m .54196 .50758 L .60497 .44495 L .831 0 0 r
F
.55983 .46341 m .60497 .44495 L .57363 .4761 L F
.56417 .4656 m .56595 .46058 L .57212 .45773 L .157 0 0 r
F
.56595 .46058 m .59122 .43234 L .57212 .45773 L F
.6037 .42644 m .59122 .43234 L .55983 .46341 L p F P
0 g
s
.56595 .46058 m .6037 .42644 L .55983 .46341 L .157 0 0 r
F
.5281 .49481 m .59122 .43234 L .55012 .38543 L p .856 0 0 r
F P
0 g
s
.54545 .48124 m .53871 .48431 L .55193 .47123 L .157 0 0 r
F
.55956 .46772 m .55193 .47123 L .59122 .43234 L F
.54884 .4797 m .55193 .47123 L .55956 .46772 L F
.5402 .48934 m .54545 .48124 L .54884 .4797 L F
.54545 .48124 m .55193 .47123 L .54884 .4797 L F
.54196 .50758 m .5806 .4799 L .57363 .4761 L .765 0 0 r
F
.5806 .4799 m .61895 .45242 L .57363 .4761 L F
.60555 .42813 m .60497 .44495 L .61895 .45242 L .578 0 0 r
F
.6037 .42644 m .60497 .44495 L .60555 .42813 L F
.57363 .4761 m .60497 .44495 L .61895 .45242 L .765 0 0 r
F
.60742 .42913 m .61895 .45242 L .62947 .45275 L .578 0 0 r
F
.60555 .42813 m .61895 .45242 L .60742 .42913 L F
.58759 .4837 m .61895 .45242 L .62947 .45275 L .582 0 0 r
F
.57363 .4761 m .61895 .45242 L .58759 .4837 L .765 0 0 r
F
.60742 .42913 m .62947 .45275 L .60882 .42916 L .578 0 0 r
F
.54531 .49216 m .60882 .42916 L .62947 .45275 L .856 0 0 r
F
.54207 .49106 m .60555 .42813 L .60742 .42913 L .764 0 0 r
F
.5402 .48934 m .60555 .42813 L .54207 .49106 L .831 0 0 r
F
.54393 .49209 m .60742 .42913 L .60882 .42916 L .576 0 0 r
F
.54207 .49106 m .60742 .42913 L .54393 .49209 L .764 0 0 r
F
.54393 .49209 m .60882 .42916 L .54531 .49216 L .576 0 0 r
F
.66934 .40072 m .60882 .42916 L .62947 .45275 L p .578 0 0 r
F P
0 g
s
.58759 .4837 m .62947 .45275 L .59802 .48417 L .582 0 0 r
F
.56624 .51593 m .62947 .45275 L .60882 .42916 L p .856 0 0 r
F P
0 g
s
.60882 .42916 m .54531 .49216 L .56624 .51593 L p .856 0 0 r
F P
0 g
s
.54531 .49216 m .60882 .42916 L .66934 .40072 L p .161 0 0 r
F P
0 g
s
.56928 .46838 m .55598 .48157 L .57033 .47509 L p 0 .05 .112 r
F P
0 g
s
.55088 .47877 m .55956 .46772 L .56417 .4656 L .157 0 0 r
F
.5402 .48934 m .54884 .4797 L .55088 .47877 L F
.54884 .4797 m .55956 .46772 L .55088 .47877 L F
.55956 .46772 m .56595 .46058 L .56417 .4656 L F
.55983 .46341 m .5281 .49481 L p .56595 .46058 L F P
0 g
s
.55012 .38543 m .59122 .43234 L .55983 .46341 L p .856 0 0 r
F P
0 g
s
.55983 .46341 m .51844 .41633 L .55012 .38543 L p .856 0 0 r
F P
0 g
s
.5402 .48934 m .53871 .48431 L .54545 .48124 L .157 0 0 r
F
.5623 .37914 m .55012 .38543 L .59122 .43234 L p .578 0 0 r
F P
0 g
s
.59122 .43234 m .6037 .42644 L .5623 .37914 L p .578 0 0 r
F P
0 g
s
.55088 .47877 m .56417 .4656 L p .5441 .48186 L .157 0 0 r
F P
0 g
s
.56417 .4656 m .6037 .42644 L p .55649 .46913 L .157 0 0 r
F P
0 g
s
.5281 .49481 m .56417 .4656 L .55649 .46913 L .157 0 0 r
F
.5623 .37914 m .6037 .42644 L .55088 .47877 L p .856 0 0 r
F P
0 g
s
.5281 .49481 m .5402 .48934 L .55088 .47877 L p .157 0 0 r
F P
0 g
s
.5281 .49481 m .55088 .47877 L .5441 .48186 L .157 0 0 r
F
.55088 .47877 m .5402 .48934 L p .54391 .47085 L .856 0 0 r
F P
0 g
s
.54391 .47085 m .5623 .37914 L .55088 .47877 L .856 0 0 r
F
.5402 .48934 m .6037 .42644 L .60555 .42813 L .831 0 0 r
F
.55598 .48157 m .56928 .46838 L .55724 .45468 L p 0 .349 .782 r
F P
0 g
s
.5402 .48934 m .5281 .49481 L .53871 .48431 L .157 0 0 r
F
.55012 .38543 m .48642 .44755 L .5281 .49481 L p .856 0 0 r
F P
0 g
s
.5402 .48934 m .49822 .44169 L .5623 .37914 L p .856 0 0 r
F P
0 g
s
.55724 .45468 m .54391 .46785 L .55598 .48157 L p 0 .349 .782 r
F P
0 g
s
.55815 .46123 m .54391 .46785 L p .56324 .47314 L 0 .316 .942 r
F P
0 g
s
.54531 .49216 m .62947 .45275 L .56624 .51593 L .856 0 0 r
F
.66934 .40072 m .60404 .46585 L .54531 .49216 L p .161 0 0 r
F P
0 g
s
.57033 .47509 m .56708 .47139 L p .56324 .47314 L 0 .316 .942 r
F P
0 g
s
.56708 .47139 m .55815 .46123 L p .56324 .47314 L 0 .316 .942 r
F P
0 g
s
.55724 .45468 m .56928 .46838 L .58252 .45525 L p 0 .349 .782 r
F P
0 g
s
.58252 .45525 m .56928 .46838 L .58372 .46179 L p 0 .05 .112 r
F P
0 g
s
.56928 .46838 m .58372 .46179 L p .57661 .45988 L 0 .317 .941 r
F P
0 g
s
.55724 .45468 m .56607 .46473 L p .57661 .45988 L 0 .317 .941 r
F P
0 g
s
.56607 .46473 m .56928 .46838 L p .57661 .45988 L 0 .317 .941 r
F P
0 g
s
.56421 .47341 m .56324 .47314 L .55598 .48157 L 0 .316 .942 r
F
.55598 .48157 m .57033 .47509 L p .56421 .47341 L F P
0 g
s
.54391 .46785 m .55277 .47791 L p .56324 .47314 L 0 .316 .942 r
F P
0 g
s
.55277 .47791 m .55598 .48157 L p .56324 .47314 L 0 .316 .942 r
F P
0 g
s
.57033 .47509 m .55598 .48157 L p .55656 .47618 L 0 .316 .942 r
F P
0 g
s
.55815 .46123 m .56708 .47139 L p .55656 .47618 L 0 .316 .942 r
F P
0 g
s
.56708 .47139 m .57033 .47509 L p .55656 .47618 L 0 .316 .942 r
F P
0 g
s
.54391 .46785 m .55815 .46123 L p .55656 .47618 L 0 .316 .942 r
F P
0 g
s
.55598 .48157 m .55277 .47791 L p .55656 .47618 L 0 .316 .942 r
F P
0 g
s
.55277 .47791 m .54391 .46785 L p .55656 .47618 L 0 .316 .942 r
F P
0 g
s
.58372 .46179 m .56928 .46838 L p .56989 .46297 L 0 .317 .941 r
F P
0 g
s
.58252 .45525 m .57051 .44157 L .55724 .45468 L p 0 .349 .782 r
F P
0 g
s
.57158 .44796 m .58048 .4581 L p .56989 .46297 L 0 .317 .941 r
F P
0 g
s
.58048 .4581 m .58372 .46179 L p .56989 .46297 L 0 .317 .941 r
F P
0 g
s
.55724 .45468 m .57158 .44796 L p .56989 .46297 L 0 .317 .941 r
F P
0 g
s
.56928 .46838 m .56607 .46473 L p .56989 .46297 L 0 .317 .941 r
F P
0 g
s
.56607 .46473 m .55724 .45468 L p .56989 .46297 L 0 .317 .941 r
F P
0 g
s
.47506 .36773 m .51476 .36322 L .50703 .33703 L .938 0 0 r
F
.47506 .36773 m .48308 .39382 L .51476 .36322 L F
.53643 .35818 m .51476 .36322 L .54008 .37088 L .578 0 0 r
F
.53643 .35818 m .50703 .33703 L .51476 .36322 L F
0 g
.51476 .36322 m
.53539 .39304 L
s
.59031 .50566 m
.60189 .51201 L
s
.54019 .35074 m .50703 .33703 L .53643 .35818 L .578 0 0 r
F
.50812 .38178 m .53643 .35818 L .54019 .35074 L .94 0 0 r
F
.49959 .39902 m .49426 .40981 L .48308 .39382 L .57 0 0 r
F
.50021 .386 m .48308 .39382 L .47506 .36773 L F
.50449 .38912 m .48731 .39289 L .50021 .386 L F
.48731 .39289 m .48308 .39382 L .50021 .386 L F
.50449 .38912 m .53643 .35818 L .54008 .37088 L .94 0 0 r
F
.50829 .40175 m .49426 .40981 L .49959 .39902 L .57 0 0 r
F
.50449 .38912 m .50829 .40175 L .49959 .39902 L F
.50449 .38912 m .49959 .39902 L .48308 .39382 L F
.47571 .41315 m .47222 .42037 L .50449 .38912 L .94 0 0 r
F
.5063 .38546 m .50449 .38912 L .53643 .35818 L F
.50812 .38178 m .50449 .38912 L .47506 .36773 L .57 0 0 r
F
.47571 .41315 m .50449 .38912 L .5063 .38546 L .94 0 0 r
F
.47222 .42037 m .54008 .37088 L .53643 .35818 L F
.56047 .37549 m .53643 .35818 L .54008 .37088 L .578 0 0 r
F
.57525 .36061 m .58944 .34677 L .56027 .31335 L p 0 .349 .782 r
F P
0 g
s
.56027 .31335 m .58944 .34677 L .60394 .33911 L p 0 .319 .936 r
F P
0 g
s
.56099 .37451 m .53643 .35818 L .56047 .37549 L .578 0 0 r
F
.56099 .37451 m .54019 .35074 L .53643 .35818 L F
.56027 .31335 m .54599 .32713 L .57525 .36061 L p 0 .349 .782 r
F P
0 g
s
.60394 .33911 m .57452 .30537 L .56027 .31335 L p 0 .319 .936 r
F P
0 g
s
.56099 .37451 m .57525 .36061 L .54599 .32713 L p 0 .349 .782 r
F P
0 g
s
.54599 .32713 m .53164 .34098 L .56099 .37451 L p 0 .349 .782 r
F P
0 g
s
.57931 .37611 m .57525 .36061 L .56099 .37451 L closepath p 0 .349 .782 r
F P
0 g
s
.57529 .36707 m .56099 .37451 L .57525 .36061 L p 0 .05 .1 r
F P
0 g
s
.57525 .36061 m .56099 .37451 L .57529 .36707 L p 0 .05 .1 r
F P
0 g
s
.57529 .36707 m .56099 .37451 L .53164 .34098 L p 0 .318 .938 r
F P
0 g
s
.57452 .30537 m .60394 .33911 L .61871 .33131 L p 0 .319 .936 r
F P
0 g
s
.61871 .33131 m .58904 .29723 L .57452 .30537 L p 0 .319 .936 r
F P
0 g
s
.61323 .37404 m .62793 .36664 L .60394 .33911 L p 0 .319 .936 r
F P
0 g
s
.60394 .33911 m .58944 .34677 L .61323 .37404 L p 0 .319 .936 r
F P
0 g
s
.61323 .37404 m .58944 .34677 L .59756 .3777 L p 0 .349 .782 r
F P
0 g
s
.57931 .37611 m .59756 .3777 L .58944 .34677 L p 0 .349 .782 r
F P
0 g
s
.58944 .34677 m .60394 .33911 L .58965 .35306 L p 0 .05 .1 r
F P
0 g
s
.58965 .35306 m .60394 .33911 L .58944 .34677 L p 0 .05 .1 r
F P
0 g
s
.61871 .33131 m .60394 .33911 L .62793 .36664 L p 0 .319 .936 r
F P
0 g
s
.58965 .35306 m .60394 .33911 L .61871 .33131 L p 0 .05 .1 r
F P
0 g
s
.60394 .33911 m .58965 .35306 L .60432 .34537 L p 0 .05 .1 r
F P
0 g
s
.60432 .34537 m .61871 .33131 L .60394 .33911 L p 0 .05 .1 r
F P
0 g
s
.61871 .33131 m .60432 .34537 L .58965 .35306 L p 0 .05 .1 r
F P
0 g
s
.60432 .34537 m .61871 .33131 L .59768 .30716 L p 0 .349 .781 r
F P
0 g
s
.59768 .30716 m .58904 .29723 L p .59348 .31123 L 0 .349 .781 r
F P
0 g
s
.60432 .34537 m .59768 .30716 L .59348 .31123 L 0 .349 .781 r
F
.61871 .33131 m .60432 .34537 L p .59348 .31123 L F P
0 g
s
.58904 .29723 m .59768 .30716 L p .59348 .31123 L 0 .349 .781 r
F P
0 g
s
.59768 .30716 m .61871 .33131 L p .59348 .31123 L 0 .349 .781 r
F P
0 g
s
.58904 .29723 m .57456 .31124 L .58323 .32118 L p 0 .349 .781 r
F P
0 g
s
.58323 .32118 m .60432 .34537 L p .59348 .31123 L 0 .349 .781 r
F P
0 g
s
.59348 .31123 m .58904 .29723 L .58323 .32118 L 0 .349 .781 r
F
.57456 .31124 m .58904 .29723 L p .59348 .31123 L F P
0 g
s
.60432 .34537 m .58323 .32118 L p .59348 .31123 L 0 .349 .781 r
F P
0 g
s
.58323 .32118 m .57456 .31124 L p .59348 .31123 L 0 .349 .781 r
F P
0 g
s
.58944 .34677 m .57525 .36061 L .57931 .37611 L p 0 .349 .782 r
F P
0 g
s
.58965 .35306 m .57525 .36061 L .58944 .34677 L p 0 .05 .1 r
F P
0 g
s
.58944 .34677 m .57525 .36061 L .58965 .35306 L p 0 .05 .1 r
F P
0 g
s
.57525 .36061 m .58965 .35306 L .57529 .36707 L p 0 .05 .1 r
F P
0 g
s
.57529 .36707 m .58965 .35306 L .57525 .36061 L p 0 .05 .1 r
F P
0 g
s
.58986 .3595 m .57529 .36707 L .58965 .35306 L p 0 .05 .1 r
F P
0 g
s
.58965 .35306 m .60432 .34537 L .58986 .3595 L p 0 .05 .1 r
F P
0 g
s
.58965 .35306 m .57529 .36707 L .58986 .3595 L p 0 .05 .1 r
F P
0 g
s
.58986 .3595 m .60432 .34537 L .58965 .35306 L p 0 .05 .1 r
F P
0 g
s
.58986 .3595 m .60432 .34537 L .57456 .31124 L p 0 .349 .781 r
F P
0 g
s
.57456 .31124 m .60432 .34537 L .58986 .3595 L p 0 .349 .781 r
F P
0 g
s
.57456 .31124 m .56001 .3253 L .58986 .3595 L p 0 .349 .781 r
F P
0 g
s
.58986 .3595 m .56001 .3253 L .57456 .31124 L p 0 .349 .781 r
F P
0 g
s
.59831 .31919 m .54019 .35074 L p .56099 .37451 L .578 0 0 r
F P
0 g
s
.50829 .40175 m .54008 .37088 L .55012 .38543 L .88 0 0 r
F
.50829 .40175 m .50394 .42367 L .49426 .40981 L .57 0 0 r
F
.55012 .38543 m .51844 .41633 L .50394 .42367 L p .1 0 0 r
F P
0 g
s
.50829 .40175 m .51844 .41633 L .50394 .42367 L .57 0 0 r
F
.47616 .43296 m .55012 .38543 L .54008 .37088 L .88 0 0 r
F
.56095 .37719 m .54008 .37088 L .55012 .38543 L .578 0 0 r
F
.50449 .38912 m .54008 .37088 L .50829 .40175 L .94 0 0 r
F
.47222 .42037 m .47616 .43296 L .54008 .37088 L F
.56047 .37549 m .54008 .37088 L .56095 .37719 L .578 0 0 r
F
.50829 .40175 m .55012 .38543 L .51844 .41633 L .88 0 0 r
F
.47616 .43296 m .48642 .44755 L .55012 .38543 L F
.49681 .4371 m .56099 .37451 L .54019 .35074 L p .856 0 0 r
F P
0 g
s
.49681 .4371 m .54019 .35074 L .56099 .37451 L .856 0 0 r
F
.47571 .41315 m .5063 .38546 L .50812 .38178 L .94 0 0 r
F
.5063 .38546 m .53643 .35818 L .50812 .38178 L F
.50812 .38178 m .53643 .35818 L .50449 .38912 L F
.50812 .38178 m .54019 .35074 L .53643 .35818 L F
.54019 .35074 m .47571 .41315 L .49681 .4371 L p .856 0 0 r
F P
0 g
s
.49681 .4371 m .47571 .41315 L .54019 .35074 L .856 0 0 r
F
.53164 .34098 m .54569 .33321 L .57529 .36707 L p 0 .318 .938 r
F P
0 g
s
.58986 .3595 m .57529 .36707 L .54569 .33321 L p 0 .318 .938 r
F P
0 g
s
.54569 .33321 m .56001 .3253 L .58986 .3595 L p 0 .318 .938 r
F P
0 g
s
.60847 .36116 m .58986 .3595 L .60432 .34537 L closepath p 0 .349 .781 r
F P
0 g
s
.507 .43217 m .5179 .42035 L .50041 .43547 L .1 0 0 r
F
.5179 .42035 m .51047 .4241 L .48642 .44755 L F
.5179 .42035 m .55012 .38543 L .51047 .4241 L F
.5179 .42035 m .5623 .37914 L .55012 .38543 L F
.53182 .45411 m .54519 .44096 L .53312 .42723 L p 0 .349 .782 r
F P
0 g
s
.53312 .42723 m .51972 .44035 L .53182 .45411 L p 0 .349 .782 r
F P
0 g
s
.53312 .42723 m .51972 .44035 L .53375 .43347 L p 0 .05 .1 r
F P
0 g
s
.507 .43217 m .5224 .41808 L .5179 .42035 L .1 0 0 r
F
.50899 .43117 m .5224 .41808 L .507 .43217 L F
.5224 .41808 m .5623 .37914 L .5179 .42035 L F
.48642 .44755 m .55012 .38543 L .5623 .37914 L p F P
0 g
s
.4991 .43612 m .51492 .42185 L .50568 .43283 L .1 0 0 r
F
.5224 .41808 m .49822 .44169 L p .51492 .42185 L F P
0 g
s
.5623 .37914 m .5224 .41808 L p .51492 .42185 L .1 0 0 r
F P
0 g
s
.49822 .44169 m .48642 .44755 L p .4991 .43612 L .1 0 0 r
F P
0 g
s
.4991 .43612 m .50568 .43283 L .49822 .44169 L .1 0 0 r
F
.49822 .44169 m .50899 .43117 L .507 .43217 L F
.49822 .44169 m .507 .43217 L .48642 .44755 L F
.507 .43217 m .50041 .43547 L .48642 .44755 L F
.49684 .43973 m .5623 .37914 L .49822 .44169 L .881 0 0 r
F
.56095 .37719 m .55012 .38543 L .5623 .37914 L .578 0 0 r
F
.49684 .43973 m .56095 .37719 L .5623 .37914 L .881 0 0 r
F
.49633 .43805 m .56095 .37719 L .49684 .43973 L .941 0 0 r
F
.49633 .43805 m .56047 .37549 L .56095 .37719 L F
.49681 .4371 m .50752 .42674 L .49633 .43805 L .931 0 0 r
F
.52085 .41384 m .56047 .37549 L .52054 .41444 L F
.52085 .41384 m .56099 .37451 L .56047 .37549 L F
.52097 .4136 m .56099 .37451 L .52085 .41384 L F
.5076 .42658 m .56099 .37451 L .50752 .42674 L F
.56099 .37451 m .54773 .38744 L .55974 .40115 L p 0 .349 .782 r
F P
0 g
s
.54646 .41416 m .55974 .40115 L .54773 .38744 L p 0 .349 .782 r
F P
0 g
s
.54773 .38744 m .53441 .40043 L .54646 .41416 L p 0 .349 .782 r
F P
0 g
s
.53312 .42723 m .54646 .41416 L .53441 .40043 L p 0 .349 .782 r
F P
0 g
s
.53441 .40043 m .52103 .41348 L .53312 .42723 L p 0 .349 .782 r
F P
0 g
s
.56099 .37451 m .52103 .41348 L p .55749 .39113 L .1 0 0 r
F P
0 g
s
.54519 .44096 m .5585 .42788 L .54646 .41416 L p 0 .349 .782 r
F P
0 g
s
.54646 .41416 m .53312 .42723 L .54519 .44096 L p 0 .349 .782 r
F P
0 g
s
.54725 .42024 m .53506 .40635 L .52103 .41348 L p 0 .317 .941 r
F P
0 g
s
.50752 .42674 m .52097 .4136 L .52085 .41384 L .931 0 0 r
F
.52103 .41348 m .52426 .41715 L p .52798 .41527 L 0 .317 .941 r
F P
0 g
s
.50752 .42674 m .52085 .41384 L .50711 .42753 L .931 0 0 r
F
.52085 .41384 m .52054 .41444 L .50711 .42753 L F
.51972 .44035 m .53312 .42723 L .52103 .41348 L p 0 .349 .782 r
F P
0 g
s
.52103 .41348 m .53506 .40635 L .53831 .41006 L p 0 .317 .941 r
F P
0 g
s
.52798 .41527 m .52103 .41348 L .53831 .41006 L 0 .317 .941 r
F
.52426 .41715 m .52103 .41348 L p .52798 .41527 L F P
0 g
s
.52103 .41348 m .5076 .42658 L .51972 .44035 L p 0 .349 .782 r
F P
0 g
s
.5585 .42788 m .57174 .41484 L .55974 .40115 L p 0 .349 .782 r
F P
0 g
s
.55974 .40115 m .54646 .41416 L .5585 .42788 L p 0 .349 .782 r
F P
0 g
s
.56164 .41312 m .54725 .42024 L .53506 .40635 L p 0 .317 .941 r
F P
0 g
s
.53831 .41006 m .54725 .42024 L p .52798 .41527 L 0 .317 .941 r
F P
0 g
s
.53312 .42723 m .54725 .42024 L p .52798 .41527 L 0 .317 .941 r
F P
0 g
s
.52426 .41715 m .53312 .42723 L p .52798 .41527 L 0 .317 .941 r
F P
0 g
s
.54725 .42024 m .53312 .42723 L .52426 .41715 L p 0 .317 .941 r
F P
0 g
s
.54725 .42024 m .52426 .41715 L .52798 .41527 L 0 .317 .941 r
F
.52153 .41956 m .53506 .40635 L .54725 .42024 L p 0 .349 .781 r
F P
0 g
s
.52103 .41348 m .5076 .42658 L p .53236 .40899 L .1 0 0 r
F P
0 g
s
.53506 .40635 m .54725 .42024 L .56164 .41312 L p 0 .317 .941 r
F P
0 g
s
.57051 .44157 m .5585 .42788 L .54519 .44096 L p 0 .349 .782 r
F P
0 g
s
.5585 .42788 m .54519 .44096 L .55942 .43411 L p 0 .05 .1 r
F P
0 g
s
.55942 .43411 m .54519 .44096 L .5585 .42788 L p 0 .05 .1 r
F P
0 g
s
.55942 .43411 m .54519 .44096 L .53312 .42723 L p 0 .317 .941 r
F P
0 g
s
.53312 .42723 m .54519 .44096 L .55942 .43411 L p 0 .317 .941 r
F P
0 g
s
.53312 .42723 m .54725 .42024 L .55942 .43411 L p 0 .317 .941 r
F P
0 g
s
.55942 .43411 m .54725 .42024 L .53312 .42723 L p 0 .317 .941 r
F P
0 g
s
.53375 .43347 m .54725 .42024 L .53312 .42723 L p 0 .05 .1 r
F P
0 g
s
.51972 .44035 m .53312 .42723 L .54725 .42024 L p 0 .05 .1 r
F P
0 g
s
.54725 .42024 m .53375 .43347 L .51972 .44035 L p 0 .05 .1 r
F P
0 g
s
.53375 .43347 m .54725 .42024 L .53506 .40635 L p 0 .349 .781 r
F P
0 g
s
.51685 .42192 m .52695 .41427 L .5076 .42658 L .1 0 0 r
F
.53506 .40635 m .54935 .3991 L .56164 .41312 L p 0 .317 .941 r
F P
0 g
s
.53506 .40635 m .52153 .41956 L .53375 .43347 L p 0 .349 .781 r
F P
0 g
s
.56164 .41312 m .54935 .3991 L .53506 .40635 L p 0 .317 .941 r
F P
0 g
s
.5076 .42658 m .51453 .4284 L .52068 .42063 L 0 .316 .942 r
F
.50752 .42674 m .50711 .42753 L .49633 .43805 L .931 0 0 r
F
.52479 .42327 m .52153 .41956 L p .51453 .4284 L 0 .316 .942 r
F P
0 g
s
.59756 .3777 m .57931 .37611 L .57297 .3882 L p 0 .349 .782 r
F P
0 g
s
.57931 .37611 m .56099 .37451 L .57297 .3882 L closepath p 0 .349 .782 r
F P
0 g
s
.58738 .38089 m .57297 .3882 L .56099 .37451 L p 0 .318 .938 r
F P
0 g
s
.55974 .40115 m .57297 .3882 L .56099 .37451 L p 0 .349 .782 r
F P
0 g
s
.56099 .37451 m .57297 .3882 L .58738 .38089 L p 0 .318 .938 r
F P
0 g
s
.57297 .3882 m .58494 .40187 L .59756 .3777 L p 0 .349 .782 r
F P
0 g
s
.58494 .40187 m .57297 .3882 L .58738 .38089 L p 0 .318 .938 r
F P
0 g
s
.60854 .37866 m .59756 .3777 L .58494 .40187 L closepath p 0 .349 .782 r
F P
0 g
s
.62793 .36664 m .61323 .37404 L .63697 .40123 L p 0 .319 .936 r
F P
0 g
s
.60854 .37866 m .6086 .39034 L .63697 .40123 L p 0 .349 .782 r
F P
0 g
s
.63697 .40123 m .61323 .37404 L .60854 .37866 L p 0 .349 .782 r
F P
0 g
s
.58494 .40187 m .6086 .39034 L .60854 .37866 L closepath p 0 .349 .782 r
F P
0 g
s
.6232 .3713 m .60854 .37866 L .58494 .40187 L p 0 .05 .1 r
F P
0 g
s
.58494 .40187 m .59944 .3947 L .6232 .3713 L p 0 .05 .1 r
F P
0 g
s
.59944 .3947 m .58494 .40187 L .60854 .37866 L p 0 .05 .1 r
F P
0 g
s
.58738 .38089 m .59944 .3947 L .58494 .40187 L p 0 .318 .938 r
F P
0 g
s
.57174 .41484 m .58494 .40187 L .57297 .3882 L p 0 .349 .782 r
F P
0 g
s
.57297 .3882 m .58494 .40187 L .59944 .3947 L p 0 .318 .938 r
F P
0 g
s
.59944 .3947 m .58738 .38089 L .57297 .3882 L p 0 .318 .938 r
F P
0 g
s
.56099 .37451 m .57529 .36707 L .58738 .38089 L p 0 .318 .938 r
F P
0 g
s
.58738 .38089 m .57529 .36707 L .56099 .37451 L p 0 .318 .938 r
F P
0 g
s
.57642 .37264 m .58864 .38662 L .57517 .39984 L p 0 .349 .781 r
F P
0 g
s
.57517 .39984 m .58864 .38662 L .57642 .37264 L p 0 .349 .781 r
F P
0 g
s
.57297 .3882 m .55974 .40115 L .57174 .41484 L p 0 .349 .782 r
F P
0 g
s
.57517 .39984 m .56291 .38584 L .57642 .37264 L p 0 .349 .781 r
F P
0 g
s
.57642 .37264 m .56291 .38584 L .57517 .39984 L p 0 .349 .781 r
F P
0 g
s
.56291 .38584 m .57517 .39984 L .56164 .41312 L p 0 .349 .781 r
F P
0 g
s
.56164 .41312 m .57517 .39984 L .56291 .38584 L p 0 .349 .781 r
F P
0 g
s
.56164 .41312 m .54935 .3991 L .56291 .38584 L p 0 .349 .781 r
F P
0 g
s
.56291 .38584 m .54935 .3991 L .56164 .41312 L p 0 .349 .781 r
F P
0 g
s
.59688 .41552 m .58494 .40187 L .57174 .41484 L p 0 .349 .782 r
F P
0 g
s
.57174 .41484 m .58373 .42852 L .59688 .41552 L p 0 .349 .782 r
F P
0 g
s
.58494 .40187 m .57174 .41484 L .58616 .40778 L p 0 .05 .1 r
F P
0 g
s
.58616 .40778 m .57174 .41484 L .58494 .40187 L p 0 .05 .1 r
F P
0 g
s
.58373 .42852 m .57174 .41484 L .5585 .42788 L p 0 .349 .782 r
F P
0 g
s
.57282 .42091 m .58616 .40778 L .57174 .41484 L p 0 .05 .1 r
F P
0 g
s
.57174 .41484 m .58616 .40778 L .57282 .42091 L p 0 .05 .1 r
F P
0 g
s
.58616 .40778 m .57282 .42091 L .58741 .41382 L p 0 .05 .1 r
F P
0 g
s
.58741 .41382 m .57282 .42091 L .58616 .40778 L p 0 .05 .1 r
F P
0 g
s
.57392 .42712 m .58741 .41382 L .57282 .42091 L p 0 .05 .1 r
F P
0 g
s
.57282 .42091 m .58741 .41382 L .57392 .42712 L p 0 .05 .1 r
F P
0 g
s
.57517 .39984 m .58741 .41382 L .57392 .42712 L p 0 .349 .781 r
F P
0 g
s
.57392 .42712 m .58741 .41382 L .57517 .39984 L p 0 .349 .781 r
F P
0 g
s
.57174 .41484 m .5585 .42788 L .57282 .42091 L p 0 .05 .1 r
F P
0 g
s
.57282 .42091 m .5585 .42788 L .57174 .41484 L p 0 .05 .1 r
F P
0 g
s
.5585 .42788 m .57051 .44157 L .58373 .42852 L p 0 .349 .782 r
F P
0 g
s
.55942 .43411 m .57282 .42091 L .5585 .42788 L p 0 .05 .1 r
F P
0 g
s
.5585 .42788 m .57282 .42091 L .55942 .43411 L p 0 .05 .1 r
F P
0 g
s
.57282 .42091 m .55942 .43411 L .57392 .42712 L p 0 .05 .1 r
F P
0 g
s
.57392 .42712 m .55942 .43411 L .57282 .42091 L p 0 .05 .1 r
F P
0 g
s
.57392 .42712 m .56164 .41312 L .57517 .39984 L p 0 .349 .781 r
F P
0 g
s
.57517 .39984 m .56164 .41312 L .57392 .42712 L p 0 .349 .781 r
F P
0 g
s
.54935 .3991 m .56164 .41312 L .57631 .40586 L p 0 .317 .941 r
F P
0 g
s
.57392 .42712 m .55942 .43411 L .54725 .42024 L p 0 .317 .941 r
F P
0 g
s
.53375 .43347 m .54725 .42024 L .55942 .43411 L p 0 .349 .781 r
F P
0 g
s
.54725 .42024 m .55942 .43411 L .57392 .42712 L p 0 .317 .941 r
F P
0 g
s
.54519 .44096 m .55724 .45468 L .57051 .44157 L p 0 .349 .782 r
F P
0 g
s
.55724 .45468 m .54519 .44096 L .55942 .43411 L p 0 .317 .941 r
F P
0 g
s
.54519 .44096 m .55724 .45468 L .57158 .44796 L p 0 .317 .941 r
F P
0 g
s
.54391 .46785 m .55724 .45468 L .54519 .44096 L p 0 .349 .782 r
F P
0 g
s
.57158 .44796 m .55942 .43411 L .54519 .44096 L p 0 .317 .941 r
F P
0 g
s
.54519 .44096 m .53182 .45411 L .54391 .46785 L p 0 .349 .782 r
F P
0 g
s
.53182 .45411 m .54519 .44096 L .55942 .43411 L p 0 .05 .1 r
F P
0 g
s
.54596 .44736 m .55942 .43411 L .54519 .44096 L p 0 .05 .1 r
F P
0 g
s
.55942 .43411 m .54596 .44736 L .53182 .45411 L p 0 .05 .1 r
F P
0 g
s
.54596 .44736 m .55942 .43411 L .54725 .42024 L p 0 .349 .781 r
F P
0 g
s
.54725 .42024 m .56164 .41312 L .57392 .42712 L p 0 .317 .941 r
F P
0 g
s
.57392 .42712 m .56164 .41312 L .54725 .42024 L p 0 .317 .941 r
F P
0 g
s
.54805 .42646 m .56164 .41312 L .54725 .42024 L p 0 .05 .1 r
F P
0 g
s
.54519 .44096 m .53182 .45411 L .54596 .44736 L p 0 .05 .1 r
F P
0 g
s
.54725 .42024 m .53375 .43347 L .54596 .44736 L p 0 .349 .781 r
F P
0 g
s
.53375 .43347 m .54725 .42024 L .56164 .41312 L p 0 .05 .1 r
F P
0 g
s
.56164 .41312 m .54805 .42646 L .53375 .43347 L p 0 .05 .1 r
F P
0 g
s
.54805 .42646 m .56164 .41312 L .54935 .3991 L p 0 .349 .781 r
F P
0 g
s
.51685 .42192 m .54118 .40708 L .54217 .40274 L .1 0 0 r
F
.56391 .3917 m .57631 .40586 L .56164 .41312 L p 0 .317 .941 r
F P
0 g
s
.56164 .41312 m .54935 .3991 L .56391 .3917 L p 0 .317 .941 r
F P
0 g
s
.53572 .41242 m .54935 .3991 L .56164 .41312 L p 0 .349 .781 r
F P
0 g
s
.53254 .41402 m .53708 .41108 L .51685 .42192 L .1 0 0 r
F
.57631 .40586 m .56391 .3917 L .54935 .3991 L p 0 .317 .941 r
F P
0 g
s
.54725 .42024 m .53375 .43347 L .52153 .41956 L p 0 .349 .781 r
F P
0 g
s
.5076 .42658 m .52153 .41956 L p .52104 .42515 L 0 .316 .942 r
F P
0 g
s
.51083 .43025 m .5076 .42658 L p .52104 .42515 L 0 .316 .942 r
F P
0 g
s
.52153 .41956 m .53375 .43347 L .51972 .44035 L p 0 .316 .942 r
F P
0 g
s
.53375 .43347 m .52153 .41956 L .53572 .41242 L p 0 .316 .942 r
F P
0 g
s
.52072 .41997 m .5076 .42658 L p .52068 .42063 L 0 .316 .942 r
F P
0 g
s
.52153 .41956 m .52072 .41997 L p .52068 .42063 L 0 .316 .942 r
F P
0 g
s
.53375 .43347 m .52479 .42327 L p .51453 .4284 L 0 .316 .942 r
F P
0 g
s
.51972 .44035 m .53375 .43347 L p .51453 .4284 L 0 .316 .942 r
F P
0 g
s
.5076 .42658 m .51083 .43025 L p .51453 .4284 L 0 .316 .942 r
F P
0 g
s
.51083 .43025 m .51972 .44035 L p .51453 .4284 L 0 .316 .942 r
F P
0 g
s
.51972 .44035 m .51083 .43025 L p .52104 .42515 L 0 .316 .942 r
F P
0 g
s
.5402 .48934 m .5281 .49481 L p .52183 .48366 L .562 0 0 r
F P
0 g
s
.54391 .46785 m .53182 .45411 L .54596 .44736 L p 0 .316 .942 r
F P
0 g
s
.58372 .46179 m .57158 .44796 L .55724 .45468 L p 0 .317 .941 r
F P
0 g
s
.54391 .46785 m .55724 .45468 L .57158 .44796 L p 0 .05 .1 r
F P
0 g
s
.55724 .45468 m .54391 .46785 L .55815 .46123 L p 0 .05 .1 r
F P
0 g
s
.57158 .44796 m .55815 .46123 L .54391 .46785 L p 0 .05 .1 r
F P
0 g
s
.53182 .45411 m .54391 .46785 L .55815 .46123 L p 0 .316 .942 r
F P
0 g
s
.52183 .48366 m .51324 .46838 L .53134 .47928 L .562 0 0 r
F
.51923 .46554 m .53134 .47928 L p .51324 .46838 L F P
0 g
s
.53134 .47928 m .5402 .48934 L p .52183 .48366 L .562 0 0 r
F P
0 g
s
.53052 .48107 m .54391 .46785 L .53182 .45411 L p 0 .349 .782 r
F P
0 g
s
.55815 .46123 m .54596 .44736 L .53182 .45411 L p 0 .316 .942 r
F P
0 g
s
.53182 .45411 m .5184 .46731 L .53052 .48107 L p 0 .349 .782 r
F P
0 g
s
.53182 .45411 m .54596 .44736 L p .52388 .46334 L 0 .05 .1 r
F P
0 g
s
.5184 .46731 m .52109 .46467 L p .52388 .46334 L 0 .05 .1 r
F P
0 g
s
.52109 .46467 m .53182 .45411 L p .52388 .46334 L 0 .05 .1 r
F P
0 g
s
.50711 .45179 m .51923 .46554 L p .50459 .45302 L .562 0 0 r
F P
0 g
s
.51324 .46838 m .50459 .45302 L .51923 .46554 L .562 0 0 r
F
.5184 .46731 m .53182 .45411 L .51972 .44035 L p 0 .349 .782 r
F P
0 g
s
.51972 .44035 m .50626 .45353 L .5184 .46731 L p 0 .349 .782 r
F P
0 g
s
.50626 .45353 m .5202 .44676 L p .5201 .44547 L 0 .05 .1 r
F P
0 g
s
.51972 .44035 m .50896 .45089 L p .5201 .44547 L 0 .05 .1 r
F P
0 g
s
.50896 .45089 m .50626 .45353 L p .5201 .44547 L 0 .05 .1 r
F P
0 g
s
.49822 .44169 m .50711 .45179 L p .50459 .45302 L .562 0 0 r
F P
0 g
s
.54205 .49362 m .5559 .51531 L .54196 .50758 L .562 0 0 r
F
.54207 .49106 m .54322 .49309 L .54205 .49362 L F
.54322 .49309 m .5559 .51531 L .54205 .49362 L F
.54393 .49209 m .56624 .51593 L .5559 .51531 L F
.54207 .49106 m .54393 .49209 L .5559 .51531 L F
.54393 .49209 m .54531 .49216 L .56624 .51593 L F
.56624 .51593 m .54531 .49216 L .55958 .48577 L p F P
0 g
s
.57033 .47509 m .58372 .46179 L .56928 .46838 L p 0 .05 .112 r
F P
0 g
s
.55815 .46123 m .57158 .44796 L .58372 .46179 L p 0 .349 .781 r
F P
0 g
s
.58372 .46179 m .57033 .47509 L .55815 .46123 L p 0 .349 .781 r
F P
0 g
s
.58372 .46179 m .57033 .47509 L .58495 .46848 L p 0 .05 .112 r
F P
0 g
s
.57033 .47509 m .58372 .46179 L .57158 .44796 L p 0 .349 .781 r
F P
0 g
s
.57266 .45449 m .58495 .46848 L .57033 .47509 L p 0 .316 .942 r
F P
0 g
s
.57158 .44796 m .55815 .46123 L .57033 .47509 L p 0 .349 .781 r
F P
0 g
s
.55815 .46123 m .57033 .47509 L .58495 .46848 L p 0 .316 .942 r
F P
0 g
s
.55958 .48577 m .57412 .47925 L p .57542 .50377 L .562 0 0 r
F P
0 g
s
.5714 .48195 m .58495 .46848 L .57033 .47509 L p 0 .05 .112 r
F P
0 g
s
.58495 .46848 m .57266 .45449 L .55815 .46123 L p 0 .316 .942 r
F P
0 g
s
.58495 .46848 m .57266 .45449 L p .57166 .47645 L 0 .349 .781 r
F P
0 g
s
.5714 .48195 m .57412 .47925 L p .57166 .47645 L 0 .349 .781 r
F P
0 g
s
.57412 .47925 m .58495 .46848 L p .57166 .47645 L 0 .349 .781 r
F P
0 g
s
.57051 .44157 m .58252 .45525 L .5957 .44217 L p 0 .349 .782 r
F P
0 g
s
.5957 .44217 m .58252 .45525 L .59705 .44855 L p 0 .05 .112 r
F P
0 g
s
.58372 .46179 m .59705 .44855 L .58252 .45525 L p 0 .05 .112 r
F P
0 g
s
.59705 .44855 m .58372 .46179 L .59843 .45507 L p 0 .05 .112 r
F P
0 g
s
.5957 .44217 m .58373 .42852 L .57051 .44157 L p 0 .349 .782 r
F P
0 g
s
.58618 .44111 m .59843 .45507 L .58372 .46179 L p 0 .317 .941 r
F P
0 g
s
.57158 .44796 m .58372 .46179 L .59843 .45507 L p 0 .317 .941 r
F P
0 g
s
.58495 .46848 m .59843 .45507 L .58372 .46179 L p 0 .05 .112 r
F P
0 g
s
.59843 .45507 m .58618 .44111 L .57158 .44796 L p 0 .317 .941 r
F P
0 g
s
.59843 .45507 m .58495 .46848 L .59984 .46175 L p 0 .05 .112 r
F P
0 g
s
.58495 .46848 m .59843 .45507 L .58618 .44111 L p 0 .349 .781 r
F P
0 g
s
.58372 .46179 m .57158 .44796 L .58618 .44111 L p 0 .317 .941 r
F P
0 g
s
.57266 .45449 m .58618 .44111 L .59843 .45507 L p 0 .349 .781 r
F P
0 g
s
.59843 .45507 m .58495 .46848 L .57266 .45449 L p 0 .349 .781 r
F P
0 g
s
.58745 .44763 m .59984 .46175 L .58495 .46848 L p 0 .316 .942 r
F P
0 g
s
.57412 .47925 m .58894 .47261 L p .58477 .49137 L .562 0 0 r
F P
0 g
s
.5862 .47533 m .59984 .46175 L .58495 .46848 L p 0 .05 .112 r
F P
0 g
s
.58618 .44111 m .57266 .45449 L .58495 .46848 L p 0 .349 .781 r
F P
0 g
s
.57266 .45449 m .58495 .46848 L .59984 .46175 L p 0 .316 .942 r
F P
0 g
s
.59984 .46175 m .58745 .44763 L .57266 .45449 L p 0 .316 .942 r
F P
0 g
s
.59984 .46175 m .58745 .44763 L p .58645 .46979 L 0 .349 .781 r
F P
0 g
s
.5862 .47533 m .58894 .47261 L p .58645 .46979 L 0 .349 .781 r
F P
0 g
s
.58894 .47261 m .59984 .46175 L p .58645 .46979 L 0 .349 .781 r
F P
0 g
s
.58894 .47261 m .60404 .46585 L p .59431 .47874 L .562 0 0 r
F P
0 g
s
.58477 .49137 m .58894 .47261 L .59431 .47874 L .562 0 0 r
F
.57542 .50377 m .57412 .47925 L .58477 .49137 L F
.56624 .51593 m .55958 .48577 L .57542 .50377 L F
.54263 .49481 m .55688 .48844 L p .5567 .48705 L 0 .05 .112 r
F P
0 g
s
.55598 .48157 m .54531 .49216 L p .5567 .48705 L 0 .05 .112 r
F P
0 g
s
.54531 .49216 m .54263 .49481 L p .5567 .48705 L 0 .05 .112 r
F P
0 g
s
.54263 .49481 m .55598 .48157 L .54391 .46785 L p 0 .349 .782 r
F P
0 g
s
.55688 .48844 m .55323 .4843 L p .55424 .4833 L 0 .349 .781 r
F P
0 g
s
.55323 .4843 m .54467 .47457 L p .55424 .4833 L 0 .349 .781 r
F P
0 g
s
.54981 .47467 m .55424 .4833 L .54467 .47457 L 0 .349 .781 r
F
.55688 .48844 m .57033 .47509 L .55598 .48157 L p 0 .05 .112 r
F P
0 g
s
.57033 .47509 m .55958 .48577 L p .54981 .47467 L 0 .349 .781 r
F P
0 g
s
.55958 .48577 m .55688 .48844 L p .54981 .47467 L 0 .349 .781 r
F P
0 g
s
.5402 .48934 m .54196 .50758 L .5281 .49481 L .562 0 0 r
F
.5402 .48934 m .54207 .49106 L .54196 .50758 L F
.54391 .46785 m .53052 .48107 L .54263 .49481 L p 0 .349 .782 r
F P
0 g
s
.54391 .46785 m .55815 .46123 L p .53602 .47713 L 0 .05 .1 r
F P
0 g
s
.53052 .48107 m .53321 .47842 L p .53602 .47713 L 0 .05 .1 r
F P
0 g
s
.53321 .47842 m .54391 .46785 L p .53602 .47713 L 0 .05 .1 r
F P
0 g
s
.50626 .45353 m .51972 .44035 L .5076 .42658 L p 0 .349 .782 r
F P
0 g
s
.52153 .41956 m .53375 .43347 L p .51311 .43296 L 0 .349 .781 r
F P
0 g
s
.51066 .43017 m .52153 .41956 L p .51311 .43296 L 0 .349 .781 r
F P
0 g
s
.49681 .4371 m .5076 .42658 L .50752 .42674 L .931 0 0 r
F
.5281 .49481 m .48642 .44755 L .49822 .44169 L p .562 0 0 r
F P
0 g
s
.49684 .43973 m .48642 .44755 L .48369 .44366 L .562 0 0 r
F
.49364 .43868 m .48369 .44366 L .47616 .43296 L F
.49684 .43973 m .48369 .44366 L .49364 .43868 L F
.49684 .43973 m .49822 .44169 L .48642 .44755 L F
.49633 .43805 m .47616 .43296 L .47222 .42037 L F
.49633 .43805 m .49684 .43973 L .47616 .43296 L F
.49681 .4371 m .49633 .43805 L .47222 .42037 L F
.5076 .42658 m .4941 .43974 L .50626 .45353 L p 0 .349 .782 r
F P
0 g
s
.49681 .4371 m .51678 .4242 L .51685 .42192 L .1 0 0 r
F
.50403 .43243 m .50748 .42902 L .50743 .42993 L 0 .05 .1 r
F
.49681 .4371 m .51066 .43017 L p .51338 .42752 L .1 0 0 r
F P
0 g
s
.54725 .42024 m .53375 .43347 L .54805 .42646 L p 0 .05 .1 r
F P
0 g
s
.54935 .3991 m .53572 .41242 L .54805 .42646 L p 0 .349 .781 r
F P
0 g
s
.53572 .41242 m .54805 .42646 L .53375 .43347 L p 0 .316 .942 r
F P
0 g
s
.52153 .41956 m .53375 .43347 L .54805 .42646 L p 0 .316 .942 r
F P
0 g
s
.53182 .45411 m .51972 .44035 L .53375 .43347 L p 0 .316 .942 r
F P
0 g
s
.51972 .44035 m .53182 .45411 L .54596 .44736 L p 0 .316 .942 r
F P
0 g
s
.54596 .44736 m .53375 .43347 L .51972 .44035 L p 0 .316 .942 r
F P
0 g
s
.5202 .44676 m .53375 .43347 L .51972 .44035 L p 0 .05 .1 r
F P
0 g
s
.50626 .45353 m .51972 .44035 L .53375 .43347 L p 0 .05 .1 r
F P
0 g
s
.53375 .43347 m .5202 .44676 L .50626 .45353 L p 0 .05 .1 r
F P
0 g
s
.5202 .44676 m .53375 .43347 L .52153 .41956 L p 0 .349 .781 r
F P
0 g
s
.54805 .42646 m .53572 .41242 L .52153 .41956 L p 0 .316 .942 r
F P
0 g
s
.52153 .41956 m .50793 .43283 L .5202 .44676 L p 0 .349 .781 r
F P
0 g
s
.56164 .41312 m .54805 .42646 L .53572 .41242 L p 0 .349 .781 r
F P
0 g
s
.51678 .4242 m .53253 .41553 L .53254 .41402 L .1 0 0 r
F
.55942 .43411 m .57158 .44796 L .55724 .45468 L p 0 .317 .941 r
F P
0 g
s
.57158 .44796 m .55942 .43411 L .57392 .42712 L p 0 .317 .941 r
F P
0 g
s
.54596 .44736 m .55942 .43411 L .57158 .44796 L p 0 .349 .781 r
F P
0 g
s
.55942 .43411 m .57158 .44796 L .58618 .44111 L p 0 .317 .941 r
F P
0 g
s
.55815 .46123 m .57158 .44796 L .55724 .45468 L p 0 .05 .1 r
F P
0 g
s
.55815 .46123 m .57158 .44796 L .55942 .43411 L p 0 .349 .781 r
F P
0 g
s
.58618 .44111 m .57392 .42712 L .55942 .43411 L p 0 .317 .941 r
F P
0 g
s
.55942 .43411 m .54596 .44736 L .55815 .46123 L p 0 .349 .781 r
F P
0 g
s
.54596 .44736 m .55942 .43411 L .57392 .42712 L p 0 .05 .1 r
F P
0 g
s
.56036 .44049 m .57392 .42712 L .55942 .43411 L p 0 .05 .1 r
F P
0 g
s
.57392 .42712 m .56036 .44049 L .54596 .44736 L p 0 .05 .1 r
F P
0 g
s
.56036 .44049 m .57392 .42712 L .56164 .41312 L p 0 .349 .781 r
F P
0 g
s
.54805 .42646 m .56164 .41312 L .57392 .42712 L p 0 .349 .781 r
F P
0 g
s
.55942 .43411 m .54596 .44736 L .53375 .43347 L p 0 .349 .781 r
F P
0 g
s
.55942 .43411 m .54596 .44736 L .56036 .44049 L p 0 .05 .1 r
F P
0 g
s
.56164 .41312 m .54805 .42646 L .56036 .44049 L p 0 .349 .781 r
F P
0 g
s
.56164 .41312 m .54805 .42646 L .56262 .41932 L p 0 .05 .1 r
F P
0 g
s
.60882 .42916 m .59688 .41552 L .58373 .42852 L p 0 .349 .782 r
F P
0 g
s
.57392 .42712 m .58741 .41382 L .59964 .42778 L p 0 .349 .781 r
F P
0 g
s
.59964 .42778 m .58741 .41382 L .57392 .42712 L p 0 .349 .781 r
F P
0 g
s
.60871 .40973 m .6086 .39034 L .58494 .40187 L p 0 .349 .782 r
F P
0 g
s
.58494 .40187 m .59688 .41552 L .60871 .40973 L p 0 .349 .782 r
F P
0 g
s
.6086 .39034 m .60871 .40973 L .62293 .41516 L p 0 .349 .782 r
F P
0 g
s
.60882 .42916 m .62293 .41516 L .60871 .40973 L closepath p 0 .349 .782 r
F P
0 g
s
.59688 .41552 m .60882 .42916 L .60871 .40973 L closepath p 0 .349 .782 r
F P
0 g
s
.59944 .3947 m .61149 .40848 L .59688 .41552 L p 0 .318 .938 r
F P
0 g
s
.59688 .41552 m .58494 .40187 L .59944 .3947 L p 0 .318 .938 r
F P
0 g
s
.59688 .41552 m .61149 .40848 L .59944 .3947 L p 0 .318 .938 r
F P
0 g
s
.59944 .3947 m .58494 .40187 L .59688 .41552 L p 0 .318 .938 r
F P
0 g
s
.63773 .40814 m .62293 .41516 L .60882 .42916 L p 0 .05 .112 r
F P
0 g
s
.62353 .42225 m .60882 .42916 L .62293 .41516 L p 0 .05 .112 r
F P
0 g
s
.60882 .42916 m .62353 .42225 L .63773 .40814 L p 0 .05 .112 r
F P
0 g
s
.62353 .42225 m .60882 .42916 L .59688 .41552 L p 0 .318 .938 r
F P
0 g
s
.60882 .42916 m .62353 .42225 L .61149 .40848 L p 0 .318 .938 r
F P
0 g
s
.61149 .40848 m .59688 .41552 L .60882 .42916 L p 0 .318 .938 r
F P
0 g
s
.59688 .41552 m .61149 .40848 L .62353 .42225 L p 0 .318 .938 r
F P
0 g
s
.61304 .41452 m .59964 .42778 L .58741 .41382 L p 0 .349 .781 r
F P
0 g
s
.58741 .41382 m .60085 .40057 L .61304 .41452 L p 0 .349 .781 r
F P
0 g
s
.61304 .41452 m .60085 .40057 L .58741 .41382 L p 0 .349 .781 r
F P
0 g
s
.58741 .41382 m .59964 .42778 L .61304 .41452 L p 0 .349 .781 r
F P
0 g
s
.60228 .40659 m .58741 .41382 L .57392 .42712 L p 0 .05 .1 r
F P
0 g
s
.57392 .42712 m .58741 .41382 L .60228 .40659 L p 0 .05 .1 r
F P
0 g
s
.57392 .42712 m .5887 .42001 L .60228 .40659 L p 0 .05 .1 r
F P
0 g
s
.60228 .40659 m .5887 .42001 L .57392 .42712 L p 0 .05 .1 r
F P
0 g
s
.56164 .41312 m .57392 .42712 L .5887 .42001 L p 0 .317 .941 r
F P
0 g
s
.57392 .42712 m .56164 .41312 L .57631 .40586 L p 0 .317 .941 r
F P
0 g
s
.5887 .42001 m .57631 .40586 L .56164 .41312 L p 0 .317 .941 r
F P
0 g
s
.54805 .42646 m .56164 .41312 L .57631 .40586 L p 0 .05 .1 r
F P
0 g
s
.57631 .40586 m .56262 .41932 L .54805 .42646 L p 0 .05 .1 r
F P
0 g
s
.55018 .40513 m .56262 .41932 L .54805 .42646 L p 0 .316 .942 r
F P
0 g
s
.54805 .42646 m .53572 .41242 L .55018 .40513 L p 0 .316 .942 r
F P
0 g
s
.53572 .41242 m .54805 .42646 L .56262 .41932 L p 0 .316 .942 r
F P
0 g
s
.54596 .44736 m .53375 .43347 L .54805 .42646 L p 0 .316 .942 r
F P
0 g
s
.53375 .43347 m .54596 .44736 L .56036 .44049 L p 0 .316 .942 r
F P
0 g
s
.53375 .43347 m .54596 .44736 L .53182 .45411 L p 0 .316 .942 r
F P
0 g
s
.5202 .44676 m .53375 .43347 L .54596 .44736 L p 0 .349 .781 r
F P
0 g
s
.53244 .46067 m .54596 .44736 L .53182 .45411 L p 0 .05 .1 r
F P
0 g
s
.54596 .44736 m .53244 .46067 L .5184 .46731 L p 0 .05 .1 r
F P
0 g
s
.53244 .46067 m .54596 .44736 L .53375 .43347 L p 0 .349 .781 r
F P
0 g
s
.56036 .44049 m .54805 .42646 L .53375 .43347 L p 0 .316 .942 r
F P
0 g
s
.5344 .43986 m .54805 .42646 L .53375 .43347 L p 0 .05 .1 r
F P
0 g
s
.53182 .45411 m .5184 .46731 L .53244 .46067 L p 0 .05 .1 r
F P
0 g
s
.53375 .43347 m .5202 .44676 L .53244 .46067 L p 0 .349 .781 r
F P
0 g
s
.5202 .44676 m .53375 .43347 L .54805 .42646 L p 0 .05 .1 r
F P
0 g
s
.54805 .42646 m .53572 .41242 L p .53466 .43437 L 0 .349 .781 r
F P
0 g
s
.51338 .42752 m .53025 .41776 L .51678 .4242 L .1 0 0 r
F
.52203 .42579 m .53572 .41242 L .54805 .42646 L p 0 .349 .781 r
F P
0 g
s
.56262 .41932 m .55018 .40513 L .53572 .41242 L p 0 .316 .942 r
F P
0 g
s
.53375 .43347 m .5202 .44676 L .50793 .43283 L p 0 .349 .781 r
F P
0 g
s
.53375 .43347 m .5202 .44676 L .5344 .43986 L p 0 .05 .1 r
F P
0 g
s
.54805 .42646 m .5344 .43986 L .5202 .44676 L p 0 .05 .1 r
F P
0 g
s
.53572 .41242 m .52203 .42579 L .5344 .43986 L p 0 .349 .781 r
F P
0 g
s
.53025 .41776 m .54743 .40782 L .53253 .41553 L .1 0 0 r
F
.56262 .41932 m .57631 .40586 L .56164 .41312 L p 0 .05 .1 r
F P
0 g
s
.56262 .41932 m .57631 .40586 L .56391 .3917 L p 0 .349 .781 r
F P
0 g
s
.55018 .40513 m .56391 .3917 L .57631 .40586 L p 0 .349 .781 r
F P
0 g
s
.53253 .41553 m .54858 .4067 L .53572 .41242 L .1 0 0 r
F
.57631 .40586 m .56262 .41932 L .55018 .40513 L p 0 .349 .781 r
F P
0 g
s
.56391 .3917 m .55018 .40513 L .56262 .41932 L p 0 .349 .781 r
F P
0 g
s
.52477 .42311 m .53916 .41592 L p .53025 .41776 L .1 0 0 r
F P
0 g
s
.55018 .40513 m .56493 .39771 L p .56431 .40351 L 0 .316 .942 r
F P
0 g
s
.56262 .41932 m .5535 .40892 L p .56431 .40351 L 0 .316 .942 r
F P
0 g
s
.5535 .40892 m .55018 .40513 L p .56431 .40351 L 0 .316 .942 r
F P
0 g
s
.62793 .36664 m .64291 .35911 L .61871 .33131 L p 0 .319 .936 r
F P
0 g
s
.60854 .37866 m .6232 .3713 L .59944 .3947 L p 0 .05 .1 r
F P
0 g
s
.63697 .40123 m .65187 .3941 L .62793 .36664 L p 0 .319 .936 r
F P
0 g
s
.64291 .35911 m .62793 .36664 L .65187 .3941 L p 0 .319 .936 r
F P
0 g
s
.63815 .3638 m .6232 .3713 L .59944 .3947 L p 0 .05 .1 r
F P
0 g
s
.59944 .3947 m .61422 .38739 L .63815 .3638 L p 0 .05 .1 r
F P
0 g
s
.61422 .38739 m .59944 .3947 L .6232 .3713 L p 0 .05 .1 r
F P
0 g
s
.61422 .38739 m .59944 .3947 L .58738 .38089 L p 0 .318 .938 r
F P
0 g
s
.58738 .38089 m .59944 .3947 L .61422 .38739 L p 0 .318 .938 r
F P
0 g
s
.57529 .36707 m .58738 .38089 L .60205 .37345 L p 0 .318 .938 r
F P
0 g
s
.59756 .3777 m .60854 .37866 L .61323 .37404 L p 0 .349 .782 r
F P
0 g
s
.61422 .38739 m .60205 .37345 L .58738 .38089 L p 0 .318 .938 r
F P
0 g
s
.58738 .38089 m .60205 .37345 L .61422 .38739 L p 0 .318 .938 r
F P
0 g
s
.60205 .37345 m .58738 .38089 L .57529 .36707 L p 0 .318 .938 r
F P
0 g
s
.60205 .37345 m .58986 .3595 L .57529 .36707 L p 0 .318 .938 r
F P
0 g
s
.57529 .36707 m .58986 .3595 L .60205 .37345 L p 0 .318 .938 r
F P
0 g
s
.627 .36281 m .61871 .33131 L .64291 .35911 L p 0 .349 .781 r
F P
0 g
s
.63376 .32336 m .61871 .33131 L .64291 .35911 L p 0 .319 .936 r
F P
0 g
s
.64291 .35911 m .65817 .35143 L .63376 .32336 L p 0 .319 .936 r
F P
0 g
s
.64291 .35911 m .62793 .36664 L .6232 .3713 L p 0 .05 .1 r
F P
0 g
s
.6232 .3713 m .63815 .3638 L .64291 .35911 L p 0 .05 .1 r
F P
0 g
s
.62793 .36664 m .64291 .35911 L .63815 .3638 L p 0 .05 .1 r
F P
0 g
s
.63815 .3638 m .64291 .35911 L .61871 .33131 L p 0 .349 .781 r
F P
0 g
s
.61871 .33131 m .627 .36281 L .63815 .3638 L p 0 .349 .781 r
F P
0 g
s
.60432 .34537 m .61871 .33131 L .627 .36281 L p 0 .349 .781 r
F P
0 g
s
.60847 .36116 m .627 .36281 L .61871 .33131 L p 0 .349 .781 r
F P
0 g
s
.60205 .37345 m .60847 .36116 L .627 .36281 L p 0 .349 .781 r
F P
0 g
s
.627 .36281 m .60847 .36116 L .60432 .34537 L p 0 .349 .781 r
F P
0 g
s
.61323 .37404 m .60854 .37866 L .6232 .3713 L p 0 .05 .1 r
F P
0 g
s
.6232 .3713 m .62793 .36664 L .61323 .37404 L p 0 .05 .1 r
F P
0 g
s
.60854 .37866 m .61323 .37404 L .62793 .36664 L p 0 .05 .1 r
F P
0 g
s
.62793 .36664 m .6232 .3713 L .60854 .37866 L p 0 .05 .1 r
F P
0 g
s
.61422 .38739 m .627 .36281 L .60847 .36116 L p 0 .349 .781 r
F P
0 g
s
.60205 .37345 m .58986 .3595 L .60847 .36116 L closepath p 0 .349 .781 r
F P
0 g
s
.60847 .36116 m .60205 .37345 L .61422 .38739 L p 0 .349 .781 r
F P
0 g
s
.60847 .36116 m .58986 .3595 L .60205 .37345 L closepath p 0 .349 .781 r
F P
0 g
s
.58986 .3595 m .60205 .37345 L .58864 .38662 L p 0 .349 .781 r
F P
0 g
s
.61701 .36587 m .60205 .37345 L .58986 .3595 L p 0 .318 .938 r
F P
0 g
s
.60432 .34537 m .58986 .3595 L .60847 .36116 L closepath p 0 .349 .781 r
F P
0 g
s
.60471 .35177 m .58986 .3595 L .60205 .37345 L p 0 .318 .938 r
F P
0 g
s
.61871 .33131 m .60432 .34537 L .60847 .36116 L p 0 .349 .781 r
F P
0 g
s
.60205 .37345 m .61701 .36587 L .60471 .35177 L p 0 .318 .938 r
F P
0 g
s
.58864 .38662 m .60205 .37345 L .58986 .3595 L p 0 .349 .781 r
F P
0 g
s
.58864 .38662 m .57642 .37264 L .58986 .3595 L p 0 .349 .781 r
F P
0 g
s
.58986 .3595 m .60471 .35177 L .61701 .36587 L p 0 .318 .938 r
F P
0 g
s
.58986 .3595 m .57642 .37264 L .58864 .38662 L p 0 .349 .781 r
F P
0 g
s
.63225 .35814 m .61701 .36587 L .60471 .35177 L p 0 .318 .938 r
F P
0 g
s
.61985 .34391 m .60471 .35177 L .61701 .36587 L p 0 .318 .938 r
F P
0 g
s
.61701 .36587 m .63225 .35814 L .61985 .34391 L p 0 .318 .938 r
F P
0 g
s
.60471 .35177 m .61985 .34391 L .63225 .35814 L p 0 .318 .938 r
F P
0 g
s
.64909 .31526 m .63376 .32336 L .65817 .35143 L p 0 .319 .936 r
F P
0 g
s
.65817 .35143 m .67372 .3436 L .64909 .31526 L p 0 .319 .936 r
F P
0 g
s
.65757 .34734 m .63875 .34563 L .63451 .32955 L p 0 .35 .78 r
F P
0 g
s
.58616 .40778 m .59944 .3947 L .58494 .40187 L p 0 .05 .1 r
F P
0 g
s
.58494 .40187 m .59944 .3947 L .58616 .40778 L p 0 .05 .1 r
F P
0 g
s
.59944 .3947 m .58616 .40778 L .60085 .40057 L p 0 .05 .1 r
F P
0 g
s
.60085 .40057 m .58616 .40778 L .59944 .3947 L p 0 .05 .1 r
F P
0 g
s
.58741 .41382 m .60085 .40057 L .58616 .40778 L p 0 .05 .1 r
F P
0 g
s
.58616 .40778 m .60085 .40057 L .58741 .41382 L p 0 .05 .1 r
F P
0 g
s
.58864 .38662 m .60085 .40057 L .58741 .41382 L p 0 .349 .781 r
F P
0 g
s
.58741 .41382 m .60085 .40057 L .58864 .38662 L p 0 .349 .781 r
F P
0 g
s
.58741 .41382 m .57517 .39984 L .58864 .38662 L p 0 .349 .781 r
F P
0 g
s
.58864 .38662 m .57517 .39984 L .58741 .41382 L p 0 .349 .781 r
F P
0 g
s
.57631 .40586 m .59126 .39847 L p .57115 .39349 L 0 .317 .941 r
F P
0 g
s
.56391 .3917 m .56722 .39548 L p .57115 .39349 L 0 .317 .941 r
F P
0 g
s
.56722 .39548 m .57631 .40586 L p .57115 .39349 L 0 .317 .941 r
F P
0 g
s
.61985 .34391 m .63451 .32955 L .63875 .34563 L closepath p 0 .35 .78 r
F P
0 g
s
.63225 .35814 m .61985 .34391 L .63875 .34563 L closepath p 0 .35 .78 r
F P
0 g
s
.65187 .3941 m .66705 .38683 L .64291 .35911 L p 0 .319 .936 r
F P
0 g
s
.65282 .40098 m .66705 .38683 L .65187 .3941 L p 0 .05 .112 r
F P
0 g
s
.65187 .3941 m .66705 .38683 L .65282 .40098 L p 0 .05 .112 r
F P
0 g
s
.63837 .39543 m .63823 .37569 L .66705 .38683 L p 0 .349 .781 r
F P
0 g
s
.65187 .3941 m .63697 .40123 L .62293 .41516 L p 0 .05 .112 r
F P
0 g
s
.63697 .40123 m .65187 .3941 L .63773 .40814 L p 0 .05 .112 r
F P
0 g
s
.62293 .41516 m .63773 .40814 L .65187 .3941 L p 0 .05 .112 r
F P
0 g
s
.65187 .3941 m .63773 .40814 L .65282 .40098 L p 0 .05 .112 r
F P
0 g
s
.65282 .40098 m .63773 .40814 L .65187 .3941 L p 0 .05 .112 r
F P
0 g
s
.66705 .38683 m .65282 .40098 L .63837 .39543 L p 0 .349 .781 r
F P
0 g
s
.66705 .38683 m .63823 .37569 L .63815 .3638 L p 0 .349 .781 r
F P
0 g
s
.63815 .3638 m .64291 .35911 L .66705 .38683 L p 0 .349 .781 r
F P
0 g
s
.66705 .38683 m .69647 .42061 L .71218 .41354 L p 0 .319 .936 r
F P
0 g
s
.71218 .41354 m .68251 .37942 L .66705 .38683 L p 0 .319 .936 r
F P
0 g
s
.65282 .40098 m .66705 .38683 L .68251 .37942 L p 0 .05 .112 r
F P
0 g
s
.65282 .40098 m .66705 .38683 L .63823 .37569 L p 0 .349 .781 r
F P
0 g
s
.65817 .35143 m .64291 .35911 L .66705 .38683 L p 0 .319 .936 r
F P
0 g
s
.63823 .37569 m .66705 .38683 L .64291 .35911 L p 0 .349 .781 r
F P
0 g
s
.66705 .38683 m .65282 .40098 L .66818 .39369 L p 0 .05 .112 r
F P
0 g
s
.64291 .35911 m .63815 .3638 L .627 .36281 L p 0 .349 .781 r
F P
0 g
s
.64291 .35911 m .63815 .3638 L .63823 .37569 L p 0 .349 .781 r
F P
0 g
s
.65817 .35143 m .64291 .35911 L .63815 .3638 L p 0 .05 .1 r
F P
0 g
s
.63815 .3638 m .65337 .35616 L .65817 .35143 L p 0 .05 .1 r
F P
0 g
s
.64291 .35911 m .65817 .35143 L .65337 .35616 L p 0 .05 .1 r
F P
0 g
s
.65337 .35616 m .63815 .3638 L .64291 .35911 L p 0 .05 .1 r
F P
0 g
s
.61422 .38739 m .63815 .3638 L .63823 .37569 L closepath p 0 .349 .781 r
F P
0 g
s
.63823 .37569 m .63815 .3638 L .61422 .38739 L closepath p 0 .349 .781 r
F P
0 g
s
.65337 .35616 m .63815 .3638 L .61422 .38739 L p 0 .05 .1 r
F P
0 g
s
.61422 .38739 m .62928 .37994 L .65337 .35616 L p 0 .05 .1 r
F P
0 g
s
.63815 .3638 m .65337 .35616 L .62928 .37994 L p 0 .05 .1 r
F P
0 g
s
.68251 .37942 m .66818 .39369 L .65282 .40098 L p 0 .05 .112 r
F P
0 g
s
.63851 .41521 m .65282 .40098 L .66818 .39369 L p 0 .05 .112 r
F P
0 g
s
.66818 .39369 m .65282 .40098 L .63851 .41521 L p 0 .05 .112 r
F P
0 g
s
.66818 .39369 m .65378 .40803 L .63851 .41521 L p 0 .05 .112 r
F P
0 g
s
.63851 .41521 m .65378 .40803 L .66818 .39369 L p 0 .05 .112 r
F P
0 g
s
.66705 .38683 m .68251 .37942 L .65817 .35143 L p 0 .319 .936 r
F P
0 g
s
.67372 .3436 m .65817 .35143 L .68251 .37942 L p 0 .319 .936 r
F P
0 g
s
.66889 .34838 m .65337 .35616 L .62928 .37994 L p 0 .05 .1 r
F P
0 g
s
.62928 .37994 m .64463 .37235 L .66889 .34838 L p 0 .05 .1 r
F P
0 g
s
.64463 .37235 m .62928 .37994 L .65337 .35616 L p 0 .05 .1 r
F P
0 g
s
.65337 .35616 m .66889 .34838 L .64463 .37235 L p 0 .05 .1 r
F P
0 g
s
.65378 .40803 m .66818 .39369 L .68384 .38626 L p 0 .05 .112 r
F P
0 g
s
.68384 .38626 m .66818 .39369 L .65378 .40803 L p 0 .05 .112 r
F P
0 g
s
.65817 .35143 m .65337 .35616 L .66889 .34838 L p 0 .05 .1 r
F P
0 g
s
.66889 .34838 m .67372 .3436 L .65817 .35143 L p 0 .05 .1 r
F P
0 g
s
.65337 .35616 m .65817 .35143 L .67372 .3436 L p 0 .05 .1 r
F P
0 g
s
.67372 .3436 m .66889 .34838 L .65337 .35616 L p 0 .05 .1 r
F P
0 g
s
.64463 .37235 m .65757 .34734 L .66889 .34838 L closepath p 0 .35 .78 r
F P
0 g
s
.66889 .34838 m .66899 .36048 L .64463 .37235 L closepath p 0 .35 .78 r
F P
0 g
s
.65699 .38655 m .64463 .37235 L .66899 .36048 L p 0 .35 .78 r
F P
0 g
s
.66899 .36048 m .66917 .38058 L .65699 .38655 L p 0 .35 .78 r
F P
0 g
s
.63875 .34563 m .65757 .34734 L .64463 .37235 L p 0 .35 .78 r
F P
0 g
s
.66818 .39369 m .68251 .37942 L .66705 .38683 L p 0 .05 .112 r
F P
0 g
s
.68251 .37942 m .71218 .41354 L .7282 .40633 L p 0 .319 .936 r
F P
0 g
s
.7282 .40633 m .69827 .37188 L .68251 .37942 L p 0 .319 .936 r
F P
0 g
s
.66818 .39369 m .68251 .37942 L .69827 .37188 L p 0 .05 .112 r
F P
0 g
s
.69827 .37188 m .68251 .37942 L .66818 .39369 L p 0 .05 .112 r
F P
0 g
s
.69827 .37188 m .68384 .38626 L .66818 .39369 L p 0 .05 .112 r
F P
0 g
s
.66818 .39369 m .68384 .38626 L .69827 .37188 L p 0 .05 .112 r
F P
0 g
s
.68384 .38626 m .66934 .40072 L .65378 .40803 L p 0 .05 .112 r
F P
0 g
s
.65378 .40803 m .66934 .40072 L .68384 .38626 L p 0 .05 .112 r
F P
0 g
s
.66917 .38058 m .66934 .40072 L .65699 .38655 L closepath p 0 .35 .78 r
F P
0 g
s
.63815 .3638 m .6232 .3713 L .62793 .36664 L p 0 .05 .1 r
F P
0 g
s
.6232 .3713 m .63815 .3638 L .61422 .38739 L p 0 .05 .1 r
F P
0 g
s
.627 .36281 m .63815 .3638 L .61422 .38739 L closepath p 0 .349 .781 r
F P
0 g
s
.61422 .38739 m .63815 .3638 L .627 .36281 L closepath p 0 .349 .781 r
F P
0 g
s
.62928 .37994 m .61422 .38739 L .63815 .3638 L p 0 .05 .1 r
F P
0 g
s
.64463 .37235 m .63225 .35814 L .63875 .34563 L p 0 .35 .78 r
F P
0 g
s
.63861 .33972 m .6252 .34665 L .66815 .39595 L p .578 0 0 r
F P
0 g
s
.62293 .41516 m .63697 .40123 L .6086 .39034 L p 0 .349 .782 r
F P
0 g
s
.63773 .40814 m .62293 .41516 L .63697 .40123 L p 0 .05 .112 r
F P
0 g
s
.62293 .41516 m .63773 .40814 L .62353 .42225 L p 0 .05 .112 r
F P
0 g
s
.60882 .42916 m .5957 .44217 L .61032 .43537 L p 0 .05 .112 r
F P
0 g
s
.61032 .43537 m .62353 .42225 L .60882 .42916 L p 0 .05 .112 r
F P
0 g
s
.59705 .44855 m .61032 .43537 L .5957 .44217 L p 0 .05 .112 r
F P
0 g
s
.65282 .40098 m .63773 .40814 L .62353 .42225 L p 0 .05 .112 r
F P
0 g
s
.63773 .40814 m .65282 .40098 L .63851 .41521 L p 0 .05 .112 r
F P
0 g
s
.63851 .41521 m .62353 .42225 L .63773 .40814 L p 0 .05 .112 r
F P
0 g
s
.62353 .42225 m .63851 .41521 L .65282 .40098 L p 0 .05 .112 r
F P
0 g
s
.63851 .41521 m .62353 .42225 L .61149 .40848 L p 0 .318 .938 r
F P
0 g
s
.62353 .42225 m .61032 .43537 L .62521 .42844 L p 0 .05 .112 r
F P
0 g
s
.62521 .42844 m .63851 .41521 L .62353 .42225 L p 0 .05 .112 r
F P
0 g
s
.62353 .42225 m .63851 .41521 L .62638 .40131 L p 0 .318 .938 r
F P
0 g
s
.62638 .40131 m .61149 .40848 L .62353 .42225 L p 0 .318 .938 r
F P
0 g
s
.62638 .40131 m .61149 .40848 L .59944 .3947 L p 0 .318 .938 r
F P
0 g
s
.61149 .40848 m .62638 .40131 L .63851 .41521 L p 0 .318 .938 r
F P
0 g
s
.61149 .40848 m .62638 .40131 L .61422 .38739 L p 0 .318 .938 r
F P
0 g
s
.59944 .3947 m .61422 .38739 L .62638 .40131 L p 0 .318 .938 r
F P
0 g
s
.61032 .43537 m .59705 .44855 L .61185 .44173 L p 0 .05 .112 r
F P
0 g
s
.61185 .44173 m .62521 .42844 L .61032 .43537 L p 0 .05 .112 r
F P
0 g
s
.59843 .45507 m .61185 .44173 L .59705 .44855 L p 0 .05 .112 r
F P
0 g
s
.65282 .40098 m .63851 .41521 L .63837 .39543 L closepath p 0 .349 .781 r
F P
0 g
s
.63823 .37569 m .63837 .39543 L .65282 .40098 L p 0 .349 .781 r
F P
0 g
s
.63837 .39543 m .63851 .41521 L .65282 .40098 L closepath p 0 .349 .781 r
F P
0 g
s
.61422 .38739 m .63823 .37569 L .63837 .39543 L p 0 .349 .781 r
F P
0 g
s
.63823 .37569 m .61422 .38739 L .62638 .40131 L p 0 .349 .781 r
F P
0 g
s
.62638 .40131 m .63837 .39543 L .63823 .37569 L p 0 .349 .781 r
F P
0 g
s
.627 .36281 m .61422 .38739 L .60205 .37345 L p 0 .349 .781 r
F P
0 g
s
.63837 .39543 m .62638 .40131 L .61422 .38739 L p 0 .349 .781 r
F P
0 g
s
.63837 .39543 m .63851 .41521 L .62638 .40131 L closepath p 0 .349 .781 r
F P
0 g
s
.62638 .40131 m .63851 .41521 L .63837 .39543 L closepath p 0 .349 .781 r
F P
0 g
s
.63851 .41521 m .62521 .42844 L .61304 .41452 L p 0 .349 .781 r
F P
0 g
s
.61304 .41452 m .62638 .40131 L .63851 .41521 L p 0 .349 .781 r
F P
0 g
s
.65378 .40803 m .63851 .41521 L .62638 .40131 L p 0 .318 .938 r
F P
0 g
s
.65378 .40803 m .63851 .41521 L .62521 .42844 L p 0 .05 .112 r
F P
0 g
s
.62638 .40131 m .63851 .41521 L .65378 .40803 L p 0 .318 .938 r
F P
0 g
s
.63851 .41521 m .62638 .40131 L .61304 .41452 L p 0 .349 .781 r
F P
0 g
s
.61304 .41452 m .62521 .42844 L .63851 .41521 L p 0 .349 .781 r
F P
0 g
s
.61422 .38739 m .59944 .3947 L .61149 .40848 L p 0 .318 .938 r
F P
0 g
s
.62638 .40131 m .61304 .41452 L .60085 .40057 L p 0 .349 .781 r
F P
0 g
s
.60085 .40057 m .61422 .38739 L .62638 .40131 L p 0 .349 .781 r
F P
0 g
s
.64154 .394 m .62638 .40131 L .61422 .38739 L p 0 .318 .938 r
F P
0 g
s
.62638 .40131 m .64154 .394 L .65378 .40803 L p 0 .318 .938 r
F P
0 g
s
.65378 .40803 m .64154 .394 L .62638 .40131 L p 0 .318 .938 r
F P
0 g
s
.61422 .38739 m .62638 .40131 L .64154 .394 L p 0 .318 .938 r
F P
0 g
s
.62638 .40131 m .61422 .38739 L .60085 .40057 L p 0 .349 .781 r
F P
0 g
s
.60085 .40057 m .61304 .41452 L .62638 .40131 L p 0 .349 .781 r
F P
0 g
s
.62928 .37994 m .61422 .38739 L .60205 .37345 L p 0 .318 .938 r
F P
0 g
s
.61422 .38739 m .62928 .37994 L .64154 .394 L p 0 .318 .938 r
F P
0 g
s
.61422 .38739 m .62928 .37994 L .61701 .36587 L p 0 .318 .938 r
F P
0 g
s
.64154 .394 m .62928 .37994 L .61422 .38739 L p 0 .318 .938 r
F P
0 g
s
.62928 .37994 m .61422 .38739 L .60085 .40057 L p 0 .05 .1 r
F P
0 g
s
.60085 .40057 m .61422 .38739 L .62928 .37994 L p 0 .05 .1 r
F P
0 g
s
.60205 .37345 m .61701 .36587 L .62928 .37994 L p 0 .318 .938 r
F P
0 g
s
.58373 .42852 m .5957 .44217 L .60882 .42916 L p 0 .349 .782 r
F P
0 g
s
.62521 .42844 m .61185 .44173 L .59964 .42778 L p 0 .349 .781 r
F P
0 g
s
.59964 .42778 m .61304 .41452 L .62521 .42844 L p 0 .349 .781 r
F P
0 g
s
.64039 .42137 m .62521 .42844 L .61185 .44173 L p 0 .05 .112 r
F P
0 g
s
.62521 .42844 m .61304 .41452 L .59964 .42778 L p 0 .349 .781 r
F P
0 g
s
.59964 .42778 m .61185 .44173 L .62521 .42844 L p 0 .349 .781 r
F P
0 g
s
.62521 .42844 m .64039 .42137 L .65378 .40803 L p 0 .05 .112 r
F P
0 g
s
.60085 .40057 m .61581 .39324 L .62928 .37994 L p 0 .05 .1 r
F P
0 g
s
.62928 .37994 m .61581 .39324 L .60085 .40057 L p 0 .05 .1 r
F P
0 g
s
.61185 .44173 m .59843 .45507 L .58618 .44111 L p 0 .349 .781 r
F P
0 g
s
.58618 .44111 m .59964 .42778 L .61185 .44173 L p 0 .349 .781 r
F P
0 g
s
.61185 .44173 m .62693 .43477 L .64039 .42137 L p 0 .05 .112 r
F P
0 g
s
.62693 .43477 m .61185 .44173 L .59843 .45507 L p 0 .05 .112 r
F P
0 g
s
.61185 .44173 m .59964 .42778 L .58618 .44111 L p 0 .349 .781 r
F P
0 g
s
.58618 .44111 m .59843 .45507 L .61185 .44173 L p 0 .349 .781 r
F P
0 g
s
.59843 .45507 m .61342 .44823 L .62693 .43477 L p 0 .05 .112 r
F P
0 g
s
.58618 .44111 m .59843 .45507 L .61342 .44823 L p 0 .317 .941 r
F P
0 g
s
.59984 .46175 m .61342 .44823 L .59843 .45507 L p 0 .05 .112 r
F P
0 g
s
.61342 .44823 m .59843 .45507 L .58618 .44111 L p 0 .317 .941 r
F P
0 g
s
.61342 .44823 m .60106 .43413 L .58618 .44111 L p 0 .317 .941 r
F P
0 g
s
.58618 .44111 m .60106 .43413 L .61342 .44823 L p 0 .317 .941 r
F P
0 g
s
.66934 .40072 m .65378 .40803 L .64154 .394 L p 0 .318 .938 r
F P
0 g
s
.66934 .40072 m .65378 .40803 L .64039 .42137 L p 0 .05 .112 r
F P
0 g
s
.64154 .394 m .65378 .40803 L .66934 .40072 L p 0 .318 .938 r
F P
0 g
s
.64463 .37235 m .65699 .38655 L .64154 .394 L p 0 .318 .938 r
F P
0 g
s
.64154 .394 m .62928 .37994 L .64463 .37235 L p 0 .318 .938 r
F P
0 g
s
.64154 .394 m .65699 .38655 L .66934 .40072 L p 0 .318 .938 r
F P
0 g
s
.66934 .40072 m .65699 .38655 L .64154 .394 L p 0 .318 .938 r
F P
0 g
s
.62928 .37994 m .64154 .394 L .65699 .38655 L p 0 .318 .938 r
F P
0 g
s
.62928 .37994 m .61701 .36587 L .63225 .35814 L p 0 .318 .938 r
F P
0 g
s
.63225 .35814 m .64463 .37235 L .62928 .37994 L p 0 .318 .938 r
F P
0 g
s
.63225 .35814 m .61701 .36587 L .62928 .37994 L p 0 .318 .938 r
F P
0 g
s
.62928 .37994 m .64463 .37235 L .63225 .35814 L p 0 .318 .938 r
F P
0 g
s
.65699 .38655 m .64463 .37235 L .62928 .37994 L p 0 .318 .938 r
F P
0 g
s
.64463 .37235 m .62928 .37994 L .61581 .39324 L p 0 .05 .1 r
F P
0 g
s
.61581 .39324 m .62928 .37994 L .64463 .37235 L p 0 .05 .1 r
F P
0 g
s
.65586 .41417 m .64039 .42137 L .62693 .43477 L p 0 .05 .112 r
F P
0 g
s
.64039 .42137 m .65586 .41417 L .66934 .40072 L p 0 .05 .112 r
F P
0 g
s
.63107 .38576 m .61581 .39324 L .60228 .40659 L p 0 .05 .1 r
F P
0 g
s
.61581 .39324 m .63107 .38576 L .64463 .37235 L p 0 .05 .1 r
F P
0 g
s
.60228 .40659 m .61581 .39324 L .63107 .38576 L p 0 .05 .1 r
F P
0 g
s
.64463 .37235 m .63107 .38576 L .61581 .39324 L p 0 .05 .1 r
F P
0 g
s
.62693 .43477 m .64231 .42769 L .65586 .41417 L p 0 .05 .112 r
F P
0 g
s
.64231 .42769 m .62693 .43477 L .61342 .44823 L p 0 .05 .112 r
F P
0 g
s
.61744 .39922 m .60228 .40659 L .5887 .42001 L p 0 .05 .1 r
F P
0 g
s
.60228 .40659 m .61744 .39922 L .63107 .38576 L p 0 .05 .1 r
F P
0 g
s
.5887 .42001 m .60228 .40659 L .61744 .39922 L p 0 .05 .1 r
F P
0 g
s
.63107 .38576 m .61744 .39922 L .60228 .40659 L p 0 .05 .1 r
F P
0 g
s
.61342 .44823 m .6287 .44126 L .64231 .42769 L p 0 .05 .112 r
F P
0 g
s
.61342 .44823 m .6287 .44126 L p .62128 .43934 L 0 .317 .941 r
F P
0 g
s
.60106 .43413 m .61012 .44447 L p .62128 .43934 L 0 .317 .941 r
F P
0 g
s
.61012 .44447 m .61342 .44823 L p .62128 .43934 L 0 .317 .941 r
F P
0 g
s
.62947 .45275 m .69071 .42525 L .66934 .40072 L p .578 0 0 r
F P
0 g
s
.69647 .42061 m .72579 .45429 L .74175 .44754 L p 0 .319 .936 r
F P
0 g
s
.74175 .44754 m .71218 .41354 L .69647 .42061 L p 0 .319 .936 r
F P
0 g
s
.71386 .42078 m .69946 .43529 L .66934 .40072 L p 0 .35 .78 r
F P
0 g
s
.66934 .40072 m .68384 .38626 L .71386 .42078 L p 0 .35 .78 r
F P
0 g
s
.66917 .38058 m .68384 .38626 L .66934 .40072 L closepath p 0 .35 .78 r
F P
0 g
s
.66934 .40072 m .69071 .42525 L .62572 .49056 L p .858 0 0 r
F P
0 g
s
.66934 .40072 m .69071 .42525 L .69538 .41786 L .578 0 0 r
F
.60404 .46585 m .69071 .42525 L .66934 .40072 L .858 0 0 r
F
.62572 .49056 m .60404 .46585 L .66934 .40072 L p F P
0 g
s
.61342 .44823 m .59984 .46175 L .61502 .45489 L p 0 .05 .112 r
F P
0 g
s
.61502 .45489 m .6287 .44126 L .61342 .44823 L p 0 .05 .112 r
F P
0 g
s
.6287 .44126 m .61342 .44823 L .61012 .44447 L p 0 .317 .941 r
F P
0 g
s
.61012 .44447 m .60106 .43413 L p .62128 .43934 L 0 .317 .941 r
F P
0 g
s
.62128 .43934 m .6287 .44126 L .61012 .44447 L 0 .317 .941 r
F
.6287 .44126 m .61623 .42701 L .60106 .43413 L p F P
0 g
s
.60106 .43413 m .61623 .42701 L .6287 .44126 L p 0 .317 .941 r
F P
0 g
s
.59984 .46175 m .61342 .44823 L .60106 .43413 L p 0 .349 .781 r
F P
0 g
s
.61342 .44823 m .59984 .46175 L .58745 .44763 L p 0 .349 .781 r
F P
0 g
s
.61502 .45489 m .59984 .46175 L p .60055 .45616 L 0 .316 .942 r
F P
0 g
s
.58745 .44763 m .60106 .43413 L .61342 .44823 L p 0 .349 .781 r
F P
0 g
s
.60252 .44063 m .61169 .45109 L p .60055 .45616 L 0 .316 .942 r
F P
0 g
s
.61169 .45109 m .61502 .45489 L p .60055 .45616 L 0 .316 .942 r
F P
0 g
s
.59984 .46175 m .61502 .45489 L p .60762 .45294 L 0 .316 .942 r
F P
0 g
s
.60106 .43413 m .58745 .44763 L .59984 .46175 L p 0 .349 .781 r
F P
0 g
s
.58745 .44763 m .59654 .45799 L p .60762 .45294 L 0 .316 .942 r
F P
0 g
s
.59654 .45799 m .59984 .46175 L p .60762 .45294 L 0 .316 .942 r
F P
0 g
s
.61502 .45489 m .59984 .46175 L p .601 .46721 L 0 .05 .112 r
F P
0 g
s
.60129 .46859 m .60404 .46585 L p .601 .46721 L 0 .05 .112 r
F P
0 g
s
.60404 .46585 m .61502 .45489 L p .601 .46721 L 0 .05 .112 r
F P
0 g
s
.66934 .40072 m .65586 .41417 L .64347 .39998 L p 0 .35 .78 r
F P
0 g
s
.64347 .39998 m .65699 .38655 L .66934 .40072 L p 0 .35 .78 r
F P
0 g
s
.61502 .45489 m .60252 .44063 L .58745 .44763 L p 0 .316 .942 r
F P
0 g
s
.65586 .41417 m .64231 .42769 L .62988 .41346 L p 0 .35 .78 r
F P
0 g
s
.62988 .41346 m .64347 .39998 L .65586 .41417 L p 0 .35 .78 r
F P
0 g
s
.64231 .42769 m .6287 .44126 L .61623 .42701 L p 0 .35 .78 r
F P
0 g
s
.61623 .42701 m .62988 .41346 L .64231 .42769 L p 0 .35 .78 r
F P
0 g
s
.60252 .44063 m .61623 .42701 L .6287 .44126 L p 0 .35 .78 r
F P
0 g
s
.6287 .44126 m .61502 .45489 L .60252 .44063 L p 0 .35 .78 r
F P
0 g
s
.59984 .46175 m .58745 .44763 L .60252 .44063 L p 0 .316 .942 r
F P
0 g
s
.58495 .46848 m .57266 .45449 L .58745 .44763 L p 0 .316 .942 r
F P
0 g
s
.57033 .47509 m .55815 .46123 L .57266 .45449 L p 0 .316 .942 r
F P
0 g
s
.54467 .47457 m .55815 .46123 L .57033 .47509 L p 0 .349 .781 r
F P
0 g
s
.55688 .48844 m .57033 .47509 L .55815 .46123 L p 0 .349 .781 r
F P
0 g
s
.55909 .46794 m .57266 .45449 L .58495 .46848 L p 0 .349 .781 r
F P
0 g
s
.57378 .46118 m .58745 .44763 L .59984 .46175 L p 0 .349 .781 r
F P
0 g
s
.58875 .4543 m .60252 .44063 L .61502 .45489 L p 0 .35 .78 r
F P
0 g
s
.59984 .46175 m .5862 .47533 L .60129 .46859 L p 0 .05 .112 r
F P
0 g
s
.58495 .46848 m .5714 .48195 L .5862 .47533 L p 0 .05 .112 r
F P
0 g
s
.57033 .47509 m .55688 .48844 L .5714 .48195 L p 0 .05 .112 r
F P
0 g
s
.58495 .46848 m .5714 .48195 L .55909 .46794 L p 0 .349 .781 r
F P
0 g
s
.59984 .46175 m .5862 .47533 L .57378 .46118 L p 0 .349 .781 r
F P
0 g
s
.61502 .45489 m .60129 .46859 L .58875 .4543 L p 0 .35 .78 r
F P
0 g
s
.60404 .46585 m .66934 .40072 L .66995 .39972 L .89 0 0 r
F
.60404 .46585 m .62572 .49056 L .69071 .42525 L .858 0 0 r
F
.60404 .46585 m .66995 .39972 L .60461 .46488 L .89 0 0 r
F
.60404 .46585 m .60461 .46488 L .60521 .46532 L .562 0 0 r
F
.60404 .46585 m .60521 .46532 L .63011 .48342 L F
.60413 .46315 m .66951 .39798 L .66815 .39595 L .885 0 0 r
F
.62698 .43917 m .63112 .43482 L .63246 .4342 L .157 0 0 r
F
.60413 .46315 m .66815 .39595 L .60273 .46112 L .885 0 0 r
F
.61595 .44915 m .63112 .43482 L .62698 .43917 L .157 0 0 r
F
.61595 .44915 m .62743 .43652 L .63112 .43482 L F
.60273 .46112 m .61373 .45016 L .61595 .44915 L F
.61373 .45016 m .62743 .43652 L .61595 .44915 L F
.62743 .43652 m .61373 .45016 L p .63246 .4342 L F P
0 g
s
.61373 .45016 m .60273 .46112 L p .61595 .44915 L .157 0 0 r
F P
0 g
s
.61595 .44915 m .63246 .4342 L .61373 .45016 L .157 0 0 r
F
.66815 .39595 m .62743 .43652 L p .6503 .41675 L F P
0 g
s
.66934 .40072 m .69538 .41786 L .66995 .39972 L .578 0 0 r
F
.60461 .46488 m .66995 .39972 L .66951 .39798 L .95 0 0 r
F
.66995 .39972 m .69218 .40475 L .66951 .39798 L .578 0 0 r
F
.66995 .39972 m .69538 .41786 L .69218 .40475 L F
.66951 .39798 m .68188 .38946 L .66815 .39595 L F
.66951 .39798 m .69218 .40475 L .68188 .38946 L F
.60461 .46488 m .66951 .39798 L .60413 .46315 L .95 0 0 r
F
.68188 .38946 m .67389 .39324 L p .6503 .41675 L .157 0 0 r
F P
0 g
s
.67389 .39324 m .66815 .39595 L p .6503 .41675 L .157 0 0 r
F P
0 g
s
.63246 .4342 m .68188 .38946 L .62743 .43652 L .157 0 0 r
F
.63246 .4342 m .66815 .39595 L .68188 .38946 L F
.62743 .43652 m .66815 .39595 L .63246 .4342 L F
.58745 .44763 m .60106 .43413 L .61623 .42701 L p 0 .05 .1 r
F P
0 g
s
.59964 .42778 m .58618 .44111 L .57392 .42712 L p 0 .349 .781 r
F P
0 g
s
.57392 .42712 m .58618 .44111 L .59964 .42778 L p 0 .349 .781 r
F P
0 g
s
.5887 .42001 m .60106 .43413 L .61623 .42701 L p 0 .317 .941 r
F P
0 g
s
.60252 .44063 m .61623 .42701 L .60106 .43413 L p 0 .05 .1 r
F P
0 g
s
.61623 .42701 m .60106 .43413 L .5887 .42001 L p 0 .317 .941 r
F P
0 g
s
.61623 .42701 m .60376 .41275 L .5887 .42001 L p 0 .317 .941 r
F P
0 g
s
.5887 .42001 m .60376 .41275 L .61744 .39922 L p 0 .05 .1 r
F P
0 g
s
.61744 .39922 m .60376 .41275 L .5887 .42001 L p 0 .05 .1 r
F P
0 g
s
.5887 .42001 m .60376 .41275 L .61623 .42701 L p 0 .317 .941 r
F P
0 g
s
.61623 .42701 m .60252 .44063 L .58745 .44763 L p 0 .05 .1 r
F P
0 g
s
.65699 .38655 m .64347 .39998 L .63107 .38576 L p 0 .35 .78 r
F P
0 g
s
.63107 .38576 m .64463 .37235 L .65699 .38655 L p 0 .35 .78 r
F P
0 g
s
.63225 .35814 m .64463 .37235 L .63107 .38576 L p 0 .35 .78 r
F P
0 g
s
.61985 .34391 m .63225 .35814 L .61865 .37152 L p 0 .35 .78 r
F P
0 g
s
.63107 .38576 m .61865 .37152 L .63225 .35814 L p 0 .35 .78 r
F P
0 g
s
.64347 .39998 m .62988 .41346 L .61744 .39922 L p 0 .35 .78 r
F P
0 g
s
.61744 .39922 m .63107 .38576 L .64347 .39998 L p 0 .35 .78 r
F P
0 g
s
.61865 .37152 m .63107 .38576 L .61744 .39922 L p 0 .35 .78 r
F P
0 g
s
.60085 .40057 m .61422 .38739 L .59944 .3947 L p 0 .05 .1 r
F P
0 g
s
.59944 .3947 m .61422 .38739 L .60085 .40057 L p 0 .05 .1 r
F P
0 g
s
.60205 .37345 m .61422 .38739 L .60085 .40057 L p 0 .349 .781 r
F P
0 g
s
.61701 .36587 m .60205 .37345 L .61422 .38739 L p 0 .318 .938 r
F P
0 g
s
.60085 .40057 m .61422 .38739 L .60205 .37345 L p 0 .349 .781 r
F P
0 g
s
.61581 .39324 m .60085 .40057 L .58741 .41382 L p 0 .05 .1 r
F P
0 g
s
.58741 .41382 m .60085 .40057 L .61581 .39324 L p 0 .05 .1 r
F P
0 g
s
.58741 .41382 m .60228 .40659 L .61581 .39324 L p 0 .05 .1 r
F P
0 g
s
.61581 .39324 m .60228 .40659 L .58741 .41382 L p 0 .05 .1 r
F P
0 g
s
.61744 .39922 m .60498 .38496 L .61865 .37152 L p 0 .35 .78 r
F P
0 g
s
.62988 .41346 m .61623 .42701 L .60376 .41275 L p 0 .35 .78 r
F P
0 g
s
.60376 .41275 m .61744 .39922 L .62988 .41346 L p 0 .35 .78 r
F P
0 g
s
.60498 .38496 m .61744 .39922 L .60376 .41275 L p 0 .35 .78 r
F P
0 g
s
.60106 .43413 m .5887 .42001 L .57392 .42712 L p 0 .317 .941 r
F P
0 g
s
.57392 .42712 m .5887 .42001 L .60106 .43413 L p 0 .317 .941 r
F P
0 g
s
.57266 .45449 m .58618 .44111 L .60106 .43413 L p 0 .05 .1 r
F P
0 g
s
.57392 .42712 m .58618 .44111 L .60106 .43413 L p 0 .317 .941 r
F P
0 g
s
.58745 .44763 m .60106 .43413 L .58618 .44111 L p 0 .05 .1 r
F P
0 g
s
.60106 .43413 m .58618 .44111 L .57392 .42712 L p 0 .317 .941 r
F P
0 g
s
.60106 .43413 m .58745 .44763 L .57266 .45449 L p 0 .05 .1 r
F P
0 g
s
.58745 .44763 m .60106 .43413 L .5887 .42001 L p 0 .349 .781 r
F P
0 g
s
.57392 .42712 m .58618 .44111 L .57158 .44796 L p 0 .317 .941 r
F P
0 g
s
.55815 .46123 m .57158 .44796 L .58618 .44111 L p 0 .05 .1 r
F P
0 g
s
.57266 .45449 m .58618 .44111 L .57158 .44796 L p 0 .05 .1 r
F P
0 g
s
.58618 .44111 m .57266 .45449 L .55815 .46123 L p 0 .05 .1 r
F P
0 g
s
.57266 .45449 m .58618 .44111 L .57392 .42712 L p 0 .349 .781 r
F P
0 g
s
.56036 .44049 m .57392 .42712 L .58618 .44111 L p 0 .349 .781 r
F P
0 g
s
.57504 .43348 m .5887 .42001 L .60106 .43413 L p 0 .349 .781 r
F P
0 g
s
.59001 .42634 m .60376 .41275 L .61623 .42701 L p 0 .35 .78 r
F P
0 g
s
.60106 .43413 m .58745 .44763 L .60252 .44063 L p 0 .05 .1 r
F P
0 g
s
.58618 .44111 m .57266 .45449 L .58745 .44763 L p 0 .05 .1 r
F P
0 g
s
.57158 .44796 m .55815 .46123 L .54596 .44736 L p 0 .349 .781 r
F P
0 g
s
.57158 .44796 m .55815 .46123 L .57266 .45449 L p 0 .05 .1 r
F P
0 g
s
.58618 .44111 m .57266 .45449 L .56036 .44049 L p 0 .349 .781 r
F P
0 g
s
.60106 .43413 m .58745 .44763 L .57504 .43348 L p 0 .349 .781 r
F P
0 g
s
.61623 .42701 m .60252 .44063 L .59001 .42634 L p 0 .35 .78 r
F P
0 g
s
.60273 .46112 m .66815 .39595 L .6252 .34665 L p .858 0 0 r
F P
0 g
s
.61865 .37152 m .60621 .35726 L .61985 .34391 L p 0 .35 .78 r
F P
0 g
s
.60085 .40057 m .58864 .38662 L .60205 .37345 L p 0 .349 .781 r
F P
0 g
s
.60205 .37345 m .58864 .38662 L .60085 .40057 L p 0 .349 .781 r
F P
0 g
s
.57392 .42712 m .56036 .44049 L .57266 .45449 L p 0 .349 .781 r
F P
0 g
s
.56036 .44049 m .57392 .42712 L .5887 .42001 L p 0 .05 .1 r
F P
0 g
s
.57504 .43348 m .5887 .42001 L .57392 .42712 L p 0 .05 .1 r
F P
0 g
s
.57392 .42712 m .56036 .44049 L .57504 .43348 L p 0 .05 .1 r
F P
0 g
s
.57631 .40586 m .5887 .42001 L .57392 .42712 L p 0 .317 .941 r
F P
0 g
s
.57392 .42712 m .56036 .44049 L .54805 .42646 L p 0 .349 .781 r
F P
0 g
s
.5887 .42001 m .57504 .43348 L .56036 .44049 L p 0 .05 .1 r
F P
0 g
s
.5887 .42001 m .57504 .43348 L .58745 .44763 L p 0 .349 .781 r
F P
0 g
s
.57504 .43348 m .5887 .42001 L .60376 .41275 L p 0 .05 .1 r
F P
0 g
s
.57631 .40586 m .5887 .42001 L .60376 .41275 L p 0 .317 .941 r
F P
0 g
s
.59001 .42634 m .60376 .41275 L .5887 .42001 L p 0 .05 .1 r
F P
0 g
s
.5887 .42001 m .57504 .43348 L .59001 .42634 L p 0 .05 .1 r
F P
0 g
s
.57504 .43348 m .5887 .42001 L .57631 .40586 L p 0 .349 .781 r
F P
0 g
s
.56262 .41932 m .57631 .40586 L .5887 .42001 L p 0 .349 .781 r
F P
0 g
s
.5887 .42001 m .57504 .43348 L .56262 .41932 L p 0 .349 .781 r
F P
0 g
s
.59126 .39847 m .60376 .41275 L .5887 .42001 L p 0 .317 .941 r
F P
0 g
s
.5887 .42001 m .57631 .40586 L .59126 .39847 L p 0 .317 .941 r
F P
0 g
s
.60376 .41275 m .59126 .39847 L .57631 .40586 L p 0 .317 .941 r
F P
0 g
s
.57748 .41203 m .59126 .39847 L .57631 .40586 L p 0 .05 .1 r
F P
0 g
s
.57631 .40586 m .56262 .41932 L .57504 .43348 L p 0 .349 .781 r
F P
0 g
s
.57631 .40586 m .56262 .41932 L .57748 .41203 L p 0 .05 .1 r
F P
0 g
s
.56262 .41932 m .57631 .40586 L .59126 .39847 L p 0 .05 .1 r
F P
0 g
s
.59126 .39847 m .57631 .40586 L p .57809 .38999 L 0 .317 .941 r
F P
0 g
s
.57875 .38416 m .58209 .38798 L p .57809 .38999 L 0 .317 .941 r
F P
0 g
s
.58209 .38798 m .59126 .39847 L p .57809 .38999 L 0 .317 .941 r
F P
0 g
s
.56391 .3917 m .57875 .38416 L p .57809 .38999 L 0 .317 .941 r
F P
0 g
s
.57631 .40586 m .56722 .39548 L p .57809 .38999 L 0 .317 .941 r
F P
0 g
s
.56722 .39548 m .56391 .3917 L p .57809 .38999 L 0 .317 .941 r
F P
0 g
s
.59126 .39847 m .57875 .38416 L .56391 .3917 L p 0 .317 .941 r
F P
0 g
s
.58745 .44763 m .57504 .43348 L .59001 .42634 L p 0 .316 .942 r
F P
0 g
s
.59001 .42634 m .60252 .44063 L .58745 .44763 L p 0 .316 .942 r
F P
0 g
s
.57504 .43348 m .58745 .44763 L .60252 .44063 L p 0 .316 .942 r
F P
0 g
s
.58745 .44763 m .57378 .46118 L .5862 .47533 L p 0 .349 .781 r
F P
0 g
s
.57378 .46118 m .58745 .44763 L .60252 .44063 L p 0 .05 .1 r
F P
0 g
s
.58875 .4543 m .60252 .44063 L .58745 .44763 L p 0 .05 .1 r
F P
0 g
s
.60376 .41275 m .59001 .42634 L .57504 .43348 L p 0 .05 .1 r
F P
0 g
s
.60252 .44063 m .59001 .42634 L .57504 .43348 L p 0 .316 .942 r
F P
0 g
s
.56036 .44049 m .57266 .45449 L .55815 .46123 L p 0 .316 .942 r
F P
0 g
s
.57266 .45449 m .56036 .44049 L .54596 .44736 L p 0 .316 .942 r
F P
0 g
s
.57266 .45449 m .56036 .44049 L .57504 .43348 L p 0 .316 .942 r
F P
0 g
s
.57504 .43348 m .58745 .44763 L .57266 .45449 L p 0 .316 .942 r
F P
0 g
s
.56036 .44049 m .57266 .45449 L .58745 .44763 L p 0 .316 .942 r
F P
0 g
s
.55815 .46123 m .54467 .47457 L .55688 .48844 L p 0 .349 .781 r
F P
0 g
s
.54467 .47457 m .55815 .46123 L .57266 .45449 L p 0 .05 .1 r
F P
0 g
s
.54596 .44736 m .55815 .46123 L .57266 .45449 L p 0 .316 .942 r
F P
0 g
s
.55909 .46794 m .57266 .45449 L .55815 .46123 L p 0 .05 .1 r
F P
0 g
s
.57266 .45449 m .55909 .46794 L .54467 .47457 L p 0 .05 .1 r
F P
0 g
s
.55909 .46794 m .57266 .45449 L .56036 .44049 L p 0 .349 .781 r
F P
0 g
s
.54596 .44736 m .55815 .46123 L .54391 .46785 L p 0 .316 .942 r
F P
0 g
s
.55815 .46123 m .54596 .44736 L .56036 .44049 L p 0 .316 .942 r
F P
0 g
s
.53244 .46067 m .54596 .44736 L .55815 .46123 L p 0 .349 .781 r
F P
0 g
s
.54467 .47457 m .55815 .46123 L .54391 .46785 L p 0 .05 .1 r
F P
0 g
s
.55815 .46123 m .54467 .47457 L .53052 .48107 L p 0 .05 .1 r
F P
0 g
s
.54467 .47457 m .55815 .46123 L .54596 .44736 L p 0 .349 .781 r
F P
0 g
s
.54675 .45391 m .56036 .44049 L .57266 .45449 L p 0 .349 .781 r
F P
0 g
s
.58745 .44763 m .57504 .43348 L .56036 .44049 L p 0 .316 .942 r
F P
0 g
s
.57266 .45449 m .55909 .46794 L .5714 .48195 L p 0 .349 .781 r
F P
0 g
s
.55909 .46794 m .57266 .45449 L .58745 .44763 L p 0 .05 .1 r
F P
0 g
s
.57378 .46118 m .58745 .44763 L .57266 .45449 L p 0 .05 .1 r
F P
0 g
s
.58745 .44763 m .57378 .46118 L .55909 .46794 L p 0 .05 .1 r
F P
0 g
s
.57378 .46118 m .58745 .44763 L .57504 .43348 L p 0 .349 .781 r
F P
0 g
s
.56133 .44702 m .57504 .43348 L .58745 .44763 L p 0 .349 .781 r
F P
0 g
s
.57266 .45449 m .55909 .46794 L .57378 .46118 L p 0 .05 .1 r
F P
0 g
s
.54391 .46785 m .53052 .48107 L .54467 .47457 L p 0 .05 .1 r
F P
0 g
s
.55815 .46123 m .54467 .47457 L .53244 .46067 L p 0 .349 .781 r
F P
0 g
s
.55815 .46123 m .54467 .47457 L .55909 .46794 L p 0 .05 .1 r
F P
0 g
s
.57266 .45449 m .55909 .46794 L .54675 .45391 L p 0 .349 .781 r
F P
0 g
s
.57504 .43348 m .56133 .44702 L .57378 .46118 L p 0 .349 .781 r
F P
0 g
s
.56133 .44702 m .57504 .43348 L .59001 .42634 L p 0 .05 .1 r
F P
0 g
s
.57748 .41203 m .59001 .42634 L .57504 .43348 L p 0 .316 .942 r
F P
0 g
s
.57504 .43348 m .56262 .41932 L .57748 .41203 L p 0 .316 .942 r
F P
0 g
s
.56262 .41932 m .57504 .43348 L .59001 .42634 L p 0 .316 .942 r
F P
0 g
s
.59001 .42634 m .57504 .43348 L p .57597 .43867 L 0 .05 .1 r
F P
0 g
s
.5762 .43999 m .57896 .43725 L p .57597 .43867 L 0 .05 .1 r
F P
0 g
s
.57896 .43725 m .59001 .42634 L p .57597 .43867 L 0 .05 .1 r
F P
0 g
s
.59126 .39847 m .57748 .41203 L .56262 .41932 L p 0 .05 .1 r
F P
0 g
s
.57748 .41203 m .56262 .41932 L p .56431 .40351 L 0 .316 .942 r
F P
0 g
s
.56493 .39771 m .56827 .40153 L p .56431 .40351 L 0 .316 .942 r
F P
0 g
s
.56827 .40153 m .57748 .41203 L p .56431 .40351 L 0 .316 .942 r
F P
0 g
s
.55018 .40513 m .56262 .41932 L .57748 .41203 L p 0 .316 .942 r
F P
0 g
s
.59001 .42634 m .57748 .41203 L .56262 .41932 L p 0 .316 .942 r
F P
0 g
s
.56262 .41932 m .57504 .43348 L .56036 .44049 L p 0 .316 .942 r
F P
0 g
s
.57504 .43348 m .56262 .41932 L .54805 .42646 L p 0 .316 .942 r
F P
0 g
s
.56036 .44049 m .54675 .45391 L .55909 .46794 L p 0 .349 .781 r
F P
0 g
s
.54675 .45391 m .56036 .44049 L .57504 .43348 L p 0 .05 .1 r
F P
0 g
s
.54805 .42646 m .56036 .44049 L .57504 .43348 L p 0 .316 .942 r
F P
0 g
s
.56133 .44702 m .57504 .43348 L .56036 .44049 L p 0 .05 .1 r
F P
0 g
s
.57504 .43348 m .56133 .44702 L .54675 .45391 L p 0 .05 .1 r
F P
0 g
s
.56133 .44702 m .57504 .43348 L .56262 .41932 L p 0 .349 .781 r
F P
0 g
s
.54805 .42646 m .56036 .44049 L .54596 .44736 L p 0 .316 .942 r
F P
0 g
s
.56036 .44049 m .54805 .42646 L .56262 .41932 L p 0 .316 .942 r
F P
0 g
s
.54596 .44736 m .53244 .46067 L .54467 .47457 L p 0 .349 .781 r
F P
0 g
s
.53244 .46067 m .54596 .44736 L .56036 .44049 L p 0 .05 .1 r
F P
0 g
s
.54675 .45391 m .56036 .44049 L .54596 .44736 L p 0 .05 .1 r
F P
0 g
s
.56036 .44049 m .54675 .45391 L .53244 .46067 L p 0 .05 .1 r
F P
0 g
s
.54675 .45391 m .56036 .44049 L .54805 .42646 L p 0 .349 .781 r
F P
0 g
s
.5344 .43986 m .54805 .42646 L .56036 .44049 L p 0 .349 .781 r
F P
0 g
s
.54887 .43283 m .56262 .41932 L .57504 .43348 L p 0 .349 .781 r
F P
0 g
s
.57748 .41203 m .56262 .41932 L p .56342 .42438 L 0 .05 .1 r
F P
0 g
s
.56363 .42566 m .5664 .42293 L p .56342 .42438 L 0 .05 .1 r
F P
0 g
s
.5664 .42293 m .57748 .41203 L p .56342 .42438 L 0 .05 .1 r
F P
0 g
s
.56036 .44049 m .54675 .45391 L .56133 .44702 L p 0 .05 .1 r
F P
0 g
s
.54596 .44736 m .53244 .46067 L .5202 .44676 L p 0 .349 .781 r
F P
0 g
s
.54596 .44736 m .53244 .46067 L .54675 .45391 L p 0 .05 .1 r
F P
0 g
s
.56036 .44049 m .54675 .45391 L .5344 .43986 L p 0 .349 .781 r
F P
0 g
s
.56262 .41932 m .54887 .43283 L .56133 .44702 L p 0 .349 .781 r
F P
0 g
s
.54887 .43283 m .56262 .41932 L .57748 .41203 L p 0 .05 .1 r
F P
0 g
s
.57748 .41203 m .56493 .39771 L .55018 .40513 L p 0 .316 .942 r
F P
0 g
s
.60252 .44063 m .58875 .4543 L .57378 .46118 L p 0 .05 .1 r
F P
0 g
s
.5762 .43999 m .56133 .44702 L p .56703 .4429 L 0 .05 .1 r
F P
0 g
s
.59001 .42634 m .57896 .43725 L p .56703 .4429 L 0 .05 .1 r
F P
0 g
s
.57896 .43725 m .5762 .43999 L p .56703 .4429 L 0 .05 .1 r
F P
0 g
s
.57748 .41203 m .56363 .42566 L .54887 .43283 L p 0 .05 .1 r
F P
0 g
s
.60621 .35726 m .61865 .37152 L .60498 .38496 L p 0 .35 .78 r
F P
0 g
s
.60498 .38496 m .59251 .37068 L .60621 .35726 L p 0 .35 .78 r
F P
0 g
s
.59251 .37068 m .60498 .38496 L .59126 .39847 L p 0 .35 .78 r
F P
0 g
s
.60376 .41275 m .59126 .39847 L .60498 .38496 L p 0 .35 .78 r
F P
0 g
s
.59126 .39847 m .57875 .38416 L .59251 .37068 L p 0 .35 .78 r
F P
0 g
s
.57748 .41203 m .59126 .39847 L .60376 .41275 L p 0 .35 .78 r
F P
0 g
s
.60376 .41275 m .59001 .42634 L .57748 .41203 L p 0 .35 .78 r
F P
0 g
s
.56493 .39771 m .57875 .38416 L .59126 .39847 L p 0 .35 .78 r
F P
0 g
s
.59126 .39847 m .57748 .41203 L .56493 .39771 L p 0 .35 .78 r
F P
0 g
s
.5762 .43999 m .59001 .42634 L .60252 .44063 L p 0 .35 .78 r
F P
0 g
s
.58745 .44763 m .57378 .46118 L .56133 .44702 L p 0 .349 .781 r
F P
0 g
s
.58745 .44763 m .57378 .46118 L .58875 .4543 L p 0 .05 .1 r
F P
0 g
s
.60252 .44063 m .58875 .4543 L .5762 .43999 L p 0 .35 .78 r
F P
0 g
s
.56363 .42566 m .57748 .41203 L .59001 .42634 L p 0 .35 .78 r
F P
0 g
s
.57504 .43348 m .56133 .44702 L .5762 .43999 L p 0 .05 .1 r
F P
0 g
s
.57504 .43348 m .56133 .44702 L .54887 .43283 L p 0 .349 .781 r
F P
0 g
s
.59001 .42634 m .5762 .43999 L .56363 .42566 L p 0 .35 .78 r
F P
0 g
s
.54887 .43283 m .56262 .41932 L .54805 .42646 L p 0 .05 .1 r
F P
0 g
s
.54805 .42646 m .5344 .43986 L .54675 .45391 L p 0 .349 .781 r
F P
0 g
s
.5344 .43986 m .54805 .42646 L .56262 .41932 L p 0 .05 .1 r
F P
0 g
s
.56262 .41932 m .55018 .40513 L p .54913 .42728 L 0 .349 .781 r
F P
0 g
s
.56262 .41932 m .54887 .43283 L .5344 .43986 L p 0 .05 .1 r
F P
0 g
s
.54887 .43283 m .55163 .43012 L p .54913 .42728 L 0 .349 .781 r
F P
0 g
s
.55163 .43012 m .56262 .41932 L p .54913 .42728 L 0 .349 .781 r
F P
0 g
s
.53639 .41862 m .55018 .40513 L .56262 .41932 L p 0 .349 .781 r
F P
0 g
s
.53713 .43718 m .54805 .42646 L p .53466 .43437 L 0 .349 .781 r
F P
0 g
s
.54805 .42646 m .5344 .43986 L .54887 .43283 L p 0 .05 .1 r
F P
0 g
s
.54805 .42646 m .5344 .43986 L .52203 .42579 L p 0 .349 .781 r
F P
0 g
s
.55018 .40513 m .53639 .41862 L .54887 .43283 L p 0 .349 .781 r
F P
0 g
s
.53916 .41592 m .55382 .40858 L p .54192 .41322 L .1 0 0 r
F P
0 g
s
.53916 .41592 m .54192 .41322 L .53025 .41776 L .1 0 0 r
F
.55382 .40858 m .56493 .39771 L p .54743 .40782 L F P
0 g
s
.53025 .41776 m .54192 .41322 L .54743 .40782 L .1 0 0 r
F
.54192 .41322 m .55382 .40858 L .54743 .40782 L F
.54858 .4067 m .56493 .39771 L .55018 .40513 L F
.54858 .4067 m .55018 .40513 L .53572 .41242 L F
.54743 .40782 m .56493 .39771 L .54858 .4067 L F
.54743 .40782 m .54858 .4067 L .53253 .41553 L F
.53708 .41108 m .57875 .38416 L .54118 .40708 L F
.53708 .41108 m .54118 .40708 L .51685 .42192 L F
.54118 .40708 m .57875 .38416 L .54935 .3991 L F
.54118 .40708 m .54935 .3991 L .54217 .40274 L F
.56493 .39771 m .57875 .38416 L p .53254 .41402 L F P
0 g
s
.57875 .38416 m .61985 .34391 L p .54217 .40274 L .1 0 0 r
F P
0 g
s
.54217 .40274 m .5386 .40455 L .53236 .40899 L .1 0 0 r
F
.54217 .40274 m .53236 .40899 L .53055 .41075 L F
.52695 .41427 m .54217 .40274 L .53055 .41075 L F
.54217 .40274 m .55749 .39113 L .5386 .40455 L F
.53236 .40899 m .5386 .40455 L .53506 .40635 L F
.5386 .40455 m .55749 .39113 L .52103 .41348 L F
.54853 .3932 m .53441 .40043 L .54773 .38744 L p 0 .05 .1 r
F P
0 g
s
.53441 .40043 m .54853 .3932 L .53506 .40635 L p 0 .05 .1 r
F P
0 g
s
.54935 .3991 m .53506 .40635 L .54853 .3932 L p 0 .05 .1 r
F P
0 g
s
.52153 .41956 m .53506 .40635 L .54935 .3991 L p 0 .05 .1 r
F P
0 g
s
.54935 .3991 m .53572 .41242 L .52153 .41956 L p 0 .05 .1 r
F P
0 g
s
.53572 .41242 m .54935 .3991 L .56391 .3917 L p 0 .05 .1 r
F P
0 g
s
.56391 .3917 m .55018 .40513 L .53572 .41242 L p 0 .05 .1 r
F P
0 g
s
.53572 .41242 m .55018 .40513 L p .52763 .42169 L 0 .05 .1 r
F P
0 g
s
.52203 .42579 m .52477 .42311 L p .52763 .42169 L 0 .05 .1 r
F P
0 g
s
.52477 .42311 m .53572 .41242 L p .52763 .42169 L 0 .05 .1 r
F P
0 g
s
.53025 .41776 m .53253 .41553 L .51678 .4242 L .1 0 0 r
F
.53253 .41553 m .53572 .41242 L .53254 .41402 L F
.51678 .4242 m .53254 .41402 L .52153 .41956 L F
.51338 .42752 m .52477 .42311 L .53025 .41776 L F
.53055 .41075 m .53236 .40899 L .5076 .42658 L F
.52695 .41427 m .53055 .41075 L .5076 .42658 L F
.53236 .40899 m .53506 .40635 L .52103 .41348 L F
.53506 .40635 m .52103 .41348 L .53441 .40043 L p 0 .05 .1 r
F P
0 g
s
.5076 .42658 m .52103 .41348 L .53506 .40635 L p 0 .05 .1 r
F P
0 g
s
.53506 .40635 m .52153 .41956 L .5076 .42658 L p 0 .05 .1 r
F P
0 g
s
.51066 .43017 m .52477 .42311 L p .51338 .42752 L .1 0 0 r
F P
0 g
s
.52153 .41956 m .53572 .41242 L p .51346 .42877 L 0 .05 .1 r
F P
0 g
s
.50793 .43283 m .51066 .43017 L p .51311 .43296 L 0 .349 .781 r
F P
0 g
s
.50793 .43283 m .51066 .43017 L p .51346 .42877 L 0 .05 .1 r
F P
0 g
s
.51066 .43017 m .52153 .41956 L p .51346 .42877 L 0 .05 .1 r
F P
0 g
s
.49681 .4371 m .51338 .42752 L .51678 .4242 L .1 0 0 r
F
.51678 .4242 m .52153 .41956 L .51685 .42192 L F
.5076 .42658 m .49681 .4371 L p .51685 .42192 L F P
0 g
s
.5076 .42658 m .52153 .41956 L p .50743 .42993 L 0 .05 .1 r
F P
0 g
s
.50793 .43283 m .4941 .43974 L p .49956 .43573 L 0 .05 .1 r
F P
0 g
s
.52153 .41956 m .51066 .43017 L p .49956 .43573 L 0 .05 .1 r
F P
0 g
s
.51066 .43017 m .50793 .43283 L p .49956 .43573 L 0 .05 .1 r
F P
0 g
s
.49956 .43573 m .50748 .42902 L .50403 .43243 L 0 .05 .1 r
F
.49956 .43573 m .5076 .42658 L .50748 .42902 L F
.49681 .4371 m .5076 .42658 L p .49956 .43573 L F P
0 g
s
.51066 .43017 m .49681 .4371 L p .50534 .42413 L .562 0 0 r
F P
0 g
s
.52203 .42579 m .50793 .43283 L p .51346 .42877 L 0 .05 .1 r
F P
0 g
s
.53572 .41242 m .52477 .42311 L p .51346 .42877 L 0 .05 .1 r
F P
0 g
s
.52477 .42311 m .52203 .42579 L p .51346 .42877 L 0 .05 .1 r
F P
0 g
s
.51762 .41498 m .53197 .38367 L .52477 .42311 L .562 0 0 r
F
.52477 .42311 m .51066 .43017 L p .51762 .41498 L F P
0 g
s
.53639 .41862 m .52203 .42579 L p .52763 .42169 L 0 .05 .1 r
F P
0 g
s
.55018 .40513 m .53916 .41592 L p .52763 .42169 L 0 .05 .1 r
F P
0 g
s
.53916 .41592 m .53639 .41862 L p .52763 .42169 L 0 .05 .1 r
F P
0 g
s
.55018 .40513 m .56391 .3917 L .57875 .38416 L p 0 .05 .1 r
F P
0 g
s
.57875 .38416 m .56493 .39771 L .55018 .40513 L p 0 .05 .1 r
F P
0 g
s
.53639 .41862 m .55018 .40513 L .56493 .39771 L p 0 .05 .1 r
F P
0 g
s
.55104 .41131 m .53639 .41862 L p .54207 .41446 L 0 .05 .1 r
F P
0 g
s
.56493 .39771 m .55382 .40858 L p .54207 .41446 L 0 .05 .1 r
F P
0 g
s
.55382 .40858 m .55104 .41131 L p .54207 .41446 L 0 .05 .1 r
F P
0 g
s
.56493 .39771 m .57748 .41203 L p .55634 .41145 L 0 .35 .78 r
F P
0 g
s
.55104 .41131 m .55382 .40858 L p .55634 .41145 L 0 .35 .78 r
F P
0 g
s
.55382 .40858 m .56493 .39771 L p .55634 .41145 L 0 .35 .78 r
F P
0 g
s
.61985 .34391 m .58986 .3595 L p .55749 .39113 L .1 0 0 r
F P
0 g
s
.58986 .3595 m .56099 .37451 L p .55749 .39113 L .1 0 0 r
F P
0 g
s
.5746 .31725 m .59031 .33526 L p .58498 .34598 L 0 .318 .938 r
F P
0 g
s
.61927 .33753 m .60432 .34537 L .58986 .3595 L p 0 .05 .1 r
F P
0 g
s
.60471 .35177 m .58986 .3595 L .60432 .34537 L p 0 .05 .1 r
F P
0 g
s
.58986 .3595 m .60471 .35177 L .61927 .33753 L p 0 .05 .1 r
F P
0 g
s
.59031 .33526 m .60471 .35177 L p .58498 .34598 L 0 .318 .938 r
F P
0 g
s
.60471 .35177 m .58986 .3595 L p .58498 .34598 L 0 .318 .938 r
F P
0 g
s
.56099 .37451 m .57529 .36707 L .56194 .38011 L p 0 .05 .1 r
F P
0 g
s
.63376 .32336 m .61871 .33131 L .60432 .34537 L p 0 .05 .1 r
F P
0 g
s
.60432 .34537 m .61871 .33131 L .63376 .32336 L p 0 .05 .1 r
F P
0 g
s
.60432 .34537 m .61927 .33753 L .63376 .32336 L p 0 .05 .1 r
F P
0 g
s
.63376 .32336 m .61927 .33753 L .60432 .34537 L p 0 .05 .1 r
F P
0 g
s
.60432 .34537 m .61927 .33753 L .60471 .35177 L p 0 .05 .1 r
F P
0 g
s
.63451 .32955 m .61927 .33753 L .60471 .35177 L p 0 .05 .1 r
F P
0 g
s
.61985 .34391 m .60471 .35177 L .61927 .33753 L p 0 .05 .1 r
F P
0 g
s
.60471 .35177 m .61985 .34391 L .63451 .32955 L p 0 .05 .1 r
F P
0 g
s
.56099 .37451 m .61985 .34391 L .59831 .31919 L p .578 0 0 r
F P
0 g
s
.57529 .36707 m .58986 .3595 L .57642 .37264 L p 0 .05 .1 r
F P
0 g
s
.57642 .37264 m .56194 .38011 L .57529 .36707 L p 0 .05 .1 r
F P
0 g
s
.56194 .38011 m .57642 .37264 L .56291 .38584 L p 0 .05 .1 r
F P
0 g
s
.58986 .3595 m .56001 .3253 L .5746 .31725 L p 0 .318 .938 r
F P
0 g
s
.57642 .37264 m .58986 .3595 L .60471 .35177 L p 0 .05 .1 r
F P
0 g
s
.60471 .35177 m .59117 .36502 L .57642 .37264 L p 0 .05 .1 r
F P
0 g
s
.56291 .38584 m .57642 .37264 L .59117 .36502 L p 0 .05 .1 r
F P
0 g
s
.59117 .36502 m .57757 .37833 L .56291 .38584 L p 0 .05 .1 r
F P
0 g
s
.54935 .3991 m .56291 .38584 L .57757 .37833 L p 0 .05 .1 r
F P
0 g
s
.57757 .37833 m .56391 .3917 L .54935 .3991 L p 0 .05 .1 r
F P
0 g
s
.58947 .30903 m .61985 .34391 L .60471 .35177 L p 0 .318 .938 r
F P
0 g
s
.60471 .35177 m .5746 .31725 L .58947 .30903 L p 0 .318 .938 r
F P
0 g
s
.59117 .36502 m .60471 .35177 L .61985 .34391 L p 0 .05 .1 r
F P
0 g
s
.61985 .34391 m .60621 .35726 L .59117 .36502 L p 0 .05 .1 r
F P
0 g
s
.57757 .37833 m .59117 .36502 L .60621 .35726 L p 0 .05 .1 r
F P
0 g
s
.56391 .3917 m .57757 .37833 L .59251 .37068 L p 0 .05 .1 r
F P
0 g
s
.60621 .35726 m .59251 .37068 L .57757 .37833 L p 0 .05 .1 r
F P
0 g
s
.59251 .37068 m .57875 .38416 L .56391 .3917 L p 0 .05 .1 r
F P
0 g
s
.59831 .31919 m .61985 .34391 L .55382 .40858 L p .858 0 0 r
F P
0 g
s
.55382 .40858 m .61985 .34391 L .59831 .31919 L .858 0 0 r
F
.55526 .4086 m .61985 .34391 L .55382 .40858 L .554 0 0 r
F
.56194 .38011 m .54773 .38744 L .56099 .37451 L p 0 .05 .1 r
F P
0 g
s
.54773 .38744 m .56194 .38011 L .54853 .3932 L p 0 .05 .1 r
F P
0 g
s
.56291 .38584 m .54853 .3932 L .56194 .38011 L p 0 .05 .1 r
F P
0 g
s
.54853 .3932 m .56291 .38584 L .54935 .3991 L p 0 .05 .1 r
F P
0 g
s
.55382 .40858 m .53197 .38367 L .59831 .31919 L p .858 0 0 r
F P
0 g
s
.55382 .40858 m .59831 .31919 L .53197 .38367 L .858 0 0 r
F
.55479 .4081 m .55382 .40858 L .53197 .38367 L .562 0 0 r
F
.55526 .4086 m .55382 .40858 L .55479 .4081 L F
.53197 .38367 m .55382 .40858 L .53916 .41592 L p F P
0 g
s
.53916 .41592 m .52477 .42311 L p .52834 .40359 L .562 0 0 r
F P
0 g
s
.52834 .40359 m .53197 .38367 L .53916 .41592 L .562 0 0 r
F
.56262 .41932 m .54887 .43283 L .53639 .41862 L p 0 .349 .781 r
F P
0 g
s
.56262 .41932 m .54887 .43283 L .56363 .42566 L p 0 .05 .1 r
F P
0 g
s
.57748 .41203 m .56363 .42566 L .55104 .41131 L p 0 .35 .78 r
F P
0 g
s
.6252 .34665 m .55916 .41143 L .60273 .46112 L p .858 0 0 r
F P
0 g
s
.58753 .4332 m .56839 .42196 L .57868 .41695 L .562 0 0 r
F
.60273 .46112 m .58097 .4363 L p .58753 .4332 L F P
0 g
s
.58097 .4363 m .56839 .42196 L p .58753 .4332 L .562 0 0 r
F P
0 g
s
.57868 .41695 m .55916 .41143 L .57216 .40497 L .562 0 0 r
F
.56839 .42196 m .55916 .41143 L p .57868 .41695 L F P
0 g
s
.57027 .40053 m .589 .38449 L .58409 .38697 L .1 0 0 r
F
.55916 .41143 m .57243 .39945 L .57027 .40053 L F
.57243 .39945 m .589 .38449 L .57027 .40053 L F
.60273 .46112 m .58753 .4332 L .60551 .44699 L .562 0 0 r
F
.60273 .46112 m .68188 .38946 L .61607 .4551 L .157 0 0 r
F
.60273 .46112 m .61607 .4551 L .68188 .38946 L p F P
0 g
s
.60273 .46112 m .60551 .44699 L .61607 .4551 L .562 0 0 r
F
.57216 .40497 m .59414 .43007 L p .58753 .4332 L F P
0 g
s
.59414 .43007 m .61607 .4551 L p .58753 .4332 L .562 0 0 r
F P
0 g
s
.58409 .38697 m .63861 .33972 L .6252 .34665 L .1 0 0 r
F
.589 .38449 m .63861 .33972 L .58409 .38697 L F
.57027 .40053 m .58409 .38697 L .57243 .39945 L F
.58409 .38697 m .6252 .34665 L p .58572 .38615 L F P
0 g
s
.58409 .38697 m .58572 .38615 L .57243 .39945 L .1 0 0 r
F
.6252 .34665 m .63861 .33972 L p .589 .38449 L F P
0 g
s
.57243 .39945 m .58572 .38615 L .589 .38449 L .1 0 0 r
F
.58572 .38615 m .6252 .34665 L .589 .38449 L F
.55916 .41143 m .57027 .40053 L p .57243 .39945 L F P
0 g
s
.5344 .43986 m .53713 .43718 L p .53466 .43437 L 0 .349 .781 r
F P
0 g
s
.4941 .43974 m .49681 .4371 L p .49956 .43573 L 0 .05 .1 r
F P
0 g
s
.50534 .42413 m .53197 .38367 L .51066 .43017 L .562 0 0 r
F
.59831 .31919 m .56533 .35125 L p .55061 .35911 L .1 0 0 r
F P
0 g
s
.53618 .36681 m .59831 .31919 L .50331 .39869 L .1 0 0 r
F
.56533 .35125 m .59831 .31919 L p .55249 .35099 L F P
0 g
s
.59831 .31919 m .5687 .33526 L p .55249 .35099 L .1 0 0 r
F P
0 g
s
.5687 .33526 m .54019 .35074 L p .55249 .35099 L .1 0 0 r
F P
0 g
s
.54019 .35074 m .5687 .33526 L p .53618 .36681 L .1 0 0 r
F P
0 g
s
.5687 .33526 m .59831 .31919 L p .53618 .36681 L .1 0 0 r
F P
0 g
s
.54599 .32713 m .56027 .31335 L .53101 .27982 L p 0 .349 .782 r
F P
0 g
s
.53101 .27982 m .51663 .29354 L .54599 .32713 L p 0 .349 .782 r
F P
0 g
s
.53164 .34098 m .54599 .32713 L .51663 .29354 L p 0 .349 .782 r
F P
0 g
s
.53101 .27982 m .56027 .31335 L .57452 .30537 L p 0 .319 .936 r
F P
0 g
s
.57452 .30537 m .54501 .27151 L .53101 .27982 L p 0 .319 .936 r
F P
0 g
s
.51663 .29354 m .50219 .30733 L .53164 .34098 L p 0 .349 .782 r
F P
0 g
s
.54501 .27151 m .57452 .30537 L .58904 .29723 L p 0 .319 .936 r
F P
0 g
s
.58904 .29723 m .55927 .26305 L .54501 .27151 L p 0 .319 .936 r
F P
0 g
s
.57456 .31124 m .58904 .29723 L .57173 .27736 L p 0 .349 .781 r
F P
0 g
s
.57173 .27736 m .55927 .26305 L p .56566 .28319 L 0 .349 .781 r
F P
0 g
s
.57456 .31124 m .57173 .27736 L .56566 .28319 L 0 .349 .781 r
F
.58904 .29723 m .57456 .31124 L p .56566 .28319 L F P
0 g
s
.55927 .26305 m .57173 .27736 L p .56566 .28319 L 0 .349 .781 r
F P
0 g
s
.57173 .27736 m .58904 .29723 L p .56566 .28319 L 0 .349 .781 r
F P
0 g
s
.55927 .26305 m .5447 .27699 L .57456 .31124 L p 0 .349 .781 r
F P
0 g
s
.57456 .31124 m .5447 .27699 L .55927 .26305 L p 0 .349 .781 r
F P
0 g
s
.56001 .3253 m .57456 .31124 L .5447 .27699 L p 0 .349 .781 r
F P
0 g
s
.5447 .27699 m .57456 .31124 L .56001 .3253 L p 0 .349 .781 r
F P
0 g
s
.5447 .27699 m .53005 .291 L .56001 .3253 L p 0 .349 .781 r
F P
0 g
s
.56001 .3253 m .53005 .291 L .5447 .27699 L p 0 .349 .781 r
F P
0 g
s
.57174 .28869 m .51452 .32142 L p .54019 .35074 L .578 0 0 r
F P
0 g
s
.54019 .35074 m .51452 .32142 L .50703 .33703 L .578 0 0 r
F
.50812 .38178 m .54019 .35074 L .51452 .32142 L p .856 0 0 r
F P
0 g
s
.50812 .38178 m .51452 .32142 L .54019 .35074 L .856 0 0 r
F
.54569 .33321 m .53164 .34098 L .50219 .30733 L p 0 .318 .938 r
F P
0 g
s
.48227 .35235 m .50703 .33703 L .51452 .32142 L .949 0 0 r
F
.48227 .35235 m .47506 .36773 L .50703 .33703 L F
.51452 .32142 m .48227 .35235 L .50812 .38178 L p .856 0 0 r
F P
0 g
s
.50812 .38178 m .48227 .35235 L .51452 .32142 L .856 0 0 r
F
.50219 .30733 m .51599 .29924 L .54569 .33321 L p 0 .318 .938 r
F P
0 g
s
.56001 .3253 m .54569 .33321 L .51599 .29924 L p 0 .318 .938 r
F P
0 g
s
.51599 .29924 m .53005 .291 L .56001 .3253 L p 0 .318 .938 r
F P
0 g
s
.54438 .2826 m .5746 .31725 L .56001 .3253 L p 0 .318 .938 r
F P
0 g
s
.56001 .3253 m .53005 .291 L .54438 .2826 L p 0 .318 .938 r
F P
0 g
s
.55898 .27404 m .58947 .30903 L .5746 .31725 L p 0 .318 .938 r
F P
0 g
s
.5746 .31725 m .54438 .2826 L .55898 .27404 L p 0 .318 .938 r
F P
0 g
s
.57174 .28869 m .53856 .32063 L .50988 .33679 L p .1 0 0 r
F P
0 g
s
.50988 .33679 m .48227 .35235 L p .52628 .32103 L .1 0 0 r
F P
0 g
s
.52628 .32103 m .57174 .28869 L .50988 .33679 L .1 0 0 r
F
.48227 .35235 m .51452 .32142 L .54259 .30536 L p F P
0 g
s
.54259 .30536 m .57174 .28869 L p .52628 .32103 L .1 0 0 r
F P
0 g
s
.48227 .35235 m .54259 .30536 L .52628 .32103 L .1 0 0 r
F
.54019 .35074 m .59831 .31919 L .57174 .28869 L p .578 0 0 r
F P
0 g
s
.54271 .3837 m .53197 .38367 L .56533 .35125 L .547 0 0 r
F
.57073 .35119 m .56533 .35125 L .59831 .31919 L F
.54271 .3837 m .56533 .35125 L .57073 .35119 L F
.60383 .28895 m .58904 .29723 L .61871 .33131 L p 0 .319 .936 r
F P
0 g
s
.61985 .34391 m .58947 .30903 L .60422 .29473 L p 0 .35 .78 r
F P
0 g
s
.61927 .33753 m .63451 .32955 L .61985 .34391 L p 0 .05 .1 r
F P
0 g
s
.61871 .33131 m .63376 .32336 L .60383 .28895 L p 0 .319 .936 r
F P
0 g
s
.64909 .31526 m .63376 .32336 L .61927 .33753 L p 0 .05 .1 r
F P
0 g
s
.63451 .32955 m .61927 .33753 L .63376 .32336 L p 0 .05 .1 r
F P
0 g
s
.61927 .33753 m .63451 .32955 L .64909 .31526 L p 0 .05 .1 r
F P
0 g
s
.60422 .29473 m .63451 .32955 L .61985 .34391 L p 0 .35 .78 r
F P
0 g
s
.62131 .34388 m .59831 .31919 L .61985 .34391 L .578 0 0 r
F
.62131 .34388 m .60924 .31892 L .59831 .31919 L F
.57616 .35113 m .59831 .31919 L .60924 .31892 L .547 0 0 r
F
.54271 .3837 m .57073 .35119 L .57616 .35113 L F
.57073 .35119 m .59831 .31919 L .57616 .35113 L F
.57174 .28869 m .59831 .31919 L .56533 .35125 L p .858 0 0 r
F P
0 g
s
.56533 .35125 m .59831 .31919 L .57174 .28869 L .858 0 0 r
F
.57616 .35113 m .59831 .31919 L .56533 .35125 L .547 0 0 r
F
.57616 .35113 m .60924 .31892 L .59831 .31919 L F
.56533 .35125 m .53856 .32063 L .57174 .28869 L p .858 0 0 r
F P
0 g
s
.56533 .35125 m .57174 .28869 L .53856 .32063 L .858 0 0 r
F
.62327 .34489 m .60924 .31892 L .62131 .34388 L .578 0 0 r
F
.62327 .34489 m .62402 .32643 L .60924 .31892 L F
.59091 .35878 m .60924 .31892 L .62402 .32643 L .76 0 0 r
F
.55744 .39149 m .58352 .35495 L .59091 .35878 L F
.58352 .35495 m .60924 .31892 L .59091 .35878 L F
.55526 .4086 m .62131 .34388 L .61985 .34391 L .554 0 0 r
F
.55721 .40964 m .62131 .34388 L .55526 .4086 L .761 0 0 r
F
.55721 .40964 m .62327 .34489 L .62131 .34388 L F
.55744 .39149 m .54271 .3837 L .57616 .35113 L .76 0 0 r
F
.58352 .35495 m .57616 .35113 L .60924 .31892 L F
.55744 .39149 m .57616 .35113 L .58352 .35495 L F
.55916 .41143 m .62327 .34489 L .55721 .40964 L .832 0 0 r
F
.55916 .41143 m .6252 .34665 L .62327 .34489 L F
.59091 .35878 m .60924 .31892 L .57616 .35113 L .76 0 0 r
F
.59091 .35878 m .62402 .32643 L .60924 .31892 L F
.6252 .34665 m .62402 .32643 L .62327 .34489 L .578 0 0 r
F
.6252 .34665 m .63861 .33972 L .62402 .32643 L F
.63861 .33972 m .57216 .40497 L .55916 .41143 L p .1 0 0 r
F P
0 g
s
.55916 .41143 m .57216 .40497 L .63861 .33972 L .1 0 0 r
F
.57216 .40497 m .62402 .32643 L .63861 .33972 L .832 0 0 r
F
.57216 .40497 m .55744 .39149 L .62402 .32643 L F
.60557 .37217 m .62402 .32643 L .59091 .35878 L F
.60557 .37217 m .63861 .33972 L .62402 .32643 L F
.61607 .4551 m .57216 .40497 L .63861 .33972 L p .859 0 0 r
F P
0 g
s
.66889 .34838 m .65757 .34734 L .64909 .31526 L p 0 .35 .78 r
F P
0 g
s
.63451 .32955 m .64909 .31526 L .65757 .34734 L p 0 .35 .78 r
F P
0 g
s
.68251 .37942 m .69827 .37188 L .67372 .3436 L p 0 .319 .936 r
F P
0 g
s
.69827 .37188 m .68384 .38626 L .66917 .38058 L p 0 .35 .78 r
F P
0 g
s
.66917 .38058 m .66899 .36048 L .69827 .37188 L p 0 .35 .78 r
F P
0 g
s
.66815 .39595 m .68188 .38946 L .63861 .33972 L p .578 0 0 r
F P
0 g
s
.63861 .33972 m .68188 .38946 L .61607 .4551 L p .859 0 0 r
F P
0 g
s
.65543 .33103 m .63861 .33972 L .68188 .38946 L p .578 0 0 r
F P
0 g
s
.64916 .4221 m .68188 .38946 L .63861 .33972 L p .859 0 0 r
F P
0 g
s
.63861 .33972 m .60557 .37217 L .64916 .4221 L p .859 0 0 r
F P
0 g
s
.60557 .37217 m .63861 .33972 L .65543 .33103 L p .1 0 0 r
F P
0 g
s
.60557 .37217 m .65543 .33103 L .63861 .33972 L .1 0 0 r
F
.65543 .33103 m .62213 .36377 L .60557 .37217 L p F P
0 g
s
.60557 .37217 m .62213 .36377 L .65543 .33103 L .1 0 0 r
F
.61121 .3693 m .59153 .33585 L .62213 .36377 L .57 0 0 r
F
.60557 .37217 m .60277 .36493 L .61121 .3693 L F
.60277 .36493 m .59153 .33585 L .61121 .3693 L F
.60277 .36493 m .59091 .35878 L .59153 .33585 L F
.60557 .37217 m .59091 .35878 L .60277 .36493 L F
.59112 .35096 m .56084 .32008 L .59153 .33585 L F
.59091 .35878 m .58489 .35103 L .59112 .35096 L F
.58489 .35103 m .56084 .32008 L .59112 .35096 L F
.58489 .35103 m .57616 .35113 L .56084 .32008 L F
.59091 .35878 m .57616 .35113 L .58489 .35103 L F
.57195 .34772 m .56533 .35125 L .53856 .32063 L F
.57616 .35113 m .56533 .35125 L .57195 .34772 L F
.53197 .38367 m .50331 .39869 L p .55061 .35911 L .1 0 0 r
F P
0 g
s
.56533 .35125 m .53197 .38367 L p .55061 .35911 L .1 0 0 r
F P
0 g
s
.50331 .39869 m .47571 .41315 L p .53618 .36681 L .1 0 0 r
F P
0 g
s
.50812 .38178 m .53618 .36681 L p .55249 .35099 L .1 0 0 r
F P
0 g
s
.53618 .36681 m .56533 .35125 L p .55249 .35099 L .1 0 0 r
F P
0 g
s
.54019 .35074 m .50812 .38178 L p .55249 .35099 L .1 0 0 r
F P
0 g
s
.47571 .41315 m .50812 .38178 L p .53618 .36681 L .1 0 0 r
F P
0 g
s
.50812 .38178 m .54019 .35074 L p .53618 .36681 L .1 0 0 r
F P
0 g
s
.48308 .39382 m
.48375 .39479 L
s
.48375 .39479 m
.48817 .4011 L
s
.76747 .52671 m .75161 .53259 L .72417 .56095 L p 0 .05 .248 r
F P
0 g
s
.75161 .53259 m .76747 .52671 L .75109 .52552 L p 0 .458 1 r
F P
0 g
s
.75109 .52552 m .73535 .53143 L .75161 .53259 L p 0 .458 1 r
F P
0 g
s
.72417 .56095 m .75161 .53259 L .73535 .53143 L closepath p 0 .349 .782 r
F P
0 g
s
.76747 .52671 m .75161 .53259 L .73535 .53143 L p 0 .458 1 r
F P
0 g
s
.60502 .60419 m .60207 .54627 L .57349 .56847 L .778 0 0 r
F
.60502 .60419 m .63368 .58217 L .60207 .54627 L F
.60588 .61219 m .63368 .58217 L .60502 .60419 L .262 0 0 r
F
.57688 .63027 m .60502 .60419 L .57349 .56847 L .83 0 0 r
F
.59213 .62494 m .60502 .60419 L .57688 .63027 L .262 0 0 r
F
.59213 .62494 m .60588 .61219 L .60502 .60419 L F
.72347 .50035 m .7097 .51445 L .71565 .53002 L p 0 .349 .782 r
F P
0 g
s
.72523 .50837 m .7097 .51445 L .72347 .50035 L p 0 .05 .218 r
F P
0 g
s
.72347 .50035 m .7097 .51445 L .72523 .50837 L p 0 .05 .218 r
F P
0 g
s
.73535 .53143 m .75109 .52552 L .73124 .52409 L p 0 .458 1 r
F P
0 g
s
.73124 .52409 m .71565 .53002 L .73535 .53143 L p 0 .458 1 r
F P
0 g
s
.73535 .53143 m .71565 .53002 L .71003 .54479 L p 0 .349 .782 r
F P
0 g
s
.71003 .54479 m .72417 .56095 L .73535 .53143 L p 0 .349 .782 r
F P
0 g
s
.73535 .53143 m .75109 .52552 L .76747 .52671 L p 0 .458 1 r
F P
0 g
s
.75109 .52552 m .73535 .53143 L .71565 .53002 L p 0 .458 1 r
F P
0 g
s
.57688 .63027 m .57349 .56847 L .54525 .59454 L .83 0 0 r
F
.59213 .62494 m .57688 .63027 L .54525 .59454 L .554 0 0 r
F
0 g
.58654 .62132 m
.60502 .60419 L
s
.55085 .66711 m .59213 .62494 L .57688 .63027 L p .262 0 0 r
F P
0 g
s
.57688 .63027 m .5359 .67206 L .55085 .66711 L p .262 0 0 r
F P
0 g
s
.5359 .67206 m .57688 .63027 L .54525 .59454 L p .855 0 0 r
F P
0 g
s
.54525 .59454 m .57688 .63027 L .59213 .62494 L p .554 0 0 r
F P
0 g
s
.57401 .5761 m .57349 .56847 L .60207 .54627 L .228 0 0 r
F
.5629 .58472 m .57349 .56847 L .57401 .5761 L F
.56021 .58885 m .54525 .59454 L .57349 .56847 L F
.57401 .5761 m .55594 .52898 L .54203 .53989 L .778 0 0 r
F
.60588 .61219 m .58098 .5707 L .57401 .5761 L F
.57401 .5761 m .57967 .57008 L .58796 .56528 L .228 0 0 r
F
.57967 .57008 m .60207 .54627 L .58796 .56528 L F
.58796 .56528 m .56627 .52277 L .55594 .52898 L .683 0 0 r
F
.60588 .61219 m .61986 .60146 L .63368 .58217 L .262 0 0 r
F
.61986 .60146 m .59317 .56226 L .58796 .56528 L .683 0 0 r
F
.63368 .58217 m .62368 .53366 L .60207 .54627 L .685 0 0 r
F
.58796 .56528 m .60207 .54627 L .62368 .53366 L .228 0 0 r
F
.61986 .60146 m .65552 .56989 L .63368 .58217 L .262 0 0 r
F
.60588 .61219 m .61986 .60146 L .55594 .52898 L .778 0 0 r
F
.60658 .61881 m .61986 .60146 L .60588 .61219 L .262 0 0 r
F
.60588 .61219 m .58796 .56528 L .61986 .60146 L .778 0 0 r
F
.60588 .61219 m .57401 .5761 L .58796 .56528 L F
.61986 .60146 m .63042 .59557 L .65552 .56989 L .262 0 0 r
F
.58796 .56528 m .59194 .56175 L .5984 .55923 L .228 0 0 r
F
.59194 .56175 m .62368 .53366 L .62389 .53345 L F
.61986 .60146 m .63042 .59557 L .60143 .5744 L .683 0 0 r
F
.60143 .5744 m .63042 .59557 L .56627 .52277 L F
.60846 .61737 m .63042 .59557 L .61986 .60146 L .262 0 0 r
F
.60658 .61881 m .60846 .61737 L .61986 .60146 L F
.61986 .60146 m .5984 .55923 L .63042 .59557 L .683 0 0 r
F
.61986 .60146 m .58796 .56528 L .5984 .55923 L F
.60846 .61737 m .60987 .61659 L .63042 .59557 L .262 0 0 r
F
.60987 .61659 m .63042 .59557 L .5984 .55923 L p .856 0 0 r
F P
0 g
s
.59317 .56226 m .56627 .52277 L .58796 .56528 L .683 0 0 r
F
.5984 .55923 m .56627 .52277 L p .58807 .56969 L .856 0 0 r
F P
0 g
s
.58807 .56969 m .60987 .61659 L .5984 .55923 L .856 0 0 r
F
.60987 .61659 m .58807 .56969 L .63042 .59557 L F
.58807 .56969 m .56627 .52277 L .5984 .55923 L F
.58807 .56969 m .5984 .55923 L .63042 .59557 L F
.63368 .58217 m .65552 .56989 L .62368 .53366 L .685 0 0 r
F
.72417 .56095 m .71003 .54479 L .68172 .5739 L p 0 .349 .782 r
F P
0 g
s
.68172 .5739 m .69596 .59011 L .72417 .56095 L p 0 .349 .782 r
F P
0 g
s
.66747 .55766 m .68172 .5739 L .71003 .54479 L p 0 .349 .782 r
F P
0 g
s
.69596 .59011 m .68172 .5739 L .65315 .60328 L p 0 .349 .782 r
F P
0 g
s
.68172 .5739 m .66747 .55766 L .63881 .58698 L p 0 .349 .782 r
F P
0 g
s
.63881 .58698 m .65315 .60328 L .68172 .5739 L p 0 .349 .782 r
F P
0 g
s
.71003 .54479 m .69586 .52861 L .66747 .55766 L p 0 .349 .782 r
F P
0 g
s
.66747 .55766 m .68272 .55194 L .65387 .58151 L p 0 .05 .218 r
F P
0 g
s
.65387 .58151 m .63881 .58698 L .66747 .55766 L p 0 .05 .218 r
F P
0 g
s
.72417 .56095 m .73985 .5553 L .76747 .52671 L p 0 .05 .248 r
F P
0 g
s
.73985 .5553 m .72417 .56095 L .71003 .54479 L p 0 .318 .938 r
F P
0 g
s
.72559 .53899 m .71003 .54479 L .72417 .56095 L p 0 .318 .938 r
F P
0 g
s
.71003 .54479 m .72559 .53899 L .73985 .5553 L p 0 .318 .938 r
F P
0 g
s
.71003 .54479 m .71565 .53002 L .69586 .52861 L closepath p 0 .349 .782 r
F P
0 g
s
.72417 .56095 m .73985 .5553 L .72559 .53899 L p 0 .318 .938 r
F P
0 g
s
.72559 .53899 m .71003 .54479 L .69586 .52861 L p 0 .318 .938 r
F P
0 g
s
.69586 .52861 m .71565 .53002 L .7097 .51445 L closepath p 0 .349 .782 r
F P
0 g
s
.71565 .53002 m .73124 .52409 L .7113 .52265 L p 0 .458 1 r
F P
0 g
s
.7113 .52265 m .69586 .52861 L .71565 .53002 L p 0 .458 1 r
F P
0 g
s
.71565 .53002 m .73124 .52409 L .75109 .52552 L p 0 .458 1 r
F P
0 g
s
.73124 .52409 m .71565 .53002 L .69586 .52861 L p 0 .458 1 r
F P
0 g
s
.69586 .52861 m .7113 .52265 L .73124 .52409 L p 0 .458 1 r
F P
0 g
s
.71003 .54479 m .72559 .53899 L .7113 .52265 L p 0 .318 .938 r
F P
0 g
s
.7113 .52265 m .69586 .52861 L .71003 .54479 L p 0 .318 .938 r
F P
0 g
s
.69586 .52861 m .7113 .52265 L .72559 .53899 L p 0 .318 .938 r
F P
0 g
s
.73985 .5553 m .72559 .53899 L .74144 .53308 L p 0 .318 .938 r
F P
0 g
s
.74144 .53308 m .72559 .53899 L .73985 .5553 L p 0 .318 .938 r
F P
0 g
s
.73124 .52409 m .75109 .52552 L .76712 .51951 L p 0 .458 1 r
F P
0 g
s
.75109 .52552 m .73124 .52409 L .74712 .51805 L p 0 .458 1 r
F P
0 g
s
.76712 .51951 m .74712 .51805 L .73124 .52409 L p 0 .458 1 r
F P
0 g
s
.7113 .52265 m .73124 .52409 L .74712 .51805 L p 0 .458 1 r
F P
0 g
s
.73124 .52409 m .7113 .52265 L .72704 .51658 L p 0 .458 1 r
F P
0 g
s
.72704 .51658 m .74712 .51805 L .73124 .52409 L p 0 .458 1 r
F P
0 g
s
.74712 .51805 m .72704 .51658 L .7113 .52265 L p 0 .458 1 r
F P
0 g
s
.72704 .51658 m .74144 .53308 L .72559 .53899 L p 0 .318 .938 r
F P
0 g
s
.72559 .53899 m .7113 .52265 L .72704 .51658 L p 0 .318 .938 r
F P
0 g
s
.72559 .53899 m .74144 .53308 L .72704 .51658 L p 0 .318 .938 r
F P
0 g
s
.72704 .51658 m .7113 .52265 L .72559 .53899 L p 0 .318 .938 r
F P
0 g
s
.69826 .54612 m .71276 .56267 L .74144 .53308 L p 0 .349 .781 r
F P
0 g
s
.74144 .53308 m .71276 .56267 L .69826 .54612 L p 0 .349 .781 r
F P
0 g
s
.71276 .56267 m .69826 .54612 L .68615 .55855 L p 0 .349 .781 r
F P
0 g
s
.68615 .55855 m .66921 .57594 L p .69461 .5682 L 0 .349 .781 r
F P
0 g
s
.69461 .5682 m .71276 .56267 L .68615 .55855 L 0 .349 .781 r
F
.68272 .55194 m .66747 .55766 L .69586 .52861 L p 0 .05 .218 r
F P
0 g
s
.68272 .55194 m .69826 .54612 L .66921 .57594 L p 0 .05 .218 r
F P
0 g
s
.66921 .57594 m .65387 .58151 L .68272 .55194 L p 0 .05 .218 r
F P
0 g
s
.62368 .53366 m .65552 .56989 L .68615 .55855 L p .568 0 0 r
F P
0 g
s
.69586 .52861 m .7113 .52265 L .68272 .55194 L p 0 .05 .218 r
F P
0 g
s
.7113 .52265 m .72704 .51658 L .69826 .54612 L p 0 .05 .218 r
F P
0 g
s
.69826 .54612 m .68272 .55194 L .7113 .52265 L p 0 .05 .218 r
F P
0 g
s
.74144 .53308 m .72704 .51658 L .69826 .54612 L p 0 .349 .781 r
F P
0 g
s
.69826 .54612 m .72704 .51658 L .74144 .53308 L p 0 .349 .781 r
F P
0 g
s
.74712 .51805 m .72704 .51658 L .74106 .50219 L closepath p 0 .349 .781 r
F P
0 g
s
.74106 .50219 m .72704 .51658 L .74712 .51805 L closepath p 0 .349 .781 r
F P
0 g
s
.74144 .53308 m .72704 .51658 L .74712 .51805 L closepath p 0 .349 .781 r
F P
0 g
s
.74712 .51805 m .74106 .50219 L .75502 .48786 L p 0 .349 .781 r
F P
0 g
s
.75502 .48786 m .76712 .51951 L .74712 .51805 L p 0 .349 .781 r
F P
0 g
s
.76712 .51951 m .75502 .48786 L .74106 .50219 L p 0 .349 .781 r
F P
0 g
s
.74106 .50219 m .74712 .51805 L .76712 .51951 L p 0 .349 .781 r
F P
0 g
s
.72704 .51658 m .74712 .51805 L .7633 .51189 L p 0 .458 1 r
F P
0 g
s
.74712 .51805 m .72704 .51658 L .74144 .53308 L closepath p 0 .349 .781 r
F P
0 g
s
.74712 .51805 m .72704 .51658 L .74306 .5104 L p 0 .458 1 r
F P
0 g
s
.75109 .52552 m .76747 .52671 L .78362 .52071 L p 0 .458 1 r
F P
0 g
s
.76747 .52671 m .75109 .52552 L .76712 .51951 L p 0 .458 1 r
F P
0 g
s
.78362 .52071 m .76712 .51951 L .75109 .52552 L p 0 .458 1 r
F P
0 g
s
.74712 .51805 m .76712 .51951 L .75109 .52552 L p 0 .458 1 r
F P
0 g
s
.76747 .52671 m .73985 .5553 L .75582 .54954 L p 0 .05 .248 r
F P
0 g
s
.76712 .51951 m .75582 .54954 L .74144 .53308 L p 0 .349 .781 r
F P
0 g
s
.74144 .53308 m .74712 .51805 L .76712 .51951 L p 0 .349 .781 r
F P
0 g
s
.75582 .54954 m .76712 .51951 L .74712 .51805 L p 0 .349 .781 r
F P
0 g
s
.74712 .51805 m .74144 .53308 L .75582 .54954 L p 0 .349 .781 r
F P
0 g
s
.72704 .51658 m .74144 .53308 L .75759 .52705 L p 0 .318 .938 r
F P
0 g
s
.7633 .51189 m .74306 .5104 L .72704 .51658 L p 0 .458 1 r
F P
0 g
s
.74144 .53308 m .72704 .51658 L .74306 .5104 L p 0 .318 .938 r
F P
0 g
s
.75502 .48786 m .78362 .52071 L .76712 .51951 L closepath p 0 .349 .781 r
F P
0 g
s
.75502 .48786 m .78362 .52071 L .80008 .51461 L p 0 .319 .936 r
F P
0 g
s
.76712 .51951 m .78362 .52071 L .75502 .48786 L closepath p 0 .349 .781 r
F P
0 g
s
.74712 .51805 m .76712 .51951 L .78345 .51338 L p 0 .458 1 r
F P
0 g
s
.76712 .51951 m .74712 .51805 L .7633 .51189 L p 0 .458 1 r
F P
0 g
s
.78345 .51338 m .7633 .51189 L .74712 .51805 L p 0 .458 1 r
F P
0 g
s
.74306 .5104 m .7633 .51189 L .74712 .51805 L p 0 .458 1 r
F P
0 g
s
.75759 .52705 m .74306 .5104 L .72704 .51658 L p 0 .318 .938 r
F P
0 g
s
.69826 .54612 m .72704 .51658 L .74306 .5104 L p 0 .05 .218 r
F P
0 g
s
.66921 .57594 m .69826 .54612 L .71276 .56267 L p 0 .349 .781 r
F P
0 g
s
.66921 .57594 m .69826 .54612 L .7141 .54018 L p 0 .05 .218 r
F P
0 g
s
.74306 .5104 m .7141 .54018 L .69826 .54612 L p 0 .05 .218 r
F P
0 g
s
.7141 .54018 m .68485 .57026 L .66921 .57594 L p 0 .05 .218 r
F P
0 g
s
.68485 .57026 m .7141 .54018 L .73024 .53413 L p 0 .05 .218 r
F P
0 g
s
.73024 .53413 m .70079 .56447 L .68485 .57026 L p 0 .05 .218 r
F P
0 g
s
.68615 .55855 m .71796 .54678 L p .66997 .5401 L .568 0 0 r
F P
0 g
s
.62368 .53366 m .68615 .55855 L .66997 .5401 L .568 0 0 r
F
.66921 .57594 m .6838 .59255 L .71276 .56267 L p 0 .349 .781 r
F P
0 g
s
.71276 .56267 m .6838 .59255 L .66921 .57594 L p 0 .349 .781 r
F P
0 g
s
.69216 .57335 m .71796 .54678 L .65552 .56989 L p .262 0 0 r
F P
0 g
s
.65315 .60328 m .63881 .58698 L .60987 .61659 L p 0 .349 .782 r
F P
0 g
s
.6838 .59255 m .66921 .57594 L .66071 .58467 L p 0 .349 .781 r
F P
0 g
s
.66071 .58467 m .63987 .60606 L p .67108 .59646 L 0 .349 .781 r
F P
0 g
s
.67108 .59646 m .6838 .59255 L .66071 .58467 L 0 .349 .781 r
F
.66921 .57594 m .6838 .59255 L p .67108 .59646 L F P
0 g
s
.63987 .60606 m .66071 .58467 L p .67108 .59646 L 0 .349 .781 r
F P
0 g
s
.66071 .58467 m .66921 .57594 L p .67108 .59646 L 0 .349 .781 r
F P
0 g
s
.63042 .59557 m .65552 .56989 L .62368 .53366 L p .856 0 0 r
F P
0 g
s
.63042 .59557 m .62368 .53366 L .65552 .56989 L .856 0 0 r
F
.62368 .53366 m .5984 .55923 L .63042 .59557 L p F P
0 g
s
.63042 .59557 m .5984 .55923 L .62368 .53366 L .856 0 0 r
F
.63042 .59557 m .5984 .55923 L p .64444 .56617 L .561 0 0 r
F P
0 g
s
.65552 .56989 m .63042 .59557 L p .69216 .57335 L .262 0 0 r
F P
0 g
s
.65387 .58151 m .66921 .57594 L .63987 .60606 L p 0 .05 .218 r
F P
0 g
s
.63987 .60606 m .66921 .57594 L .68485 .57026 L p 0 .05 .218 r
F P
0 g
s
.68485 .57026 m .65531 .60063 L .63987 .60606 L p 0 .05 .218 r
F P
0 g
s
.65531 .60063 m .68485 .57026 L .70079 .56447 L p 0 .05 .218 r
F P
0 g
s
.70079 .56447 m .67104 .59511 L .65531 .60063 L p 0 .05 .218 r
F P
0 g
s
.69216 .57335 m .66071 .58467 L p .64444 .56617 L .561 0 0 r
F P
0 g
s
.63881 .58698 m .65387 .58151 L .62473 .61137 L p 0 .05 .218 r
F P
0 g
s
.62473 .61137 m .60987 .61659 L .63881 .58698 L p 0 .05 .218 r
F P
0 g
s
.63987 .60606 m .62473 .61137 L .65387 .58151 L p 0 .05 .218 r
F P
0 g
s
.66071 .58467 m .63042 .59557 L p .64444 .56617 L .561 0 0 r
F P
0 g
s
.63042 .59557 m .66071 .58467 L p .62814 .54763 L .561 0 0 r
F P
0 g
s
.66071 .58467 m .69216 .57335 L p .62814 .54763 L .561 0 0 r
F P
0 g
s
.7113 .52265 m .69586 .52861 L .7097 .51445 L p 0 .05 .218 r
F P
0 g
s
.66694 .49556 m .69586 .52861 L .7097 .51445 L p 0 .349 .782 r
F P
0 g
s
.7097 .51445 m .69586 .52861 L .7113 .52265 L p 0 .05 .218 r
F P
0 g
s
.69586 .52861 m .66694 .49556 L .68214 .48929 L p 0 .318 .938 r
F P
0 g
s
.68214 .48929 m .7113 .52265 L .69586 .52861 L p 0 .318 .938 r
F P
0 g
s
.71796 .54678 m .68501 .50912 L .62368 .53366 L p .568 0 0 r
F P
0 g
s
.65902 .53558 m .5984 .55923 L .62368 .53366 L p .228 0 0 r
F P
0 g
s
.56627 .52277 m .5984 .55923 L p .62814 .54763 L .561 0 0 r
F P
0 g
s
.5984 .55923 m .63042 .59557 L p .62814 .54763 L .561 0 0 r
F P
0 g
s
.58098 .5707 m .55594 .52898 L .57401 .5761 L .778 0 0 r
F
.56021 .58885 m .5629 .58472 L .57401 .5761 L .228 0 0 r
F
0 g
.5584 .5824 m
.57006 .57163 L
s
.59213 .62494 m .54525 .59454 L .56021 .58885 L .554 0 0 r
F
.54525 .59454 m .50399 .63617 L .5359 .67206 L p .855 0 0 r
F P
0 g
s
.59213 .62494 m .56021 .58885 L .54525 .59454 L p .554 0 0 r
F P
0 g
s
.51864 .63085 m .50399 .63617 L .54525 .59454 L p .228 0 0 r
F P
0 g
s
.54525 .59454 m .56021 .58885 L .51864 .63085 L p .228 0 0 r
F P
0 g
s
.54525 .59454 m
.55504 .59081 L
s
.54965 .59952 m
.57688 .63027 L
s
.54525 .59454 m
.5584 .5824 L
s
.7097 .51445 m .72523 .50837 L .7113 .52265 L p 0 .05 .218 r
F P
0 g
s
.7113 .52265 m .72523 .50837 L .7097 .51445 L p 0 .05 .218 r
F P
0 g
s
.72417 .56095 m .69596 .59011 L .71145 .5847 L p 0 .05 .248 r
F P
0 g
s
.71145 .5847 m .73985 .5553 L .72417 .56095 L p 0 .05 .248 r
F P
0 g
s
.65482 .48171 m .71694 .45536 L .69071 .42525 L p .578 0 0 r
F P
0 g
s
.64813 .47407 m
.65482 .48171 L
s
.55085 .66711 m .5359 .67206 L .50399 .63617 L p .541 0 0 r
F P
0 g
s
.55085 .66711 m .50399 .63617 L .5359 .67206 L .541 0 0 r
F
.51501 .69603 m .5359 .67206 L .50399 .63617 L .882 0 0 r
F
.54072 .67876 m .5359 .67206 L .51501 .69603 L .262 0 0 r
F
.54072 .67876 m .55085 .66711 L .5359 .67206 L F
.75582 .54954 m .78362 .52071 L .76747 .52671 L p 0 .05 .248 r
F P
0 g
s
.76712 .51951 m .78362 .52071 L .76747 .52671 L p 0 .458 1 r
F P
0 g
s
.65315 .60328 m .66747 .61954 L .69596 .59011 L p 0 .349 .782 r
F P
0 g
s
.69596 .59011 m .66747 .61954 L .68278 .61439 L p 0 .05 .248 r
F P
0 g
s
.68278 .61439 m .71145 .5847 L .69596 .59011 L p 0 .05 .248 r
F P
0 g
s
.59802 .48417 m
.60979 .47241 L
s
.50399 .63617 m .51864 .63085 L .55085 .66711 L p .541 0 0 r
F P
0 g
s
.55085 .66711 m .51864 .63085 L .50399 .63617 L .541 0 0 r
F
.51501 .69603 m .50399 .63617 L .48285 .65994 L .882 0 0 r
F
.50839 .6424 m .50399 .63617 L .51864 .63085 L .228 0 0 r
F
0 g
.50896 .64176 m
.5359 .67206 L
s
.50839 .6424 m .48285 .65994 L .50399 .63617 L .228 0 0 r
F
.38198 .35153 m .38545 .41403 L .41417 .388 L .83 0 0 r
F
.38868 .48451 m .43143 .44322 L .39896 .4065 L p .856 0 0 r
F P
0 g
s
.4099 .39605 m .41417 .388 L .38545 .41403 L .1 0 0 r
F
.38198 .35153 m .35316 .37756 L .38545 .41403 L .83 0 0 r
F
.36637 .36964 m .38545 .41403 L .35316 .37756 L .554 0 0 r
F
.41299 .39377 m .38545 .41403 L .39896 .4065 L .1 0 0 r
F
.36637 .36964 m .39896 .4065 L .38545 .41403 L .554 0 0 r
F
.36637 .36964 m .35316 .37756 L .38545 .41403 L p F P
0 g
s
.38545 .41403 m .39896 .4065 L .36637 .36964 L p .554 0 0 r
F P
0 g
s
.34274 .45479 m .38545 .41403 L .35316 .37756 L p .855 0 0 r
F P
0 g
s
.39896 .4065 m .38545 .41403 L .34274 .45479 L p .1 0 0 r
F P
0 g
s
.35591 .44761 m .39896 .4065 L p .38187 .42118 L .1 0 0 r
F P
0 g
s
.34274 .45479 m .35591 .44761 L p .38187 .42118 L .1 0 0 r
F P
0 g
s
.35591 .44761 m .37794 .49568 L .38868 .48451 L .883 0 0 r
F
.35316 .37756 m .31015 .41813 L .34274 .45479 L p .855 0 0 r
F P
0 g
s
.35591 .44761 m .34274 .45479 L .32033 .47756 L .1 0 0 r
F
.32302 .41057 m .34274 .45479 L .35591 .44761 L .541 0 0 r
F
.32302 .41057 m .35591 .44761 L .34274 .45479 L p F P
0 g
s
.35591 .44761 m .34875 .45364 L .34504 .45867 L .1 0 0 r
F
.34875 .45364 m .32033 .47756 L .34504 .45867 L F
.34504 .45867 m .37343 .50221 L .37794 .49568 L .966 0 0 r
F
.31015 .41813 m .32033 .47756 L .34274 .45479 L .882 0 0 r
F
.33811 .46512 m .32033 .47756 L .31042 .49087 L .1 0 0 r
F
.34504 .45867 m .33653 .46518 L .33811 .46512 L F
.33653 .46518 m .32033 .47756 L .33811 .46512 L F
.34271 .46185 m .37343 .50221 L .34504 .45867 L .966 0 0 r
F
.3984 .48038 m .37794 .49568 L .37343 .50221 L .1 0 0 r
F
.31015 .41813 m .28749 .4407 L .32033 .47756 L .882 0 0 r
F
.34504 .45867 m .31042 .49087 L .34036 .46503 L .1 0 0 r
F
.31202 .42154 m .30717 .42772 L .34036 .46503 L .966 0 0 r
F
.34271 .46185 m .34036 .46503 L .37343 .50221 L F
.31202 .42154 m .34036 .46503 L .34271 .46185 L F
.34036 .46503 m .316 .49093 L .33389 .47382 L .1 0 0 r
F
.39781 .48124 m .37343 .50221 L .37644 .50229 L F
.3984 .48038 m .37343 .50221 L .39781 .48124 L F
.34036 .46503 m .37644 .50229 L .37343 .50221 L F
.34178 .46498 m .37644 .50229 L .34036 .46503 L F
.31202 .42154 m .34504 .45867 L .34036 .46503 L .966 0 0 r
F
.31202 .42154 m .34036 .46503 L .30717 .42772 L F
.30717 .42772 m .3432 .46492 L .30984 .42741 L .1 0 0 r
F
.30717 .42772 m .30984 .42741 L .3432 .46492 L F
.34178 .46498 m .3432 .46492 L .37644 .50229 L F
.30717 .42772 m .34036 .46503 L .3432 .46492 L F
.30717 .42772 m .3432 .46492 L .34178 .46498 L F
.34036 .46503 m .33389 .47382 L .3432 .46492 L F
.30717 .42772 m .34178 .46498 L .34036 .46503 L F
.31202 .42154 m .34271 .46185 L .34504 .45867 L .966 0 0 r
F
.32302 .41057 m .35048 .45313 L .35591 .44761 L .883 0 0 r
F
.35048 .45313 m .37794 .49568 L .35591 .44761 L F
.39896 .4065 m .36637 .36964 L p .37751 .42698 L .856 0 0 r
F P
0 g
s
.38868 .48451 m .39896 .4065 L .37751 .42698 L .856 0 0 r
F
.41299 .39377 m .41317 .39293 L .4099 .39605 L .1 0 0 r
F
.41317 .39293 m .41417 .388 L .4099 .39605 L F
.41008 .32822 m .41417 .388 L .44236 .36488 L .778 0 0 r
F
.41008 .32822 m .38198 .35153 L .41417 .388 L F
.42675 .3825 m .41417 .388 L .41299 .39377 L .1 0 0 r
F
.42675 .3825 m .44236 .36488 L .41417 .388 L F
0 g
.39665 .40389 m
.41417 .388 L
s
.54531 .49216 m
.55323 .4843 L
s
.59213 .62494 m .60588 .61219 L .54203 .53989 L .831 0 0 r
F
.60474 .62053 m .60588 .61219 L .59213 .62494 L .262 0 0 r
F
.60474 .62053 m .60658 .61881 L .60588 .61219 L F
.59213 .62494 m .57401 .5761 L .60588 .61219 L .831 0 0 r
F
0 g
.60588 .61219 m
.60731 .61109 L
s
.60588 .61219 m
.60731 .61109 L
s
.50812 .38178 m .47506 .36773 L .48227 .35235 L .57 0 0 r
F
0 g
.47506 .36773 m
.48308 .39382 L
s
.56321 .66301 m .60474 .62053 L .59213 .62494 L p .262 0 0 r
F P
0 g
s
.59213 .62494 m .55085 .66711 L .56321 .66301 L p .262 0 0 r
F P
0 g
s
.55085 .66711 m .59213 .62494 L .52819 .55263 L p .856 0 0 r
F P
0 g
s
.59213 .62494 m .54203 .53989 L .52819 .55263 L .831 0 0 r
F
.59213 .62494 m .56021 .58885 L .57401 .5761 L F
.52819 .55263 m .59213 .62494 L .60474 .62053 L p .554 0 0 r
F P
0 g
s
.60072 .61697 m
.60588 .61219 L
s
.60072 .61697 m
.60588 .61219 L
s
.60474 .62053 m .59213 .62494 L .52819 .55263 L .554 0 0 r
F
.56021 .58885 m .59213 .62494 L .55085 .66711 L p .856 0 0 r
F P
0 g
s
.59213 .62494 m
.59213 .62494 L
s
.56021 .58885 m
.59213 .62494 L
s
.51663 .29354 m .53101 .27982 L .50165 .24618 L p 0 .349 .782 r
F P
0 g
s
.50165 .24618 m .53101 .27982 L .54501 .27151 L p 0 .319 .936 r
F P
0 g
s
.5281 .49481 m
.54196 .50758 L
s
.5281 .49481 m
.53849 .49012 L
s
.38045 .35692 m .35316 .37756 L .38198 .35153 L .1 0 0 r
F
.39416 .34556 m .38198 .35153 L .41008 .32822 L F
.39416 .34556 m .38045 .35692 L .38198 .35153 L F
0 g
.57401 .5761 m
.58653 .56639 L
s
.56453 .58486 m
.57401 .5761 L
s
.54196 .50758 m
.5559 .51531 L
s
.63396 .54536 m
.64022 .55248 L
s
.7113 .52265 m .72523 .50837 L .74106 .50219 L p 0 .05 .218 r
F P
0 g
s
.72523 .50837 m .7113 .52265 L .72704 .51658 L p 0 .05 .218 r
F P
0 g
s
.72704 .51658 m .74106 .50219 L .72523 .50837 L p 0 .05 .218 r
F P
0 g
s
.55085 .66711 m .51864 .63085 L .56021 .58885 L p .856 0 0 r
F P
0 g
s
.56021 .58885 m
.56021 .58885 L
s
.56021 .58885 m
.59213 .62494 L
s
.50165 .24618 m .5154 .23755 L .48624 .2041 L p 0 .319 .936 r
F P
0 g
s
.48624 .2041 m .47274 .21305 L .50165 .24618 L p 0 .319 .936 r
F P
0 g
s
.50165 .24618 m .47274 .21305 L .47271 .23074 L closepath p 0 .349 .782 r
F P
0 g
s
.50165 .24618 m .48719 .25985 L .51663 .29354 L p 0 .349 .782 r
F P
0 g
s
.54501 .27151 m .5154 .23755 L .50165 .24618 L p 0 .319 .936 r
F P
0 g
s
.50165 .24618 m .5154 .23755 L .50084 .25132 L p 0 .05 .1 r
F P
0 g
s
.50084 .25132 m .48719 .25985 L .50165 .24618 L p 0 .05 .1 r
F P
0 g
s
.5154 .23755 m .50165 .24618 L .48719 .25985 L p 0 .05 .1 r
F P
0 g
s
.48719 .25985 m .50165 .24618 L .47271 .23074 L p 0 .349 .782 r
F P
0 g
s
.65839 .45773 m .68481 .48795 L .62355 .51324 L p .57 0 0 r
F P
0 g
s
.60189 .51201 m
.62355 .51324 L
s
.60965 .49742 m
.62355 .51324 L
s
.74144 .53308 m .75582 .54954 L .73985 .5553 L p 0 .318 .938 r
F P
0 g
s
.73985 .5553 m .75582 .54954 L .74144 .53308 L p 0 .318 .938 r
F P
0 g
s
.73985 .5553 m .71145 .5847 L .72724 .57919 L p 0 .05 .248 r
F P
0 g
s
.72724 .57919 m .75582 .54954 L .73985 .5553 L p 0 .05 .248 r
F P
0 g
s
.31015 .41813 m .35316 .37756 L .36637 .36964 L p .1 0 0 r
F P
0 g
s
.35491 .37953 m
.37205 .39889 L
s
.38045 .35692 m .36637 .36964 L .35316 .37756 L .1 0 0 r
F
0 g
.35316 .37756 m
.38198 .35153 L
s
.66747 .61954 m .65315 .60328 L .6243 .63294 L p 0 .349 .782 r
F P
0 g
s
.6243 .63294 m .63872 .64926 L .66747 .61954 L p 0 .349 .782 r
F P
0 g
s
.66747 .61954 m .63872 .64926 L .65383 .64436 L p 0 .05 .248 r
F P
0 g
s
.65383 .64436 m .68278 .61439 L .66747 .61954 L p 0 .05 .248 r
F P
0 g
s
.50219 .30733 m .51663 .29354 L .48719 .25985 L p 0 .349 .782 r
F P
0 g
s
.54218 .54591 m .54203 .53989 L .55594 .52898 L .191 0 0 r
F
.54032 .54762 m .54203 .53989 L .54218 .54591 L F
.54032 .54762 m .52819 .55263 L .54203 .53989 L F
0 g
.48642 .44755 m
.49655 .44252 L
s
.47616 .43296 m
.48642 .44755 L
s
.522 .32996 m
.54019 .35074 L
s
.62396 .53355 m .68501 .50912 L .65902 .53558 L p .228 0 0 r
F P
0 g
s
.65902 .53558 m .63021 .49773 L .62576 .49766 L .184 0 0 r
F
.69216 .57335 m .68501 .50912 L .65902 .53558 L .858 0 0 r
F
.69216 .57335 m .65902 .53558 L .68501 .50912 L p F P
0 g
s
.69216 .57335 m .66132 .53571 L .65902 .53558 L .184 0 0 r
F
.71796 .54678 m .69485 .50938 L .68501 .50912 L .212 0 0 r
F
.69216 .57335 m .71796 .54678 L .68501 .50912 L .858 0 0 r
F
.68501 .50912 m .71796 .54678 L .69216 .57335 L p F P
0 g
s
.65902 .53558 m .66796 .52647 L .66618 .53035 L .228 0 0 r
F
.65902 .53558 m .69485 .50938 L .66364 .53584 L F
.66132 .53571 m .66364 .53584 L .63021 .49773 L .184 0 0 r
F
.66132 .53571 m .63021 .49773 L .65902 .53558 L F
.62368 .53366 m .62396 .53355 L p .65902 .53558 L .228 0 0 r
F P
0 g
s
.69216 .57335 m .62576 .49766 L .56627 .52277 L p .561 0 0 r
F P
0 g
s
.67104 .59511 m .69216 .57335 L .63042 .59557 L p .262 0 0 r
F P
0 g
s
.5984 .55923 m .65902 .53558 L .69216 .57335 L p .561 0 0 r
F P
0 g
s
.62576 .49766 m .69216 .57335 L .67104 .59511 L p .858 0 0 r
F P
0 g
s
.67104 .59511 m .69216 .57335 L .62576 .49766 L .858 0 0 r
F
.67104 .59511 m .62576 .49766 L .60433 .51923 L F
.67104 .59511 m .60433 .51923 L .62576 .49766 L p F P
0 g
s
.66364 .53584 m .62683 .50449 L .63021 .49773 L .98 0 0 r
F
.75582 .54954 m .74144 .53308 L .71276 .56267 L p 0 .349 .781 r
F P
0 g
s
.71276 .56267 m .74144 .53308 L .75582 .54954 L p 0 .349 .781 r
F P
0 g
s
.71276 .56267 m .72724 .57919 L .75582 .54954 L p 0 .349 .781 r
F P
0 g
s
.75582 .54954 m .72724 .57919 L .71276 .56267 L p 0 .349 .781 r
F P
0 g
s
.72724 .57919 m .71276 .56267 L .6838 .59255 L p 0 .349 .781 r
F P
0 g
s
.6838 .59255 m .71276 .56267 L .72724 .57919 L p 0 .349 .781 r
F P
0 g
s
.74498 .55101 m .71563 .58141 L .70079 .56447 L p 0 .35 .78 r
F P
0 g
s
.70079 .56447 m .73024 .53413 L .74498 .55101 L p 0 .35 .78 r
F P
0 g
s
.67104 .59511 m .70079 .56447 L .71563 .58141 L p 0 .35 .78 r
F P
0 g
s
.69216 .57335 m .72815 .54746 L .71796 .54678 L .262 0 0 r
F
.69216 .57335 m .69695 .57382 L .72815 .54746 L F
.69216 .57335 m .69695 .57382 L .66364 .53584 L .184 0 0 r
F
.69216 .57335 m .66364 .53584 L .66132 .53571 L F
.69216 .57335 m .66364 .53584 L .69695 .57382 L F
.69216 .57335 m .65902 .53558 L .66364 .53584 L F
.69695 .57382 m .66204 .53931 L .66364 .53584 L .98 0 0 r
F
.66204 .53931 m .62683 .50449 L .66364 .53584 L F
.66618 .53035 m .68501 .50912 L .69485 .50938 L .228 0 0 r
F
.66796 .52647 m .68501 .50912 L .66618 .53035 L F
.43028 .31362 m .44236 .36488 L .4628 .35061 L .685 0 0 r
F
.43028 .31362 m .41008 .32822 L .44236 .36488 L F
.43661 .37564 m .44236 .36488 L .42903 .37993 L .1 0 0 r
F
.48719 .25985 m .47265 .27358 L .50219 .30733 L p 0 .349 .782 r
F P
0 g
s
.51599 .29924 m .50219 .30733 L .47265 .27358 L p 0 .318 .938 r
F P
0 g
s
.47265 .27358 m .4862 .26516 L .51599 .29924 L p 0 .318 .938 r
F P
0 g
s
.43028 .31362 m .4628 .35061 L p .47357 .31615 L .568 0 0 r
F P
0 g
s
.48478 .28028 m .45701 .29727 L p .47357 .31615 L .568 0 0 r
F P
0 g
s
.45701 .29727 m .43028 .31362 L p .47357 .31615 L .568 0 0 r
F P
0 g
s
.44283 .30176 m .47265 .27358 L .45812 .25697 L p 0 .349 .782 r
F P
0 g
s
.47265 .27358 m .44283 .30176 L .45617 .29356 L p 0 .05 .1 r
F P
0 g
s
.45617 .29356 m .4862 .26516 L .47265 .27358 L p 0 .05 .1 r
F P
0 g
s
.4862 .26516 m .45617 .29356 L .46975 .28521 L p 0 .05 .1 r
F P
0 g
s
.46975 .28521 m .45486 .26822 L p .44833 .28737 L 0 .349 .781 r
F P
0 g
s
.43661 .37564 m .4628 .35061 L .44236 .36488 L .1 0 0 r
F
.43661 .37564 m .4628 .35061 L .43028 .31362 L p .856 0 0 r
F P
0 g
s
.40391 .33853 m .43028 .31362 L .4628 .35061 L .856 0 0 r
F
.43028 .31362 m .40391 .33853 L .43661 .37564 L p F P
0 g
s
.42584 .32224 m .45617 .29356 L .44283 .30176 L p 0 .05 .1 r
F P
0 g
s
.40391 .33853 m .43028 .31362 L .45701 .29727 L p .1 0 0 r
F P
0 g
s
.45701 .29727 m .48478 .28028 L p .44366 .3099 L .1 0 0 r
F P
0 g
s
.40391 .33853 m .45701 .29727 L .44366 .3099 L .1 0 0 r
F
.40391 .33853 m .4628 .35061 L .43661 .37564 L .856 0 0 r
F
.40391 .33853 m .43661 .37564 L p .44691 .34152 L .561 0 0 r
F P
0 g
s
.45763 .30601 m .43026 .32258 L p .44691 .34152 L .561 0 0 r
F P
0 g
s
.43026 .32258 m .40391 .33853 L p .44691 .34152 L .561 0 0 r
F P
0 g
s
.40391 .33853 m .41008 .32822 L .43028 .31362 L .1 0 0 r
F
.41273 .3302 m .44283 .30176 L .4282 .28509 L p 0 .349 .782 r
F P
0 g
s
.44283 .30176 m .41273 .3302 L .42584 .32224 L p 0 .05 .1 r
F P
0 g
s
.48478 .28028 m .45763 .30601 L .43026 .32258 L p .1 0 0 r
F P
0 g
s
.43026 .32258 m .40391 .33853 L p .44366 .3099 L .1 0 0 r
F P
0 g
s
.44366 .3099 m .48478 .28028 L .43026 .32258 L .1 0 0 r
F
.40391 .33853 m .39416 .34556 L .41008 .32822 L F
.43661 .37564 m .42903 .37993 L .42675 .3825 L F
.40391 .33853 m .45922 .41931 L .4692 .41262 L .683 0 0 r
F
.40391 .33853 m .39416 .34556 L .45922 .41931 L F
.40391 .33853 m .42675 .3825 L .39416 .34556 L F
.40391 .33853 m .43661 .37564 L .42675 .3825 L F
.39416 .34556 m .44542 .43049 L .45922 .41931 L .778 0 0 r
F
.39416 .34556 m .38045 .35692 L .44542 .43049 L F
.39416 .34556 m .41299 .39377 L .38045 .35692 L F
.39416 .34556 m .42675 .3825 L .41299 .39377 L F
.38232 .35893 m .39416 .34556 L .40391 .33853 L .1 0 0 r
F
.38232 .35893 m .40391 .33853 L .4692 .41262 L .856 0 0 r
F
.44658 .43409 m .45922 .41931 L .44542 .43049 L .1 0 0 r
F
.44791 .4332 m .45922 .41931 L .44689 .43373 L F
.38045 .35692 m .43143 .44322 L .44542 .43049 L .831 0 0 r
F
.44473 .43559 m .44542 .43049 L .43143 .44322 L .1 0 0 r
F
.44658 .43409 m .44542 .43049 L .44473 .43559 L F
.38045 .35692 m .36637 .36964 L .43143 .44322 L .831 0 0 r
F
.44473 .43559 m .43143 .44322 L .44285 .4373 L .1 0 0 r
F
.38045 .35692 m .41299 .39377 L .39896 .4065 L .831 0 0 r
F
.38045 .35692 m .39896 .4065 L .36637 .36964 L F
.43143 .44322 m .44285 .4373 L .43196 .42497 L p .554 0 0 r
F P
0 g
s
.43196 .42497 m .41832 .40953 L p .4225 .43 L .554 0 0 r
F P
0 g
s
.4225 .43 m .41832 .40953 L .41128 .41339 L .554 0 0 r
F
.37729 .3631 m .36637 .36964 L .40709 .41569 L p F P
0 g
s
.40709 .41569 m .43143 .44322 L p .41128 .41339 L .554 0 0 r
F P
0 g
s
.41128 .41339 m .37729 .3631 L .40709 .41569 L .554 0 0 r
F
.44791 .4332 m .4692 .41262 L .45922 .41931 L .1 0 0 r
F
.44791 .4332 m .4692 .41262 L .44477 .3849 L p .856 0 0 r
F P
0 g
s
.44477 .3849 m .40391 .33853 L p .43141 .3977 L .856 0 0 r
F P
0 g
s
.44791 .4332 m .44477 .3849 L .43141 .3977 L .856 0 0 r
F
.38232 .35893 m .4692 .41262 L .44791 .4332 L F
.40391 .33853 m .38232 .35893 L .44791 .4332 L p F P
0 g
s
.43661 .37564 m .4692 .41262 L p .46353 .36043 L .561 0 0 r
F P
0 g
s
.4628 .35061 m .43661 .37564 L p .47684 .34768 L .1 0 0 r
F P
0 g
s
.51846 .31877 m .4901 .33499 L p .47684 .34768 L .1 0 0 r
F P
0 g
s
.4901 .33499 m .4628 .35061 L p .47684 .34768 L .1 0 0 r
F P
0 g
s
.43661 .37564 m .40391 .33853 L .43026 .32258 L p .561 0 0 r
F P
0 g
s
.43026 .32258 m .45763 .30601 L p .44691 .34152 L .561 0 0 r
F P
0 g
s
.43661 .37564 m .43026 .32258 L .44691 .34152 L .561 0 0 r
F
.45617 .29356 m .42584 .32224 L .4392 .31412 L p 0 .05 .1 r
F P
0 g
s
.40835 .34332 m .4392 .31412 L .42584 .32224 L p 0 .05 .1 r
F P
0 g
s
.42422 .29706 m .4392 .31412 L .43026 .32258 L p 0 .349 .781 r
F P
0 g
s
.39521 .3512 m .42584 .32224 L .41273 .3302 L p 0 .05 .1 r
F P
0 g
s
.38232 .35893 m .40391 .33853 L .45763 .30601 L p .1 0 0 r
F P
0 g
s
.45763 .30601 m .43539 .32709 L .38232 .35893 L p .1 0 0 r
F P
0 g
s
.42584 .32224 m .39521 .3512 L .40835 .34332 L p 0 .05 .1 r
F P
0 g
s
.43026 .32258 m .40835 .34332 L p .41961 .31048 L 0 .349 .781 r
F P
0 g
s
.41961 .31048 m .42422 .29706 L .43026 .32258 L 0 .349 .781 r
F
.44791 .4332 m .38232 .35893 L .40835 .34332 L p .555 0 0 r
F P
0 g
s
.43676 .37556 m .43667 .37545 L .43661 .37564 L .561 0 0 r
F
.53856 .32063 m .56533 .35125 L .50812 .38178 L p .57 0 0 r
F P
0 g
s
.50812 .38178 m .48227 .35235 L .53856 .32063 L p .57 0 0 r
F P
0 g
s
.49525 .34386 m .52525 .3831 L .52917 .38254 L .184 0 0 r
F
.4915 .34463 m .51846 .31877 L p .47694 .34762 L .1 0 0 r
F P
0 g
s
.4628 .35061 m .51846 .31877 L .48478 .28028 L p .568 0 0 r
F P
0 g
s
.48478 .28028 m .51846 .31877 L .4915 .34463 L p .858 0 0 r
F P
0 g
s
.45763 .30601 m .51846 .31877 L .48478 .28028 L .858 0 0 r
F
.45763 .30601 m .4915 .34463 L .51846 .31877 L F
.49525 .34386 m .51846 .31877 L .50078 .33573 L .1 0 0 r
F
.49525 .34386 m .50078 .33573 L .4915 .34463 L F
.4915 .34463 m .45763 .30601 L .48478 .28028 L p .858 0 0 r
F P
0 g
s
.4612 .30503 m .49337 .34424 L .49525 .34386 L .184 0 0 r
F
.43661 .37564 m .46353 .36043 L p .47684 .34768 L .1 0 0 r
F P
0 g
s
.46353 .36043 m .45763 .30601 L .43667 .37545 L .561 0 0 r
F
.47684 .34768 m .4915 .34463 L .47694 .34762 L .1 0 0 r
F
.46353 .36043 m .4915 .34463 L p .47684 .34768 L F P
0 g
s
.4692 .41262 m .52525 .3831 L .45763 .30601 L p .561 0 0 r
F P
0 g
s
.45763 .30601 m .4915 .34463 L .43661 .37564 L p .561 0 0 r
F P
0 g
s
.49681 .4371 m .47571 .41315 L .53197 .38367 L p .562 0 0 r
F P
0 g
s
.49681 .4371 m .47222 .42037 L .47571 .41315 L .562 0 0 r
F
.4692 .41262 m .44791 .4332 L p .46675 .42099 L .1 0 0 r
F P
0 g
s
.46675 .42099 m .48591 .40858 L .48281 .40545 L .1 0 0 r
F
.48281 .40545 m .4692 .41262 L p .46675 .42099 L F P
0 g
s
.45063 .43628 m .46412 .42931 L p .45866 .42761 L 0 .315 .945 r
F P
0 g
s
.46961 .43553 m .46412 .42931 L .45063 .43628 L p 0 .315 .945 r
F P
0 g
s
.45118 .4369 m .45876 .44107 L .46961 .43553 L p 0 .315 .945 r
F P
0 g
s
.45063 .43628 m .45118 .4369 L p .46961 .43553 L 0 .315 .945 r
F P
0 g
s
.46647 .44634 m .46961 .43553 L .45876 .44107 L p 0 .103 .572 r
F P
0 g
s
.46412 .42931 m .46961 .43553 L .46647 .44634 L p 0 .349 .781 r
F P
0 g
s
.46412 .42931 m .46961 .43553 L .4834 .42849 L p 0 .315 .945 r
F P
0 g
s
.45764 .45079 m .45876 .44107 L .45118 .4369 L p 0 .275 .686 r
F P
0 g
s
.45558 .45812 m .45764 .45079 L p .45118 .4369 L 0 .275 .686 r
F P
0 g
s
.45118 .4369 m .43884 .44884 L .45558 .45812 L p 0 .275 .686 r
F P
0 g
s
.46961 .43553 m .46412 .42931 L .45169 .44135 L p 0 .349 .781 r
F P
0 g
s
.4834 .42849 m .47786 .4222 L .46412 .42931 L p 0 .315 .945 r
F P
0 g
s
.46534 .43435 m .47786 .4222 L .46412 .42931 L p 0 .05 .1 r
F P
0 g
s
.45876 .44107 m .45764 .45079 L .46647 .44634 L p 0 .103 .572 r
F P
0 g
s
.46316 .45433 m .46647 .44634 L .45764 .45079 L p 0 .066 .496 r
F P
0 g
s
.46316 .45433 m .45169 .44135 L .46412 .42931 L p 0 .349 .781 r
F P
0 g
s
.46647 .44634 m .46316 .45433 L p .46412 .42931 L 0 .349 .781 r
F P
0 g
s
.45169 .44135 m .46412 .42931 L .47786 .4222 L p 0 .05 .1 r
F P
0 g
s
.46675 .42099 m .4787 .41556 L .48591 .40858 L .1 0 0 r
F
.44791 .4332 m .46137 .4262 L p .46675 .42099 L F P
0 g
s
.46137 .4262 m .47509 .41906 L p .46675 .42099 L .1 0 0 r
F P
0 g
s
.47509 .41906 m .48908 .41179 L p .4787 .41556 L .1 0 0 r
F P
0 g
s
.48908 .41179 m .4909 .41002 L .4787 .41556 L .1 0 0 r
F
.47509 .41906 m .4787 .41556 L .46675 .42099 L F
.45038 .41373 m .46412 .42931 L .47786 .4222 L p 0 .315 .945 r
F P
0 g
s
.48908 .41179 m .50334 .40437 L p .4909 .41002 L .1 0 0 r
F P
0 g
s
.50334 .40437 m .52525 .3831 L p .50541 .39595 L .1 0 0 r
F P
0 g
s
.48591 .40858 m .49453 .4065 L .50541 .39595 L .1 0 0 r
F
.49453 .4065 m .50334 .40437 L .50541 .39595 L F
.47786 .4222 m .4834 .42849 L .49746 .42131 L p 0 .315 .945 r
F P
0 g
s
.4834 .42849 m .47786 .4222 L .46534 .43435 L p 0 .349 .781 r
F P
0 g
s
.48025 .43939 m .4834 .42849 L .46961 .43553 L p 0 .103 .572 r
F P
0 g
s
.47786 .4222 m .4834 .42849 L .48025 .43939 L p 0 .349 .781 r
F P
0 g
s
.49746 .42131 m .49187 .41496 L .47786 .4222 L p 0 .315 .945 r
F P
0 g
s
.46647 .44634 m .46961 .43553 L p .45169 .44135 L 0 .349 .781 r
F P
0 g
s
.46961 .43553 m .46647 .44634 L .48025 .43939 L p 0 .103 .572 r
F P
0 g
s
.47691 .44746 m .48025 .43939 L .46647 .44634 L p 0 .066 .496 r
F P
0 g
s
.47691 .44746 m .46534 .43435 L .47786 .4222 L p 0 .349 .781 r
F P
0 g
s
.48025 .43939 m .47691 .44746 L p .47786 .4222 L 0 .349 .781 r
F P
0 g
s
.46534 .43435 m .47786 .4222 L .49187 .41496 L p 0 .05 .1 r
F P
0 g
s
.47926 .42721 m .49187 .41496 L .47786 .4222 L p 0 .05 .1 r
F P
0 g
s
.4787 .41556 m .4909 .41002 L .48591 .40858 L .1 0 0 r
F
.4909 .41002 m .50334 .40437 L .49453 .4065 L F
.4909 .41002 m .49453 .4065 L .48591 .40858 L F
.464 .40647 m .47786 .4222 L .49187 .41496 L p 0 .315 .945 r
F P
0 g
s
.48656 .41423 m .4838 .41914 L .49187 .41496 L 0 .349 .781 r
F
.49187 .41496 m .47926 .42721 L .46534 .43435 L p 0 .05 .1 r
F P
0 g
s
.4838 .41914 m .47926 .42721 L .49187 .41496 L 0 .349 .781 r
F
.52525 .3831 m .49669 .39814 L p .48591 .40858 L .1 0 0 r
F P
0 g
s
.49669 .39814 m .48281 .40545 L p .48591 .40858 L .1 0 0 r
F P
0 g
s
.46353 .36043 m .43667 .37545 L .43676 .37556 L .561 0 0 r
F
.43539 .32709 m .50334 .40437 L .48908 .41179 L p .555 0 0 r
F P
0 g
s
.48908 .41179 m .44791 .4332 L p .43862 .35446 L .555 0 0 r
F P
0 g
s
.43862 .35446 m .43539 .32709 L .48908 .41179 L .555 0 0 r
F
.47786 .4222 m .464 .40647 L .45038 .41373 L p 0 .315 .945 r
F P
0 g
s
.464 .40647 m .4733 .4208 L .46456 .4181 L 0 .349 .781 r
F
.464 .40647 m .47509 .41906 L p .4733 .4208 L F P
0 g
s
.47786 .4222 m .46534 .43435 L .45169 .44135 L p 0 .05 .1 r
F P
0 g
s
.47786 .4222 m .46534 .43435 L p .46508 .42877 L 0 .349 .781 r
F P
0 g
s
.47509 .41906 m .47786 .4222 L p .46508 .42877 L 0 .349 .781 r
F P
0 g
s
.46534 .43435 m .47786 .4222 L p .47259 .42148 L 0 .349 .781 r
F P
0 g
s
.45825 .42748 m .4584 .42774 L p .45866 .42761 L 0 .315 .945 r
F P
0 g
s
.44153 .42226 m .43701 .42086 L .43976 .42397 L 0 .315 .945 r
F
.4418 .42628 m .44791 .4332 L p .4572 .42837 L F P
0 g
s
.44791 .4332 m .40835 .34332 L .44178 .38126 L .555 0 0 r
F
.43143 .44322 m .43196 .42497 L .4225 .43 L .554 0 0 r
F
.4225 .43 m .44285 .4373 L .43143 .44322 L F
.37729 .3631 m .43196 .42497 L .4225 .43 L F
.43196 .42497 m .44285 .4373 L .4225 .43 L F
.46412 .42931 m .45038 .41373 L .43701 .42086 L p 0 .315 .945 r
F P
0 g
s
.43701 .42086 m .45038 .41373 L p .44348 .41884 L 0 .05 .1 r
F P
0 g
s
.37919 .36139 m .44473 .43559 L .44285 .4373 L .831 0 0 r
F
.38103 .35986 m .44473 .43559 L .37919 .36139 L .778 0 0 r
F
.38103 .35986 m .44658 .43409 L .44473 .43559 L F
.41832 .40953 m .37729 .3631 L p .41128 .41339 L .554 0 0 r
F P
0 g
s
.44285 .4373 m .43143 .44322 L .38868 .48451 L p .1 0 0 r
F P
0 g
s
.37729 .3631 m .43143 .44322 L .36637 .36964 L .554 0 0 r
F
.36637 .36964 m .39896 .4065 L .35591 .44761 L p .856 0 0 r
F P
0 g
s
.43884 .44884 m .43829 .44822 L .4259 .46021 L p 0 .349 .782 r
F P
0 g
s
.4259 .46021 m .42645 .46083 L .43884 .44884 L p 0 .349 .782 r
F P
0 g
s
.43884 .44884 m .42645 .46083 L .44671 .47214 L p 0 .275 .686 r
F P
0 g
s
.43829 .44822 m .4259 .46021 L .43921 .45344 L p 0 .05 .1 r
F P
0 g
s
.42141 .45802 m .4338 .44605 L p .41727 .46014 L .1 0 0 r
F P
0 g
s
.38868 .48451 m .4338 .44605 L .43138 .44729 L .1 0 0 r
F
.38868 .48451 m .39983 .47889 L .40898 .47004 L p F P
0 g
s
.40898 .47004 m .42141 .45802 L p .40249 .47334 L .1 0 0 r
F P
0 g
s
.38868 .48451 m .40898 .47004 L .40249 .47334 L .1 0 0 r
F
.42645 .46083 m .4259 .46021 L .41346 .47225 L p 0 .349 .782 r
F P
0 g
s
.41346 .47225 m .41401 .47287 L .42645 .46083 L p 0 .349 .782 r
F P
0 g
s
.42645 .46083 m .41401 .47287 L .43073 .48228 L p 0 .275 .686 r
F P
0 g
s
.4259 .46021 m .41346 .47225 L .42668 .46558 L p 0 .05 .1 r
F P
0 g
s
.38868 .48451 m .42141 .45802 L .41727 .46014 L .1 0 0 r
F
.4338 .44605 m .44285 .4373 L p .43138 .44729 L F P
0 g
s
.37729 .3631 m .44285 .4373 L .39983 .47889 L p .856 0 0 r
F P
0 g
s
.39973 .45676 m .41346 .47225 L .4259 .46021 L p 0 .349 .782 r
F P
0 g
s
.4259 .46021 m .42645 .46083 L .44671 .47214 L p 0 .314 .946 r
F P
0 g
s
.42645 .46083 m .4259 .46021 L .43921 .45344 L p 0 .314 .946 r
F P
0 g
s
.44671 .47214 m .42645 .46083 L p .43921 .45344 L 0 .314 .946 r
F P
0 g
s
.44671 .47214 m .42645 .46083 L p .43073 .48228 L 0 .275 .686 r
F P
0 g
s
.44671 .47214 m .45171 .46611 L p .43884 .44884 L 0 .275 .686 r
F P
0 g
s
.45171 .46611 m .44671 .47214 L .453 .46904 L p 0 .05 .17 r
F P
0 g
s
.453 .46904 m .43921 .45344 L .4259 .46021 L p 0 .314 .946 r
F P
0 g
s
.44671 .47214 m .453 .46904 L p .4259 .46021 L 0 .314 .946 r
F P
0 g
s
.41346 .47225 m .4259 .46021 L .43921 .45344 L p 0 .05 .1 r
F P
0 g
s
.43921 .45344 m .42668 .46558 L .41346 .47225 L p 0 .05 .1 r
F P
0 g
s
.41346 .47225 m .42668 .46558 L p .42125 .4638 L 0 .313 .947 r
F P
0 g
s
.39973 .45676 m .41072 .46916 L p .42125 .4638 L 0 .313 .947 r
F P
0 g
s
.41072 .46916 m .41346 .47225 L p .42125 .4638 L 0 .313 .947 r
F P
0 g
s
.41221 .44474 m .42279 .45669 L p .43237 .44743 L 0 .349 .782 r
F P
0 g
s
.42279 .45669 m .4259 .46021 L p .43237 .44743 L 0 .349 .782 r
F P
0 g
s
.4259 .46021 m .43829 .44822 L p .43237 .44743 L 0 .349 .782 r
F P
0 g
s
.43829 .44822 m .43884 .44884 L .45118 .4369 L p 0 .349 .782 r
F P
0 g
s
.43884 .44884 m .43829 .44822 L .45169 .44135 L p 0 .314 .946 r
F P
0 g
s
.45558 .45812 m .43884 .44884 L p .45169 .44135 L 0 .314 .946 r
F P
0 g
s
.45764 .45079 m .45558 .45812 L .46316 .45433 L p 0 .066 .496 r
F P
0 g
s
.43884 .44884 m .45558 .45812 L .46316 .45433 L p 0 .314 .946 r
F P
0 g
s
.43829 .44822 m .43884 .44884 L p .46316 .45433 L 0 .314 .946 r
F P
0 g
s
.45532 .45906 m .45558 .45812 L .43884 .44884 L p 0 .275 .686 r
F P
0 g
s
.45171 .46611 m .45532 .45906 L p .43884 .44884 L 0 .275 .686 r
F P
0 g
s
.46316 .45433 m .45169 .44135 L .43829 .44822 L p 0 .314 .946 r
F P
0 g
s
.4259 .46021 m .43829 .44822 L .45169 .44135 L p 0 .05 .1 r
F P
0 g
s
.45169 .44135 m .43921 .45344 L .4259 .46021 L p 0 .05 .1 r
F P
0 g
s
.4259 .46021 m .43921 .45344 L p .43377 .45169 L 0 .314 .946 r
F P
0 g
s
.41221 .44474 m .42317 .45712 L p .43377 .45169 L 0 .314 .946 r
F P
0 g
s
.42317 .45712 m .4259 .46021 L p .43377 .45169 L 0 .314 .946 r
F P
0 g
s
.37919 .36139 m .44285 .4373 L .37729 .3631 L .831 0 0 r
F
.38232 .35893 m .44658 .43409 L .38103 .35986 L .681 0 0 r
F
.44791 .4332 m .44689 .43373 L .44658 .43409 L .1 0 0 r
F
.38232 .35893 m .44791 .4332 L .44658 .43409 L .681 0 0 r
F
.43812 .4228 m .42464 .43278 L p .44545 .43558 L 0 .349 .782 r
F P
0 g
s
.42464 .43278 m .43829 .44822 L .45063 .43628 L p 0 .349 .782 r
F P
0 g
s
.42464 .43278 m .43791 .42575 L p .43822 .44377 L 0 .314 .946 r
F P
0 g
s
.43829 .44822 m .43556 .44514 L p .43822 .44377 L 0 .314 .946 r
F P
0 g
s
.43556 .44514 m .42464 .43278 L p .43822 .44377 L 0 .314 .946 r
F P
0 g
s
.43372 .42403 m .43764 .42195 L .43701 .42086 L 0 .349 .782 r
F
.44791 .4332 m .43701 .42086 L p .44545 .43558 L F P
0 g
s
.42464 .43278 m .43372 .42403 L p .44348 .41884 L 0 .05 .1 r
F P
0 g
s
.43372 .42403 m .43701 .42086 L p .44348 .41884 L 0 .05 .1 r
F P
0 g
s
.44791 .4332 m .45063 .43628 L p .45866 .42761 L 0 .315 .945 r
F P
0 g
s
.45038 .41373 m .43791 .42575 L p .45889 .4286 L 0 .349 .781 r
F P
0 g
s
.46137 .4262 m .45038 .41373 L p .45889 .4286 L 0 .349 .781 r
F P
0 g
s
.45038 .41373 m .46137 .4262 L p .45143 .43582 L 0 .349 .781 r
F P
0 g
s
.45319 .41691 m .45144 .41859 L p .45511 .41909 L 0 .349 .781 r
F P
0 g
s
.45511 .41909 m .47259 .42148 L .45319 .41691 L 0 .349 .781 r
F
.464 .40647 m .45319 .41691 L p .47259 .42148 L F P
0 g
s
.47786 .4222 m .47509 .41906 L p .47259 .42148 L 0 .349 .781 r
F P
0 g
s
.47509 .41906 m .464 .40647 L p .47259 .42148 L 0 .349 .781 r
F P
0 g
s
.47786 .4222 m .46534 .43435 L .47926 .42721 L p 0 .05 .1 r
F P
0 g
s
.46524 .4113 m .47646 .42403 L p .48656 .41423 L 0 .349 .781 r
F P
0 g
s
.47646 .42403 m .47926 .42721 L p .48656 .41423 L 0 .349 .781 r
F P
0 g
s
.49187 .41496 m .47926 .42721 L p .47899 .42158 L 0 .349 .781 r
F P
0 g
s
.49187 .41496 m .47789 .39907 L .464 .40647 L p 0 .315 .945 r
F P
0 g
s
.47789 .39907 m .48908 .41179 L p .47899 .42158 L 0 .349 .781 r
F P
0 g
s
.48908 .41179 m .49187 .41496 L p .47899 .42158 L 0 .349 .781 r
F P
0 g
s
.46456 .4181 m .4733 .4208 L .46508 .42877 L 0 .349 .781 r
F
.47789 .39907 m .46524 .4113 L p .48656 .41423 L F P
0 g
s
.49187 .41496 m .48908 .41179 L p .48656 .41423 L 0 .349 .781 r
F P
0 g
s
.48908 .41179 m .47789 .39907 L p .48656 .41423 L 0 .349 .781 r
F P
0 g
s
.46412 .42931 m .46137 .4262 L p .45889 .4286 L 0 .349 .781 r
F P
0 g
s
.45118 .4369 m .45063 .43628 L .43829 .44822 L p 0 .349 .782 r
F P
0 g
s
.45169 .44135 m .46412 .42931 L .45063 .43628 L p 0 .05 .1 r
F P
0 g
s
.43829 .44822 m .45063 .43628 L .46412 .42931 L p 0 .05 .1 r
F P
0 g
s
.46412 .42931 m .45169 .44135 L .43829 .44822 L p 0 .05 .1 r
F P
0 g
s
.46412 .42931 m .45169 .44135 L p .45143 .43582 L 0 .349 .781 r
F P
0 g
s
.46137 .4262 m .46412 .42931 L p .45143 .43582 L 0 .349 .781 r
F P
0 g
s
.46412 .42931 m .45169 .44135 L .46534 .43435 L p 0 .05 .1 r
F P
0 g
s
.45063 .43628 m .44791 .4332 L p .44545 .43558 L 0 .349 .782 r
F P
0 g
s
.45063 .43628 m .43829 .44822 L .45169 .44135 L p 0 .05 .1 r
F P
0 g
s
.43791 .42575 m .45169 .44135 L .46412 .42931 L p 0 .349 .781 r
F P
0 g
s
.45144 .41859 m .46257 .4312 L p .47259 .42148 L 0 .349 .781 r
F P
0 g
s
.46257 .4312 m .46534 .43435 L p .47259 .42148 L 0 .349 .781 r
F P
0 g
s
.45763 .30601 m .52525 .3831 L .50334 .40437 L p .858 0 0 r
F P
0 g
s
.43539 .32709 m .52525 .3831 L .45763 .30601 L .858 0 0 r
F
.4612 .30503 m .45763 .30601 L .4915 .34463 L .184 0 0 r
F
.49337 .34424 m .4915 .34463 L .52525 .3831 L F
.4612 .30503 m .4915 .34463 L .49337 .34424 L F
.49337 .34424 m .52525 .3831 L .49525 .34386 L F
.49321 .34686 m .49525 .34386 L .52917 .38254 L .98 0 0 r
F
.43539 .32709 m .50334 .40437 L .52525 .3831 L .858 0 0 r
F
.50384 .40431 m .52525 .3831 L .50334 .40437 L .1 0 0 r
F
.50384 .40431 m .52917 .38254 L .52525 .3831 L F
.50334 .40437 m .43539 .32709 L .45763 .30601 L p .858 0 0 r
F P
0 g
s
.50616 .40758 m .49205 .39153 L .47789 .39907 L p 0 .315 .945 r
F P
0 g
s
.49187 .41496 m .49746 .42131 L .50891 .41547 L p 0 .315 .945 r
F P
0 g
s
.49746 .42131 m .49187 .41496 L .47926 .42721 L p 0 .349 .781 r
F P
0 g
s
.49429 .43231 m .49746 .42131 L .4834 .42849 L p 0 .103 .572 r
F P
0 g
s
.49187 .41496 m .49746 .42131 L .49429 .43231 L p 0 .349 .781 r
F P
0 g
s
.50616 .40758 m .49187 .41496 L p .50891 .41547 L 0 .315 .945 r
F P
0 g
s
.49345 .41993 m .50616 .40758 L .49187 .41496 L p 0 .05 .1 r
F P
0 g
s
.4834 .42849 m .48025 .43939 L .49429 .43231 L p 0 .103 .572 r
F P
0 g
s
.48025 .43939 m .4834 .42849 L p .46534 .43435 L 0 .349 .781 r
F P
0 g
s
.49093 .44045 m .49429 .43231 L .48025 .43939 L p 0 .066 .496 r
F P
0 g
s
.49093 .44045 m .47926 .42721 L .49187 .41496 L p 0 .349 .781 r
F P
0 g
s
.49429 .43231 m .49093 .44045 L p .49187 .41496 L 0 .349 .781 r
F P
0 g
s
.47926 .42721 m .49187 .41496 L .50616 .40758 L p 0 .05 .1 r
F P
0 g
s
.47789 .39907 m .49187 .41496 L .50616 .40758 L p 0 .315 .945 r
F P
0 g
s
.50616 .40758 m .49345 .41993 L .47926 .42721 L p 0 .05 .1 r
F P
0 g
s
.49205 .39153 m .50616 .40758 L .49345 .41993 L p 0 .35 .78 r
F P
0 g
s
.50331 .40515 m .52917 .38254 L .50384 .40431 L .1 0 0 r
F
.50331 .40515 m .52526 .38875 L .52917 .38254 L F
.49115 .34988 m .52917 .38254 L .52526 .38875 L .98 0 0 r
F
.45692 .31087 m .49321 .34686 L .49115 .34988 L F
.49321 .34686 m .52917 .38254 L .49115 .34988 L F
.50187 .40666 m .52526 .38875 L .50331 .40515 L .1 0 0 r
F
.50187 .40666 m .51446 .40013 L .52526 .38875 L F
.48022 .36115 m .52526 .38875 L .51446 .40013 L .889 0 0 r
F
.44585 .32202 m .4857 .3555 L .48022 .36115 L F
.4857 .3555 m .52526 .38875 L .48022 .36115 L F
.45038 .41373 m .43662 .39813 L .42337 .40541 L p 0 .315 .945 r
F P
0 g
s
.42337 .40541 m .43701 .42086 L .45038 .41373 L p 0 .315 .945 r
F P
0 g
s
.43791 .42575 m .45038 .41373 L .43701 .42086 L p 0 .05 .1 r
F P
0 g
s
.45038 .41373 m .43791 .42575 L .42464 .43278 L p 0 .05 .1 r
F P
0 g
s
.43662 .39813 m .45038 .41373 L .43791 .42575 L p 0 .349 .781 r
F P
0 g
s
.43662 .39813 m .45038 .41373 L .464 .40647 L p 0 .315 .945 r
F P
0 g
s
.43701 .42086 m .42337 .40541 L .41096 .41731 L p 0 .349 .782 r
F P
0 g
s
.45038 .41373 m .43662 .39813 L .42411 .41013 L p 0 .349 .781 r
F P
0 g
s
.42284 .38251 m .43662 .39813 L .45012 .39072 L p 0 .315 .945 r
F P
0 g
s
.464 .40647 m .45012 .39072 L .43662 .39813 L p 0 .315 .945 r
F P
0 g
s
.43752 .40282 m .45012 .39072 L .43662 .39813 L p 0 .05 .1 r
F P
0 g
s
.42464 .43278 m .43791 .42575 L p .43725 .42215 L 0 .05 .1 r
F P
0 g
s
.43701 .42086 m .43372 .42403 L p .43725 .42215 L 0 .05 .1 r
F P
0 g
s
.43372 .42403 m .42464 .43278 L p .43725 .42215 L 0 .05 .1 r
F P
0 g
s
.41096 .41731 m .42464 .43278 L .43701 .42086 L p 0 .349 .782 r
F P
0 g
s
.43791 .42575 m .42411 .41013 L .43662 .39813 L p 0 .349 .781 r
F P
0 g
s
.42411 .41013 m .43662 .39813 L .45012 .39072 L p 0 .05 .1 r
F P
0 g
s
.45012 .39072 m .43622 .37494 L .42284 .38251 L p 0 .315 .945 r
F P
0 g
s
.45012 .39072 m .43752 .40282 L .42411 .41013 L p 0 .05 .1 r
F P
0 g
s
.43752 .40282 m .45012 .39072 L .44178 .38126 L p 0 .349 .781 r
F P
0 g
s
.43752 .40282 m .44178 .38126 L .43674 .38608 L 0 .349 .781 r
F
.45012 .39072 m .43752 .40282 L p .43674 .38608 L F P
0 g
s
.44178 .38126 m .45012 .39072 L p .43674 .38608 L 0 .349 .781 r
F P
0 g
s
.43662 .39813 m .42411 .41013 L .43752 .40282 L p 0 .05 .1 r
F P
0 g
s
.42411 .41013 m .43791 .42575 L .45038 .41373 L p 0 .349 .781 r
F P
0 g
s
.43791 .42575 m .42411 .41013 L .43752 .40282 L p 0 .314 .946 r
F P
0 g
s
.42411 .41013 m .43791 .42575 L .42464 .43278 L p 0 .314 .946 r
F P
0 g
s
.43791 .42575 m .42411 .41013 L .41096 .41731 L p 0 .314 .946 r
F P
0 g
s
.42464 .43278 m .43829 .44822 L .45169 .44135 L p 0 .314 .946 r
F P
0 g
s
.43829 .44822 m .42464 .43278 L .41221 .44474 L p 0 .349 .782 r
F P
0 g
s
.41096 .41731 m .42464 .43278 L .43791 .42575 L p 0 .314 .946 r
F P
0 g
s
.45169 .44135 m .43791 .42575 L .42464 .43278 L p 0 .314 .946 r
F P
0 g
s
.4254 .43782 m .43791 .42575 L .42464 .43278 L p 0 .05 .1 r
F P
0 g
s
.41221 .44474 m .42464 .43278 L .43791 .42575 L p 0 .05 .1 r
F P
0 g
s
.43791 .42575 m .4254 .43782 L .41221 .44474 L p 0 .05 .1 r
F P
0 g
s
.42411 .41013 m .43791 .42575 L .4254 .43782 L p 0 .349 .781 r
F P
0 g
s
.45169 .44135 m .43791 .42575 L .45038 .41373 L p 0 .349 .781 r
F P
0 g
s
.45038 .41373 m .43791 .42575 L .45144 .41859 L p 0 .05 .1 r
F P
0 g
s
.43791 .42575 m .45038 .41373 L .464 .40647 L p 0 .05 .1 r
F P
0 g
s
.464 .40647 m .45144 .41859 L .43791 .42575 L p 0 .05 .1 r
F P
0 g
s
.42411 .41013 m .43791 .42575 L .45144 .41859 L p 0 .314 .946 r
F P
0 g
s
.42464 .43278 m .41096 .41731 L .42411 .41013 L p 0 .314 .946 r
F P
0 g
s
.42464 .43278 m .41096 .41731 L .3985 .42925 L p 0 .349 .782 r
F P
0 g
s
.43791 .42575 m .42411 .41013 L .41156 .42218 L p 0 .349 .781 r
F P
0 g
s
.45144 .41859 m .43752 .40282 L .42411 .41013 L p 0 .314 .946 r
F P
0 g
s
.42488 .41496 m .43752 .40282 L .42411 .41013 L p 0 .05 .1 r
F P
0 g
s
.42464 .43278 m .41221 .44474 L .4254 .43782 L p 0 .05 .1 r
F P
0 g
s
.3985 .42925 m .41221 .44474 L .42464 .43278 L p 0 .349 .782 r
F P
0 g
s
.4254 .43782 m .41156 .42218 L .42411 .41013 L p 0 .349 .781 r
F P
0 g
s
.41156 .42218 m .42411 .41013 L .43752 .40282 L p 0 .05 .1 r
F P
0 g
s
.45012 .39072 m .464 .40647 L .47789 .39907 L p 0 .315 .945 r
F P
0 g
s
.464 .40647 m .45012 .39072 L .43752 .40282 L p 0 .349 .781 r
F P
0 g
s
.45144 .41859 m .464 .40647 L .45038 .41373 L p 0 .05 .1 r
F P
0 g
s
.45012 .39072 m .464 .40647 L .45144 .41859 L p 0 .349 .781 r
F P
0 g
s
.47789 .39907 m .46388 .38316 L .45012 .39072 L p 0 .315 .945 r
F P
0 g
s
.45144 .41859 m .43752 .40282 L .45012 .39072 L p 0 .349 .781 r
F P
0 g
s
.43752 .40282 m .45012 .39072 L .46388 .38316 L p 0 .05 .1 r
F P
0 g
s
.44986 .36723 m .43622 .37494 L .45012 .39072 L p 0 .315 .945 r
F P
0 g
s
.45012 .39072 m .46388 .38316 L .44986 .36723 L p 0 .315 .945 r
F P
0 g
s
.46388 .38316 m .45012 .39072 L .43752 .40282 L p 0 .05 .1 r
F P
0 g
s
.42337 .40541 m .43662 .39813 L p .42974 .40327 L 0 .05 .1 r
F P
0 g
s
.40971 .38994 m .42337 .40541 L .43662 .39813 L p 0 .315 .945 r
F P
0 g
s
.42411 .41013 m .43662 .39813 L .42337 .40541 L p 0 .05 .1 r
F P
0 g
s
.43662 .39813 m .42284 .38251 L .40971 .38994 L p 0 .315 .945 r
F P
0 g
s
.43662 .39813 m .42411 .41013 L .41096 .41731 L p 0 .05 .1 r
F P
0 g
s
.43752 .40282 m .42358 .38702 L .43622 .37494 L p 0 .349 .781 r
F P
0 g
s
.43622 .37494 m .42358 .38702 L .43752 .40282 L p 0 .349 .781 r
F P
0 g
s
.41096 .41731 m .42007 .40858 L p .42974 .40327 L 0 .05 .1 r
F P
0 g
s
.42007 .40858 m .42337 .40541 L p .42974 .40327 L 0 .05 .1 r
F P
0 g
s
.43752 .40282 m .42488 .41496 L .41156 .42218 L p 0 .05 .1 r
F P
0 g
s
.42358 .38702 m .43752 .40282 L .42488 .41496 L p 0 .349 .781 r
F P
0 g
s
.42488 .41496 m .43752 .40282 L .42358 .38702 L p 0 .349 .781 r
F P
0 g
s
.43752 .40282 m .45144 .41859 L .43791 .42575 L p 0 .314 .946 r
F P
0 g
s
.45144 .41859 m .43752 .40282 L .42488 .41496 L p 0 .349 .781 r
F P
0 g
s
.43791 .42575 m .45169 .44135 L .43829 .44822 L p 0 .314 .946 r
F P
0 g
s
.45169 .44135 m .43791 .42575 L .45144 .41859 L p 0 .314 .946 r
F P
0 g
s
.43921 .45344 m .45169 .44135 L .43829 .44822 L p 0 .05 .1 r
F P
0 g
s
.43791 .42575 m .45169 .44135 L .43921 .45344 L p 0 .349 .781 r
F P
0 g
s
.43791 .42575 m .45169 .44135 L .46534 .43435 L p 0 .314 .946 r
F P
0 g
s
.45169 .44135 m .43791 .42575 L .4254 .43782 L p 0 .349 .781 r
F P
0 g
s
.46534 .43435 m .45144 .41859 L .43791 .42575 L p 0 .314 .946 r
F P
0 g
s
.43883 .43076 m .45144 .41859 L .43791 .42575 L p 0 .05 .1 r
F P
0 g
s
.43921 .45344 m .4254 .43782 L .43791 .42575 L p 0 .349 .781 r
F P
0 g
s
.4254 .43782 m .43791 .42575 L .45144 .41859 L p 0 .05 .1 r
F P
0 g
s
.45144 .41859 m .43883 .43076 L .4254 .43782 L p 0 .05 .1 r
F P
0 g
s
.43752 .40282 m .45144 .41859 L .43883 .43076 L p 0 .349 .781 r
F P
0 g
s
.43752 .40282 m .45144 .41859 L .464 .40647 L p 0 .349 .781 r
F P
0 g
s
.45144 .41859 m .43752 .40282 L .45119 .39536 L p 0 .314 .946 r
F P
0 g
s
.46534 .43435 m .45144 .41859 L .464 .40647 L p 0 .349 .781 r
F P
0 g
s
.464 .40647 m .45144 .41859 L .46524 .4113 L p 0 .05 .1 r
F P
0 g
s
.45144 .41859 m .464 .40647 L .47789 .39907 L p 0 .05 .1 r
F P
0 g
s
.47789 .39907 m .46524 .4113 L .45144 .41859 L p 0 .05 .1 r
F P
0 g
s
.43752 .40282 m .45144 .41859 L .46524 .4113 L p 0 .314 .946 r
F P
0 g
s
.46524 .4113 m .45119 .39536 L .43752 .40282 L p 0 .314 .946 r
F P
0 g
s
.43791 .42575 m .4254 .43782 L .43883 .43076 L p 0 .05 .1 r
F P
0 g
s
.41156 .42218 m .4254 .43782 L .43791 .42575 L p 0 .349 .781 r
F P
0 g
s
.43883 .43076 m .42488 .41496 L .43752 .40282 L p 0 .349 .781 r
F P
0 g
s
.42488 .41496 m .43752 .40282 L .45119 .39536 L p 0 .05 .1 r
F P
0 g
s
.45119 .39536 m .43752 .40282 L .42488 .41496 L p 0 .05 .1 r
F P
0 g
s
.45119 .39536 m .43845 .40761 L .42488 .41496 L p 0 .05 .1 r
F P
0 g
s
.42488 .41496 m .43845 .40761 L .45119 .39536 L p 0 .05 .1 r
F P
0 g
s
.42488 .41496 m .43845 .40761 L .42435 .39163 L p 0 .314 .946 r
F P
0 g
s
.42435 .39163 m .43845 .40761 L .42488 .41496 L p 0 .314 .946 r
F P
0 g
s
.46376 .35936 m .44986 .36723 L .46388 .38316 L p 0 .315 .945 r
F P
0 g
s
.46388 .38316 m .47791 .37546 L .46376 .35936 L p 0 .315 .945 r
F P
0 g
s
.44178 .38126 m .43622 .37494 L p .43674 .38608 L 0 .349 .781 r
F P
0 g
s
.43622 .37494 m .44178 .38126 L p .43674 .38608 L 0 .349 .781 r
F P
0 g
s
.46388 .38316 m .45119 .39536 L .43752 .40282 L p 0 .05 .1 r
F P
0 g
s
.43752 .40282 m .45119 .39536 L .46388 .38316 L p 0 .05 .1 r
F P
0 g
s
.43806 .38397 m .42435 .39163 L .43845 .40761 L p 0 .314 .946 r
F P
0 g
s
.45119 .39536 m .46524 .4113 L .45144 .41859 L p 0 .314 .946 r
F P
0 g
s
.46524 .4113 m .45119 .39536 L .43845 .40761 L p 0 .349 .781 r
F P
0 g
s
.45144 .41859 m .46534 .43435 L .45169 .44135 L p 0 .314 .946 r
F P
0 g
s
.46534 .43435 m .45144 .41859 L .46524 .4113 L p 0 .314 .946 r
F P
0 g
s
.45144 .41859 m .46534 .43435 L .47926 .42721 L p 0 .314 .946 r
F P
0 g
s
.46534 .43435 m .45144 .41859 L .43883 .43076 L p 0 .349 .781 r
F P
0 g
s
.45169 .44135 m .46316 .45433 L .45558 .45812 L p 0 .314 .946 r
F P
0 g
s
.45169 .44135 m .46316 .45433 L .46647 .44634 L p 0 .349 .781 r
F P
0 g
s
.46316 .45433 m .45169 .44135 L .46534 .43435 L p 0 .314 .946 r
F P
0 g
s
.46274 .45535 m .46316 .45433 L .45558 .45812 L p 0 .066 .496 r
F P
0 g
s
.45169 .44135 m .46316 .45433 L .46274 .45535 L p 0 .349 .781 r
F P
0 g
s
.46647 .44634 m .46316 .45433 L .47691 .44746 L p 0 .066 .496 r
F P
0 g
s
.45169 .44135 m .46316 .45433 L .47691 .44746 L p 0 .314 .946 r
F P
0 g
s
.46316 .45433 m .45169 .44135 L .43921 .45344 L p 0 .349 .781 r
F P
0 g
s
.45558 .45812 m .45532 .45906 L .46274 .45535 L p 0 .066 .496 r
F P
0 g
s
.45829 .46284 m .46274 .45535 L .45532 .45906 L p 0 .05 .372 r
F P
0 g
s
.46274 .45535 m .45829 .46284 L p .45169 .44135 L 0 .349 .781 r
F P
0 g
s
.45532 .45906 m .45171 .46611 L .45829 .46284 L p 0 .05 .372 r
F P
0 g
s
.453 .46904 m .45829 .46284 L .45171 .46611 L p 0 .05 .17 r
F P
0 g
s
.45829 .46284 m .453 .46904 L p .45169 .44135 L 0 .349 .781 r
F P
0 g
s
.47691 .44746 m .46534 .43435 L .45169 .44135 L p 0 .314 .946 r
F P
0 g
s
.45277 .44654 m .46534 .43435 L .45169 .44135 L p 0 .05 .1 r
F P
0 g
s
.453 .46904 m .43921 .45344 L .45169 .44135 L p 0 .349 .781 r
F P
0 g
s
.43921 .45344 m .45169 .44135 L .46534 .43435 L p 0 .05 .1 r
F P
0 g
s
.46534 .43435 m .45277 .44654 L .43921 .45344 L p 0 .05 .1 r
F P
0 g
s
.45144 .41859 m .46534 .43435 L .45277 .44654 L p 0 .349 .781 r
F P
0 g
s
.47926 .42721 m .46524 .4113 L .45144 .41859 L p 0 .314 .946 r
F P
0 g
s
.45253 .42357 m .46524 .4113 L .45144 .41859 L p 0 .05 .1 r
F P
0 g
s
.45169 .44135 m .43921 .45344 L .45277 .44654 L p 0 .05 .1 r
F P
0 g
s
.4254 .43782 m .43921 .45344 L .45169 .44135 L p 0 .349 .781 r
F P
0 g
s
.45277 .44654 m .43883 .43076 L .45144 .41859 L p 0 .349 .781 r
F P
0 g
s
.43883 .43076 m .45144 .41859 L .46524 .4113 L p 0 .05 .1 r
F P
0 g
s
.46524 .4113 m .45253 .42357 L .43883 .43076 L p 0 .05 .1 r
F P
0 g
s
.45119 .39536 m .46524 .4113 L .45253 .42357 L p 0 .349 .781 r
F P
0 g
s
.47789 .39907 m .46388 .38316 L .45119 .39536 L p 0 .349 .781 r
F P
0 g
s
.46524 .4113 m .47789 .39907 L .464 .40647 L p 0 .05 .1 r
F P
0 g
s
.45119 .39536 m .46524 .4113 L .47789 .39907 L p 0 .349 .781 r
F P
0 g
s
.46388 .38316 m .47789 .39907 L .46524 .4113 L p 0 .349 .781 r
F P
0 g
s
.46524 .4113 m .45119 .39536 L .46388 .38316 L p 0 .349 .781 r
F P
0 g
s
.46524 .4113 m .45119 .39536 L .46513 .38776 L p 0 .314 .946 r
F P
0 g
s
.47926 .42721 m .46524 .4113 L .47789 .39907 L p 0 .349 .781 r
F P
0 g
s
.47789 .39907 m .46524 .4113 L .4793 .40386 L p 0 .05 .1 r
F P
0 g
s
.46524 .4113 m .47789 .39907 L .49205 .39153 L p 0 .05 .1 r
F P
0 g
s
.4793 .40386 m .46524 .4113 L p .48486 .39683 L 0 .05 .1 r
F P
0 g
s
.49205 .39153 m .48865 .39481 L p .48486 .39683 L 0 .05 .1 r
F P
0 g
s
.48865 .39481 m .4793 .40386 L p .48486 .39683 L 0 .05 .1 r
F P
0 g
s
.40835 .34332 m .43539 .32709 L p .44178 .38126 L .555 0 0 r
F P
0 g
s
.46388 .38316 m .47789 .39907 L .49205 .39153 L p 0 .315 .945 r
F P
0 g
s
.49205 .39153 m .47789 .39907 L p .47826 .40034 L 0 .05 .1 r
F P
0 g
s
.4793 .40386 m .48865 .39481 L p .47826 .40034 L 0 .05 .1 r
F P
0 g
s
.48865 .39481 m .49205 .39153 L p .47826 .40034 L 0 .05 .1 r
F P
0 g
s
.43585 .32698 m .50334 .40437 L .43539 .32709 L .16 0 0 r
F
.43585 .32698 m .50384 .40431 L .50334 .40437 L F
.44959 .34324 m .43581 .35127 L .44986 .36723 L p 0 .315 .945 r
F P
0 g
s
.44986 .36723 m .46376 .35936 L .44959 .34324 L p 0 .315 .945 r
F P
0 g
s
.43539 .32709 m .42174 .33528 L .43581 .35127 L p 0 .315 .945 r
F P
0 g
s
.43581 .35127 m .44959 .34324 L .43539 .32709 L p 0 .315 .945 r
F P
0 g
s
.49205 .39153 m .47791 .37546 L .46388 .38316 L p 0 .315 .945 r
F P
0 g
s
.45119 .39536 m .46388 .38316 L .47791 .37546 L p 0 .05 .1 r
F P
0 g
s
.47791 .37546 m .46388 .38316 L .45119 .39536 L p 0 .05 .1 r
F P
0 g
s
.46513 .38776 m .45119 .39536 L p .47075 .3808 L 0 .05 .1 r
F P
0 g
s
.47791 .37546 m .47451 .37873 L p .47075 .3808 L 0 .05 .1 r
F P
0 g
s
.47451 .37873 m .46513 .38776 L p .47075 .3808 L 0 .05 .1 r
F P
0 g
s
.45119 .39536 m .46513 .38776 L .47451 .37873 L p 0 .05 .1 r
F P
0 g
s
.47451 .37873 m .47791 .37546 L p .47075 .3808 L 0 .05 .1 r
F P
0 g
s
.45119 .39536 m .47451 .37873 L .47075 .3808 L 0 .05 .1 r
F
.46376 .35936 m .47791 .37546 L .47451 .37873 L p 0 .35 .78 r
F P
0 g
s
.46413 .36693 m .46376 .35936 L .47451 .37873 L 0 .35 .78 r
F
.44959 .34324 m .46376 .35936 L .45094 .37164 L p F P
0 g
s
.46513 .38776 m .45094 .37164 L .46376 .35936 L p 0 .35 .78 r
F P
0 g
s
.43622 .37494 m .44986 .36723 L .43581 .35127 L p 0 .315 .945 r
F P
0 g
s
.43539 .32709 m .44959 .34324 L .43672 .35549 L p 0 .35 .78 r
F P
0 g
s
.45094 .37164 m .43672 .35549 L .44959 .34324 L p 0 .35 .78 r
F P
0 g
s
.43581 .35127 m .42229 .35914 L .43622 .37494 L p 0 .315 .945 r
F P
0 g
s
.42229 .35914 m .43581 .35127 L .42174 .33528 L p 0 .315 .945 r
F P
0 g
s
.43672 .35549 m .42249 .33932 L .43539 .32709 L p 0 .35 .78 r
F P
0 g
s
.43526 .32777 m .50384 .40431 L .43585 .32698 L .978 0 0 r
F
.4793 .40386 m .46513 .38776 L .47791 .37546 L p 0 .35 .78 r
F P
0 g
s
.47791 .37546 m .49205 .39153 L .4793 .40386 L p 0 .35 .78 r
F P
0 g
s
.49187 .41496 m .47926 .42721 L .49345 .41993 L p 0 .05 .1 r
F P
0 g
s
.49345 .41993 m .4793 .40386 L .49205 .39153 L p 0 .35 .78 r
F P
0 g
s
.43379 .32925 m .50187 .40666 L .50331 .40515 L .888 0 0 r
F
.43379 .32925 m .4764 .3777 L p .4747 .3746 L .554 0 0 r
F P
0 g
s
.43526 .32777 m .50331 .40515 L .50384 .40431 L .978 0 0 r
F
.43379 .32925 m .50331 .40515 L .43526 .32777 L .888 0 0 r
F
.44585 .32202 m .43446 .32884 L p .4747 .3746 L .554 0 0 r
F P
0 g
s
.43446 .32884 m .43379 .32925 L p .4747 .3746 L .554 0 0 r
F P
0 g
s
.47451 .37873 m .46513 .38776 L p .46413 .36693 L 0 .35 .78 r
F P
0 g
s
.4764 .3777 m .49056 .3938 L p .47948 .37601 L .554 0 0 r
F P
0 g
s
.47948 .37601 m .44585 .32202 L .4764 .3777 L .554 0 0 r
F
.50187 .40666 m .51446 .40013 L .50306 .38715 L p F P
0 g
s
.50306 .38715 m .44585 .32202 L p .49263 .3927 L .554 0 0 r
F P
0 g
s
.50187 .40666 m .50306 .38715 L .49263 .3927 L .554 0 0 r
F
.49056 .3938 m .50187 .40666 L p .49263 .3927 L F P
0 g
s
.49263 .3927 m .44585 .32202 L .49056 .3938 L .554 0 0 r
F
.45119 .39536 m .46524 .4113 L .4793 .40386 L p 0 .314 .946 r
F P
0 g
s
.4793 .40386 m .46513 .38776 L .45119 .39536 L p 0 .314 .946 r
F P
0 g
s
.45144 .41859 m .43883 .43076 L .45253 .42357 L p 0 .05 .1 r
F P
0 g
s
.42488 .41496 m .43883 .43076 L .45144 .41859 L p 0 .349 .781 r
F P
0 g
s
.45253 .42357 m .43845 .40761 L .45119 .39536 L p 0 .349 .781 r
F P
0 g
s
.43845 .40761 m .45119 .39536 L .46513 .38776 L p 0 .05 .1 r
F P
0 g
s
.46513 .38776 m .45119 .39536 L .43845 .40761 L p 0 .05 .1 r
F P
0 g
s
.46513 .38776 m .45229 .40011 L .43845 .40761 L p 0 .05 .1 r
F P
0 g
s
.43845 .40761 m .45229 .40011 L .46513 .38776 L p 0 .05 .1 r
F P
0 g
s
.43845 .40761 m .45229 .40011 L .43806 .38397 L p 0 .314 .946 r
F P
0 g
s
.43806 .38397 m .45229 .40011 L .43845 .40761 L p 0 .314 .946 r
F P
0 g
s
.43845 .40761 m .42435 .39163 L .43806 .38397 L p 0 .314 .946 r
F P
0 g
s
.46534 .43435 m .47691 .44746 L .46316 .45433 L p 0 .314 .946 r
F P
0 g
s
.46534 .43435 m .47691 .44746 L .48025 .43939 L p 0 .349 .781 r
F P
0 g
s
.47691 .44746 m .46534 .43435 L .47926 .42721 L p 0 .314 .946 r
F P
0 g
s
.48025 .43939 m .47691 .44746 L .49093 .44045 L p 0 .066 .496 r
F P
0 g
s
.47926 .42721 m .49093 .44045 L .47691 .44746 L p 0 .314 .946 r
F P
0 g
s
.46534 .43435 m .47691 .44746 L .49093 .44045 L p 0 .314 .946 r
F P
0 g
s
.47691 .44746 m .46534 .43435 L .45277 .44654 L p 0 .349 .781 r
F P
0 g
s
.47649 .44848 m .47691 .44746 L .46316 .45433 L p 0 .066 .496 r
F P
0 g
s
.47649 .44848 m .47691 .44746 L p .45277 .44654 L 0 .349 .781 r
F P
0 g
s
.46534 .43435 m .47691 .44746 L .47649 .44848 L p 0 .349 .781 r
F P
0 g
s
.46316 .45433 m .46274 .45535 L .47649 .44848 L p 0 .066 .496 r
F P
0 g
s
.47201 .45604 m .47649 .44848 L .46274 .45535 L p 0 .05 .372 r
F P
0 g
s
.47201 .45604 m .47649 .44848 L p .45277 .44654 L 0 .349 .781 r
F P
0 g
s
.47649 .44848 m .47201 .45604 L p .46534 .43435 L 0 .349 .781 r
F P
0 g
s
.46524 .4113 m .47926 .42721 L .46534 .43435 L p 0 .314 .946 r
F P
0 g
s
.43883 .43076 m .45277 .44654 L .46534 .43435 L p 0 .349 .781 r
F P
0 g
s
.49093 .44045 m .47926 .42721 L .46534 .43435 L p 0 .314 .946 r
F P
0 g
s
.46274 .45535 m .46316 .45433 L p .43921 .45344 L 0 .349 .781 r
F P
0 g
s
.45829 .46284 m .46274 .45535 L p .43921 .45344 L 0 .349 .781 r
F P
0 g
s
.46274 .45535 m .45829 .46284 L .47201 .45604 L p 0 .05 .372 r
F P
0 g
s
.46669 .46229 m .47201 .45604 L .45829 .46284 L p 0 .05 .17 r
F P
0 g
s
.46669 .46229 m .45277 .44654 L .46534 .43435 L p 0 .349 .781 r
F P
0 g
s
.47201 .45604 m .46669 .46229 L p .46534 .43435 L 0 .349 .781 r
F P
0 g
s
.45277 .44654 m .46534 .43435 L .47926 .42721 L p 0 .05 .1 r
F P
0 g
s
.46534 .43435 m .45277 .44654 L .46659 .4395 L p 0 .05 .1 r
F P
0 g
s
.46659 .4395 m .47926 .42721 L .46534 .43435 L p 0 .05 .1 r
F P
0 g
s
.45277 .44654 m .46669 .46229 L .47201 .45604 L p 0 .349 .781 r
F P
0 g
s
.47649 .44848 m .47201 .45604 L .486 .44911 L p 0 .05 .372 r
F P
0 g
s
.47201 .45604 m .46669 .46229 L .48063 .45541 L p 0 .05 .17 r
F P
0 g
s
.48063 .45541 m .486 .44911 L .47201 .45604 L p 0 .05 .17 r
F P
0 g
s
.45277 .44654 m .46669 .46229 L .48063 .45541 L p 0 .314 .946 r
F P
0 g
s
.46669 .46229 m .45277 .44654 L .46659 .4395 L p 0 .314 .946 r
F P
0 g
s
.46659 .4395 m .48063 .45541 L .46669 .46229 L p 0 .314 .946 r
F P
0 g
s
.43921 .45344 m .453 .46904 L .44671 .47214 L p 0 .314 .946 r
F P
0 g
s
.43921 .45344 m .453 .46904 L .45829 .46284 L p 0 .349 .781 r
F P
0 g
s
.44671 .47412 m .453 .46904 L .44671 .47214 L p 0 .05 .1 r
F P
0 g
s
.44671 .47214 m .44017 .47734 L .44671 .47412 L p 0 .05 .1 r
F P
0 g
s
.44017 .47734 m .44671 .47214 L p .43073 .48228 L 0 .275 .686 r
F P
0 g
s
.43921 .45344 m .453 .46904 L .44671 .47412 L p 0 .349 .781 r
F P
0 g
s
.45829 .46284 m .453 .46904 L .46669 .46229 L p 0 .05 .17 r
F P
0 g
s
.43921 .45344 m .453 .46904 L .46669 .46229 L p 0 .314 .946 r
F P
0 g
s
.453 .46904 m .43921 .45344 L .42668 .46558 L p 0 .349 .781 r
F P
0 g
s
.453 .46904 m .43921 .45344 L .45277 .44654 L p 0 .314 .946 r
F P
0 g
s
.45277 .44654 m .46669 .46229 L .453 .46904 L p 0 .314 .946 r
F P
0 g
s
.43073 .48228 m .43189 .48183 L .44017 .47734 L p 0 .275 .686 r
F P
0 g
s
.43921 .47823 m .44671 .47412 L .44017 .47734 L p 0 .05 .1 r
F P
0 g
s
.44017 .47734 m .43189 .48183 L .43921 .47823 L p 0 .05 .1 r
F P
0 g
s
.44671 .47412 m .43921 .47823 L p .43921 .45344 L 0 .349 .781 r
F P
0 g
s
.46669 .46229 m .45277 .44654 L .43921 .45344 L p 0 .314 .946 r
F P
0 g
s
.46669 .46229 m .45277 .44654 L .44015 .45878 L p 0 .349 .781 r
F P
0 g
s
.46035 .46741 m .46669 .46229 L .453 .46904 L p 0 .05 .1 r
F P
0 g
s
.45277 .44654 m .46669 .46229 L .46035 .46741 L p 0 .349 .781 r
F P
0 g
s
.48063 .45541 m .46659 .4395 L .45277 .44654 L p 0 .314 .946 r
F P
0 g
s
.453 .46904 m .44671 .47412 L .46035 .46741 L p 0 .05 .1 r
F P
0 g
s
.44671 .47412 m .453 .46904 L p .42668 .46558 L 0 .349 .781 r
F P
0 g
s
.45279 .47156 m .46035 .46741 L .44671 .47412 L p 0 .05 .1 r
F P
0 g
s
.45178 .47193 m .44015 .45878 L .45277 .44654 L p 0 .349 .781 r
F P
0 g
s
.45279 .47156 m .45178 .47193 L p .45277 .44654 L 0 .349 .781 r
F P
0 g
s
.46035 .46741 m .45279 .47156 L p .45277 .44654 L 0 .349 .781 r
F P
0 g
s
.44015 .45878 m .45277 .44654 L .46659 .4395 L p 0 .05 .1 r
F P
0 g
s
.45388 .45185 m .46659 .4395 L .45277 .44654 L p 0 .05 .1 r
F P
0 g
s
.47926 .42721 m .46659 .4395 L .45277 .44654 L p 0 .05 .1 r
F P
0 g
s
.43883 .43076 m .45277 .44654 L .46659 .4395 L p 0 .314 .946 r
F P
0 g
s
.45277 .44654 m .43883 .43076 L .45253 .42357 L p 0 .314 .946 r
F P
0 g
s
.45253 .42357 m .46659 .4395 L .45277 .44654 L p 0 .314 .946 r
F P
0 g
s
.43883 .43076 m .45277 .44654 L .43921 .45344 L p 0 .314 .946 r
F P
0 g
s
.45277 .44654 m .43883 .43076 L .4254 .43782 L p 0 .314 .946 r
F P
0 g
s
.4254 .43782 m .43921 .45344 L .4259 .46021 L p 0 .314 .946 r
F P
0 g
s
.43921 .45344 m .4254 .43782 L .41221 .44474 L p 0 .314 .946 r
F P
0 g
s
.42668 .46558 m .43921 .45344 L .4259 .46021 L p 0 .05 .1 r
F P
0 g
s
.4254 .43782 m .43921 .45344 L .42668 .46558 L p 0 .349 .781 r
F P
0 g
s
.4254 .43782 m .43921 .45344 L .45277 .44654 L p 0 .314 .946 r
F P
0 g
s
.4259 .46021 m .41221 .44474 L .39973 .45676 L p 0 .349 .782 r
F P
0 g
s
.4259 .46021 m .41221 .44474 L .4254 .43782 L p 0 .314 .946 r
F P
0 g
s
.43921 .45344 m .4254 .43782 L .41283 .44994 L p 0 .349 .781 r
F P
0 g
s
.43921 .45344 m .4254 .43782 L .43883 .43076 L p 0 .314 .946 r
F P
0 g
s
.45277 .44654 m .43883 .43076 L .42617 .44298 L p 0 .349 .781 r
F P
0 g
s
.43821 .4786 m .42668 .46558 L .43921 .45344 L p 0 .349 .781 r
F P
0 g
s
.43921 .47823 m .43821 .4786 L p .43921 .45344 L 0 .349 .781 r
F P
0 g
s
.42668 .46558 m .43921 .45344 L .45277 .44654 L p 0 .05 .1 r
F P
0 g
s
.44015 .45878 m .45277 .44654 L .43921 .45344 L p 0 .05 .1 r
F P
0 g
s
.45277 .44654 m .44015 .45878 L .42668 .46558 L p 0 .05 .1 r
F P
0 g
s
.43883 .43076 m .45277 .44654 L .44015 .45878 L p 0 .349 .781 r
F P
0 g
s
.46659 .4395 m .45253 .42357 L .43883 .43076 L p 0 .314 .946 r
F P
0 g
s
.43978 .43589 m .45253 .42357 L .43883 .43076 L p 0 .05 .1 r
F P
0 g
s
.42488 .41496 m .43883 .43076 L .45253 .42357 L p 0 .314 .946 r
F P
0 g
s
.43921 .45344 m .42668 .46558 L .44015 .45878 L p 0 .05 .1 r
F P
0 g
s
.41283 .44994 m .42668 .46558 L .43921 .45344 L p 0 .349 .781 r
F P
0 g
s
.44015 .45878 m .42617 .44298 L .43883 .43076 L p 0 .349 .781 r
F P
0 g
s
.42617 .44298 m .43883 .43076 L .45253 .42357 L p 0 .05 .1 r
F P
0 g
s
.43845 .40761 m .45253 .42357 L .43883 .43076 L p 0 .314 .946 r
F P
0 g
s
.45253 .42357 m .43845 .40761 L .42488 .41496 L p 0 .314 .946 r
F P
0 g
s
.46659 .4395 m .45388 .45185 L .44015 .45878 L p 0 .05 .1 r
F P
0 g
s
.45253 .42357 m .43978 .43589 L .42617 .44298 L p 0 .05 .1 r
F P
0 g
s
.49429 .43231 m .49746 .42131 L p .47926 .42721 L 0 .349 .781 r
F P
0 g
s
.47926 .42721 m .49093 .44045 L .49429 .43231 L p 0 .349 .781 r
F P
0 g
s
.49093 .44045 m .47926 .42721 L .49345 .41993 L p 0 .314 .946 r
F P
0 g
s
.49429 .43231 m .49093 .44045 L .49889 .43647 L p 0 .066 .496 r
F P
0 g
s
.47926 .42721 m .49093 .44045 L .49889 .43647 L p 0 .314 .946 r
F P
0 g
s
.49093 .44045 m .47926 .42721 L .46659 .4395 L p 0 .349 .781 r
F P
0 g
s
.4905 .44149 m .49093 .44045 L .47691 .44746 L p 0 .066 .496 r
F P
0 g
s
.4905 .44149 m .49093 .44045 L p .46659 .4395 L 0 .349 .781 r
F P
0 g
s
.47926 .42721 m .49093 .44045 L .4905 .44149 L p 0 .349 .781 r
F P
0 g
s
.47691 .44746 m .47649 .44848 L .4905 .44149 L p 0 .066 .496 r
F P
0 g
s
.486 .44911 m .4905 .44149 L .47649 .44848 L p 0 .05 .372 r
F P
0 g
s
.486 .44911 m .4905 .44149 L p .46659 .4395 L 0 .349 .781 r
F P
0 g
s
.4905 .44149 m .486 .44911 L p .47926 .42721 L 0 .349 .781 r
F P
0 g
s
.47926 .42721 m .46524 .4113 L .4793 .40386 L p 0 .314 .946 r
F P
0 g
s
.49345 .41993 m .47926 .42721 L p .47927 .42258 L 0 .314 .946 r
F P
0 g
s
.4793 .40386 m .49062 .41672 L p .47927 .42258 L 0 .314 .946 r
F P
0 g
s
.49062 .41672 m .49345 .41993 L p .47927 .42258 L 0 .314 .946 r
F P
0 g
s
.51446 .40013 m .50187 .40666 L .49253 .41573 L p .1 0 0 r
F P
0 g
s
.46524 .4113 m .47926 .42721 L .49345 .41993 L p 0 .314 .946 r
F P
0 g
s
.48063 .45541 m .46659 .4395 L .47926 .42721 L p 0 .349 .781 r
F P
0 g
s
.486 .44911 m .48063 .45541 L p .47926 .42721 L 0 .349 .781 r
F P
0 g
s
.47926 .42721 m .46659 .4395 L .48069 .43233 L p 0 .05 .1 r
F P
0 g
s
.49746 .42131 m .49429 .43231 L .50357 .42763 L p 0 .103 .572 r
F P
0 g
s
.49889 .43647 m .50357 .42763 L .49429 .43231 L p 0 .066 .496 r
F P
0 g
s
.49345 .41993 m .47926 .42721 L p .49889 .43647 L 0 .314 .946 r
F P
0 g
s
.48069 .43233 m .49345 .41993 L .47926 .42721 L p 0 .05 .1 r
F P
0 g
s
.46659 .4395 m .47926 .42721 L .49345 .41993 L p 0 .05 .1 r
F P
0 g
s
.46659 .4395 m .48063 .45541 L .486 .44911 L p 0 .349 .781 r
F P
0 g
s
.49345 .41993 m .4793 .40386 L .46524 .4113 L p 0 .314 .946 r
F P
0 g
s
.486 .44911 m .48063 .45541 L .48724 .45216 L p 0 .05 .17 r
F P
0 g
s
.46659 .4395 m .48063 .45541 L .48724 .45216 L p 0 .314 .946 r
F P
0 g
s
.48063 .45541 m .46659 .4395 L .45388 .45185 L p 0 .349 .781 r
F P
0 g
s
.47425 .46058 m .48063 .45541 L .46669 .46229 L p 0 .05 .1 r
F P
0 g
s
.46659 .4395 m .48063 .45541 L .47425 .46058 L p 0 .349 .781 r
F P
0 g
s
.48063 .45541 m .46659 .4395 L .48069 .43233 L p 0 .314 .946 r
F P
0 g
s
.48126 .43297 m .48069 .43233 L .46659 .4395 L p 0 .314 .946 r
F P
0 g
s
.50572 .45406 m .49356 .44027 L .49143 .44366 L p 0 .332 .562 r
F P
0 g
s
.50107 .46163 m .50572 .45406 L p .49143 .44366 L 0 .332 .562 r
F P
0 g
s
.50626 .45353 m .4941 .43974 L .50793 .43283 L p 0 .316 .943 r
F P
0 g
s
.4941 .43974 m .50626 .45353 L .5202 .44676 L p 0 .316 .943 r
F P
0 g
s
.50572 .45406 m .50626 .45353 L .4941 .43974 L p 0 .349 .782 r
F P
0 g
s
.4941 .43974 m .49356 .44027 L .50572 .45406 L p 0 .349 .782 r
F P
0 g
s
.5202 .44676 m .50793 .43283 L .4941 .43974 L p 0 .316 .943 r
F P
0 g
s
.4941 .43974 m .50793 .43283 L p .49143 .44366 L 0 .05 .1 r
F P
0 g
s
.49143 .44366 m .49356 .44027 L .4941 .43974 L p 0 .05 .1 r
F P
0 g
s
.50793 .43283 m .50248 .43816 L .49143 .44366 L p 0 .05 .1 r
F P
0 g
s
.49143 .44366 m .49655 .45382 L .50107 .46163 L p 0 .332 .562 r
F P
0 g
s
.49655 .45382 m .49143 .44366 L .50248 .43816 L p 0 .238 .818 r
F P
0 g
s
.4905 .44149 m .486 .44911 L .49291 .44569 L p 0 .05 .372 r
F P
0 g
s
.48724 .45216 m .49291 .44569 L .486 .44911 L p 0 .05 .17 r
F P
0 g
s
.48724 .45216 m .48126 .43297 L p .46659 .4395 L 0 .314 .946 r
F P
0 g
s
.46035 .46741 m .46669 .46229 L p .44015 .45878 L 0 .349 .781 r
F P
0 g
s
.46669 .46229 m .46035 .46741 L .47425 .46058 L p 0 .05 .1 r
F P
0 g
s
.46663 .46476 m .47425 .46058 L .46035 .46741 L p 0 .05 .1 r
F P
0 g
s
.47425 .46058 m .46663 .46476 L p .46659 .4395 L 0 .349 .781 r
F P
0 g
s
.46788 .44478 m .48069 .43233 L .46659 .4395 L p 0 .05 .1 r
F P
0 g
s
.46561 .46513 m .45388 .45185 L .46659 .4395 L p 0 .349 .781 r
F P
0 g
s
.46663 .46476 m .46561 .46513 L p .46659 .4395 L 0 .349 .781 r
F P
0 g
s
.46659 .4395 m .45388 .45185 L .46788 .44478 L p 0 .05 .1 r
F P
0 g
s
.45253 .42357 m .46659 .4395 L .47926 .42721 L p 0 .349 .781 r
F P
0 g
s
.46524 .4113 m .47926 .42721 L .46659 .4395 L p 0 .349 .781 r
F P
0 g
s
.49345 .41993 m .48069 .43233 L .46659 .4395 L p 0 .05 .1 r
F P
0 g
s
.46659 .4395 m .48069 .43233 L p .47502 .43056 L 0 .314 .946 r
F P
0 g
s
.46659 .4395 m .45253 .42357 L .46524 .4113 L p 0 .349 .781 r
F P
0 g
s
.45253 .42357 m .46378 .43632 L p .47502 .43056 L 0 .314 .946 r
F P
0 g
s
.46378 .43632 m .46659 .4395 L p .47502 .43056 L 0 .314 .946 r
F P
0 g
s
.4793 .40386 m .49345 .41993 L .48069 .43233 L p 0 .35 .78 r
F P
0 g
s
.47926 .42721 m .46524 .4113 L .45253 .42357 L p 0 .349 .781 r
F P
0 g
s
.48069 .43233 m .4665 .41623 L .4793 .40386 L p 0 .35 .78 r
F P
0 g
s
.49253 .41573 m .47975 .42814 L p .50239 .41064 L .1 0 0 r
F P
0 g
s
.45388 .45185 m .46659 .4395 L .48069 .43233 L p 0 .05 .1 r
F P
0 g
s
.4665 .41623 m .48069 .43233 L .46659 .4395 L p 0 .314 .946 r
F P
0 g
s
.48069 .43233 m .4665 .41623 L .45253 .42357 L p 0 .314 .946 r
F P
0 g
s
.45277 .44654 m .44015 .45878 L .45388 .45185 L p 0 .05 .1 r
F P
0 g
s
.42617 .44298 m .44015 .45878 L .45277 .44654 L p 0 .349 .781 r
F P
0 g
s
.43978 .43589 m .45388 .45185 L .46659 .4395 L p 0 .349 .781 r
F P
0 g
s
.45253 .42357 m .46659 .4395 L .45388 .45185 L p 0 .349 .781 r
F P
0 g
s
.48069 .43233 m .46788 .44478 L .45388 .45185 L p 0 .05 .1 r
F P
0 g
s
.45388 .45185 m .46788 .44478 L p .46222 .44299 L 0 .313 .947 r
F P
0 g
s
.45388 .45185 m .43978 .43589 L .45253 .42357 L p 0 .349 .781 r
F P
0 g
s
.43978 .43589 m .45106 .44866 L p .46222 .44299 L 0 .313 .947 r
F P
0 g
s
.45106 .44866 m .45388 .45185 L p .46222 .44299 L 0 .313 .947 r
F P
0 g
s
.4665 .41623 m .48069 .43233 L .46788 .44478 L p 0 .35 .78 r
F P
0 g
s
.46659 .4395 m .45253 .42357 L .43978 .43589 L p 0 .349 .781 r
F P
0 g
s
.46659 .4395 m .45253 .42357 L .4665 .41623 L p 0 .314 .946 r
F P
0 g
s
.46788 .44478 m .45365 .42866 L .4665 .41623 L p 0 .35 .78 r
F P
0 g
s
.47975 .42814 m .46692 .4406 L p .48595 .42497 L .1 0 0 r
F P
0 g
s
.45365 .42866 m .46788 .44478 L .45388 .45185 L p 0 .313 .947 r
F P
0 g
s
.46788 .44478 m .45365 .42866 L .43978 .43589 L p 0 .313 .947 r
F P
0 g
s
.46035 .46741 m .45279 .47156 L .46663 .46476 L p 0 .05 .1 r
F P
0 g
s
.45279 .47156 m .46035 .46741 L p .44015 .45878 L 0 .349 .781 r
F P
0 g
s
.44015 .45878 m .45178 .47193 L .45279 .47156 L p 0 .349 .781 r
F P
0 g
s
.45388 .45185 m .46561 .46513 L .45178 .47193 L p 0 .313 .947 r
F P
0 g
s
.46561 .46513 m .45388 .45185 L .44015 .45878 L p 0 .313 .947 r
F P
0 g
s
.47425 .46058 m .48063 .45541 L p .45388 .45185 L 0 .349 .781 r
F P
0 g
s
.46663 .46476 m .47425 .46058 L p .45388 .45185 L 0 .349 .781 r
F P
0 g
s
.45388 .45185 m .46561 .46513 L .46663 .46476 L p 0 .349 .781 r
F P
0 g
s
.47425 .46058 m .46663 .46476 L .47433 .46097 L p 0 .05 .1 r
F P
0 g
s
.45388 .45185 m .46561 .46513 L .47347 .46127 L p 0 .313 .947 r
F P
0 g
s
.44671 .47412 m .43921 .47823 L .45279 .47156 L p 0 .05 .1 r
F P
0 g
s
.43921 .47823 m .44671 .47412 L p .42668 .46558 L 0 .349 .781 r
F P
0 g
s
.42668 .46558 m .43821 .4786 L .43921 .47823 L p 0 .349 .781 r
F P
0 g
s
.44015 .45878 m .45178 .47193 L .43821 .4786 L p 0 .313 .947 r
F P
0 g
s
.45178 .47193 m .44015 .45878 L .42668 .46558 L p 0 .313 .947 r
F P
0 g
s
.44015 .45878 m .45178 .47193 L .46561 .46513 L p 0 .313 .947 r
F P
0 g
s
.43821 .4786 m .42668 .46558 L .41346 .47225 L p 0 .313 .947 r
F P
0 g
s
.41346 .47225 m .42668 .46558 L p .43073 .48228 L 0 .313 .947 r
F P
0 g
s
.42668 .46558 m .43821 .4786 L .43073 .48228 L p 0 .313 .947 r
F P
0 g
s
.43073 .48228 m .43821 .4786 L p .41346 .47225 L 0 .313 .947 r
F P
0 g
s
.42668 .46558 m .43821 .4786 L .43029 .4815 L p 0 .349 .781 r
F P
0 g
s
.42668 .46558 m .43821 .4786 L .45178 .47193 L p 0 .313 .947 r
F P
0 g
s
.41346 .47225 m .41401 .47287 L .43073 .48228 L p 0 .313 .947 r
F P
0 g
s
.43073 .48228 m .41401 .47287 L .41346 .47225 L p 0 .313 .947 r
F P
0 g
s
.43073 .48228 m .41401 .47287 L p .40909 .48925 L 0 .275 .686 r
F P
0 g
s
.43821 .4786 m .42668 .46558 L .4141 .47777 L p 0 .349 .781 r
F P
0 g
s
.43821 .4786 m .42668 .46558 L .44015 .45878 L p 0 .313 .947 r
F P
0 g
s
.43029 .4815 m .41965 .48403 L p .42668 .46558 L 0 .349 .781 r
F P
0 g
s
.45178 .47193 m .44015 .45878 L .42747 .47107 L p 0 .349 .781 r
F P
0 g
s
.45178 .47193 m .44015 .45878 L .45388 .45185 L p 0 .313 .947 r
F P
0 g
s
.44015 .45878 m .45178 .47193 L .44379 .47485 L p 0 .349 .781 r
F P
0 g
s
.44379 .47485 m .43307 .47739 L p .44015 .45878 L 0 .349 .781 r
F P
0 g
s
.46561 .46513 m .45388 .45185 L .44111 .46425 L p 0 .349 .781 r
F P
0 g
s
.45388 .45185 m .46561 .46513 L .45757 .46807 L p 0 .349 .781 r
F P
0 g
s
.46561 .46513 m .45388 .45185 L .46788 .44478 L p 0 .313 .947 r
F P
0 g
s
.46844 .44543 m .46788 .44478 L .45388 .45185 L p 0 .313 .947 r
F P
0 g
s
.47347 .46127 m .46844 .44543 L p .45388 .45185 L 0 .313 .947 r
F P
0 g
s
.45757 .46807 m .44676 .47063 L p .45388 .45185 L 0 .349 .781 r
F P
0 g
s
.45501 .45728 m .46788 .44478 L .45388 .45185 L p 0 .05 .1 r
F P
0 g
s
.44676 .47063 m .44111 .46425 L .45388 .45185 L p 0 .349 .781 r
F P
0 g
s
.44111 .46425 m .45388 .45185 L .46788 .44478 L p 0 .05 .1 r
F P
0 g
s
.46788 .44478 m .45501 .45728 L .44111 .46425 L p 0 .05 .1 r
F P
0 g
s
.45365 .42866 m .46788 .44478 L .45501 .45728 L p 0 .35 .78 r
F P
0 g
s
.46692 .4406 m .45747 .44977 L p .46951 .43928 L .1 0 0 r
F P
0 g
s
.46951 .43928 m .48595 .42497 L .46692 .4406 L .1 0 0 r
F
.48595 .42497 m .50239 .41064 L .47975 .42814 L F
.50239 .41064 m .51446 .40013 L .49253 .41573 L F
.46513 .38776 m .4793 .40386 L .46524 .4113 L p 0 .314 .946 r
F P
0 g
s
.46524 .4113 m .45253 .42357 L .4665 .41623 L p 0 .05 .1 r
F P
0 g
s
.4665 .41623 m .4793 .40386 L .46524 .4113 L p 0 .05 .1 r
F P
0 g
s
.43845 .40761 m .45253 .42357 L .46524 .4113 L p 0 .349 .781 r
F P
0 g
s
.45253 .42357 m .46524 .4113 L .4793 .40386 L p 0 .05 .1 r
F P
0 g
s
.45365 .42866 m .4665 .41623 L .45253 .42357 L p 0 .05 .1 r
F P
0 g
s
.45253 .42357 m .43978 .43589 L .45365 .42866 L p 0 .05 .1 r
F P
0 g
s
.4793 .40386 m .4665 .41623 L .45253 .42357 L p 0 .05 .1 r
F P
0 g
s
.43845 .40761 m .45253 .42357 L .4665 .41623 L p 0 .314 .946 r
F P
0 g
s
.42488 .41496 m .43883 .43076 L .4254 .43782 L p 0 .314 .946 r
F P
0 g
s
.43883 .43076 m .42488 .41496 L .41156 .42218 L p 0 .314 .946 r
F P
0 g
s
.41156 .42218 m .4254 .43782 L .41221 .44474 L p 0 .314 .946 r
F P
0 g
s
.4254 .43782 m .41156 .42218 L .3985 .42925 L p 0 .314 .946 r
F P
0 g
s
.41283 .44994 m .4254 .43782 L .41221 .44474 L p 0 .05 .1 r
F P
0 g
s
.3985 .42925 m .41221 .44474 L .4254 .43782 L p 0 .314 .946 r
F P
0 g
s
.39973 .45676 m .41221 .44474 L .4254 .43782 L p 0 .05 .1 r
F P
0 g
s
.4254 .43782 m .41283 .44994 L .39973 .45676 L p 0 .05 .1 r
F P
0 g
s
.41156 .42218 m .4254 .43782 L .41283 .44994 L p 0 .349 .781 r
F P
0 g
s
.41156 .42218 m .4254 .43782 L .43883 .43076 L p 0 .314 .946 r
F P
0 g
s
.35591 .44761 m .32302 .41057 L .36637 .36964 L p .856 0 0 r
F P
0 g
s
.36637 .36964 m .32302 .41057 L .38868 .48451 L p .856 0 0 r
F P
0 g
s
.39983 .47889 m .33366 .40432 L .37729 .3631 L p .856 0 0 r
F P
0 g
s
.41221 .44474 m .3985 .42925 L .38598 .44125 L p 0 .349 .782 r
F P
0 g
s
.41221 .44474 m .3985 .42925 L .41156 .42218 L p 0 .314 .946 r
F P
0 g
s
.4254 .43782 m .41156 .42218 L .39895 .43427 L p 0 .349 .781 r
F P
0 g
s
.4254 .43782 m .41156 .42218 L .42488 .41496 L p 0 .314 .946 r
F P
0 g
s
.43883 .43076 m .42488 .41496 L .41218 .42716 L p 0 .349 .781 r
F P
0 g
s
.43883 .43076 m .42488 .41496 L .43845 .40761 L p 0 .314 .946 r
F P
0 g
s
.42617 .44298 m .43883 .43076 L .4254 .43782 L p 0 .05 .1 r
F P
0 g
s
.42668 .46558 m .41283 .44994 L .4254 .43782 L p 0 .349 .781 r
F P
0 g
s
.41283 .44994 m .4254 .43782 L .43883 .43076 L p 0 .05 .1 r
F P
0 g
s
.43883 .43076 m .42617 .44298 L .41283 .44994 L p 0 .05 .1 r
F P
0 g
s
.42488 .41496 m .43883 .43076 L .42617 .44298 L p 0 .349 .781 r
F P
0 g
s
.45253 .42357 m .43845 .40761 L .42566 .41991 L p 0 .349 .781 r
F P
0 g
s
.43883 .43076 m .42617 .44298 L .43978 .43589 L p 0 .05 .1 r
F P
0 g
s
.4254 .43782 m .41283 .44994 L .42617 .44298 L p 0 .05 .1 r
F P
0 g
s
.41221 .44474 m .39973 .45676 L .41283 .44994 L p 0 .05 .1 r
F P
0 g
s
.38598 .44125 m .39973 .45676 L .41221 .44474 L p 0 .349 .782 r
F P
0 g
s
.39895 .43427 m .41283 .44994 L .4254 .43782 L p 0 .349 .781 r
F P
0 g
s
.41218 .42716 m .42617 .44298 L .43883 .43076 L p 0 .349 .781 r
F P
0 g
s
.42566 .41991 m .43978 .43589 L .45253 .42357 L p 0 .349 .781 r
F P
0 g
s
.43845 .40761 m .45253 .42357 L .43978 .43589 L p 0 .349 .781 r
F P
0 g
s
.43978 .43589 m .45253 .42357 L .4665 .41623 L p 0 .05 .1 r
F P
0 g
s
.45253 .42357 m .43845 .40761 L .45229 .40011 L p 0 .314 .946 r
F P
0 g
s
.45229 .40011 m .4665 .41623 L .45253 .42357 L p 0 .314 .946 r
F P
0 g
s
.4665 .41623 m .45229 .40011 L .43845 .40761 L p 0 .314 .946 r
F P
0 g
s
.43978 .43589 m .42566 .41991 L .43845 .40761 L p 0 .349 .781 r
F P
0 g
s
.42566 .41991 m .43845 .40761 L .45229 .40011 L p 0 .05 .1 r
F P
0 g
s
.45229 .40011 m .4394 .41252 L .42566 .41991 L p 0 .05 .1 r
F P
0 g
s
.4394 .41252 m .45229 .40011 L .43845 .40761 L p 0 .05 .1 r
F P
0 g
s
.45388 .45185 m .43978 .43589 L .45365 .42866 L p 0 .313 .947 r
F P
0 g
s
.43978 .43589 m .45388 .45185 L .44015 .45878 L p 0 .313 .947 r
F P
0 g
s
.45388 .45185 m .43978 .43589 L .42617 .44298 L p 0 .313 .947 r
F P
0 g
s
.42617 .44298 m .44015 .45878 L .42668 .46558 L p 0 .313 .947 r
F P
0 g
s
.44015 .45878 m .42617 .44298 L .41283 .44994 L p 0 .313 .947 r
F P
0 g
s
.42617 .44298 m .44015 .45878 L .45388 .45185 L p 0 .313 .947 r
F P
0 g
s
.41283 .44994 m .42668 .46558 L .41346 .47225 L p 0 .313 .947 r
F P
0 g
s
.42668 .46558 m .41283 .44994 L .39973 .45676 L p 0 .313 .947 r
F P
0 g
s
.41401 .47287 m .41346 .47225 L .40098 .48434 L p 0 .349 .782 r
F P
0 g
s
.40098 .48434 m .40153 .48496 L .41401 .47287 L p 0 .349 .782 r
F P
0 g
s
.41401 .47287 m .40153 .48496 L .40909 .48925 L p 0 .275 .686 r
F P
0 g
s
.4141 .47777 m .42668 .46558 L .41346 .47225 L p 0 .05 .1 r
F P
0 g
s
.40098 .48434 m .41346 .47225 L .42668 .46558 L p 0 .05 .1 r
F P
0 g
s
.42668 .46558 m .4141 .47777 L .40098 .48434 L p 0 .05 .1 r
F P
0 g
s
.42668 .46558 m .4141 .47777 L p .41384 .4722 L 0 .349 .781 r
F P
0 g
s
.41283 .44994 m .42391 .46245 L p .41384 .4722 L 0 .349 .781 r
F P
0 g
s
.42391 .46245 m .42668 .46558 L p .41384 .4722 L 0 .349 .781 r
F P
0 g
s
.39822 .48124 m .37644 .50229 L p .39488 .49055 L .1 0 0 r
F P
0 g
s
.41346 .47225 m .40098 .48434 L .4141 .47777 L p 0 .05 .1 r
F P
0 g
s
.40909 .48925 m .40153 .48496 L .40098 .48434 L p 0 .312 .948 r
F P
0 g
s
.39983 .47889 m .38868 .48451 L p .3796 .47128 L .541 0 0 r
F P
0 g
s
.38598 .44125 m .39973 .45676 L .41283 .44994 L p 0 .313 .947 r
F P
0 g
s
.37507 .45098 m .38884 .46649 L p .3682 .45466 L .541 0 0 r
F P
0 g
s
.38884 .46649 m .38868 .48451 L .39983 .47889 L .541 0 0 r
F
.37507 .45098 m .3796 .47128 L .38884 .46649 L F
.3682 .45466 m .3796 .47128 L .37507 .45098 L F
.33366 .40432 m .3682 .45466 L .37507 .45098 L F
.3796 .47128 m .38868 .48451 L .38884 .46649 L F
.3796 .47128 m .3682 .45466 L .38884 .46649 L F
.33366 .40432 m .37507 .45098 L p .3682 .45466 L F P
0 g
s
.38884 .46649 m .39983 .47889 L p .3796 .47128 L .541 0 0 r
F P
0 g
s
.39983 .47889 m .38868 .48451 L .37794 .49568 L .1 0 0 r
F
.39983 .47889 m .37794 .49568 L .3984 .48038 L F
.33366 .40432 m .39983 .47889 L .3984 .48038 L .884 0 0 r
F
.38868 .48451 m .32302 .41057 L .33366 .40432 L p .541 0 0 r
F P
0 g
s
.33366 .40432 m .32302 .41057 L .38868 .48451 L .541 0 0 r
F
.33219 .40578 m .3984 .48038 L .39781 .48124 L .968 0 0 r
F
.33366 .40432 m .3984 .48038 L .33219 .40578 L .884 0 0 r
F
.33219 .40578 m .39781 .48124 L .33156 .4066 L .968 0 0 r
F
.39973 .45676 m .38598 .44125 L .37342 .45329 L p 0 .349 .782 r
F P
0 g
s
.38019 .44825 m .38598 .44125 L .38742 .44286 L 0 .05 .1 r
F
.39973 .45676 m .38598 .44125 L .39895 .43427 L p 0 .313 .947 r
F P
0 g
s
.41283 .44994 m .39895 .43427 L .38598 .44125 L p 0 .313 .947 r
F P
0 g
s
.38598 .44125 m .39895 .43427 L p .38742 .44286 L 0 .05 .1 r
F P
0 g
s
.37342 .45329 m .37677 .45007 L p .38019 .44825 L 0 .05 .1 r
F P
0 g
s
.37677 .45007 m .38598 .44125 L p .38019 .44825 L 0 .05 .1 r
F P
0 g
s
.41346 .47225 m .39973 .45676 L .38721 .46883 L p 0 .349 .782 r
F P
0 g
s
.394 .46382 m .39973 .45676 L .40125 .45847 L 0 .05 .1 r
F
.41346 .47225 m .39973 .45676 L .41283 .44994 L p 0 .313 .947 r
F P
0 g
s
.39973 .45676 m .41283 .44994 L p .40125 .45847 L 0 .05 .1 r
F P
0 g
s
.38721 .46883 m .39055 .4656 L p .394 .46382 L 0 .05 .1 r
F P
0 g
s
.39055 .4656 m .39973 .45676 L p .394 .46382 L 0 .05 .1 r
F P
0 g
s
.39895 .43427 m .38598 .44125 L .37677 .45007 L p 0 .05 .1 r
F P
0 g
s
.37677 .45007 m .37342 .45329 L p .38019 .44825 L 0 .05 .1 r
F P
0 g
s
.39895 .43427 m .37677 .45007 L .38019 .44825 L 0 .05 .1 r
F
.38721 .46883 m .40021 .4621 L p .40008 .46067 L F P
0 g
s
.39973 .45676 m .39055 .4656 L p .40008 .46067 L 0 .05 .1 r
F P
0 g
s
.39055 .4656 m .38721 .46883 L p .40008 .46067 L 0 .05 .1 r
F P
0 g
s
.38721 .46883 m .40098 .48434 L .41346 .47225 L p 0 .349 .782 r
F P
0 g
s
.40021 .4621 m .4141 .47777 L .40098 .48434 L p 0 .312 .948 r
F P
0 g
s
.40098 .48434 m .4141 .47777 L p .40909 .48925 L 0 .312 .948 r
F P
0 g
s
.4141 .47777 m .41965 .48403 L .40909 .48925 L p 0 .312 .948 r
F P
0 g
s
.43029 .4815 m .43821 .4786 L p .4141 .47777 L 0 .349 .781 r
F P
0 g
s
.42747 .47107 m .44015 .45878 L .42668 .46558 L p 0 .05 .1 r
F P
0 g
s
.41965 .48403 m .4141 .47777 L .42668 .46558 L p 0 .349 .781 r
F P
0 g
s
.42668 .46558 m .4141 .47777 L .42747 .47107 L p 0 .05 .1 r
F P
0 g
s
.40021 .4621 m .4141 .47777 L .42668 .46558 L p 0 .349 .781 r
F P
0 g
s
.4141 .47777 m .42668 .46558 L .44015 .45878 L p 0 .05 .1 r
F P
0 g
s
.4141 .47777 m .41965 .48403 L .43029 .4815 L p 0 .349 .781 r
F P
0 g
s
.4141 .47777 m .40021 .4621 L .41283 .44994 L p 0 .349 .781 r
F P
0 g
s
.41965 .48403 m .4141 .47777 L .42747 .47107 L p 0 .312 .948 r
F P
0 g
s
.42668 .46558 m .41283 .44994 L .40021 .4621 L p 0 .349 .781 r
F P
0 g
s
.44015 .45878 m .42747 .47107 L .4141 .47777 L p 0 .05 .1 r
F P
0 g
s
.41346 .45525 m .42747 .47107 L .4141 .47777 L p 0 .312 .948 r
F P
0 g
s
.4141 .47777 m .40021 .4621 L .41346 .45525 L p 0 .312 .948 r
F P
0 g
s
.44111 .46425 m .45388 .45185 L .44015 .45878 L p 0 .05 .1 r
F P
0 g
s
.43307 .47739 m .42747 .47107 L .44015 .45878 L p 0 .349 .781 r
F P
0 g
s
.44015 .45878 m .42747 .47107 L .44111 .46425 L p 0 .05 .1 r
F P
0 g
s
.41283 .44994 m .42668 .46558 L .44015 .45878 L p 0 .313 .947 r
F P
0 g
s
.42747 .47107 m .44015 .45878 L p .43482 .45808 L 0 .349 .781 r
F P
0 g
s
.42668 .46558 m .41283 .44994 L .42617 .44298 L p 0 .313 .947 r
F P
0 g
s
.41346 .45525 m .42467 .46791 L p .43482 .45808 L 0 .349 .781 r
F P
0 g
s
.42467 .46791 m .42747 .47107 L p .43482 .45808 L 0 .349 .781 r
F P
0 g
s
.39488 .49055 m .41364 .4786 L .41132 .47464 L .1 0 0 r
F
.42747 .47107 m .44015 .45878 L .45388 .45185 L p 0 .05 .1 r
F P
0 g
s
.44015 .45878 m .42747 .47107 L p .42721 .46545 L 0 .349 .781 r
F P
0 g
s
.42617 .44298 m .43735 .45562 L p .42721 .46545 L 0 .349 .781 r
F P
0 g
s
.43735 .45562 m .44015 .45878 L p .42721 .46545 L 0 .349 .781 r
F P
0 g
s
.42747 .47107 m .43307 .47739 L .41965 .48403 L p 0 .312 .948 r
F P
0 g
s
.44379 .47485 m .45178 .47193 L p .42747 .47107 L 0 .349 .781 r
F P
0 g
s
.42747 .47107 m .43307 .47739 L .44379 .47485 L p 0 .349 .781 r
F P
0 g
s
.42747 .47107 m .41346 .45525 L .42617 .44298 L p 0 .349 .781 r
F P
0 g
s
.44111 .46425 m .44676 .47063 L .43307 .47739 L p 0 .312 .948 r
F P
0 g
s
.43307 .47739 m .42747 .47107 L .44111 .46425 L p 0 .312 .948 r
F P
0 g
s
.44015 .45878 m .42617 .44298 L .41346 .45525 L p 0 .349 .781 r
F P
0 g
s
.42697 .44826 m .43576 .4582 L p .42716 .45706 L 0 .312 .948 r
F P
0 g
s
.45388 .45185 m .44111 .46425 L .42747 .47107 L p 0 .05 .1 r
F P
0 g
s
.43576 .4582 m .44111 .46425 L p .42716 .45706 L 0 .312 .948 r
F P
0 g
s
.44111 .46425 m .42747 .47107 L p .42716 .45706 L 0 .312 .948 r
F P
0 g
s
.42747 .47107 m .41346 .45525 L .42697 .44826 L p 0 .312 .948 r
F P
0 g
s
.45757 .46807 m .46561 .46513 L p .44111 .46425 L 0 .349 .781 r
F P
0 g
s
.45388 .45185 m .44111 .46425 L .45501 .45728 L p 0 .05 .1 r
F P
0 g
s
.44111 .46425 m .45388 .45185 L p .44851 .45113 L 0 .349 .781 r
F P
0 g
s
.44015 .45878 m .42617 .44298 L .43978 .43589 L p 0 .313 .947 r
F P
0 g
s
.42697 .44826 m .43828 .46105 L p .44851 .45113 L 0 .349 .781 r
F P
0 g
s
.43828 .46105 m .44111 .46425 L p .44851 .45113 L 0 .349 .781 r
F P
0 g
s
.45388 .45185 m .44111 .46425 L p .44084 .45857 L 0 .349 .781 r
F P
0 g
s
.43978 .43589 m .45106 .44866 L p .44084 .45857 L 0 .349 .781 r
F P
0 g
s
.45106 .44866 m .45388 .45185 L p .44084 .45857 L 0 .349 .781 r
F P
0 g
s
.41364 .4786 m .43273 .46644 L .42467 .46791 L .1 0 0 r
F
.44111 .46425 m .42697 .44826 L .43978 .43589 L p 0 .349 .781 r
F P
0 g
s
.45388 .45185 m .43978 .43589 L .42697 .44826 L p 0 .349 .781 r
F P
0 g
s
.44074 .44114 m .44972 .45129 L p .44088 .45012 L 0 .312 .948 r
F P
0 g
s
.45216 .45406 m .45501 .45728 L p .4504 .45495 L 0 .312 .948 r
F P
0 g
s
.45501 .45728 m .44111 .46425 L p .44088 .45012 L 0 .312 .948 r
F P
0 g
s
.44111 .46425 m .44676 .47063 L .45757 .46807 L p 0 .349 .781 r
F P
0 g
s
.44676 .47063 m .44111 .46425 L .45501 .45728 L p 0 .312 .948 r
F P
0 g
s
.45501 .45728 m .44074 .44114 L .45365 .42866 L p 0 .35 .78 r
F P
0 g
s
.45216 .45406 m .44016 .469 L .45324 .45351 L .1 0 0 r
F
.45216 .45406 m .45324 .45351 L .45355 .45314 L F
.44972 .45129 m .45216 .45406 L p .44088 .45012 L 0 .312 .948 r
F P
0 g
s
.44088 .45012 m .45216 .45406 L .4504 .45495 L 0 .312 .948 r
F
.44111 .46425 m .42697 .44826 L .44074 .44114 L p F P
0 g
s
.45216 .45406 m .43828 .46105 L p .43273 .46644 L .1 0 0 r
F P
0 g
s
.43828 .46105 m .42467 .46791 L p .43273 .46644 L .1 0 0 r
F P
0 g
s
.42972 .47585 m .45216 .45406 L p .43273 .46644 L .1 0 0 r
F P
0 g
s
.41364 .4786 m .42159 .47724 L .43273 .46644 L .1 0 0 r
F
.42159 .47724 m .42972 .47585 L .43273 .46644 L F
.37644 .50229 m .40257 .48933 L p .41364 .4786 L F P
0 g
s
.40257 .48933 m .42972 .47585 L p .41364 .4786 L .1 0 0 r
F P
0 g
s
.42467 .46791 m .41132 .47464 L p .41364 .4786 L .1 0 0 r
F P
0 g
s
.40098 .48434 m .38721 .46883 L .40021 .4621 L p 0 .312 .948 r
F P
0 g
s
.41132 .47464 m .39822 .48124 L p .39488 .49055 L .1 0 0 r
F P
0 g
s
.44074 .44114 m .45365 .42866 L .43978 .43589 L p 0 .05 .1 r
F P
0 g
s
.4665 .41623 m .45365 .42866 L .43978 .43589 L p 0 .05 .1 r
F P
0 g
s
.42566 .41991 m .43978 .43589 L .45365 .42866 L p 0 .313 .947 r
F P
0 g
s
.42697 .44826 m .43978 .43589 L .45365 .42866 L p 0 .05 .1 r
F P
0 g
s
.4394 .41252 m .45365 .42866 L .43978 .43589 L p 0 .313 .947 r
F P
0 g
s
.45365 .42866 m .4394 .41252 L .42566 .41991 L p 0 .313 .947 r
F P
0 g
s
.45365 .42866 m .44074 .44114 L .42697 .44826 L p 0 .05 .1 r
F P
0 g
s
.46513 .38776 m .4793 .40386 L .4665 .41623 L p 0 .35 .78 r
F P
0 g
s
.4665 .41623 m .45229 .40011 L .46513 .38776 L p 0 .35 .78 r
F P
0 g
s
.45094 .37164 m .46513 .38776 L .45229 .40011 L p 0 .35 .78 r
F P
0 g
s
.43672 .35549 m .45094 .37164 L .43806 .38397 L p 0 .35 .78 r
F P
0 g
s
.45229 .40011 m .43806 .38397 L .45094 .37164 L p 0 .35 .78 r
F P
0 g
s
.45229 .40011 m .4665 .41623 L .45365 .42866 L p 0 .35 .78 r
F P
0 g
s
.45365 .42866 m .4394 .41252 L .45229 .40011 L p 0 .35 .78 r
F P
0 g
s
.42513 .39635 m .43806 .38397 L .45229 .40011 L p 0 .35 .78 r
F P
0 g
s
.42617 .44298 m .41218 .42716 L .42488 .41496 L p 0 .349 .781 r
F P
0 g
s
.41218 .42716 m .42488 .41496 L .43845 .40761 L p 0 .05 .1 r
F P
0 g
s
.42566 .41991 m .43845 .40761 L .42488 .41496 L p 0 .05 .1 r
F P
0 g
s
.43845 .40761 m .42566 .41991 L .41218 .42716 L p 0 .05 .1 r
F P
0 g
s
.43845 .40761 m .42566 .41991 L .4394 .41252 L p 0 .05 .1 r
F P
0 g
s
.45229 .40011 m .4394 .41252 L .42513 .39635 L p 0 .35 .78 r
F P
0 g
s
.4394 .41252 m .45365 .42866 L .44074 .44114 L p 0 .35 .78 r
F P
0 g
s
.45747 .44977 m .50187 .40666 L .43379 .32925 L p .858 0 0 r
F P
0 g
s
.43379 .32925 m .51446 .40013 L .50187 .40666 L .554 0 0 r
F
.41096 .41731 m .42411 .41013 L p .42357 .40666 L 0 .05 .1 r
F P
0 g
s
.42337 .40541 m .42007 .40858 L p .42357 .40666 L 0 .05 .1 r
F P
0 g
s
.42007 .40858 m .41096 .41731 L p .42357 .40666 L 0 .05 .1 r
F P
0 g
s
.41096 .41731 m .42337 .40541 L .40971 .38994 L p 0 .349 .782 r
F P
0 g
s
.39726 .40181 m .40971 .38994 L .39603 .37444 L p 0 .349 .782 r
F P
0 g
s
.39603 .37444 m .40971 .38994 L .42284 .38251 L p 0 .315 .945 r
F P
0 g
s
.40971 .38994 m .39726 .40181 L .41096 .41731 L p 0 .349 .782 r
F P
0 g
s
.38354 .3863 m .39603 .37444 L .38232 .35893 L p 0 .349 .782 r
F P
0 g
s
.38232 .35893 m .39603 .37444 L .40904 .36687 L p 0 .315 .945 r
F P
0 g
s
.39603 .37444 m .38354 .3863 L .39726 .40181 L p 0 .349 .782 r
F P
0 g
s
.42284 .38251 m .40904 .36687 L .39603 .37444 L p 0 .315 .945 r
F P
0 g
s
.41156 .42218 m .42411 .41013 L .41096 .41731 L p 0 .05 .1 r
F P
0 g
s
.3985 .42925 m .41096 .41731 L .42411 .41013 L p 0 .05 .1 r
F P
0 g
s
.40904 .36687 m .39521 .3512 L .38232 .35893 L p 0 .315 .945 r
F P
0 g
s
.42411 .41013 m .41156 .42218 L .3985 .42925 L p 0 .05 .1 r
F P
0 g
s
.40904 .36687 m .42284 .38251 L .43622 .37494 L p 0 .315 .945 r
F P
0 g
s
.39521 .3512 m .40904 .36687 L .42229 .35914 L p 0 .315 .945 r
F P
0 g
s
.43622 .37494 m .42229 .35914 L .40904 .36687 L p 0 .315 .945 r
F P
0 g
s
.42411 .41013 m .41156 .42218 L .42488 .41496 L p 0 .05 .1 r
F P
0 g
s
.42229 .35914 m .40835 .34332 L .39521 .3512 L p 0 .315 .945 r
F P
0 g
s
.42229 .35914 m .43622 .37494 L .42358 .38702 L p 0 .349 .781 r
F P
0 g
s
.42358 .38702 m .43622 .37494 L .42229 .35914 L p 0 .349 .781 r
F P
0 g
s
.40835 .34332 m .42229 .35914 L .40962 .37119 L p 0 .349 .781 r
F P
0 g
s
.42358 .38702 m .40962 .37119 L .42229 .35914 L p 0 .349 .781 r
F P
0 g
s
.42174 .33528 m .40835 .34332 L .42229 .35914 L p 0 .315 .945 r
F P
0 g
s
.40962 .37119 m .42229 .35914 L .40835 .34332 L p 0 .349 .781 r
F P
0 g
s
.42229 .35914 m .40962 .37119 L .42358 .38702 L p 0 .349 .781 r
F P
0 g
s
.40962 .37119 m .39564 .35534 L .40835 .34332 L p 0 .349 .781 r
F P
0 g
s
.40835 .34332 m .39564 .35534 L .40962 .37119 L p 0 .349 .781 r
F P
0 g
s
.40962 .37119 m .42358 .38702 L .4109 .39914 L p 0 .349 .781 r
F P
0 g
s
.42488 .41496 m .4109 .39914 L .42358 .38702 L p 0 .349 .781 r
F P
0 g
s
.4109 .39914 m .42358 .38702 L .40962 .37119 L p 0 .349 .781 r
F P
0 g
s
.42358 .38702 m .4109 .39914 L .42488 .41496 L p 0 .349 .781 r
F P
0 g
s
.39564 .35534 m .40962 .37119 L .3969 .38329 L p 0 .349 .781 r
F P
0 g
s
.4109 .39914 m .3969 .38329 L .40962 .37119 L p 0 .349 .781 r
F P
0 g
s
.3969 .38329 m .40962 .37119 L .39564 .35534 L p 0 .349 .781 r
F P
0 g
s
.40962 .37119 m .3969 .38329 L .4109 .39914 L p 0 .349 .781 r
F P
0 g
s
.42435 .39163 m .4109 .39914 L .42488 .41496 L p 0 .314 .946 r
F P
0 g
s
.42488 .41496 m .4109 .39914 L .42435 .39163 L p 0 .314 .946 r
F P
0 g
s
.3969 .38329 m .38288 .36742 L .39564 .35534 L p 0 .349 .781 r
F P
0 g
s
.39564 .35534 m .38288 .36742 L .3969 .38329 L p 0 .349 .781 r
F P
0 g
s
.41022 .37562 m .3969 .38329 L .4109 .39914 L p 0 .314 .946 r
F P
0 g
s
.4109 .39914 m .42435 .39163 L .41022 .37562 L p 0 .314 .946 r
F P
0 g
s
.41022 .37562 m .42435 .39163 L .4109 .39914 L p 0 .314 .946 r
F P
0 g
s
.4109 .39914 m .3969 .38329 L .41022 .37562 L p 0 .314 .946 r
F P
0 g
s
.39607 .35959 m .38288 .36742 L .3969 .38329 L p 0 .314 .946 r
F P
0 g
s
.3969 .38329 m .41022 .37562 L .39607 .35959 L p 0 .314 .946 r
F P
0 g
s
.39607 .35959 m .41022 .37562 L .3969 .38329 L p 0 .314 .946 r
F P
0 g
s
.3969 .38329 m .38288 .36742 L .39607 .35959 L p 0 .314 .946 r
F P
0 g
s
.4238 .3678 m .41022 .37562 L .42435 .39163 L p 0 .314 .946 r
F P
0 g
s
.42435 .39163 m .43806 .38397 L .4238 .3678 L p 0 .314 .946 r
F P
0 g
s
.4238 .3678 m .43806 .38397 L .42435 .39163 L p 0 .314 .946 r
F P
0 g
s
.42435 .39163 m .41022 .37562 L .4238 .3678 L p 0 .314 .946 r
F P
0 g
s
.43978 .43589 m .42566 .41991 L .4394 .41252 L p 0 .313 .947 r
F P
0 g
s
.40953 .3516 m .39607 .35959 L .41022 .37562 L p 0 .314 .946 r
F P
0 g
s
.41022 .37562 m .4238 .3678 L .40953 .3516 L p 0 .314 .946 r
F P
0 g
s
.40953 .3516 m .4238 .3678 L .41022 .37562 L p 0 .314 .946 r
F P
0 g
s
.41022 .37562 m .39607 .35959 L .40953 .3516 L p 0 .314 .946 r
F P
0 g
s
.41218 .42716 m .42617 .44298 L .41283 .44994 L p 0 .313 .947 r
F P
0 g
s
.41283 .44994 m .39895 .43427 L .41156 .42218 L p 0 .349 .781 r
F P
0 g
s
.42617 .44298 m .41218 .42716 L .39895 .43427 L p 0 .313 .947 r
F P
0 g
s
.41218 .42716 m .42617 .44298 L .43978 .43589 L p 0 .313 .947 r
F P
0 g
s
.39895 .43427 m .41283 .44994 L .39973 .45676 L p 0 .313 .947 r
F P
0 g
s
.40021 .4621 m .41283 .44994 L .39973 .45676 L p 0 .05 .1 r
F P
0 g
s
.41283 .44994 m .40021 .4621 L .38721 .46883 L p 0 .05 .1 r
F P
0 g
s
.39895 .43427 m .41283 .44994 L .40021 .4621 L p 0 .349 .781 r
F P
0 g
s
.39895 .43427 m .41283 .44994 L .42617 .44298 L p 0 .313 .947 r
F P
0 g
s
.41283 .44994 m .39895 .43427 L .3863 .44641 L p 0 .349 .781 r
F P
0 g
s
.41283 .44994 m .39895 .43427 L .41218 .42716 L p 0 .313 .947 r
F P
0 g
s
.42617 .44298 m .41218 .42716 L .39943 .4394 L p 0 .349 .781 r
F P
0 g
s
.42566 .41991 m .43978 .43589 L .42617 .44298 L p 0 .313 .947 r
F P
0 g
s
.42617 .44298 m .41218 .42716 L .42566 .41991 L p 0 .313 .947 r
F P
0 g
s
.41346 .45525 m .42617 .44298 L .41283 .44994 L p 0 .05 .1 r
F P
0 g
s
.40021 .4621 m .41283 .44994 L .42617 .44298 L p 0 .05 .1 r
F P
0 g
s
.42617 .44298 m .41346 .45525 L .40021 .4621 L p 0 .05 .1 r
F P
0 g
s
.41218 .42716 m .42617 .44298 L .41346 .45525 L p 0 .349 .781 r
F P
0 g
s
.43978 .43589 m .42566 .41991 L .41218 .42716 L p 0 .313 .947 r
F P
0 g
s
.43978 .43589 m .42566 .41991 L .41281 .43226 L p 0 .349 .781 r
F P
0 g
s
.42697 .44826 m .43978 .43589 L .42617 .44298 L p 0 .05 .1 r
F P
0 g
s
.41346 .45525 m .42617 .44298 L .43978 .43589 L p 0 .05 .1 r
F P
0 g
s
.43978 .43589 m .42697 .44826 L .41346 .45525 L p 0 .05 .1 r
F P
0 g
s
.42566 .41991 m .43978 .43589 L .42697 .44826 L p 0 .349 .781 r
F P
0 g
s
.42617 .44298 m .41346 .45525 L .42697 .44826 L p 0 .05 .1 r
F P
0 g
s
.41283 .44994 m .40021 .4621 L .41346 .45525 L p 0 .05 .1 r
F P
0 g
s
.37342 .45329 m .38721 .46883 L .39973 .45676 L p 0 .349 .782 r
F P
0 g
s
.3863 .44641 m .40021 .4621 L .41283 .44994 L p 0 .349 .781 r
F P
0 g
s
.39943 .4394 m .41346 .45525 L .42617 .44298 L p 0 .349 .781 r
F P
0 g
s
.42697 .44826 m .41281 .43226 L .42566 .41991 L p 0 .349 .781 r
F P
0 g
s
.41281 .43226 m .42566 .41991 L .4394 .41252 L p 0 .05 .1 r
F P
0 g
s
.42645 .42497 m .41281 .43226 L p .41986 .42702 L 0 .05 .1 r
F P
0 g
s
.4394 .41252 m .42991 .42165 L p .41986 .42702 L 0 .05 .1 r
F P
0 g
s
.42991 .42165 m .42645 .42497 L p .41986 .42702 L 0 .05 .1 r
F P
0 g
s
.4394 .41252 m .42566 .41991 L p .42624 .42361 L 0 .05 .1 r
F P
0 g
s
.42991 .42165 m .4394 .41252 L p .42624 .42361 L 0 .05 .1 r
F P
0 g
s
.42249 .33932 m .43672 .35549 L .4238 .3678 L p 0 .35 .78 r
F P
0 g
s
.43806 .38397 m .4238 .3678 L .43672 .35549 L p 0 .35 .78 r
F P
0 g
s
.4238 .3678 m .40953 .3516 L .42249 .33932 L p 0 .35 .78 r
F P
0 g
s
.41083 .38015 m .4238 .3678 L .43806 .38397 L p 0 .35 .78 r
F P
0 g
s
.43806 .38397 m .42513 .39635 L .41083 .38015 L p 0 .35 .78 r
F P
0 g
s
.39652 .36393 m .40953 .3516 L .4238 .3678 L p 0 .35 .78 r
F P
0 g
s
.4238 .3678 m .41083 .38015 L .39652 .36393 L p 0 .35 .78 r
F P
0 g
s
.43978 .43589 m .42697 .44826 L .44074 .44114 L p 0 .05 .1 r
F P
0 g
s
.41281 .43226 m .42697 .44826 L .43978 .43589 L p 0 .349 .781 r
F P
0 g
s
.44074 .44114 m .42645 .42497 L .4394 .41252 L p 0 .35 .78 r
F P
0 g
s
.3985 .42925 m .41096 .41731 L .39726 .40181 L p 0 .349 .782 r
F P
0 g
s
.42488 .41496 m .4109 .39914 L .3977 .40651 L p 0 .314 .946 r
F P
0 g
s
.3977 .40651 m .4109 .39914 L .42488 .41496 L p 0 .314 .946 r
F P
0 g
s
.41096 .41731 m .3985 .42925 L .41156 .42218 L p 0 .05 .1 r
F P
0 g
s
.39726 .40181 m .38476 .41374 L .3985 .42925 L p 0 .349 .782 r
F P
0 g
s
.41156 .42218 m .3977 .40651 L .38476 .41374 L p 0 .314 .946 r
F P
0 g
s
.38476 .41374 m .3977 .40651 L .41156 .42218 L p 0 .314 .946 r
F P
0 g
s
.3977 .40651 m .41156 .42218 L .42488 .41496 L p 0 .314 .946 r
F P
0 g
s
.42488 .41496 m .41156 .42218 L .3977 .40651 L p 0 .314 .946 r
F P
0 g
s
.39816 .41131 m .4109 .39914 L .42488 .41496 L p 0 .349 .781 r
F P
0 g
s
.42488 .41496 m .4109 .39914 L .39816 .41131 L p 0 .349 .781 r
F P
0 g
s
.41214 .40878 m .42513 .39635 L .4394 .41252 L p 0 .35 .78 r
F P
0 g
s
.42645 .42497 m .42991 .42165 L p .42624 .42361 L 0 .05 .1 r
F P
0 g
s
.42488 .41496 m .41156 .42218 L .39895 .43427 L p 0 .05 .1 r
F P
0 g
s
.39895 .43427 m .41156 .42218 L .42488 .41496 L p 0 .05 .1 r
F P
0 g
s
.39895 .43427 m .41218 .42716 L .42488 .41496 L p 0 .05 .1 r
F P
0 g
s
.42488 .41496 m .41218 .42716 L .39895 .43427 L p 0 .05 .1 r
F P
0 g
s
.38476 .41374 m .3985 .42925 L .41156 .42218 L p 0 .314 .946 r
F P
0 g
s
.41156 .42218 m .3985 .42925 L .38598 .44125 L p 0 .05 .1 r
F P
0 g
s
.41156 .42218 m .3985 .42925 L .38476 .41374 L p 0 .314 .946 r
F P
0 g
s
.38598 .44125 m .3985 .42925 L .41156 .42218 L p 0 .05 .1 r
F P
0 g
s
.38598 .44125 m .39895 .43427 L .41156 .42218 L p 0 .05 .1 r
F P
0 g
s
.41156 .42218 m .39895 .43427 L .38598 .44125 L p 0 .05 .1 r
F P
0 g
s
.42488 .41496 m .41218 .42716 L .39816 .41131 L p 0 .349 .781 r
F P
0 g
s
.39816 .41131 m .41218 .42716 L .42488 .41496 L p 0 .349 .781 r
F P
0 g
s
.42488 .41496 m .41218 .42716 L .42566 .41991 L p 0 .05 .1 r
F P
0 g
s
.41346 .45525 m .39943 .4394 L .41218 .42716 L p 0 .349 .781 r
F P
0 g
s
.39943 .4394 m .41218 .42716 L .42566 .41991 L p 0 .05 .1 r
F P
0 g
s
.41281 .43226 m .42566 .41991 L .41218 .42716 L p 0 .05 .1 r
F P
0 g
s
.42566 .41991 m .41281 .43226 L .39943 .4394 L p 0 .05 .1 r
F P
0 g
s
.42566 .41991 m .41281 .43226 L .42645 .42497 L p 0 .05 .1 r
F P
0 g
s
.4394 .41252 m .42645 .42497 L .41214 .40878 L p 0 .35 .78 r
F P
0 g
s
.38476 .41374 m .39726 .40181 L .38354 .3863 L p 0 .349 .782 r
F P
0 g
s
.4109 .39914 m .3969 .38329 L .38383 .39082 L p 0 .314 .946 r
F P
0 g
s
.38383 .39082 m .3969 .38329 L .4109 .39914 L p 0 .314 .946 r
F P
0 g
s
.38354 .3863 m .371 .3982 L .38476 .41374 L p 0 .349 .782 r
F P
0 g
s
.3977 .40651 m .38383 .39082 L .371 .3982 L p 0 .314 .946 r
F P
0 g
s
.371 .3982 m .38383 .39082 L .3977 .40651 L p 0 .314 .946 r
F P
0 g
s
.38383 .39082 m .3977 .40651 L .4109 .39914 L p 0 .314 .946 r
F P
0 g
s
.4109 .39914 m .3977 .40651 L .38383 .39082 L p 0 .314 .946 r
F P
0 g
s
.38412 .39544 m .3969 .38329 L .4109 .39914 L p 0 .349 .781 r
F P
0 g
s
.4109 .39914 m .3969 .38329 L .38412 .39544 L p 0 .349 .781 r
F P
0 g
s
.39781 .39256 m .41083 .38015 L .42513 .39635 L p 0 .35 .78 r
F P
0 g
s
.371 .3982 m .38476 .41374 L .3977 .40651 L p 0 .314 .946 r
F P
0 g
s
.3977 .40651 m .38476 .41374 L .371 .3982 L p 0 .314 .946 r
F P
0 g
s
.4109 .39914 m .39816 .41131 L .38412 .39544 L p 0 .349 .781 r
F P
0 g
s
.38412 .39544 m .39816 .41131 L .4109 .39914 L p 0 .349 .781 r
F P
0 g
s
.42513 .39635 m .41214 .40878 L .39781 .39256 L p 0 .35 .78 r
F P
0 g
s
.38232 .35893 m .3698 .37076 L .38354 .3863 L p 0 .349 .782 r
F P
0 g
s
.371 .3982 m .38354 .3863 L .3698 .37076 L p 0 .349 .782 r
F P
0 g
s
.3698 .37076 m .35723 .38264 L .371 .3982 L p 0 .349 .782 r
F P
0 g
s
.3969 .38329 m .38288 .36742 L .36993 .3751 L p 0 .314 .946 r
F P
0 g
s
.36993 .3751 m .38288 .36742 L .3969 .38329 L p 0 .314 .946 r
F P
0 g
s
.38383 .39082 m .36993 .3751 L .35723 .38264 L p 0 .314 .946 r
F P
0 g
s
.35723 .38264 m .36993 .3751 L .38383 .39082 L p 0 .314 .946 r
F P
0 g
s
.36993 .3751 m .38383 .39082 L .3969 .38329 L p 0 .314 .946 r
F P
0 g
s
.3969 .38329 m .38383 .39082 L .36993 .3751 L p 0 .314 .946 r
F P
0 g
s
.37006 .37955 m .38288 .36742 L .3969 .38329 L p 0 .349 .781 r
F P
0 g
s
.3969 .38329 m .38288 .36742 L .37006 .37955 L p 0 .349 .781 r
F P
0 g
s
.38345 .37632 m .39652 .36393 L .41083 .38015 L p 0 .35 .78 r
F P
0 g
s
.35723 .38264 m .371 .3982 L .38383 .39082 L p 0 .314 .946 r
F P
0 g
s
.38383 .39082 m .371 .3982 L .35723 .38264 L p 0 .314 .946 r
F P
0 g
s
.3969 .38329 m .38412 .39544 L .37006 .37955 L p 0 .349 .781 r
F P
0 g
s
.37006 .37955 m .38412 .39544 L .3969 .38329 L p 0 .349 .781 r
F P
0 g
s
.41083 .38015 m .39781 .39256 L .38345 .37632 L p 0 .35 .78 r
F P
0 g
s
.43379 .32925 m .38873 .37196 L .43175 .42066 L p .858 0 0 r
F P
0 g
s
.43175 .42066 m .45747 .44977 L p .44857 .40448 L .858 0 0 r
F P
0 g
s
.44857 .40448 m .43379 .32925 L .43175 .42066 L .858 0 0 r
F
.38873 .37196 m .40049 .36505 L p .43627 .41825 L .541 0 0 r
F P
0 g
s
.45747 .44977 m .43175 .42066 L p .43627 .41825 L .541 0 0 r
F P
0 g
s
.43175 .42066 m .38873 .37196 L p .43627 .41825 L .541 0 0 r
F P
0 g
s
.45747 .44977 m .43627 .41825 L .45389 .43156 L .541 0 0 r
F
.46844 .44543 m .46788 .44478 L .48069 .43233 L p 0 .35 .78 r
F P
0 g
s
.49889 .43647 m .49093 .44045 L p .49345 .41993 L 0 .314 .946 r
F P
0 g
s
.48724 .45216 m .48063 .45541 L p .48069 .43233 L 0 .314 .946 r
F P
0 g
s
.49345 .41993 m .49401 .42057 L .49889 .43647 L p 0 .314 .946 r
F P
0 g
s
.49889 .43647 m .49401 .42057 L .49345 .41993 L p 0 .314 .946 r
F P
0 g
s
.50891 .41547 m .50672 .40822 L .50616 .40758 L p 0 .315 .945 r
F P
0 g
s
.48069 .43233 m .48126 .43297 L .48724 .45216 L p 0 .314 .946 r
F P
0 g
s
.50616 .40758 m .50672 .40822 L .49401 .42057 L p 0 .35 .78 r
F P
0 g
s
.49401 .42057 m .49345 .41993 L .50616 .40758 L p 0 .35 .78 r
F P
0 g
s
.49345 .41993 m .49401 .42057 L .48126 .43297 L p 0 .35 .78 r
F P
0 g
s
.48126 .43297 m .48069 .43233 L .49345 .41993 L p 0 .35 .78 r
F P
0 g
s
.48069 .43233 m .48126 .43297 L .46844 .44543 L p 0 .35 .78 r
F P
0 g
s
.45747 .44977 m .46977 .44356 L .51446 .40013 L p .1 0 0 r
F P
0 g
s
.45747 .44977 m .45389 .43156 L .46977 .44356 L .541 0 0 r
F
.40049 .36505 m .44385 .41419 L p .43627 .41825 L F P
0 g
s
.44385 .41419 m .46977 .44356 L p .43627 .41825 L .541 0 0 r
F P
0 g
s
.43379 .32925 m .44585 .32202 L .51446 .40013 L .554 0 0 r
F
.44585 .32202 m .51446 .40013 L .46977 .44356 L p .859 0 0 r
F P
0 g
s
.40049 .36505 m .44585 .32202 L p .45779 .38268 L .859 0 0 r
F P
0 g
s
.46977 .44356 m .4352 .40438 L p .45779 .38268 L .859 0 0 r
F P
0 g
s
.4352 .40438 m .40049 .36505 L p .45779 .38268 L .859 0 0 r
F P
0 g
s
.37221 .42571 m .38598 .44125 L .3985 .42925 L p 0 .349 .782 r
F P
0 g
s
.3985 .42925 m .38476 .41374 L .37221 .42571 L p 0 .349 .782 r
F P
0 g
s
.37342 .45329 m .3863 .44641 L .39895 .43427 L p 0 .05 .1 r
F P
0 g
s
.39895 .43427 m .3863 .44641 L .37342 .45329 L p 0 .05 .1 r
F P
0 g
s
.40021 .4621 m .3863 .44641 L .39895 .43427 L p 0 .349 .781 r
F P
0 g
s
.41218 .42716 m .39895 .43427 L .3863 .44641 L p 0 .05 .1 r
F P
0 g
s
.3863 .44641 m .39895 .43427 L .41218 .42716 L p 0 .05 .1 r
F P
0 g
s
.3863 .44641 m .39943 .4394 L .41218 .42716 L p 0 .05 .1 r
F P
0 g
s
.41218 .42716 m .39943 .4394 L .3863 .44641 L p 0 .05 .1 r
F P
0 g
s
.38537 .42353 m .39816 .41131 L .41218 .42716 L p 0 .349 .781 r
F P
0 g
s
.41218 .42716 m .39943 .4394 L .38537 .42353 L p 0 .349 .781 r
F P
0 g
s
.38537 .42353 m .39943 .4394 L .41218 .42716 L p 0 .349 .781 r
F P
0 g
s
.41218 .42716 m .39816 .41131 L .38537 .42353 L p 0 .349 .781 r
F P
0 g
s
.41218 .42716 m .39943 .4394 L .41281 .43226 L p 0 .05 .1 r
F P
0 g
s
.38476 .41374 m .371 .3982 L .35842 .41015 L p 0 .349 .782 r
F P
0 g
s
.37129 .40764 m .38412 .39544 L .39816 .41131 L p 0 .349 .781 r
F P
0 g
s
.35842 .41015 m .37221 .42571 L .38476 .41374 L p 0 .349 .782 r
F P
0 g
s
.39816 .41131 m .38537 .42353 L .37129 .40764 L p 0 .349 .781 r
F P
0 g
s
.37129 .40764 m .38537 .42353 L .39816 .41131 L p 0 .349 .781 r
F P
0 g
s
.39816 .41131 m .38412 .39544 L .37129 .40764 L p 0 .349 .781 r
F P
0 g
s
.39822 .48124 m .45216 .45406 L .38345 .37632 L p .54 0 0 r
F P
0 g
s
.41214 .40878 m .42645 .42497 L .41281 .43226 L p 0 .312 .948 r
F P
0 g
s
.41281 .43226 m .42697 .44826 L .41346 .45525 L p 0 .312 .948 r
F P
0 g
s
.41346 .45525 m .39943 .4394 L .41281 .43226 L p 0 .312 .948 r
F P
0 g
s
.39863 .41623 m .41281 .43226 L .39943 .4394 L p 0 .312 .948 r
F P
0 g
s
.42645 .42497 m .44074 .44114 L .42697 .44826 L p 0 .312 .948 r
F P
0 g
s
.42697 .44826 m .41281 .43226 L .42645 .42497 L p 0 .312 .948 r
F P
0 g
s
.41281 .43226 m .39863 .41623 L .41214 .40878 L p 0 .312 .948 r
F P
0 g
s
.39781 .39256 m .41214 .40878 L .39863 .41623 L p 0 .312 .948 r
F P
0 g
s
.39863 .41623 m .38442 .40017 L .39781 .39256 L p 0 .312 .948 r
F P
0 g
s
.38345 .37632 m .39781 .39256 L .38442 .40017 L p 0 .312 .948 r
F P
0 g
s
.38345 .37632 m .45216 .45406 L .42972 .47585 L p .858 0 0 r
F P
0 g
s
.38345 .37632 m .45216 .45406 L .45355 .45314 L .674 0 0 r
F
.38345 .37632 m .42972 .47585 L .45216 .45406 L .858 0 0 r
F
.38481 .37535 m .45355 .45314 L .4555 .45157 L .776 0 0 r
F
.38345 .37632 m .45355 .45314 L .38481 .37535 L .674 0 0 r
F
.38873 .37196 m .45747 .44977 L .46977 .44356 L .541 0 0 r
F
.38675 .37375 m .45747 .44977 L .38873 .37196 L .832 0 0 r
F
.38675 .37375 m .4555 .45157 L .45747 .44977 L F
.38481 .37535 m .4555 .45157 L .38675 .37375 L .776 0 0 r
F
.38873 .37196 m .46977 .44356 L .40049 .36505 L .541 0 0 r
F
.46788 .44478 m .46844 .44543 L p .46561 .46513 L 0 .313 .947 r
F P
0 g
s
.46788 .44478 m .46844 .44543 L .45558 .45793 L p 0 .35 .78 r
F P
0 g
s
.45558 .45793 m .45501 .45728 L .46788 .44478 L p 0 .35 .78 r
F P
0 g
s
.45216 .45406 m .42972 .47585 L .44016 .469 L .1 0 0 r
F
.45355 .45314 m .45486 .45716 L .4555 .45157 L F
.45355 .45314 m .44016 .469 L .45486 .45716 L F
.4555 .45157 m .46977 .44356 L .45747 .44977 L F
.4555 .45157 m .45486 .45716 L .46977 .44356 L F
.38547 .37864 m .46977 .44356 L .45486 .45716 L .832 0 0 r
F
.38547 .37864 m .40049 .36505 L .46977 .44356 L F
.42023 .41797 m .42355 .41556 L .4352 .40438 L .1 0 0 r
F
.42355 .41556 m .45029 .39615 L .4352 .40438 L F
.48022 .36115 m .4352 .40438 L p .4535 .38868 L F P
0 g
s
.44585 .32202 m .45692 .31087 L .52526 .38875 L .889 0 0 r
F
.49568 .35252 m .48022 .36115 L p .4535 .38868 L .1 0 0 r
F P
0 g
s
.48022 .36115 m .48785 .35474 L .49115 .34988 L .1 0 0 r
F
.48785 .35474 m .51833 .32913 L .49115 .34988 L F
.49115 .34988 m .49827 .34323 L .49525 .34386 L F
.49827 .34323 m .52652 .31688 L .49525 .34386 L F
.4612 .30503 m .4915 .34463 L .45763 .30601 L .184 0 0 r
F
.4612 .30503 m .49525 .34386 L .4915 .34463 L F
.45692 .31087 m .4612 .30503 L .49525 .34386 L .98 0 0 r
F
.45692 .31087 m .49525 .34386 L .49321 .34686 L F
.38103 .35986 m .38045 .35692 L .39416 .34556 L .1 0 0 r
F
.38232 .35893 m .38103 .35986 L .39416 .34556 L F
.38232 .35893 m .41273 .3302 L .398 .31348 L p 0 .349 .782 r
F P
0 g
s
.41273 .3302 m .38232 .35893 L .39521 .3512 L p 0 .05 .1 r
F P
0 g
s
.398 .31348 m .3675 .34215 L .38232 .35893 L p 0 .349 .782 r
F P
0 g
s
.39326 .3262 m .38026 .33425 L .39521 .3512 L p 0 .315 .945 r
F P
0 g
s
.39521 .3512 m .40835 .34332 L .39326 .3262 L p 0 .315 .945 r
F P
0 g
s
.40835 .34332 m .39521 .3512 L .38026 .33425 L p 0 .315 .945 r
F P
0 g
s
.38026 .33425 m .39326 .3262 L .40835 .34332 L p 0 .315 .945 r
F P
0 g
s
.38891 .34158 m .40835 .34332 L .39326 .3262 L closepath p 0 .349 .781 r
F P
0 g
s
.4392 .31412 m .42422 .29706 L p .41961 .31048 L 0 .349 .781 r
F P
0 g
s
.40835 .34332 m .43026 .32258 L p .41961 .31048 L 0 .349 .781 r
F P
0 g
s
.43026 .32258 m .4392 .31412 L p .41961 .31048 L 0 .349 .781 r
F P
0 g
s
.39326 .3262 m .40835 .34332 L .38891 .34158 L closepath p 0 .349 .781 r
F P
0 g
s
.4392 .31412 m .46975 .28521 L .45617 .29356 L p 0 .05 .1 r
F P
0 g
s
.4392 .31412 m .45701 .29727 L p .44833 .28737 L 0 .349 .781 r
F P
0 g
s
.45701 .29727 m .46975 .28521 L p .44833 .28737 L 0 .349 .781 r
F P
0 g
s
.60987 .61659 m .6243 .63294 L .65315 .60328 L p 0 .349 .782 r
F P
0 g
s
.48624 .2041 m .47274 .21305 L .47271 .23074 L p 0 .181 .719 r
F P
0 g
s
.47271 .23074 m .47274 .21305 L .44356 .24034 L closepath p 0 .349 .782 r
F P
0 g
s
.47274 .21305 m .48624 .2041 L .48623 .22194 L p 0 .181 .719 r
F P
0 g
s
.48623 .22194 m .47271 .23074 L .47274 .21305 L p 0 .181 .719 r
F P
0 g
s
.47274 .21305 m .48624 .2041 L .45685 .2316 L p 0 .05 .1 r
F P
0 g
s
.45685 .2316 m .44356 .24034 L .47274 .21305 L p 0 .05 .1 r
F P
0 g
s
.52819 .55263 m .48632 .59446 L .55085 .66711 L p .856 0 0 r
F P
0 g
s
.60474 .62053 m .56453 .57502 L p .55681 .57802 L .554 0 0 r
F P
0 g
s
.56453 .57502 m .52819 .55263 L .54032 .54762 L .554 0 0 r
F
.60474 .62053 m .55681 .57802 L .56453 .57502 L F
.55681 .57802 m .52819 .55263 L .56453 .57502 L F
.60658 .61881 m .54405 .54444 L .60846 .61737 L .778 0 0 r
F
.60658 .61881 m .54218 .54591 L .54405 .54444 L F
.60474 .62053 m .54218 .54591 L .60658 .61881 L .831 0 0 r
F
.54032 .54762 m .52819 .55263 L p .55681 .57802 L .554 0 0 r
F P
0 g
s
.56453 .57502 m .54032 .54762 L p .55681 .57802 L .554 0 0 r
F P
0 g
s
.54032 .54762 m .60474 .62053 L .56321 .66301 L p .856 0 0 r
F P
0 g
s
.60474 .62053 m .54032 .54762 L .54218 .54591 L .831 0 0 r
F
.60846 .61737 m .54405 .54444 L .54543 .54362 L .681 0 0 r
F
.60846 .61737 m .54543 .54362 L .60987 .61659 L F
.58307 .58625 m .56964 .57105 L .55762 .58318 L p 0 .349 .782 r
F P
0 g
s
.55762 .58318 m .57205 .57762 L p .57028 .57279 L 0 .05 .173 r
F P
0 g
s
.56964 .57105 m .56644 .57428 L p .57028 .57279 L 0 .05 .173 r
F P
0 g
s
.56644 .57428 m .55762 .58318 L p .57028 .57279 L 0 .05 .173 r
F P
0 g
s
.57205 .57762 m .55762 .58318 L .56644 .57428 L p 0 .05 .173 r
F P
0 g
s
.56644 .57428 m .56964 .57105 L p .57028 .57279 L 0 .05 .173 r
F P
0 g
s
.57205 .57762 m .56644 .57428 L .57028 .57279 L 0 .05 .173 r
F
.56321 .66301 m .4982 .58975 L .54032 .54762 L p .856 0 0 r
F P
0 g
s
.54555 .59536 m .53203 .58009 L .51987 .5923 L p 0 .349 .782 r
F P
0 g
s
.53203 .58009 m .54555 .59536 L .55762 .58318 L p 0 .349 .782 r
F P
0 g
s
.55762 .58318 m .54414 .56793 L .53203 .58009 L p 0 .349 .782 r
F P
0 g
s
.54555 .59536 m .53203 .58009 L .54626 .57449 L p 0 .314 .946 r
F P
0 g
s
.57108 .5984 m .55762 .58318 L .54555 .59536 L p 0 .349 .782 r
F P
0 g
s
.55989 .58991 m .54555 .59536 L .55762 .58318 L p 0 .05 .173 r
F P
0 g
s
.55762 .58318 m .54555 .59536 L .55989 .58991 L p 0 .05 .173 r
F P
0 g
s
.53203 .58009 m .54555 .59536 L .55989 .58991 L p 0 .314 .946 r
F P
0 g
s
.55989 .58991 m .54626 .57449 L .53203 .58009 L p 0 .314 .946 r
F P
0 g
s
.51987 .5923 m .53203 .58009 L .54626 .57449 L p 0 .05 .157 r
F P
0 g
s
.53203 .58009 m .51987 .5923 L .53402 .5868 L p 0 .05 .157 r
F P
0 g
s
.49523 .58556 m .52819 .55263 L p .50462 .5818 L .191 0 0 r
F P
0 g
s
.52819 .55263 m .54032 .54762 L .53146 .55648 L p .191 0 0 r
F P
0 g
s
.53146 .55648 m .51934 .56861 L p .52192 .56039 L .191 0 0 r
F P
0 g
s
.52192 .56039 m .51934 .56861 L .51331 .57105 L .191 0 0 r
F
.52819 .55263 m .53146 .55648 L .52192 .56039 L F
.54414 .56793 m .53064 .55266 L .51849 .5648 L p 0 .349 .782 r
F P
0 g
s
.51849 .5648 m .5326 .55905 L p .53249 .56329 L 0 .314 .946 r
F P
0 g
s
.51849 .5648 m .53203 .58009 L .54414 .56793 L p 0 .349 .782 r
F P
0 g
s
.53203 .58009 m .5212 .56786 L p .53249 .56329 L 0 .314 .946 r
F P
0 g
s
.5212 .56786 m .51849 .5648 L p .53249 .56329 L 0 .314 .946 r
F P
0 g
s
.51934 .56861 m .50716 .58079 L p .51331 .57105 L .191 0 0 r
F P
0 g
s
.51331 .57105 m .50716 .58079 L .50462 .5818 L .191 0 0 r
F
.53203 .58009 m .51849 .5648 L .5063 .57698 L p 0 .349 .782 r
F P
0 g
s
.5063 .57698 m .52033 .57134 L p .52023 .57556 L 0 .313 .947 r
F P
0 g
s
.52017 .57866 m .51987 .5923 L .53203 .58009 L p 0 .349 .782 r
F P
0 g
s
.50901 .58005 m .51427 .57795 L p .5063 .57698 L 0 .349 .782 r
F P
0 g
s
.51987 .5923 m .50901 .58005 L p .52023 .57556 L 0 .313 .947 r
F P
0 g
s
.50901 .58005 m .5063 .57698 L p .52023 .57556 L 0 .313 .947 r
F P
0 g
s
.50716 .58079 m .4982 .58975 L p .50462 .5818 L .191 0 0 r
F P
0 g
s
.5445 .54401 m .55594 .52898 L .56627 .52277 L .191 0 0 r
F
.54405 .54444 m .54434 .54407 L .5445 .54401 L F
.54434 .54407 m .55594 .52898 L .5445 .54401 L F
.60987 .61659 m .54543 .54362 L .56627 .52277 L .856 0 0 r
F
.56627 .52277 m .54543 .54362 L .60987 .61659 L p F P
0 g
s
.5562 .55582 m .5706 .55001 L p .54827 .54245 L 0 .315 .945 r
F P
0 g
s
.54218 .54591 m .55594 .52898 L .54405 .54444 L .191 0 0 r
F
.54543 .54362 m .56627 .52277 L p .57549 .52191 L F P
0 g
s
.57549 .52191 m .5849 .52104 L .55974 .5377 L .191 0 0 r
F
.57432 .53166 m .55974 .5377 L p .5849 .52104 L F P
0 g
s
.54543 .54362 m .60433 .51923 L .67104 .59511 L p .555 0 0 r
F P
0 g
s
.55974 .5377 m .54543 .54362 L p .57549 .52191 L .191 0 0 r
F P
0 g
s
.54405 .54444 m .56627 .52277 L .54543 .54362 L .191 0 0 r
F
.5706 .55001 m .55702 .53462 L .54273 .54057 L p 0 .315 .945 r
F P
0 g
s
.55974 .5377 m .5706 .55001 L p .5573 .54013 L 0 .349 .781 r
F P
0 g
s
.55702 .53462 m .5706 .55001 L .58528 .5441 L p 0 .315 .945 r
F P
0 g
s
.54543 .54362 m .5562 .55582 L p .54827 .54245 L 0 .315 .945 r
F P
0 g
s
.5562 .55582 m .54273 .54057 L .53064 .55266 L p 0 .349 .782 r
F P
0 g
s
.54664 .545 m .54484 .54681 L p .54866 .54728 L 0 .349 .781 r
F P
0 g
s
.63042 .59557 m .60987 .61659 L .67104 .59511 L p .262 0 0 r
F P
0 g
s
.67104 .59511 m .60987 .61659 L .54543 .54362 L p .555 0 0 r
F P
0 g
s
.5706 .55001 m .54664 .545 L .54866 .54728 L 0 .349 .781 r
F
.5706 .55001 m .55702 .53462 L .54664 .545 L p F P
0 g
s
.58528 .5441 m .57157 .52855 L .55702 .53462 L p 0 .315 .945 r
F P
0 g
s
.57157 .52855 m .55931 .54084 L p .56451 .5415 L 0 .349 .781 r
F P
0 g
s
.58528 .5441 m .57432 .53166 L p .56451 .5415 L 0 .349 .781 r
F P
0 g
s
.57432 .53166 m .57157 .52855 L p .56451 .5415 L 0 .349 .781 r
F P
0 g
s
.5849 .52104 m .59451 .52015 L .57432 .53166 L .191 0 0 r
F
.58918 .52551 m .57432 .53166 L p .59451 .52015 L F P
0 g
s
.57157 .52855 m .58528 .5441 L .60023 .53806 L p 0 .315 .945 r
F P
0 g
s
.58416 .56539 m .5706 .55001 L .5562 .55582 L p 0 .315 .945 r
F P
0 g
s
.58416 .56539 m .56964 .57105 L .58307 .58625 L p 0 .315 .945 r
F P
0 g
s
.56964 .57105 m .58416 .56539 L .57205 .57762 L p 0 .05 .173 r
F P
0 g
s
.5562 .55582 m .56964 .57105 L .58416 .56539 L p 0 .315 .945 r
F P
0 g
s
.57205 .57762 m .58416 .56539 L .56964 .57105 L p 0 .05 .173 r
F P
0 g
s
.5706 .55001 m .58416 .56539 L .57205 .57762 L p 0 .349 .781 r
F P
0 g
s
.5706 .55001 m .58416 .56539 L .59896 .55962 L p 0 .315 .945 r
F P
0 g
s
.56964 .57105 m .5562 .55582 L .54414 .56793 L p 0 .349 .782 r
F P
0 g
s
.58416 .56539 m .5706 .55001 L .55845 .56223 L p 0 .349 .781 r
F P
0 g
s
.59896 .55962 m .58528 .5441 L .5706 .55001 L p 0 .315 .945 r
F P
0 g
s
.57304 .55641 m .58528 .5441 L .5706 .55001 L p 0 .05 .157 r
F P
0 g
s
.54414 .56793 m .55762 .58318 L .56964 .57105 L p 0 .349 .782 r
F P
0 g
s
.57205 .57762 m .55845 .56223 L .5706 .55001 L p 0 .349 .781 r
F P
0 g
s
.55845 .56223 m .5706 .55001 L .58528 .5441 L p 0 .05 .157 r
F P
0 g
s
.58528 .5441 m .57304 .55641 L .55845 .56223 L p 0 .05 .157 r
F P
0 g
s
.57157 .52855 m .58528 .5441 L .57304 .55641 L p 0 .349 .781 r
F P
0 g
s
.60023 .53806 m .58641 .52236 L .57157 .52855 L p 0 .315 .945 r
F P
0 g
s
.58641 .52236 m .57405 .53476 L p .5793 .53543 L 0 .349 .781 r
F P
0 g
s
.60023 .53806 m .58918 .52551 L p .5793 .53543 L 0 .349 .781 r
F P
0 g
s
.58918 .52551 m .58641 .52236 L p .5793 .53543 L 0 .349 .781 r
F P
0 g
s
.60433 .51923 m .58918 .52551 L p .59451 .52015 L .191 0 0 r
F P
0 g
s
.54414 .56793 m .5562 .55582 L .5706 .55001 L p 0 .05 .157 r
F P
0 g
s
.55845 .56223 m .5706 .55001 L .5562 .55582 L p 0 .05 .157 r
F P
0 g
s
.5706 .55001 m .55845 .56223 L .54414 .56793 L p 0 .05 .157 r
F P
0 g
s
.5706 .55001 m .55845 .56223 L p .5573 .54013 L 0 .349 .781 r
F P
0 g
s
.55702 .53462 m .55974 .5377 L p .5573 .54013 L 0 .349 .781 r
F P
0 g
s
.54273 .54057 m .54543 .54362 L p .54827 .54245 L 0 .315 .945 r
F P
0 g
s
.53064 .55266 m .54484 .54681 L p .54469 .55107 L 0 .314 .946 r
F P
0 g
s
.53064 .55266 m .54414 .56793 L .5562 .55582 L p 0 .349 .782 r
F P
0 g
s
.54414 .56793 m .53334 .55572 L p .54469 .55107 L 0 .314 .946 r
F P
0 g
s
.53334 .55572 m .53064 .55266 L p .54469 .55107 L 0 .314 .946 r
F P
0 g
s
.54626 .57449 m .53402 .5868 L .51987 .5923 L p 0 .05 .157 r
F P
0 g
s
.51987 .5923 m .53402 .5868 L p .5118 .57893 L 0 .313 .947 r
F P
0 g
s
.5063 .57698 m .50901 .58005 L p .5118 .57893 L 0 .313 .947 r
F P
0 g
s
.50901 .58005 m .51987 .5923 L p .5118 .57893 L 0 .313 .947 r
F P
0 g
s
.4982 .58975 m .48632 .59446 L .49523 .58556 L p .191 0 0 r
F P
0 g
s
.50462 .5818 m .4982 .58975 L .49523 .58556 L .191 0 0 r
F
0 g
.52819 .55263 m
.54203 .53989 L
s
.52819 .55263 m
.53241 .55089 L
s
.50716 .7114 m .51501 .69603 L .48285 .65994 L .964 0 0 r
F
.53704 .68613 m .51501 .69603 L .50716 .7114 L .262 0 0 r
F
.53704 .68613 m .54072 .67876 L .51501 .69603 L F
0 g
.51501 .69603 m
.5359 .67206 L
s
.74106 .50219 m .72704 .51658 L .7113 .52265 L p 0 .05 .218 r
F P
0 g
s
.7113 .52265 m .68214 .48929 L .69762 .4829 L p 0 .318 .938 r
F P
0 g
s
.69762 .4829 m .72704 .51658 L .7113 .52265 L p 0 .318 .938 r
F P
0 g
s
.48719 .25985 m .50084 .25132 L .5154 .23755 L p 0 .05 .1 r
F P
0 g
s
.47271 .23074 m .47268 .25214 L .48719 .25985 L p 0 .349 .782 r
F P
0 g
s
.48719 .25985 m .50084 .25132 L .4862 .26516 L p 0 .05 .1 r
F P
0 g
s
.4862 .26516 m .47265 .27358 L .48719 .25985 L p 0 .05 .1 r
F P
0 g
s
.50084 .25132 m .48719 .25985 L .47265 .27358 L p 0 .05 .1 r
F P
0 g
s
.48719 .25985 m .47268 .25214 L .47265 .27358 L closepath p 0 .349 .782 r
F P
0 g
s
.47271 .23074 m .48623 .22194 L .48624 .2041 L p 0 .181 .719 r
F P
0 g
s
.48623 .22194 m .47271 .23074 L .47268 .25214 L p 0 .181 .719 r
F P
0 g
s
.47268 .25214 m .47271 .23074 L .44356 .24034 L p 0 .349 .782 r
F P
0 g
s
.47271 .23074 m .48623 .22194 L .48621 .24353 L p 0 .181 .719 r
F P
0 g
s
.48621 .24353 m .47268 .25214 L .47271 .23074 L p 0 .181 .719 r
F P
0 g
s
.54203 .53989 m
.55594 .52898 L
s
.41063 .32783 m
.4145 .32503 L
s
.50716 .7114 m .48285 .65994 L .47466 .67497 L .964 0 0 r
F
.50455 .6496 m .49959 .64845 L .50839 .6424 L .228 0 0 r
F
.53704 .68613 m .54072 .67876 L .47595 .60592 L .966 0 0 r
F
.56138 .66554 m .54072 .67876 L .53704 .68613 L .262 0 0 r
F
.53704 .68613 m .50839 .6424 L .54072 .67876 L .966 0 0 r
F
.53704 .68613 m .50455 .6496 L .50839 .6424 L F
.50455 .6496 m .47595 .60592 L .47195 .61295 L F
.53704 .68613 m .50648 .646 L .50455 .6496 L F
.50648 .646 m .47595 .60592 L .50455 .6496 L F
.56191 .66567 m .53704 .68613 L .54088 .68717 L .262 0 0 r
F
.56191 .66567 m .56138 .66554 L .53704 .68613 L F
.54088 .68717 m .53704 .68613 L .50455 .6496 L .1 0 0 r
F
.54088 .68717 m .50455 .6496 L .50639 .65003 L F
.54088 .68717 m .50455 .6496 L .53704 .68613 L F
.54088 .68717 m .50823 .65046 L .50455 .6496 L F
.50823 .65046 m .47195 .61295 L .47546 .61362 L F
.54088 .68717 m .50639 .65003 L .50823 .65046 L F
.50639 .65003 m .47195 .61295 L .50823 .65046 L F
.54072 .67876 m .55085 .66711 L .48632 .59446 L .883 0 0 r
F
.54072 .67876 m .51864 .63085 L .55085 .66711 L F
.54072 .67876 m .50839 .6424 L .51864 .63085 L F
.54072 .67876 m .48632 .59446 L .47595 .60592 L F
.56321 .66301 m .48632 .59446 L .55085 .66711 L .541 0 0 r
F
.56185 .66457 m .55085 .66711 L .54072 .67876 L .262 0 0 r
F
.56185 .66457 m .56321 .66301 L .55085 .66711 L F
.56321 .66301 m .55085 .66711 L .48632 .59446 L p .541 0 0 r
F P
0 g
s
.56138 .66554 m .56185 .66457 L .54072 .67876 L .262 0 0 r
F
.51987 .5923 m .53343 .60759 L .54555 .59536 L p 0 .349 .782 r
F P
0 g
s
.54696 .62286 m .55904 .61061 L .54555 .59536 L p 0 .349 .782 r
F P
0 g
s
.54555 .59536 m .53343 .60759 L .54696 .62286 L p 0 .349 .782 r
F P
0 g
s
.54555 .59536 m .55904 .61061 L .57108 .5984 L p 0 .349 .782 r
F P
0 g
s
.55989 .58991 m .54555 .59536 L .55904 .61061 L p 0 .314 .946 r
F P
0 g
s
.55904 .61061 m .54555 .59536 L .55989 .58991 L p 0 .314 .946 r
F P
0 g
s
.53343 .60759 m .54555 .59536 L .55989 .58991 L p 0 .05 .173 r
F P
0 g
s
.54555 .59536 m .53343 .60759 L .54769 .60224 L p 0 .05 .173 r
F P
0 g
s
.55989 .58991 m .54769 .60224 L .53343 .60759 L p 0 .05 .173 r
F P
0 g
s
.51987 .5923 m .53343 .60759 L .54769 .60224 L p 0 .313 .947 r
F P
0 g
s
.50907 .602 m .52263 .61728 L p .5024 .60456 L .541 0 0 r
F P
0 g
s
.51507 .62009 m .4982 .58975 L .48632 .59446 L .541 0 0 r
F
.56321 .66301 m .52263 .61728 L .51507 .62009 L F
.52263 .61728 m .50907 .602 L .51507 .62009 L F
.50907 .602 m .50573 .60328 L .51507 .62009 L F
.50907 .602 m .4982 .58975 L .50573 .60328 L F
.48632 .59446 m .4982 .58975 L .50907 .602 L p F P
0 g
s
.48632 .59446 m .50907 .602 L .5024 .60456 L .541 0 0 r
F
.52263 .61728 m .56321 .66301 L p .51507 .62009 L F P
0 g
s
.48632 .59446 m .52263 .61728 L .51507 .62009 L .541 0 0 r
F
.56185 .66457 m .4982 .58975 L .56321 .66301 L .884 0 0 r
F
.56185 .66457 m .49682 .59128 L .4982 .58975 L F
.56138 .66554 m .49682 .59128 L .56185 .66457 L .968 0 0 r
F
.56138 .66554 m .4963 .59221 L .49682 .59128 L F
.53343 .60759 m .51987 .5923 L .50767 .60455 L p 0 .349 .782 r
F P
0 g
s
.52172 .59916 m .52123 .59732 L .50767 .60455 L 0 .05 .157 r
F
.51987 .5923 m .51093 .60128 L p .52123 .59732 L F P
0 g
s
.51093 .60128 m .50767 .60455 L p .52123 .59732 L 0 .05 .157 r
F P
0 g
s
.53483 .63516 m .54696 .62286 L .53343 .60759 L p 0 .349 .782 r
F P
0 g
s
.53343 .60759 m .52126 .61987 L .53483 .63516 L p 0 .349 .782 r
F P
0 g
s
.52126 .61987 m .53543 .61462 L p .53489 .61273 L 0 .05 .173 r
F P
0 g
s
.53343 .60759 m .52451 .61659 L p .53489 .61273 L 0 .05 .173 r
F P
0 g
s
.52451 .61659 m .52126 .61987 L p .53489 .61273 L 0 .05 .173 r
F P
0 g
s
.53343 .60759 m .51987 .5923 L .53402 .5868 L p 0 .313 .947 r
F P
0 g
s
.54769 .60224 m .53402 .5868 L .51987 .5923 L p 0 .313 .947 r
F P
0 g
s
.51987 .5923 m .53402 .5868 L p .51466 .59984 L 0 .05 .157 r
F P
0 g
s
.50767 .60455 m .51093 .60128 L p .51466 .59984 L 0 .05 .157 r
F P
0 g
s
.51093 .60128 m .51987 .5923 L p .51466 .59984 L 0 .05 .157 r
F P
0 g
s
.53343 .60759 m .54769 .60224 L p .52827 .61519 L 0 .05 .173 r
F P
0 g
s
.52126 .61987 m .52451 .61659 L p .52827 .61519 L 0 .05 .173 r
F P
0 g
s
.52451 .61659 m .53343 .60759 L p .52827 .61519 L 0 .05 .173 r
F P
0 g
s
.56191 .66567 m .4963 .59221 L .56138 .66554 L .1 0 0 r
F
.56191 .66567 m .49678 .59229 L .4963 .59221 L F
.54088 .68717 m .56191 .66567 L .49678 .59229 L p .856 0 0 r
F P
0 g
s
.56191 .66567 m .54088 .68717 L .47546 .61362 L .856 0 0 r
F
.58598 .64103 m .59902 .66772 L .61016 .66834 L closepath p 0 .349 .782 r
F P
0 g
s
.61016 .66834 m .59902 .66772 L .59106 .69852 L p 0 .349 .782 r
F P
0 g
s
.59902 .66772 m .5805 .6667 L .5765 .68211 L p 0 .349 .782 r
F P
0 g
s
.5765 .68211 m .59106 .69852 L .59902 .66772 L p 0 .349 .782 r
F P
0 g
s
.5805 .6667 m .59902 .66772 L .58598 .64103 L p 0 .349 .782 r
F P
0 g
s
.58598 .64103 m .57397 .65333 L .5805 .6667 L p 0 .349 .782 r
F P
0 g
s
.56191 .66567 m .5765 .68211 L .5805 .6667 L closepath p 0 .349 .782 r
F P
0 g
s
.57397 .65333 m .56191 .66567 L .5805 .6667 L closepath p 0 .349 .782 r
F P
0 g
s
.56191 .66567 m .57397 .65333 L .56047 .6381 L p 0 .349 .782 r
F P
0 g
s
.58858 .64842 m .57397 .65333 L .56191 .66567 L p 0 .05 .218 r
F P
0 g
s
.57397 .65333 m .58858 .64842 L .57643 .66087 L p 0 .05 .218 r
F P
0 g
s
.57643 .66087 m .56191 .66567 L .57397 .65333 L p 0 .05 .218 r
F P
0 g
s
.54838 .65042 m .56047 .6381 L .54696 .62286 L p 0 .349 .782 r
F P
0 g
s
.56047 .6381 m .54838 .65042 L .56191 .66567 L p 0 .349 .782 r
F P
0 g
s
.59115 .67747 m .5765 .68211 L .56191 .66567 L p 0 .312 .948 r
F P
0 g
s
.5469 .71254 m .5765 .68211 L .56191 .66567 L p 0 .349 .782 r
F P
0 g
s
.5765 .68211 m .59115 .67747 L .57643 .66087 L p 0 .312 .948 r
F P
0 g
s
.57643 .66087 m .56191 .66567 L .5765 .68211 L p 0 .312 .948 r
F P
0 g
s
.54696 .62286 m .53483 .63516 L .54838 .65042 L p 0 .349 .782 r
F P
0 g
s
.56191 .66567 m .54838 .65042 L .56279 .64548 L p 0 .312 .948 r
F P
0 g
s
.56191 .66567 m .57643 .66087 L .58858 .64842 L p 0 .05 .218 r
F P
0 g
s
.56279 .64548 m .57643 .66087 L .56191 .66567 L p 0 .312 .948 r
F P
0 g
s
.56191 .66567 m .57643 .66087 L .59115 .67747 L p 0 .312 .948 r
F P
0 g
s
.56191 .66567 m .53222 .69604 L .5469 .71254 L p 0 .349 .782 r
F P
0 g
s
.53222 .69604 m .56191 .66567 L .57643 .66087 L p 0 .05 .218 r
F P
0 g
s
.60998 .63644 m .61009 .65632 L .63872 .64926 L p 0 .349 .782 r
F P
0 g
s
.61498 .67379 m .63872 .64926 L .61009 .65632 L p 0 .349 .782 r
F P
0 g
s
.61009 .65632 m .60998 .63644 L .59795 .62879 L p 0 .349 .782 r
F P
0 g
s
.59795 .62879 m .58598 .64103 L .61009 .65632 L p 0 .349 .782 r
F P
0 g
s
.61009 .65632 m .61016 .66834 L .61498 .67379 L p 0 .349 .782 r
F P
0 g
s
.61016 .66834 m .61009 .65632 L .58598 .64103 L closepath p 0 .349 .782 r
F P
0 g
s
.65383 .64436 m .63872 .64926 L .61498 .67379 L p 0 .05 .248 r
F P
0 g
s
.61016 .66834 m .62506 .66359 L .60068 .63602 L p 0 .314 .946 r
F P
0 g
s
.60068 .63602 m .58598 .64103 L .61016 .66834 L p 0 .314 .946 r
F P
0 g
s
.62506 .66359 m .61016 .66834 L .58598 .64103 L p 0 .314 .946 r
F P
0 g
s
.58598 .64103 m .60068 .63602 L .62506 .66359 L p 0 .314 .946 r
F P
0 g
s
.63872 .64926 m .6243 .63294 L .60998 .63644 L p 0 .349 .782 r
F P
0 g
s
.60998 .63644 m .6243 .63294 L .60987 .61659 L closepath p 0 .349 .782 r
F P
0 g
s
.61498 .67379 m .62993 .6691 L .65383 .64436 L p 0 .05 .248 r
F P
0 g
s
.66922 .63936 m .65383 .64436 L .62993 .6691 L p 0 .05 .248 r
F P
0 g
s
.62506 .66359 m .64025 .65876 L .61565 .63092 L p 0 .314 .946 r
F P
0 g
s
.60998 .63644 m .60987 .61659 L .59795 .62879 L closepath p 0 .349 .782 r
F P
0 g
s
.61565 .63092 m .60068 .63602 L .62506 .66359 L p 0 .314 .946 r
F P
0 g
s
.64025 .65876 m .62506 .66359 L .60068 .63602 L p 0 .314 .946 r
F P
0 g
s
.60068 .63602 m .61565 .63092 L .64025 .65876 L p 0 .314 .946 r
F P
0 g
s
.60608 .67274 m .59115 .67747 L .57643 .66087 L p 0 .312 .948 r
F P
0 g
s
.59115 .67747 m .60608 .67274 L .59124 .65598 L p 0 .312 .948 r
F P
0 g
s
.59124 .65598 m .57643 .66087 L .59115 .67747 L p 0 .312 .948 r
F P
0 g
s
.57643 .66087 m .59124 .65598 L .60608 .67274 L p 0 .312 .948 r
F P
0 g
s
.62993 .6691 m .61498 .67379 L .59106 .69852 L p 0 .05 .248 r
F P
0 g
s
.61016 .66834 m .61498 .67379 L .62993 .6691 L p 0 .314 .946 r
F P
0 g
s
.61498 .67379 m .61016 .66834 L .62506 .66359 L p 0 .314 .946 r
F P
0 g
s
.62506 .66359 m .62993 .6691 L .61498 .67379 L p 0 .314 .946 r
F P
0 g
s
.62993 .6691 m .62506 .66359 L .61016 .66834 L p 0 .314 .946 r
F P
0 g
s
.59106 .69852 m .60584 .69404 L .62993 .6691 L p 0 .05 .248 r
F P
0 g
s
.64516 .66432 m .62993 .6691 L .60584 .69404 L p 0 .05 .248 r
F P
0 g
s
.64025 .65876 m .62506 .66359 L .62993 .6691 L p 0 .314 .946 r
F P
0 g
s
.62993 .6691 m .64516 .66432 L .66922 .63936 L p 0 .05 .248 r
F P
0 g
s
.64516 .66432 m .62993 .6691 L .62506 .66359 L p 0 .314 .946 r
F P
0 g
s
.62506 .66359 m .64025 .65876 L .64516 .66432 L p 0 .314 .946 r
F P
0 g
s
.60584 .69404 m .6209 .68947 L .64516 .66432 L p 0 .05 .248 r
F P
0 g
s
.61013 .65705 m .62894 .65812 L .6209 .68947 L p 0 .349 .781 r
F P
0 g
s
.61565 .63092 m .62894 .65812 L .61013 .65705 L p 0 .349 .781 r
F P
0 g
s
.59106 .69852 m .61498 .67379 L .61016 .66834 L p 0 .349 .782 r
F P
0 g
s
.62894 .65812 m .61013 .65705 L .60608 .67274 L p 0 .349 .781 r
F P
0 g
s
.62894 .65812 m .61565 .63092 L .60347 .64342 L p 0 .349 .781 r
F P
0 g
s
.60347 .64342 m .61013 .65705 L .62894 .65812 L p 0 .349 .781 r
F P
0 g
s
.61013 .65705 m .60347 .64342 L .61565 .63092 L p 0 .349 .781 r
F P
0 g
s
.6209 .68947 m .60608 .67274 L .61013 .65705 L p 0 .349 .781 r
F P
0 g
s
.60608 .67274 m .59124 .65598 L .61013 .65705 L closepath p 0 .349 .781 r
F P
0 g
s
.61013 .65705 m .59124 .65598 L .60347 .64342 L closepath p 0 .349 .781 r
F P
0 g
s
.61013 .65705 m .59124 .65598 L .60608 .67274 L closepath p 0 .349 .781 r
F P
0 g
s
.60347 .64342 m .59124 .65598 L .61013 .65705 L closepath p 0 .349 .781 r
F P
0 g
s
.56191 .66567 m .47546 .61362 L .49678 .59229 L .856 0 0 r
F
.49678 .59229 m .47546 .61362 L .54088 .68717 L p F P
0 g
s
.54088 .68717 m .47546 .61362 L p .53669 .64043 L .533 0 0 r
F P
0 g
s
.60584 .69404 m .59106 .69852 L .5765 .68211 L p 0 .312 .948 r
F P
0 g
s
.56156 .72901 m .59106 .69852 L .5765 .68211 L p 0 .349 .782 r
F P
0 g
s
.59106 .69852 m .60584 .69404 L .59115 .67747 L p 0 .312 .948 r
F P
0 g
s
.59115 .67747 m .5765 .68211 L .59106 .69852 L p 0 .312 .948 r
F P
0 g
s
.5765 .68211 m .59115 .67747 L .60584 .69404 L p 0 .312 .948 r
F P
0 g
s
.60584 .69404 m .59115 .67747 L .60608 .67274 L p 0 .312 .948 r
F P
0 g
s
.60608 .67274 m .59115 .67747 L .60584 .69404 L p 0 .312 .948 r
F P
0 g
s
.60608 .67274 m .59124 .65598 L p .5805 .68978 L 0 .349 .781 r
F P
0 g
s
.59124 .65598 m .60608 .67274 L .58483 .69467 L p 0 .349 .781 r
F P
0 g
s
.58483 .69467 m .57607 .70371 L p .5805 .68978 L 0 .349 .781 r
F P
0 g
s
.59124 .65598 m .58483 .69467 L .5805 .68978 L 0 .349 .781 r
F
.5765 .68211 m .5469 .71254 L .56156 .72901 L p 0 .349 .782 r
F P
0 g
s
.56113 .68689 m .57607 .70371 L p .5805 .68978 L 0 .349 .781 r
F P
0 g
s
.59124 .65598 m .56992 .67787 L p .5805 .68978 L 0 .349 .781 r
F P
0 g
s
.56992 .67787 m .56113 .68689 L p .5805 .68978 L 0 .349 .781 r
F P
0 g
s
.60608 .67274 m .6209 .68947 L .62894 .65812 L p 0 .349 .781 r
F P
0 g
s
.59124 .65598 m .60608 .67274 L .62131 .66792 L p 0 .312 .948 r
F P
0 g
s
.62131 .66792 m .60608 .67274 L .59124 .65598 L p 0 .312 .948 r
F P
0 g
s
.62131 .66792 m .60633 .651 L .59124 .65598 L p 0 .312 .948 r
F P
0 g
s
.59124 .65598 m .60633 .651 L .62131 .66792 L p 0 .312 .948 r
F P
0 g
s
.57607 .70371 m .56113 .68689 L .56992 .67787 L p 0 .349 .781 r
F P
0 g
s
.56992 .67787 m .59124 .65598 L p .5805 .68978 L 0 .349 .781 r
F P
0 g
s
.5805 .68978 m .57607 .70371 L .56992 .67787 L 0 .349 .781 r
F
.62993 .6691 m .64516 .66432 L .64025 .65876 L p 0 .314 .946 r
F P
0 g
s
.62894 .65812 m .6209 .68947 L .64516 .66432 L p 0 .349 .781 r
F P
0 g
s
.6209 .68947 m .62894 .65812 L .64025 .65876 L p 0 .349 .781 r
F P
0 g
s
.60633 .651 m .62131 .66792 L .63682 .66301 L p 0 .312 .948 r
F P
0 g
s
.63682 .66301 m .62131 .66792 L .60633 .651 L p 0 .312 .948 r
F P
0 g
s
.64516 .66432 m .64025 .65876 L .62894 .65812 L p 0 .349 .781 r
F P
0 g
s
.61565 .63092 m .64025 .65876 L .62894 .65812 L closepath p 0 .349 .781 r
F P
0 g
s
.62894 .65812 m .64025 .65876 L .61565 .63092 L closepath p 0 .349 .781 r
F P
0 g
s
.63682 .66301 m .62172 .64591 L .60633 .651 L p 0 .312 .948 r
F P
0 g
s
.60633 .651 m .62172 .64591 L .63682 .66301 L p 0 .312 .948 r
F P
0 g
s
.60009 .66819 m .62172 .64591 L p .58972 .65648 L .262 0 0 r
F P
0 g
s
.57397 .65333 m .58598 .64103 L .60068 .63602 L p 0 .05 .218 r
F P
0 g
s
.57397 .65333 m .58598 .64103 L .57252 .62583 L p 0 .349 .782 r
F P
0 g
s
.60068 .63602 m .58598 .64103 L .57397 .65333 L p 0 .05 .218 r
F P
0 g
s
.57252 .62583 m .56047 .6381 L .57397 .65333 L p 0 .349 .782 r
F P
0 g
s
.56047 .6381 m .57252 .62583 L .55904 .61061 L p 0 .349 .782 r
F P
0 g
s
.55904 .61061 m .54696 .62286 L .56047 .6381 L p 0 .349 .782 r
F P
0 g
s
.57397 .65333 m .58858 .64842 L .60068 .63602 L p 0 .05 .218 r
F P
0 g
s
.60068 .63602 m .58858 .64842 L .57397 .65333 L p 0 .05 .218 r
F P
0 g
s
.58598 .64103 m .59795 .62879 L .61273 .62367 L p 0 .05 .218 r
F P
0 g
s
.59795 .62879 m .58452 .61361 L .57252 .62583 L p 0 .349 .782 r
F P
0 g
s
.57252 .62583 m .58598 .64103 L .59795 .62879 L p 0 .349 .782 r
F P
0 g
s
.59795 .62879 m .58598 .64103 L .60068 .63602 L p 0 .05 .218 r
F P
0 g
s
.55904 .61061 m .57252 .62583 L .58452 .61361 L p 0 .349 .782 r
F P
0 g
s
.61273 .62367 m .60068 .63602 L .58598 .64103 L p 0 .05 .218 r
F P
0 g
s
.58598 .64103 m .60068 .63602 L .5871 .62067 L p 0 .314 .946 r
F P
0 g
s
.5871 .62067 m .57252 .62583 L .58598 .64103 L p 0 .314 .946 r
F P
0 g
s
.58598 .64103 m .57252 .62583 L .5871 .62067 L p 0 .314 .946 r
F P
0 g
s
.5871 .62067 m .60068 .63602 L .58598 .64103 L p 0 .314 .946 r
F P
0 g
s
.58452 .61361 m .57108 .5984 L .55904 .61061 L p 0 .349 .782 r
F P
0 g
s
.57252 .62583 m .5871 .62067 L .57351 .6053 L p 0 .314 .946 r
F P
0 g
s
.57351 .6053 m .55904 .61061 L .57252 .62583 L p 0 .314 .946 r
F P
0 g
s
.57252 .62583 m .55904 .61061 L .57351 .6053 L p 0 .314 .946 r
F P
0 g
s
.57351 .6053 m .5871 .62067 L .57252 .62583 L p 0 .314 .946 r
F P
0 g
s
.53543 .61462 m .54769 .60224 L .53343 .60759 L p 0 .05 .173 r
F P
0 g
s
.50767 .60455 m .52126 .61987 L .53343 .60759 L p 0 .349 .782 r
F P
0 g
s
.49682 .59128 m .48632 .59446 L .4982 .58975 L .191 0 0 r
F
.49682 .59128 m .47595 .60592 L .48632 .59446 L F
.4963 .59221 m .47595 .60592 L .49682 .59128 L F
.49406 .58922 m .50767 .60455 L .51987 .5923 L p 0 .349 .782 r
F P
0 g
s
.54769 .60224 m .53543 .61462 L .52126 .61987 L p 0 .05 .173 r
F P
0 g
s
.53402 .5868 m .52172 .59916 L .50767 .60455 L p 0 .05 .157 r
F P
0 g
s
.60347 .64342 m .58858 .64842 L .60068 .63602 L p 0 .05 .218 r
F P
0 g
s
.60068 .63602 m .61565 .63092 L .60347 .64342 L p 0 .05 .218 r
F P
0 g
s
.61565 .63092 m .60068 .63602 L .58858 .64842 L p 0 .05 .218 r
F P
0 g
s
.60347 .64342 m .58858 .64842 L .57643 .66087 L p 0 .05 .218 r
F P
0 g
s
.58858 .64842 m .60347 .64342 L .61565 .63092 L p 0 .05 .218 r
F P
0 g
s
.58858 .64842 m .60347 .64342 L .59124 .65598 L p 0 .05 .218 r
F P
0 g
s
.59124 .65598 m .57643 .66087 L .58858 .64842 L p 0 .05 .218 r
F P
0 g
s
.57643 .66087 m .59124 .65598 L .60347 .64342 L p 0 .05 .218 r
F P
0 g
s
.55904 .61061 m .57351 .6053 L .55989 .58991 L p 0 .314 .946 r
F P
0 g
s
.55989 .58991 m .57351 .6053 L .55904 .61061 L p 0 .314 .946 r
F P
0 g
s
.53543 .61462 m .54769 .60224 L .56222 .59679 L p 0 .05 .173 r
F P
0 g
s
.53402 .5868 m .54769 .60224 L .53343 .60759 L p 0 .313 .947 r
F P
0 g
s
.53402 .5868 m .54769 .60224 L .53543 .61462 L p 0 .349 .781 r
F P
0 g
s
.52172 .59916 m .53543 .61462 L .54769 .60224 L p 0 .349 .781 r
F P
0 g
s
.54769 .60224 m .53543 .61462 L .54988 .60928 L p 0 .05 .173 r
F P
0 g
s
.53543 .61462 m .52172 .59916 L .53402 .5868 L p 0 .349 .781 r
F P
0 g
s
.56222 .59679 m .54988 .60928 L .53543 .61462 L p 0 .05 .173 r
F P
0 g
s
.61273 .62367 m .59795 .62879 L .60987 .61659 L p 0 .05 .218 r
F P
0 g
s
.60987 .61659 m .59648 .60143 L .58452 .61361 L p 0 .349 .782 r
F P
0 g
s
.58452 .61361 m .59795 .62879 L .60987 .61659 L p 0 .349 .782 r
F P
0 g
s
.60987 .61659 m .59795 .62879 L .61273 .62367 L p 0 .05 .218 r
F P
0 g
s
.60068 .63602 m .61273 .62367 L .59795 .62879 L p 0 .05 .218 r
F P
0 g
s
.61565 .63092 m .60068 .63602 L .61273 .62367 L p 0 .05 .218 r
F P
0 g
s
.61273 .62367 m .60068 .63602 L .61565 .63092 L p 0 .05 .218 r
F P
0 g
s
.60068 .63602 m .61565 .63092 L .60196 .61542 L p 0 .314 .946 r
F P
0 g
s
.60196 .61542 m .61565 .63092 L .60068 .63602 L p 0 .314 .946 r
F P
0 g
s
.60196 .61542 m .61565 .63092 L .60347 .64342 L p 0 .349 .781 r
F P
0 g
s
.61865 .63833 m .60347 .64342 L .61565 .63092 L p 0 .05 .218 r
F P
0 g
s
.61565 .63092 m .60347 .64342 L .61865 .63833 L p 0 .05 .218 r
F P
0 g
s
.60347 .64342 m .61565 .63092 L .60196 .61542 L p 0 .349 .781 r
F P
0 g
s
.60196 .61542 m .5871 .62067 L .60068 .63602 L p 0 .314 .946 r
F P
0 g
s
.60068 .63602 m .5871 .62067 L .60196 .61542 L p 0 .314 .946 r
F P
0 g
s
.60347 .64342 m .58974 .6279 L .60196 .61542 L p 0 .349 .781 r
F P
0 g
s
.60196 .61542 m .58974 .6279 L .60347 .64342 L p 0 .349 .781 r
F P
0 g
s
.58974 .6279 m .60347 .64342 L .59124 .65598 L p 0 .349 .781 r
F P
0 g
s
.60633 .651 m .61865 .63833 L .60347 .64342 L p 0 .05 .218 r
F P
0 g
s
.60347 .64342 m .59124 .65598 L .60633 .651 L p 0 .05 .218 r
F P
0 g
s
.59124 .65598 m .60347 .64342 L .58974 .6279 L p 0 .349 .781 r
F P
0 g
s
.60633 .651 m .59124 .65598 L .60347 .64342 L p 0 .05 .218 r
F P
0 g
s
.60347 .64342 m .61865 .63833 L .60633 .651 L p 0 .05 .218 r
F P
0 g
s
.57599 .61236 m .58974 .6279 L .57747 .64044 L p 0 .349 .781 r
F P
0 g
s
.59124 .65598 m .57747 .64044 L .58974 .6279 L p 0 .349 .781 r
F P
0 g
s
.57747 .64044 m .58974 .6279 L .57599 .61236 L p 0 .349 .781 r
F P
0 g
s
.58974 .6279 m .57747 .64044 L .59124 .65598 L p 0 .349 .781 r
F P
0 g
s
.57747 .64044 m .56369 .62487 L .57599 .61236 L p 0 .349 .781 r
F P
0 g
s
.56222 .59679 m .57599 .61236 L .56369 .62487 L p 0 .349 .781 r
F P
0 g
s
.57599 .61236 m .56369 .62487 L .57747 .64044 L p 0 .349 .781 r
F P
0 g
s
.56369 .62487 m .57599 .61236 L .56222 .59679 L p 0 .349 .781 r
F P
0 g
s
.56369 .62487 m .54988 .60928 L .56222 .59679 L p 0 .349 .781 r
F P
0 g
s
.56222 .59679 m .54988 .60928 L .56369 .62487 L p 0 .349 .781 r
F P
0 g
s
.61865 .63833 m .60633 .651 L .62172 .64591 L p 0 .05 .218 r
F P
0 g
s
.62172 .64591 m .60633 .651 L .61865 .63833 L p 0 .05 .218 r
F P
0 g
s
.49678 .59229 m .56191 .66567 L .62172 .64591 L p .54 0 0 r
F P
0 g
s
.54838 .65042 m .53483 .63516 L .54912 .63006 L p 0 .312 .948 r
F P
0 g
s
.54912 .63006 m .56279 .64548 L .54838 .65042 L p 0 .312 .948 r
F P
0 g
s
.53483 .63516 m .52126 .61987 L .53543 .61462 L p 0 .312 .948 r
F P
0 g
s
.53543 .61462 m .54912 .63006 L .53483 .63516 L p 0 .312 .948 r
F P
0 g
s
.52172 .59916 m .53543 .61462 L .52126 .61987 L p 0 .312 .948 r
F P
0 g
s
.59648 .60143 m .58307 .58625 L .57108 .5984 L p 0 .349 .782 r
F P
0 g
s
.57108 .5984 m .58452 .61361 L .59648 .60143 L p 0 .349 .782 r
F P
0 g
s
.55762 .58318 m .57108 .5984 L .58307 .58625 L p 0 .349 .782 r
F P
0 g
s
.55762 .58318 m .57205 .57762 L .55989 .58991 L p 0 .05 .173 r
F P
0 g
s
.55845 .56223 m .57205 .57762 L .55762 .58318 L p 0 .314 .946 r
F P
0 g
s
.55762 .58318 m .54414 .56793 L .55845 .56223 L p 0 .314 .946 r
F P
0 g
s
.55989 .58991 m .57205 .57762 L .55762 .58318 L p 0 .05 .173 r
F P
0 g
s
.54414 .56793 m .55762 .58318 L .57205 .57762 L p 0 .314 .946 r
F P
0 g
s
.57205 .57762 m .55845 .56223 L .54414 .56793 L p 0 .314 .946 r
F P
0 g
s
.53203 .58009 m .54414 .56793 L .55845 .56223 L p 0 .05 .157 r
F P
0 g
s
.54626 .57449 m .55845 .56223 L .54414 .56793 L p 0 .05 .157 r
F P
0 g
s
.54414 .56793 m .53203 .58009 L .54626 .57449 L p 0 .05 .157 r
F P
0 g
s
.54626 .57449 m .55989 .58991 L .54555 .59536 L p 0 .314 .946 r
F P
0 g
s
.54769 .60224 m .55989 .58991 L .54555 .59536 L p 0 .05 .173 r
F P
0 g
s
.55845 .56223 m .54626 .57449 L .53203 .58009 L p 0 .05 .157 r
F P
0 g
s
.5326 .55905 m .54626 .57449 L .53203 .58009 L p 0 .314 .946 r
F P
0 g
s
.53402 .5868 m .54626 .57449 L .53203 .58009 L p 0 .05 .157 r
F P
0 g
s
.51849 .5648 m .53203 .58009 L .54626 .57449 L p 0 .314 .946 r
F P
0 g
s
.54626 .57449 m .5326 .55905 L .51849 .5648 L p 0 .314 .946 r
F P
0 g
s
.52033 .57134 m .53402 .5868 L .51987 .5923 L p 0 .313 .947 r
F P
0 g
s
.52172 .59916 m .53402 .5868 L .51987 .5923 L p 0 .05 .157 r
F P
0 g
s
.51987 .5923 m .5063 .57698 L .49406 .58922 L p 0 .349 .782 r
F P
0 g
s
.53402 .5868 m .52033 .57134 L .5063 .57698 L p 0 .313 .947 r
F P
0 g
s
.57452 .58435 m .55989 .58991 L .57205 .57762 L p 0 .05 .173 r
F P
0 g
s
.55845 .56223 m .57205 .57762 L .55989 .58991 L p 0 .349 .781 r
F P
0 g
s
.57205 .57762 m .55989 .58991 L .57452 .58435 L p 0 .05 .173 r
F P
0 g
s
.54626 .57449 m .55989 .58991 L .57205 .57762 L p 0 .349 .781 r
F P
0 g
s
.57205 .57762 m .55845 .56223 L .54626 .57449 L p 0 .349 .781 r
F P
0 g
s
.5871 .62067 m .60196 .61542 L .58825 .5999 L p 0 .314 .946 r
F P
0 g
s
.58825 .5999 m .57351 .6053 L .5871 .62067 L p 0 .314 .946 r
F P
0 g
s
.5871 .62067 m .57351 .6053 L .58825 .5999 L p 0 .314 .946 r
F P
0 g
s
.58825 .5999 m .60196 .61542 L .5871 .62067 L p 0 .314 .946 r
F P
0 g
s
.55989 .58991 m .54626 .57449 L .55845 .56223 L p 0 .349 .781 r
F P
0 g
s
.55845 .56223 m .57205 .57762 L .58416 .56539 L p 0 .349 .781 r
F P
0 g
s
.57205 .57762 m .55845 .56223 L .57304 .55641 L p 0 .314 .946 r
F P
0 g
s
.58307 .58625 m .5977 .58074 L .58416 .56539 L p 0 .315 .945 r
F P
0 g
s
.58676 .57196 m .57205 .57762 L .58416 .56539 L p 0 .05 .173 r
F P
0 g
s
.58416 .56539 m .57205 .57762 L .58676 .57196 L p 0 .05 .173 r
F P
0 g
s
.55845 .56223 m .57205 .57762 L .58676 .57196 L p 0 .314 .946 r
F P
0 g
s
.58676 .57196 m .57304 .55641 L .55845 .56223 L p 0 .314 .946 r
F P
0 g
s
.54626 .57449 m .55845 .56223 L .57304 .55641 L p 0 .05 .157 r
F P
0 g
s
.5562 .55582 m .54414 .56793 L .55845 .56223 L p 0 .05 .157 r
F P
0 g
s
.54484 .54681 m .55845 .56223 L .54414 .56793 L p 0 .314 .946 r
F P
0 g
s
.53064 .55266 m .54414 .56793 L .55845 .56223 L p 0 .314 .946 r
F P
0 g
s
.55845 .56223 m .54484 .54681 L .53064 .55266 L p 0 .314 .946 r
F P
0 g
s
.55845 .56223 m .54626 .57449 L p .54512 .55234 L 0 .349 .781 r
F P
0 g
s
.54484 .54681 m .54756 .54989 L p .54512 .55234 L 0 .349 .781 r
F P
0 g
s
.54756 .54989 m .55845 .56223 L p .54512 .55234 L 0 .349 .781 r
F P
0 g
s
.55845 .56223 m .54626 .57449 L .56076 .56878 L p 0 .05 .157 r
F P
0 g
s
.5326 .55905 m .54626 .57449 L .55845 .56223 L p 0 .349 .781 r
F P
0 g
s
.57351 .6053 m .58825 .5999 L .57452 .58435 L p 0 .314 .946 r
F P
0 g
s
.57452 .58435 m .55989 .58991 L .57351 .6053 L p 0 .314 .946 r
F P
0 g
s
.57351 .6053 m .55989 .58991 L .57452 .58435 L p 0 .314 .946 r
F P
0 g
s
.57452 .58435 m .58825 .5999 L .57351 .6053 L p 0 .314 .946 r
F P
0 g
s
.54626 .57449 m .5326 .55905 L .54484 .54681 L p 0 .349 .781 r
F P
0 g
s
.54769 .60224 m .55989 .58991 L .57452 .58435 L p 0 .05 .173 r
F P
0 g
s
.56076 .56878 m .57452 .58435 L .55989 .58991 L p 0 .314 .946 r
F P
0 g
s
.55989 .58991 m .54626 .57449 L .56076 .56878 L p 0 .314 .946 r
F P
0 g
s
.54626 .57449 m .55989 .58991 L .54769 .60224 L p 0 .349 .781 r
F P
0 g
s
.55989 .58991 m .54769 .60224 L .56222 .59679 L p 0 .05 .173 r
F P
0 g
s
.56222 .59679 m .57452 .58435 L .55989 .58991 L p 0 .05 .173 r
F P
0 g
s
.54626 .57449 m .55989 .58991 L .57452 .58435 L p 0 .314 .946 r
F P
0 g
s
.53402 .5868 m .54769 .60224 L .55989 .58991 L p 0 .349 .781 r
F P
0 g
s
.55989 .58991 m .54626 .57449 L .53402 .5868 L p 0 .349 .781 r
F P
0 g
s
.57304 .55641 m .56076 .56878 L .54626 .57449 L p 0 .05 .157 r
F P
0 g
s
.55845 .56223 m .54484 .54681 L .5326 .55905 L p 0 .349 .781 r
F P
0 g
s
.54699 .55319 m .56076 .56878 L .54626 .57449 L p 0 .314 .946 r
F P
0 g
s
.54626 .57449 m .5326 .55905 L .54699 .55319 L p 0 .314 .946 r
F P
0 g
s
.54769 .60224 m .53402 .5868 L .54626 .57449 L p 0 .349 .781 r
F P
0 g
s
.57452 .58435 m .56076 .56878 L .54626 .57449 L p 0 .314 .946 r
F P
0 g
s
.53402 .5868 m .54626 .57449 L .56076 .56878 L p 0 .05 .157 r
F P
0 g
s
.5326 .55905 m .54626 .57449 L .53402 .5868 L p 0 .349 .781 r
F P
0 g
s
.54626 .57449 m .53402 .5868 L .54843 .5812 L p 0 .05 .157 r
F P
0 g
s
.54843 .5812 m .56076 .56878 L .54626 .57449 L p 0 .05 .157 r
F P
0 g
s
.5326 .55905 m .54626 .57449 L .56076 .56878 L p 0 .314 .946 r
F P
0 g
s
.52033 .57134 m .53402 .5868 L .54626 .57449 L p 0 .349 .781 r
F P
0 g
s
.54626 .57449 m .5326 .55905 L .52033 .57134 L p 0 .349 .781 r
F P
0 g
s
.53402 .5868 m .52033 .57134 L .5326 .55905 L p 0 .349 .781 r
F P
0 g
s
.57452 .58435 m .56222 .59679 L .54769 .60224 L p 0 .05 .173 r
F P
0 g
s
.53402 .5868 m .54769 .60224 L .56222 .59679 L p 0 .313 .947 r
F P
0 g
s
.54769 .60224 m .53402 .5868 L .52172 .59916 L p 0 .349 .781 r
F P
0 g
s
.54988 .60928 m .56222 .59679 L .54769 .60224 L p 0 .05 .173 r
F P
0 g
s
.54769 .60224 m .53402 .5868 L .54843 .5812 L p 0 .313 .947 r
F P
0 g
s
.54843 .5812 m .56222 .59679 L .54769 .60224 L p 0 .313 .947 r
F P
0 g
s
.56222 .59679 m .54843 .5812 L .53402 .5868 L p 0 .313 .947 r
F P
0 g
s
.52172 .59916 m .53402 .5868 L .54843 .5812 L p 0 .05 .157 r
F P
0 g
s
.53402 .5868 m .52172 .59916 L p .5206 .5769 L 0 .349 .781 r
F P
0 g
s
.52033 .57134 m .52307 .57443 L p .5206 .5769 L 0 .349 .781 r
F P
0 g
s
.52307 .57443 m .53402 .5868 L p .5206 .5769 L 0 .349 .781 r
F P
0 g
s
.53402 .5868 m .52172 .59916 L .53605 .59367 L p 0 .05 .157 r
F P
0 g
s
.53605 .59367 m .54843 .5812 L .53402 .5868 L p 0 .05 .157 r
F P
0 g
s
.56076 .56878 m .54843 .5812 L .53402 .5868 L p 0 .05 .157 r
F P
0 g
s
.52033 .57134 m .53402 .5868 L .54843 .5812 L p 0 .313 .947 r
F P
0 g
s
.508 .58368 m .52172 .59916 L .53402 .5868 L p 0 .349 .781 r
F P
0 g
s
.53402 .5868 m .52033 .57134 L .508 .58368 L p 0 .349 .781 r
F P
0 g
s
.53402 .5868 m .52033 .57134 L .53462 .56558 L p 0 .313 .947 r
F P
0 g
s
.53462 .56558 m .54843 .5812 L .53402 .5868 L p 0 .313 .947 r
F P
0 g
s
.52172 .59916 m .508 .58368 L .52033 .57134 L p 0 .349 .781 r
F P
0 g
s
.54843 .5812 m .53462 .56558 L .52033 .57134 L p 0 .313 .947 r
F P
0 g
s
.54843 .5812 m .53605 .59367 L .52172 .59916 L p 0 .05 .157 r
F P
0 g
s
.58825 .5999 m .60196 .61542 L .58974 .6279 L p 0 .349 .781 r
F P
0 g
s
.58974 .6279 m .60196 .61542 L .58825 .5999 L p 0 .349 .781 r
F P
0 g
s
.58974 .6279 m .57599 .61236 L .58825 .5999 L p 0 .349 .781 r
F P
0 g
s
.57452 .58435 m .58825 .5999 L .57599 .61236 L p 0 .349 .781 r
F P
0 g
s
.58825 .5999 m .57599 .61236 L .58974 .6279 L p 0 .349 .781 r
F P
0 g
s
.57599 .61236 m .58825 .5999 L .57452 .58435 L p 0 .349 .781 r
F P
0 g
s
.57599 .61236 m .56222 .59679 L .57452 .58435 L p 0 .349 .781 r
F P
0 g
s
.57452 .58435 m .56222 .59679 L .57599 .61236 L p 0 .349 .781 r
F P
0 g
s
.57452 .58435 m .56222 .59679 L .57704 .59123 L p 0 .05 .173 r
F P
0 g
s
.54843 .5812 m .56222 .59679 L .57452 .58435 L p 0 .349 .781 r
F P
0 g
s
.57452 .58435 m .56076 .56878 L .54843 .5812 L p 0 .349 .781 r
F P
0 g
s
.57704 .59123 m .56222 .59679 L .57452 .58435 L p 0 .05 .173 r
F P
0 g
s
.56076 .56878 m .57452 .58435 L .56222 .59679 L p 0 .349 .781 r
F P
0 g
s
.57304 .55641 m .58676 .57196 L .57205 .57762 L p 0 .314 .946 r
F P
0 g
s
.57205 .57762 m .58676 .57196 L .57452 .58435 L p 0 .05 .173 r
F P
0 g
s
.57452 .58435 m .58676 .57196 L .57205 .57762 L p 0 .05 .173 r
F P
0 g
s
.56076 .56878 m .57452 .58435 L .58676 .57196 L p 0 .349 .781 r
F P
0 g
s
.58676 .57196 m .57304 .55641 L .56076 .56878 L p 0 .349 .781 r
F P
0 g
s
.57304 .55641 m .58676 .57196 L .57452 .58435 L p 0 .349 .781 r
F P
0 g
s
.57452 .58435 m .56076 .56878 L .57304 .55641 L p 0 .349 .781 r
F P
0 g
s
.57452 .58435 m .56076 .56878 L .57554 .56296 L p 0 .314 .946 r
F P
0 g
s
.59648 .60143 m .61123 .59607 L .5977 .58074 L p 0 .315 .945 r
F P
0 g
s
.5977 .58074 m .58307 .58625 L .59648 .60143 L p 0 .315 .945 r
F P
0 g
s
.57452 .58435 m .58676 .57196 L .60046 .58748 L p 0 .349 .781 r
F P
0 g
s
.60046 .58748 m .58676 .57196 L .57452 .58435 L p 0 .349 .781 r
F P
0 g
s
.58676 .57196 m .57452 .58435 L .58942 .57869 L p 0 .05 .173 r
F P
0 g
s
.5977 .58074 m .61262 .57512 L .59896 .55962 L p 0 .315 .945 r
F P
0 g
s
.59896 .55962 m .58416 .56539 L .5977 .58074 L p 0 .315 .945 r
F P
0 g
s
.61262 .57512 m .5977 .58074 L .61123 .59607 L p 0 .315 .945 r
F P
0 g
s
.61262 .57512 m .60046 .58748 L .58676 .57196 L p 0 .349 .781 r
F P
0 g
s
.58676 .57196 m .59896 .55962 L .61262 .57512 L p 0 .349 .781 r
F P
0 g
s
.61262 .57512 m .59896 .55962 L .58676 .57196 L p 0 .349 .781 r
F P
0 g
s
.58676 .57196 m .60046 .58748 L .61262 .57512 L p 0 .349 .781 r
F P
0 g
s
.57452 .58435 m .58676 .57196 L .60175 .56619 L p 0 .05 .173 r
F P
0 g
s
.60175 .56619 m .58942 .57869 L .57452 .58435 L p 0 .05 .173 r
F P
0 g
s
.56076 .56878 m .57452 .58435 L .58942 .57869 L p 0 .314 .946 r
F P
0 g
s
.58942 .57869 m .57554 .56296 L .56076 .56878 L p 0 .314 .946 r
F P
0 g
s
.56222 .59679 m .54843 .5812 L .56076 .56878 L p 0 .349 .781 r
F P
0 g
s
.54843 .5812 m .56076 .56878 L .57554 .56296 L p 0 .05 .157 r
F P
0 g
s
.56076 .56878 m .54843 .5812 L .56312 .57549 L p 0 .05 .157 r
F P
0 g
s
.54843 .5812 m .56076 .56878 L p .53986 .56622 L 0 .349 .781 r
F P
0 g
s
.53462 .56558 m .53738 .56871 L p .53986 .56622 L 0 .349 .781 r
F P
0 g
s
.53738 .56871 m .54843 .5812 L p .53986 .56622 L 0 .349 .781 r
F P
0 g
s
.56076 .56878 m .54699 .55319 L .5326 .55905 L p 0 .314 .946 r
F P
0 g
s
.56076 .56878 m .54843 .5812 L p .54728 .55878 L 0 .349 .781 r
F P
0 g
s
.54699 .55319 m .54974 .55631 L p .54728 .55878 L 0 .349 .781 r
F P
0 g
s
.54974 .55631 m .56076 .56878 L p .54728 .55878 L 0 .349 .781 r
F P
0 g
s
.54843 .5812 m .53462 .56558 L .54699 .55319 L p 0 .349 .781 r
F P
0 g
s
.54843 .5812 m .56222 .59679 L .57704 .59123 L p 0 .313 .947 r
F P
0 g
s
.53605 .59367 m .54988 .60928 L .56222 .59679 L p 0 .349 .781 r
F P
0 g
s
.56222 .59679 m .54843 .5812 L .53605 .59367 L p 0 .349 .781 r
F P
0 g
s
.56222 .59679 m .54988 .60928 L .56461 .60383 L p 0 .05 .173 r
F P
0 g
s
.56461 .60383 m .57704 .59123 L .56222 .59679 L p 0 .05 .173 r
F P
0 g
s
.56222 .59679 m .54843 .5812 L .56312 .57549 L p 0 .313 .947 r
F P
0 g
s
.56312 .57549 m .57704 .59123 L .56222 .59679 L p 0 .313 .947 r
F P
0 g
s
.56461 .60383 m .54988 .60928 L .56222 .59679 L p 0 .05 .173 r
F P
0 g
s
.56222 .59679 m .57704 .59123 L .56461 .60383 L p 0 .05 .173 r
F P
0 g
s
.54843 .5812 m .56222 .59679 L .54988 .60928 L p 0 .349 .781 r
F P
0 g
s
.57704 .59123 m .56312 .57549 L .54843 .5812 L p 0 .313 .947 r
F P
0 g
s
.54988 .60928 m .53605 .59367 L .54843 .5812 L p 0 .349 .781 r
F P
0 g
s
.53605 .59367 m .54843 .5812 L .56312 .57549 L p 0 .05 .157 r
F P
0 g
s
.54843 .5812 m .53605 .59367 L .55065 .58807 L p 0 .05 .157 r
F P
0 g
s
.55065 .58807 m .56312 .57549 L .54843 .5812 L p 0 .05 .157 r
F P
0 g
s
.57554 .56296 m .56312 .57549 L .54843 .5812 L p 0 .05 .157 r
F P
0 g
s
.53462 .56558 m .54843 .5812 L .56312 .57549 L p 0 .313 .947 r
F P
0 g
s
.5222 .57803 m .53605 .59367 L .54843 .5812 L p 0 .349 .781 r
F P
0 g
s
.54843 .5812 m .53462 .56558 L .5222 .57803 L p 0 .349 .781 r
F P
0 g
s
.56076 .56878 m .54699 .55319 L .53462 .56558 L p 0 .349 .781 r
F P
0 g
s
.54843 .5812 m .53462 .56558 L .54919 .55972 L p 0 .313 .947 r
F P
0 g
s
.54919 .55972 m .56312 .57549 L .54843 .5812 L p 0 .313 .947 r
F P
0 g
s
.53462 .56558 m .54843 .5812 L .53605 .59367 L p 0 .349 .781 r
F P
0 g
s
.56312 .57549 m .54919 .55972 L .53462 .56558 L p 0 .313 .947 r
F P
0 g
s
.53605 .59367 m .5222 .57803 L .53462 .56558 L p 0 .349 .781 r
F P
0 g
s
.56312 .57549 m .55065 .58807 L .53605 .59367 L p 0 .05 .157 r
F P
0 g
s
.57704 .59123 m .56461 .60383 L .57962 .59828 L p 0 .05 .173 r
F P
0 g
s
.55065 .58807 m .56461 .60383 L .57704 .59123 L p 0 .349 .781 r
F P
0 g
s
.57704 .59123 m .56312 .57549 L .55065 .58807 L p 0 .349 .781 r
F P
0 g
s
.56312 .57549 m .57704 .59123 L .56461 .60383 L p 0 .349 .781 r
F P
0 g
s
.57962 .59828 m .56461 .60383 L .57704 .59123 L p 0 .05 .173 r
F P
0 g
s
.57554 .56296 m .58942 .57869 L .57452 .58435 L p 0 .314 .946 r
F P
0 g
s
.60046 .58748 m .58825 .5999 L .57452 .58435 L p 0 .349 .781 r
F P
0 g
s
.57452 .58435 m .58825 .5999 L .60046 .58748 L p 0 .349 .781 r
F P
0 g
s
.60987 .61659 m .62473 .61137 L .61123 .59607 L p 0 .315 .945 r
F P
0 g
s
.61123 .59607 m .59648 .60143 L .60987 .61659 L p 0 .315 .945 r
F P
0 g
s
.58825 .5999 m .60046 .58748 L .61413 .60298 L p 0 .349 .781 r
F P
0 g
s
.61413 .60298 m .60046 .58748 L .58825 .5999 L p 0 .349 .781 r
F P
0 g
s
.57452 .58435 m .58825 .5999 L .60327 .59439 L p 0 .314 .946 r
F P
0 g
s
.60327 .59439 m .58825 .5999 L .57452 .58435 L p 0 .314 .946 r
F P
0 g
s
.60327 .59439 m .58942 .57869 L .57452 .58435 L p 0 .314 .946 r
F P
0 g
s
.57452 .58435 m .58942 .57869 L .60327 .59439 L p 0 .314 .946 r
F P
0 g
s
.57704 .59123 m .58942 .57869 L .57452 .58435 L p 0 .05 .173 r
F P
0 g
s
.57452 .58435 m .58942 .57869 L .57704 .59123 L p 0 .05 .173 r
F P
0 g
s
.56312 .57549 m .57704 .59123 L .58942 .57869 L p 0 .349 .781 r
F P
0 g
s
.58942 .57869 m .57554 .56296 L .56312 .57549 L p 0 .349 .781 r
F P
0 g
s
.57554 .56296 m .58942 .57869 L .57704 .59123 L p 0 .349 .781 r
F P
0 g
s
.57704 .59123 m .56312 .57549 L .57554 .56296 L p 0 .349 .781 r
F P
0 g
s
.58942 .57869 m .57704 .59123 L .59214 .58557 L p 0 .05 .173 r
F P
0 g
s
.59214 .58557 m .57704 .59123 L .58942 .57869 L p 0 .05 .173 r
F P
0 g
s
.56312 .57549 m .57704 .59123 L .59214 .58557 L p 0 .313 .947 r
F P
0 g
s
.57704 .59123 m .56312 .57549 L .5781 .56967 L p 0 .313 .947 r
F P
0 g
s
.59214 .58557 m .5781 .56967 L .56312 .57549 L p 0 .313 .947 r
F P
0 g
s
.56461 .60383 m .55065 .58807 L .56312 .57549 L p 0 .349 .781 r
F P
0 g
s
.56312 .57549 m .5781 .56967 L p .55793 .58319 L 0 .05 .157 r
F P
0 g
s
.55065 .58807 m .55398 .58471 L p .55793 .58319 L 0 .05 .157 r
F P
0 g
s
.55398 .58471 m .56312 .57549 L p .55793 .58319 L 0 .05 .157 r
F P
0 g
s
.63872 .64926 m .65383 .64436 L .63929 .62788 L p 0 .315 .945 r
F P
0 g
s
.63929 .62788 m .6243 .63294 L .63872 .64926 L p 0 .315 .945 r
F P
0 g
s
.63872 .64926 m .6243 .63294 L .63929 .62788 L p 0 .315 .945 r
F P
0 g
s
.63929 .62788 m .65383 .64436 L .63872 .64926 L p 0 .315 .945 r
F P
0 g
s
.62473 .61137 m .60987 .61659 L .6243 .63294 L p 0 .315 .945 r
F P
0 g
s
.6243 .63294 m .63929 .62788 L .62473 .61137 L p 0 .315 .945 r
F P
0 g
s
.6243 .63294 m .60987 .61659 L .62473 .61137 L p 0 .315 .945 r
F P
0 g
s
.62473 .61137 m .63929 .62788 L .6243 .63294 L p 0 .315 .945 r
F P
0 g
s
.60987 .61659 m .62473 .61137 L .61273 .62367 L p 0 .05 .218 r
F P
0 g
s
.61273 .62367 m .62473 .61137 L .60987 .61659 L p 0 .05 .218 r
F P
0 g
s
.62779 .61846 m .61273 .62367 L .62473 .61137 L p 0 .05 .218 r
F P
0 g
s
.62473 .61137 m .61273 .62367 L .62779 .61846 L p 0 .05 .218 r
F P
0 g
s
.61273 .62367 m .62779 .61846 L .61565 .63092 L p 0 .05 .218 r
F P
0 g
s
.61565 .63092 m .62779 .61846 L .61273 .62367 L p 0 .05 .218 r
F P
0 g
s
.68278 .61439 m .65383 .64436 L .66922 .63936 L p 0 .05 .248 r
F P
0 g
s
.63929 .62788 m .65383 .64436 L .66922 .63936 L p 0 .315 .945 r
F P
0 g
s
.65383 .64436 m .63929 .62788 L .65456 .62272 L p 0 .315 .945 r
F P
0 g
s
.65456 .62272 m .66922 .63936 L .65383 .64436 L p 0 .315 .945 r
F P
0 g
s
.66922 .63936 m .65456 .62272 L .63929 .62788 L p 0 .315 .945 r
F P
0 g
s
.63929 .62788 m .65456 .62272 L .63987 .60606 L p 0 .315 .945 r
F P
0 g
s
.63987 .60606 m .65456 .62272 L .63929 .62788 L p 0 .315 .945 r
F P
0 g
s
.64002 .62626 m .64016 .64652 L .66922 .63936 L p 0 .349 .781 r
F P
0 g
s
.64016 .64652 m .64002 .62626 L .65456 .62272 L p 0 .349 .781 r
F P
0 g
s
.63987 .60606 m .62473 .61137 L .63929 .62788 L p 0 .315 .945 r
F P
0 g
s
.63929 .62788 m .62473 .61137 L .63987 .60606 L p 0 .315 .945 r
F P
0 g
s
.62779 .61846 m .64002 .62626 L .64016 .64652 L p 0 .349 .781 r
F P
0 g
s
.64002 .62626 m .62779 .61846 L .61565 .63092 L p 0 .349 .781 r
F P
0 g
s
.61565 .63092 m .64016 .64652 L .64002 .62626 L p 0 .349 .781 r
F P
0 g
s
.64016 .64652 m .61565 .63092 L .62779 .61846 L p 0 .349 .781 r
F P
0 g
s
.62779 .61846 m .61565 .63092 L .60196 .61542 L p 0 .349 .781 r
F P
0 g
s
.60196 .61542 m .61413 .60298 L .62779 .61846 L p 0 .349 .781 r
F P
0 g
s
.63092 .62571 m .61565 .63092 L .62779 .61846 L p 0 .05 .218 r
F P
0 g
s
.64002 .62626 m .63987 .60606 L .65456 .62272 L closepath p 0 .349 .781 r
F P
0 g
s
.65456 .62272 m .63987 .60606 L .64002 .62626 L closepath p 0 .349 .781 r
F P
0 g
s
.62779 .61846 m .63987 .60606 L .64002 .62626 L closepath p 0 .349 .781 r
F P
0 g
s
.64002 .62626 m .63987 .60606 L .62779 .61846 L closepath p 0 .349 .781 r
F P
0 g
s
.64314 .61315 m .62779 .61846 L .61565 .63092 L p 0 .05 .218 r
F P
0 g
s
.62779 .61846 m .61413 .60298 L .60196 .61542 L p 0 .349 .781 r
F P
0 g
s
.60196 .61542 m .61565 .63092 L .62779 .61846 L p 0 .349 .781 r
F P
0 g
s
.64016 .64652 m .64025 .65876 L .61565 .63092 L closepath p 0 .349 .781 r
F P
0 g
s
.61565 .63092 m .64025 .65876 L .64016 .64652 L closepath p 0 .349 .781 r
F P
0 g
s
.63092 .62571 m .61565 .63092 L .64025 .65876 L p 0 .314 .946 r
F P
0 g
s
.65456 .62272 m .66922 .63936 L .64016 .64652 L p 0 .349 .781 r
F P
0 g
s
.64016 .64652 m .66922 .63936 L .64516 .66432 L p 0 .349 .781 r
F P
0 g
s
.68491 .63427 m .66922 .63936 L .64516 .66432 L p 0 .05 .248 r
F P
0 g
s
.66922 .63936 m .64016 .64652 L .64025 .65876 L p 0 .349 .781 r
F P
0 g
s
.64025 .65876 m .64516 .66432 L .66922 .63936 L p 0 .349 .781 r
F P
0 g
s
.64516 .66432 m .64025 .65876 L .64016 .64652 L p 0 .349 .781 r
F P
0 g
s
.64025 .65876 m .65573 .65383 L .63092 .62571 L p 0 .314 .946 r
F P
0 g
s
.65573 .65383 m .64025 .65876 L .61565 .63092 L p 0 .314 .946 r
F P
0 g
s
.61413 .60298 m .60196 .61542 L .58825 .5999 L p 0 .349 .781 r
F P
0 g
s
.58825 .5999 m .60196 .61542 L .61413 .60298 L p 0 .349 .781 r
F P
0 g
s
.61565 .63092 m .63092 .62571 L .65573 .65383 L p 0 .314 .946 r
F P
0 g
s
.61565 .63092 m .63092 .62571 L .61865 .63833 L p 0 .05 .218 r
F P
0 g
s
.61865 .63833 m .63092 .62571 L .61565 .63092 L p 0 .05 .218 r
F P
0 g
s
.61565 .63092 m .63092 .62571 L .64314 .61315 L p 0 .05 .218 r
F P
0 g
s
.60196 .61542 m .61565 .63092 L .63092 .62571 L p 0 .314 .946 r
F P
0 g
s
.63092 .62571 m .61565 .63092 L .60196 .61542 L p 0 .314 .946 r
F P
0 g
s
.58825 .5999 m .60196 .61542 L .61711 .61006 L p 0 .314 .946 r
F P
0 g
s
.63092 .62571 m .61711 .61006 L .60196 .61542 L p 0 .314 .946 r
F P
0 g
s
.61711 .61006 m .60196 .61542 L .58825 .5999 L p 0 .314 .946 r
F P
0 g
s
.60196 .61542 m .61711 .61006 L .63092 .62571 L p 0 .314 .946 r
F P
0 g
s
.61711 .61006 m .60327 .59439 L .58825 .5999 L p 0 .314 .946 r
F P
0 g
s
.58825 .5999 m .60327 .59439 L .61711 .61006 L p 0 .314 .946 r
F P
0 g
s
.66922 .63936 m .65456 .62272 L .64002 .62626 L p 0 .349 .781 r
F P
0 g
s
.64648 .62041 m .63092 .62571 L .65573 .65383 L p 0 .314 .946 r
F P
0 g
s
.64516 .66432 m .66068 .65944 L .68491 .63427 L p 0 .05 .248 r
F P
0 g
s
.7009 .62907 m .68491 .63427 L .66068 .65944 L p 0 .05 .248 r
F P
0 g
s
.65573 .65383 m .67151 .6488 L .64648 .62041 L p 0 .314 .946 r
F P
0 g
s
.67151 .6488 m .65573 .65383 L .63092 .62571 L p 0 .314 .946 r
F P
0 g
s
.63092 .62571 m .64648 .62041 L .67151 .6488 L p 0 .314 .946 r
F P
0 g
s
.61865 .63833 m .63092 .62571 L .64648 .62041 L p 0 .05 .218 r
F P
0 g
s
.63412 .63314 m .64648 .62041 L .63092 .62571 L p 0 .05 .218 r
F P
0 g
s
.63092 .62571 m .61865 .63833 L .63412 .63314 L p 0 .05 .218 r
F P
0 g
s
.62172 .64591 m .63412 .63314 L .61865 .63833 L p 0 .05 .218 r
F P
0 g
s
.64648 .62041 m .63412 .63314 L .61865 .63833 L p 0 .05 .218 r
F P
0 g
s
.61865 .63833 m .63412 .63314 L .62172 .64591 L p 0 .05 .218 r
F P
0 g
s
.59214 .58557 m .57704 .59123 L p .57892 .59639 L 0 .05 .173 r
F P
0 g
s
.57962 .59828 m .58296 .59489 L p .57892 .59639 L 0 .05 .173 r
F P
0 g
s
.58296 .59489 m .59214 .58557 L p .57892 .59639 L 0 .05 .173 r
F P
0 g
s
.63987 .60606 m .65456 .62272 L .6838 .59255 L p 0 .349 .781 r
F P
0 g
s
.6838 .59255 m .65456 .62272 L .63987 .60606 L p 0 .349 .781 r
F P
0 g
s
.71145 .5847 m .68278 .61439 L .69837 .60913 L p 0 .05 .248 r
F P
0 g
s
.69837 .60913 m .6838 .59255 L .65456 .62272 L p 0 .349 .781 r
F P
0 g
s
.65456 .62272 m .6838 .59255 L .69837 .60913 L p 0 .349 .781 r
F P
0 g
s
.67012 .61746 m .65456 .62272 L .63987 .60606 L p 0 .315 .945 r
F P
0 g
s
.65456 .62272 m .67012 .61746 L .65531 .60063 L p 0 .315 .945 r
F P
0 g
s
.65531 .60063 m .63987 .60606 L .65456 .62272 L p 0 .315 .945 r
F P
0 g
s
.63987 .60606 m .65531 .60063 L .67012 .61746 L p 0 .315 .945 r
F P
0 g
s
.68598 .61211 m .67012 .61746 L .65531 .60063 L p 0 .315 .945 r
F P
0 g
s
.67104 .59511 m .65531 .60063 L .67012 .61746 L p 0 .315 .945 r
F P
0 g
s
.65531 .60063 m .67104 .59511 L .68598 .61211 L p 0 .315 .945 r
F P
0 g
s
.67012 .61746 m .68598 .61211 L .67104 .59511 L p 0 .315 .945 r
F P
0 g
s
.65878 .60773 m .67104 .59511 L .67122 .6157 L closepath p 0 .35 .78 r
F P
0 g
s
.66922 .63936 m .69837 .60913 L .68278 .61439 L p 0 .05 .248 r
F P
0 g
s
.65456 .62272 m .66922 .63936 L .69837 .60913 L p 0 .349 .781 r
F P
0 g
s
.69837 .60913 m .66922 .63936 L .65456 .62272 L p 0 .349 .781 r
F P
0 g
s
.71426 .60377 m .69837 .60913 L .66922 .63936 L p 0 .05 .248 r
F P
0 g
s
.66922 .63936 m .68491 .63427 L .71426 .60377 L p 0 .05 .248 r
F P
0 g
s
.68491 .63427 m .66922 .63936 L .65456 .62272 L p 0 .315 .945 r
F P
0 g
s
.65456 .62272 m .66922 .63936 L .68491 .63427 L p 0 .315 .945 r
F P
0 g
s
.65456 .62272 m .67012 .61746 L .68491 .63427 L p 0 .315 .945 r
F P
0 g
s
.68491 .63427 m .67012 .61746 L .65456 .62272 L p 0 .315 .945 r
F P
0 g
s
.73045 .59832 m .71426 .60377 L .68491 .63427 L p 0 .05 .248 r
F P
0 g
s
.68491 .63427 m .7009 .62907 L .73045 .59832 L p 0 .05 .248 r
F P
0 g
s
.7009 .62907 m .68491 .63427 L .67012 .61746 L p 0 .315 .945 r
F P
0 g
s
.68598 .61211 m .67012 .61746 L .68491 .63427 L p 0 .315 .945 r
F P
0 g
s
.67012 .61746 m .68598 .61211 L .7009 .62907 L p 0 .315 .945 r
F P
0 g
s
.67122 .6157 m .6714 .63633 L .64648 .62041 L p 0 .35 .78 r
F P
0 g
s
.64648 .62041 m .65878 .60773 L .67122 .6157 L p 0 .35 .78 r
F P
0 g
s
.64648 .62041 m .6714 .63633 L .67151 .6488 L closepath p 0 .35 .78 r
F P
0 g
s
.67151 .6488 m .66001 .64813 L .64648 .62041 L closepath p 0 .35 .78 r
F P
0 g
s
.63412 .63314 m .64648 .62041 L .66001 .64813 L p 0 .35 .78 r
F P
0 g
s
.66001 .64813 m .64091 .64703 L .63412 .63314 L p 0 .35 .78 r
F P
0 g
s
.64091 .64703 m .62172 .64591 L .63412 .63314 L closepath p 0 .35 .78 r
F P
0 g
s
.66989 .59773 m .62711 .64181 L .64074 .63729 L p .262 0 0 r
F P
0 g
s
.62473 .61137 m .63987 .60606 L .62779 .61846 L p 0 .05 .218 r
F P
0 g
s
.62473 .61137 m .63987 .60606 L .62625 .5906 L p 0 .315 .945 r
F P
0 g
s
.62625 .5906 m .61123 .59607 L .62473 .61137 L p 0 .315 .945 r
F P
0 g
s
.62779 .61846 m .63987 .60606 L .62473 .61137 L p 0 .05 .218 r
F P
0 g
s
.61123 .59607 m .62625 .5906 L .61262 .57512 L p 0 .315 .945 r
F P
0 g
s
.63987 .60606 m .62779 .61846 L .61413 .60298 L p 0 .349 .781 r
F P
0 g
s
.61413 .60298 m .62625 .5906 L .63987 .60606 L p 0 .349 .781 r
F P
0 g
s
.64314 .61315 m .62779 .61846 L .63987 .60606 L p 0 .05 .218 r
F P
0 g
s
.63987 .60606 m .65531 .60063 L .64314 .61315 L p 0 .05 .218 r
F P
0 g
s
.62625 .5906 m .63987 .60606 L .65531 .60063 L p 0 .315 .945 r
F P
0 g
s
.65531 .60063 m .63987 .60606 L .62779 .61846 L p 0 .05 .218 r
F P
0 g
s
.63987 .60606 m .62625 .5906 L .61413 .60298 L p 0 .349 .781 r
F P
0 g
s
.61413 .60298 m .62779 .61846 L .63987 .60606 L p 0 .349 .781 r
F P
0 g
s
.62625 .5906 m .61413 .60298 L .60046 .58748 L p 0 .349 .781 r
F P
0 g
s
.60046 .58748 m .61262 .57512 L .62625 .5906 L p 0 .349 .781 r
F P
0 g
s
.61262 .57512 m .62625 .5906 L .64157 .58503 L p 0 .315 .945 r
F P
0 g
s
.62625 .5906 m .61262 .57512 L .60046 .58748 L p 0 .349 .781 r
F P
0 g
s
.60046 .58748 m .61413 .60298 L .62625 .5906 L p 0 .349 .781 r
F P
0 g
s
.65531 .60063 m .64157 .58503 L .62625 .5906 L p 0 .315 .945 r
F P
0 g
s
.64157 .58503 m .62781 .5694 L .61262 .57512 L p 0 .315 .945 r
F P
0 g
s
.59896 .55962 m .61262 .57512 L .62781 .5694 L p 0 .315 .945 r
F P
0 g
s
.62779 .61846 m .64314 .61315 L .63092 .62571 L p 0 .05 .218 r
F P
0 g
s
.62779 .61846 m .64314 .61315 L .65531 .60063 L p 0 .05 .218 r
F P
0 g
s
.62781 .5694 m .61403 .55374 L .59896 .55962 L p 0 .315 .945 r
F P
0 g
s
.60175 .56619 m .61403 .55374 L .59896 .55962 L p 0 .05 .173 r
F P
0 g
s
.58528 .5441 m .59896 .55962 L .61403 .55374 L p 0 .315 .945 r
F P
0 g
s
.58676 .57196 m .59896 .55962 L .61403 .55374 L p 0 .05 .173 r
F P
0 g
s
.61403 .55374 m .60023 .53806 L .58528 .5441 L p 0 .315 .945 r
F P
0 g
s
.61403 .55374 m .60175 .56619 L .58676 .57196 L p 0 .05 .173 r
F P
0 g
s
.65878 .60773 m .64314 .61315 L .65531 .60063 L p 0 .05 .218 r
F P
0 g
s
.65531 .60063 m .67104 .59511 L .65878 .60773 L p 0 .05 .218 r
F P
0 g
s
.64157 .58503 m .65531 .60063 L .67104 .59511 L p 0 .315 .945 r
F P
0 g
s
.67104 .59511 m .65531 .60063 L .64314 .61315 L p 0 .05 .218 r
F P
0 g
s
.62781 .5694 m .64157 .58503 L .65718 .57935 L p 0 .315 .945 r
F P
0 g
s
.67104 .59511 m .65718 .57935 L .64157 .58503 L p 0 .315 .945 r
F P
0 g
s
.65718 .57935 m .6433 .56356 L .62781 .5694 L p 0 .315 .945 r
F P
0 g
s
.61403 .55374 m .62781 .5694 L .6433 .56356 L p 0 .315 .945 r
F P
0 g
s
.63092 .62571 m .64314 .61315 L .65878 .60773 L p 0 .05 .218 r
F P
0 g
s
.64314 .61315 m .65878 .60773 L .67104 .59511 L p 0 .05 .218 r
F P
0 g
s
.65878 .60773 m .64314 .61315 L .63092 .62571 L p 0 .05 .218 r
F P
0 g
s
.60023 .53806 m .61403 .55374 L .6294 .54775 L p 0 .315 .945 r
F P
0 g
s
.58416 .56539 m .59896 .55962 L .58676 .57196 L p 0 .05 .173 r
F P
0 g
s
.58676 .57196 m .59896 .55962 L .58416 .56539 L p 0 .05 .173 r
F P
0 g
s
.59896 .55962 m .58676 .57196 L .60175 .56619 L p 0 .05 .173 r
F P
0 g
s
.57304 .55641 m .58676 .57196 L .59896 .55962 L p 0 .349 .781 r
F P
0 g
s
.59896 .55962 m .58528 .5441 L .57304 .55641 L p 0 .349 .781 r
F P
0 g
s
.58528 .5441 m .59896 .55962 L .58676 .57196 L p 0 .349 .781 r
F P
0 g
s
.58791 .55049 m .60175 .56619 L .61403 .55374 L p 0 .349 .781 r
F P
0 g
s
.61403 .55374 m .60023 .53806 L .58791 .55049 L p 0 .349 .781 r
F P
0 g
s
.60023 .53806 m .61403 .55374 L .60175 .56619 L p 0 .349 .781 r
F P
0 g
s
.6433 .56356 m .6294 .54775 L .61403 .55374 L p 0 .315 .945 r
F P
0 g
s
.6294 .54775 m .61403 .55374 L p .61482 .55548 L 0 .05 .173 r
F P
0 g
s
.61703 .56031 m .62611 .55109 L p .61482 .55548 L 0 .05 .173 r
F P
0 g
s
.62611 .55109 m .6294 .54775 L p .61482 .55548 L 0 .05 .173 r
F P
0 g
s
.56627 .52277 m .62576 .49766 L .60433 .51923 L p .191 0 0 r
F P
0 g
s
.61548 .53192 m .60153 .51606 L .58641 .52236 L p 0 .315 .945 r
F P
0 g
s
.69837 .60913 m .72724 .57919 L .71145 .5847 L p 0 .05 .248 r
F P
0 g
s
.6838 .59255 m .69837 .60913 L .72724 .57919 L p 0 .349 .781 r
F P
0 g
s
.72724 .57919 m .69837 .60913 L .6838 .59255 L p 0 .349 .781 r
F P
0 g
s
.71563 .58141 m .68598 .61211 L .67104 .59511 L p 0 .35 .78 r
F P
0 g
s
.67104 .59511 m .69695 .57382 L .69216 .57335 L .262 0 0 r
F
.67104 .59511 m .67166 .59519 L .69695 .57382 L F
.67104 .59511 m .6049 .51926 L .67166 .59519 L .16 0 0 r
F
.67104 .59511 m .60433 .51923 L .6049 .51926 L F
.61403 .55374 m .6294 .54775 L p .62199 .5527 L 0 .05 .173 r
F P
0 g
s
.60175 .56619 m .61076 .55706 L p .62199 .5527 L 0 .05 .173 r
F P
0 g
s
.61076 .55706 m .61403 .55374 L p .62199 .5527 L 0 .05 .173 r
F P
0 g
s
.6294 .54775 m .61548 .53192 L .60023 .53806 L p 0 .315 .945 r
F P
0 g
s
.60175 .56619 m .58791 .55049 L .60023 .53806 L p 0 .349 .781 r
F P
0 g
s
.58791 .55049 m .60023 .53806 L .61548 .53192 L p 0 .05 .157 r
F P
0 g
s
.61548 .53192 m .60023 .53806 L p .60098 .53975 L 0 .05 .157 r
F P
0 g
s
.60307 .54445 m .61217 .53525 L p .60098 .53975 L 0 .05 .157 r
F P
0 g
s
.61217 .53525 m .61548 .53192 L p .60098 .53975 L 0 .05 .157 r
F P
0 g
s
.58641 .52236 m .60023 .53806 L .61548 .53192 L p 0 .315 .945 r
F P
0 g
s
.6294 .54775 m .61703 .56031 L .60175 .56619 L p 0 .05 .173 r
F P
0 g
s
.60307 .54445 m .58791 .55049 L p .60809 .5369 L 0 .05 .157 r
F P
0 g
s
.61548 .53192 m .61217 .53525 L p .60809 .5369 L 0 .05 .157 r
F P
0 g
s
.61217 .53525 m .60307 .54445 L p .60809 .5369 L 0 .05 .157 r
F P
0 g
s
.67104 .59511 m .68598 .61211 L .67122 .6157 L closepath p 0 .35 .78 r
F P
0 g
s
.67104 .59511 m .65878 .60773 L .64489 .59195 L p 0 .35 .78 r
F P
0 g
s
.64489 .59195 m .65718 .57935 L .67104 .59511 L p 0 .35 .78 r
F P
0 g
s
.65718 .57935 m .64489 .59195 L .63097 .57614 L p 0 .35 .78 r
F P
0 g
s
.63097 .57614 m .6433 .56356 L .65718 .57935 L p 0 .35 .78 r
F P
0 g
s
.6433 .56356 m .63097 .57614 L .61703 .56031 L p 0 .35 .78 r
F P
0 g
s
.61703 .56031 m .6294 .54775 L .6433 .56356 L p 0 .35 .78 r
F P
0 g
s
.61548 .53192 m .6294 .54775 L .61703 .56031 L p 0 .35 .78 r
F P
0 g
s
.61403 .55374 m .60175 .56619 L .61703 .56031 L p 0 .05 .173 r
F P
0 g
s
.61703 .56031 m .60307 .54445 L .61548 .53192 L p 0 .35 .78 r
F P
0 g
s
.60153 .51606 m .61548 .53192 L .60307 .54445 L p 0 .35 .78 r
F P
0 g
s
.67166 .59519 m .60444 .52017 L .67124 .59615 L .978 0 0 r
F
.67124 .59615 m .60305 .52172 L .66989 .59773 L .888 0 0 r
F
.67124 .59615 m .60444 .52017 L .60305 .52172 L F
.62817 .55029 m .61423 .53443 L .61624 .53556 L .554 0 0 r
F
.67166 .59519 m .6049 .51926 L .60444 .52017 L .978 0 0 r
F
.62893 .55 m .61624 .53556 L .63663 .547 L .554 0 0 r
F
.62817 .55029 m .61624 .53556 L .62893 .55 L F
.61423 .53443 m .60305 .52172 L .61794 .53293 L F
.61423 .53443 m .61794 .53293 L .63663 .547 L F
.61646 .53353 m .62817 .55029 L .63324 .54832 L F
.60305 .52172 m .61423 .53443 L p .61646 .53353 L F P
0 g
s
.61423 .53443 m .62817 .55029 L p .61646 .53353 L .554 0 0 r
F P
0 g
s
.67166 .59519 m .69392 .58094 L .69695 .57382 L .262 0 0 r
F
.67166 .59519 m .67124 .59615 L .69392 .58094 L F
.67124 .59615 m .68379 .59287 L .69392 .58094 L F
.63324 .54832 m .66441 .59034 L .68379 .59287 L .554 0 0 r
F
.67124 .59615 m .66989 .59773 L .68379 .59287 L .262 0 0 r
F
.66989 .59773 m .67067 .59746 L p .66441 .59034 L .554 0 0 r
F P
0 g
s
.67067 .59746 m .68379 .59287 L p .66441 .59034 L .554 0 0 r
F P
0 g
s
.62817 .55029 m .66989 .59773 L p .63324 .54832 L .554 0 0 r
F P
0 g
s
.63663 .547 m .60305 .52172 L .61643 .5162 L .554 0 0 r
F
.66989 .59773 m .62817 .55029 L .63663 .547 L F
.63092 .62571 m .64648 .62041 L .65878 .60773 L p 0 .05 .218 r
F P
0 g
s
.65878 .60773 m .64648 .62041 L .63092 .62571 L p 0 .05 .218 r
F P
0 g
s
.61711 .61006 m .63092 .62571 L .64648 .62041 L p 0 .314 .946 r
F P
0 g
s
.64648 .62041 m .63092 .62571 L .61711 .61006 L p 0 .314 .946 r
F P
0 g
s
.60461 .57291 m .61703 .56031 L .60175 .56619 L p 0 .05 .173 r
F P
0 g
s
.58791 .55049 m .60175 .56619 L .61703 .56031 L p 0 .314 .946 r
F P
0 g
s
.60307 .54445 m .61703 .56031 L .60175 .56619 L p 0 .314 .946 r
F P
0 g
s
.58942 .57869 m .60175 .56619 L .61703 .56031 L p 0 .05 .173 r
F P
0 g
s
.60327 .59439 m .61711 .61006 L .63254 .6046 L p 0 .314 .946 r
F P
0 g
s
.64648 .62041 m .63254 .6046 L .61711 .61006 L p 0 .314 .946 r
F P
0 g
s
.63254 .6046 m .61711 .61006 L .60327 .59439 L p 0 .314 .946 r
F P
0 g
s
.61711 .61006 m .63254 .6046 L .64648 .62041 L p 0 .314 .946 r
F P
0 g
s
.61703 .56031 m .60307 .54445 L .58791 .55049 L p 0 .314 .946 r
F P
0 g
s
.63254 .6046 m .61859 .58877 L .60327 .59439 L p 0 .314 .946 r
F P
0 g
s
.58942 .57869 m .60327 .59439 L .61859 .58877 L p 0 .314 .946 r
F P
0 g
s
.60327 .59439 m .61859 .58877 L .63254 .6046 L p 0 .314 .946 r
F P
0 g
s
.61859 .58877 m .60327 .59439 L .58942 .57869 L p 0 .314 .946 r
F P
0 g
s
.61859 .58877 m .60461 .57291 L .58942 .57869 L p 0 .314 .946 r
F P
0 g
s
.58942 .57869 m .60461 .57291 L .61859 .58877 L p 0 .314 .946 r
F P
0 g
s
.61703 .56031 m .60461 .57291 L .58942 .57869 L p 0 .05 .173 r
F P
0 g
s
.65878 .60773 m .64648 .62041 L .63254 .6046 L p 0 .35 .78 r
F P
0 g
s
.63254 .6046 m .64489 .59195 L .65878 .60773 L p 0 .35 .78 r
F P
0 g
s
.64489 .59195 m .63254 .6046 L .61859 .58877 L p 0 .35 .78 r
F P
0 g
s
.61859 .58877 m .63097 .57614 L .64489 .59195 L p 0 .35 .78 r
F P
0 g
s
.63097 .57614 m .61859 .58877 L .60461 .57291 L p 0 .35 .78 r
F P
0 g
s
.60461 .57291 m .61703 .56031 L .63097 .57614 L p 0 .35 .78 r
F P
0 g
s
.63254 .6046 m .64648 .62041 L .63412 .63314 L p 0 .35 .78 r
F P
0 g
s
.60307 .54445 m .61703 .56031 L .60461 .57291 L p 0 .35 .78 r
F P
0 g
s
.61859 .58877 m .63254 .6046 L .62015 .6173 L p 0 .35 .78 r
F P
0 g
s
.63412 .63314 m .62015 .6173 L .63254 .6046 L p 0 .35 .78 r
F P
0 g
s
.62015 .6173 m .60616 .60145 L .61859 .58877 L p 0 .35 .78 r
F P
0 g
s
.60461 .57291 m .61859 .58877 L .60616 .60145 L p 0 .35 .78 r
F P
0 g
s
.62015 .6173 m .63412 .63314 L .62172 .64591 L p 0 .35 .78 r
F P
0 g
s
.62711 .64181 m .66989 .59773 L .60305 .52172 L p .858 0 0 r
F P
0 g
s
.5706 .55001 m .55845 .56223 L .57304 .55641 L p 0 .05 .157 r
F P
0 g
s
.54484 .54681 m .55845 .56223 L .5706 .55001 L p 0 .349 .781 r
F P
0 g
s
.55931 .54084 m .57304 .55641 L .55845 .56223 L p 0 .314 .946 r
F P
0 g
s
.56076 .56878 m .57304 .55641 L .55845 .56223 L p 0 .05 .157 r
F P
0 g
s
.55845 .56223 m .54484 .54681 L .55702 .53462 L p 0 .349 .781 r
F P
0 g
s
.54484 .54681 m .55845 .56223 L .57304 .55641 L p 0 .314 .946 r
F P
0 g
s
.57304 .55641 m .55931 .54084 L .54484 .54681 L p 0 .314 .946 r
F P
0 g
s
.58676 .57196 m .57304 .55641 L .58528 .5441 L p 0 .349 .781 r
F P
0 g
s
.57304 .55641 m .58528 .5441 L .60023 .53806 L p 0 .05 .157 r
F P
0 g
s
.58791 .55049 m .60023 .53806 L .58528 .5441 L p 0 .05 .157 r
F P
0 g
s
.58528 .5441 m .57304 .55641 L .58791 .55049 L p 0 .05 .157 r
F P
0 g
s
.55931 .54084 m .57304 .55641 L .58528 .5441 L p 0 .349 .781 r
F P
0 g
s
.57304 .55641 m .55931 .54084 L .57157 .52855 L p 0 .349 .781 r
F P
0 g
s
.58942 .57869 m .60175 .56619 L .58676 .57196 L p 0 .05 .173 r
F P
0 g
s
.57304 .55641 m .58676 .57196 L .60175 .56619 L p 0 .314 .946 r
F P
0 g
s
.58791 .55049 m .60175 .56619 L .58676 .57196 L p 0 .314 .946 r
F P
0 g
s
.58676 .57196 m .57304 .55641 L .58791 .55049 L p 0 .314 .946 r
F P
0 g
s
.60023 .53806 m .58791 .55049 L .57304 .55641 L p 0 .05 .157 r
F P
0 g
s
.57405 .53476 m .58791 .55049 L .57304 .55641 L p 0 .314 .946 r
F P
0 g
s
.57304 .55641 m .55931 .54084 L .57405 .53476 L p 0 .314 .946 r
F P
0 g
s
.60175 .56619 m .58791 .55049 L .57304 .55641 L p 0 .314 .946 r
F P
0 g
s
.56076 .56878 m .57304 .55641 L .58791 .55049 L p 0 .05 .157 r
F P
0 g
s
.57554 .56296 m .58791 .55049 L .57304 .55641 L p 0 .05 .157 r
F P
0 g
s
.57304 .55641 m .56076 .56878 L .57554 .56296 L p 0 .05 .157 r
F P
0 g
s
.55931 .54084 m .57304 .55641 L .58791 .55049 L p 0 .314 .946 r
F P
0 g
s
.55845 .56223 m .54484 .54681 L .55931 .54084 L p 0 .314 .946 r
F P
0 g
s
.54699 .55319 m .56076 .56878 L .57304 .55641 L p 0 .349 .781 r
F P
0 g
s
.57304 .55641 m .55931 .54084 L .54699 .55319 L p 0 .349 .781 r
F P
0 g
s
.55931 .54084 m .57304 .55641 L .56076 .56878 L p 0 .349 .781 r
F P
0 g
s
.58791 .55049 m .57405 .53476 L .55931 .54084 L p 0 .314 .946 r
F P
0 g
s
.56076 .56878 m .54699 .55319 L .55931 .54084 L p 0 .349 .781 r
F P
0 g
s
.58791 .55049 m .57554 .56296 L .56076 .56878 L p 0 .05 .157 r
F P
0 g
s
.56165 .54722 m .57554 .56296 L .56076 .56878 L p 0 .314 .946 r
F P
0 g
s
.56076 .56878 m .54699 .55319 L .56165 .54722 L p 0 .314 .946 r
F P
0 g
s
.56312 .57549 m .57554 .56296 L .56076 .56878 L p 0 .05 .157 r
F P
0 g
s
.54699 .55319 m .56076 .56878 L .57554 .56296 L p 0 .314 .946 r
F P
0 g
s
.57554 .56296 m .56165 .54722 L .54699 .55319 L p 0 .314 .946 r
F P
0 g
s
.60023 .53806 m .58791 .55049 L .60307 .54445 L p 0 .05 .157 r
F P
0 g
s
.57405 .53476 m .58791 .55049 L .60023 .53806 L p 0 .349 .781 r
F P
0 g
s
.58641 .52236 m .60023 .53806 L .58791 .55049 L p 0 .349 .781 r
F P
0 g
s
.58791 .55049 m .57405 .53476 L .58641 .52236 L p 0 .349 .781 r
F P
0 g
s
.60175 .56619 m .58942 .57869 L .60461 .57291 L p 0 .05 .173 r
F P
0 g
s
.57554 .56296 m .58942 .57869 L .60175 .56619 L p 0 .349 .781 r
F P
0 g
s
.60175 .56619 m .58791 .55049 L .57554 .56296 L p 0 .349 .781 r
F P
0 g
s
.58791 .55049 m .60175 .56619 L .58942 .57869 L p 0 .349 .781 r
F P
0 g
s
.60175 .56619 m .58791 .55049 L .60307 .54445 L p 0 .314 .946 r
F P
0 g
s
.58942 .57869 m .57554 .56296 L .58791 .55049 L p 0 .349 .781 r
F P
0 g
s
.57554 .56296 m .58791 .55049 L .60307 .54445 L p 0 .05 .157 r
F P
0 g
s
.59061 .55703 m .60307 .54445 L .58791 .55049 L p 0 .05 .157 r
F P
0 g
s
.58791 .55049 m .57554 .56296 L .59061 .55703 L p 0 .05 .157 r
F P
0 g
s
.56165 .54722 m .57554 .56296 L .58791 .55049 L p 0 .349 .781 r
F P
0 g
s
.58791 .55049 m .57405 .53476 L .56165 .54722 L p 0 .349 .781 r
F P
0 g
s
.57405 .53476 m .58791 .55049 L .57554 .56296 L p 0 .349 .781 r
F P
0 g
s
.60307 .54445 m .58791 .55049 L p .58885 .53299 L 0 .314 .946 r
F P
0 g
s
.58909 .52857 m .59189 .53175 L p .58885 .53299 L 0 .314 .946 r
F P
0 g
s
.59189 .53175 m .60307 .54445 L p .58885 .53299 L 0 .314 .946 r
F P
0 g
s
.57405 .53476 m .58909 .52857 L p .58885 .53299 L 0 .314 .946 r
F P
0 g
s
.58791 .55049 m .57683 .53791 L p .58885 .53299 L 0 .314 .946 r
F P
0 g
s
.57683 .53791 m .57405 .53476 L p .58885 .53299 L 0 .314 .946 r
F P
0 g
s
.68379 .59287 m .61643 .5162 L .60305 .52172 L p .554 0 0 r
F P
0 g
s
.60305 .52172 m .61643 .5162 L .60724 .52546 L p .191 0 0 r
F P
0 g
s
.57405 .53476 m .58791 .55049 L .60307 .54445 L p 0 .314 .946 r
F P
0 g
s
.60307 .54445 m .58909 .52857 L .57405 .53476 L p 0 .314 .946 r
F P
0 g
s
.57554 .56296 m .56165 .54722 L .57405 .53476 L p 0 .349 .781 r
F P
0 g
s
.59061 .55703 m .60461 .57291 L .58942 .57869 L p 0 .314 .946 r
F P
0 g
s
.58942 .57869 m .57554 .56296 L .59061 .55703 L p 0 .314 .946 r
F P
0 g
s
.59214 .58557 m .60461 .57291 L .58942 .57869 L p 0 .05 .173 r
F P
0 g
s
.57554 .56296 m .58942 .57869 L .60461 .57291 L p 0 .314 .946 r
F P
0 g
s
.58942 .57869 m .60461 .57291 L .59214 .58557 L p 0 .05 .173 r
F P
0 g
s
.60307 .54445 m .59061 .55703 L .57554 .56296 L p 0 .05 .157 r
F P
0 g
s
.59061 .55703 m .57554 .56296 L p .57638 .54553 L 0 .314 .946 r
F P
0 g
s
.57659 .54113 m .5794 .54431 L p .57638 .54553 L 0 .314 .946 r
F P
0 g
s
.5794 .54431 m .59061 .55703 L p .57638 .54553 L 0 .314 .946 r
F P
0 g
s
.56165 .54722 m .57659 .54113 L p .57638 .54553 L 0 .314 .946 r
F P
0 g
s
.57554 .56296 m .56443 .55037 L p .57638 .54553 L 0 .314 .946 r
F P
0 g
s
.56443 .55037 m .56165 .54722 L p .57638 .54553 L 0 .314 .946 r
F P
0 g
s
.60461 .57291 m .59061 .55703 L .57554 .56296 L p 0 .314 .946 r
F P
0 g
s
.56312 .57549 m .57554 .56296 L .59061 .55703 L p 0 .05 .157 r
F P
0 g
s
.57554 .56296 m .56312 .57549 L .5781 .56967 L p 0 .05 .157 r
F P
0 g
s
.5781 .56967 m .59061 .55703 L .57554 .56296 L p 0 .05 .157 r
F P
0 g
s
.56165 .54722 m .57554 .56296 L .59061 .55703 L p 0 .314 .946 r
F P
0 g
s
.54919 .55972 m .56312 .57549 L .57554 .56296 L p 0 .349 .781 r
F P
0 g
s
.57554 .56296 m .56165 .54722 L .54919 .55972 L p 0 .349 .781 r
F P
0 g
s
.56165 .54722 m .57554 .56296 L .56312 .57549 L p 0 .349 .781 r
F P
0 g
s
.59061 .55703 m .57659 .54113 L .56165 .54722 L p 0 .314 .946 r
F P
0 g
s
.56312 .57549 m .54919 .55972 L .56165 .54722 L p 0 .349 .781 r
F P
0 g
s
.5781 .56967 m .59214 .58557 L .57704 .59123 L p 0 .313 .947 r
F P
0 g
s
.57704 .59123 m .59214 .58557 L .58296 .59489 L p 0 .05 .173 r
F P
0 g
s
.58296 .59489 m .57962 .59828 L p .57892 .59639 L 0 .05 .173 r
F P
0 g
s
.57704 .59123 m .58296 .59489 L .57892 .59639 L 0 .05 .173 r
F
.5781 .56967 m .56312 .57549 L p .56489 .58051 L 0 .05 .157 r
F P
0 g
s
.56554 .58235 m .5689 .57897 L p .56489 .58051 L 0 .05 .157 r
F P
0 g
s
.5689 .57897 m .5781 .56967 L p .56489 .58051 L 0 .05 .157 r
F P
0 g
s
.59061 .55703 m .5781 .56967 L .56312 .57549 L p 0 .05 .157 r
F P
0 g
s
.56312 .57549 m .5781 .56967 L p .55493 .56169 L 0 .313 .947 r
F P
0 g
s
.54919 .55972 m .55198 .56287 L p .55493 .56169 L 0 .313 .947 r
F P
0 g
s
.55198 .56287 m .56312 .57549 L p .55493 .56169 L 0 .313 .947 r
F P
0 g
s
.56312 .57549 m .54919 .55972 L .56405 .55374 L p 0 .313 .947 r
F P
0 g
s
.56405 .55374 m .5781 .56967 L .56312 .57549 L p 0 .313 .947 r
F P
0 g
s
.5781 .56967 m .56405 .55374 L .54919 .55972 L p 0 .313 .947 r
F P
0 g
s
.56554 .58235 m .55065 .58807 L p .55793 .58319 L 0 .05 .157 r
F P
0 g
s
.5781 .56967 m .5689 .57897 L p .55793 .58319 L 0 .05 .157 r
F P
0 g
s
.5689 .57897 m .56554 .58235 L p .55793 .58319 L 0 .05 .157 r
F P
0 g
s
.60307 .54445 m .58909 .52857 L .60153 .51606 L p 0 .35 .78 r
F P
0 g
s
.60461 .57291 m .59061 .55703 L .60307 .54445 L p 0 .35 .78 r
F P
0 g
s
.58909 .52857 m .60307 .54445 L .59061 .55703 L p 0 .35 .78 r
F P
0 g
s
.59061 .55703 m .57659 .54113 L .58909 .52857 L p 0 .35 .78 r
F P
0 g
s
.59061 .55703 m .60461 .57291 L .59214 .58557 L p 0 .35 .78 r
F P
0 g
s
.60616 .60145 m .59214 .58557 L .60461 .57291 L p 0 .35 .78 r
F P
0 g
s
.60616 .60145 m .62015 .6173 L .6077 .63006 L p 0 .35 .78 r
F P
0 g
s
.62172 .64591 m .6077 .63006 L .62015 .6173 L p 0 .35 .78 r
F P
0 g
s
.59214 .58557 m .5781 .56967 L .59061 .55703 L p 0 .35 .78 r
F P
0 g
s
.57659 .54113 m .59061 .55703 L .5781 .56967 L p 0 .35 .78 r
F P
0 g
s
.6077 .63006 m .59367 .61418 L .60616 .60145 L p 0 .35 .78 r
F P
0 g
s
.59214 .58557 m .60616 .60145 L .59367 .61418 L p 0 .35 .78 r
F P
0 g
s
.5781 .56967 m .56405 .55374 L .57659 .54113 L p 0 .35 .78 r
F P
0 g
s
.5781 .56967 m .59214 .58557 L .57962 .59828 L p 0 .35 .78 r
F P
0 g
s
.59367 .61418 m .57962 .59828 L .59214 .58557 L p 0 .35 .78 r
F P
0 g
s
.57962 .59828 m .56554 .58235 L .5781 .56967 L p 0 .35 .78 r
F P
0 g
s
.56405 .55374 m .5781 .56967 L .56554 .58235 L p 0 .35 .78 r
F P
0 g
s
.56312 .57549 m .55065 .58807 L .56554 .58235 L p 0 .05 .157 r
F P
0 g
s
.55065 .58807 m .56312 .57549 L p .54198 .57292 L 0 .349 .781 r
F P
0 g
s
.53668 .57227 m .53948 .57543 L p .54198 .57292 L 0 .349 .781 r
F P
0 g
s
.53948 .57543 m .55065 .58807 L p .54198 .57292 L 0 .349 .781 r
F P
0 g
s
.54919 .55972 m .53668 .57227 L p .54198 .57292 L 0 .349 .781 r
F P
0 g
s
.56312 .57549 m .55198 .56287 L p .54198 .57292 L 0 .349 .781 r
F P
0 g
s
.55198 .56287 m .54919 .55972 L p .54198 .57292 L 0 .349 .781 r
F P
0 g
s
.56312 .57549 m .55065 .58807 L p .54948 .56538 L 0 .349 .781 r
F P
0 g
s
.54919 .55972 m .55198 .56287 L p .54948 .56538 L 0 .349 .781 r
F P
0 g
s
.55198 .56287 m .56312 .57549 L p .54948 .56538 L 0 .349 .781 r
F P
0 g
s
.55065 .58807 m .53668 .57227 L .54919 .55972 L p 0 .349 .781 r
F P
0 g
s
.62172 .64591 m .55427 .5696 L .49678 .59229 L p .54 0 0 r
F P
0 g
s
.508 .58368 m .52172 .59916 L .50767 .60455 L p 0 .312 .948 r
F P
0 g
s
.52172 .59916 m .508 .58368 L .5222 .57803 L p 0 .312 .948 r
F P
0 g
s
.5222 .57803 m .53605 .59367 L .52172 .59916 L p 0 .312 .948 r
F P
0 g
s
.53605 .59367 m .5222 .57803 L .53668 .57227 L p 0 .312 .948 r
F P
0 g
s
.53668 .57227 m .55065 .58807 L .53605 .59367 L p 0 .312 .948 r
F P
0 g
s
.52138 .58477 m .53767 .57725 L .51418 .59199 L .191 0 0 r
F
.53668 .57227 m .55145 .5664 L p .55129 .57077 L 0 .312 .948 r
F P
0 g
s
.55065 .58807 m .53948 .57543 L p .55129 .57077 L 0 .312 .948 r
F P
0 g
s
.53948 .57543 m .53668 .57227 L p .55129 .57077 L 0 .312 .948 r
F P
0 g
s
.55145 .5664 m .56405 .55374 L p .56435 .55946 L 0 .35 .78 r
F P
0 g
s
.56554 .58235 m .55427 .5696 L p .56435 .55946 L 0 .35 .78 r
F P
0 g
s
.55427 .5696 m .55145 .5664 L p .56435 .55946 L 0 .35 .78 r
F P
0 g
s
.6232 .64511 m .55571 .56875 L .55427 .5696 L .674 0 0 r
F
.55571 .56875 m .55524 .56921 L .55427 .5696 L .191 0 0 r
F
.55145 .5664 m .56554 .58235 L .55065 .58807 L p 0 .312 .948 r
F P
0 g
s
.59124 .65598 m .60633 .651 L .576 .68218 L p 0 .05 .218 r
F P
0 g
s
.60633 .651 m .59124 .65598 L .57747 .64044 L p 0 .312 .948 r
F P
0 g
s
.59244 .6353 m .57747 .64044 L .56369 .62487 L p 0 .312 .948 r
F P
0 g
s
.57747 .64044 m .59244 .6353 L .60633 .651 L p 0 .312 .948 r
F P
0 g
s
.56369 .62487 m .57853 .61958 L .59244 .6353 L p 0 .312 .948 r
F P
0 g
s
.57853 .61958 m .56369 .62487 L .54988 .60928 L p 0 .312 .948 r
F P
0 g
s
.54988 .60928 m .56461 .60383 L .57853 .61958 L p 0 .312 .948 r
F P
0 g
s
.59117 .67738 m .576 .68218 L .60633 .651 L p 0 .05 .218 r
F P
0 g
s
.60633 .651 m .62172 .64591 L .59117 .67738 L p 0 .05 .218 r
F P
0 g
s
.62172 .64591 m .60633 .651 L .59244 .6353 L p 0 .312 .948 r
F P
0 g
s
.59244 .6353 m .6077 .63006 L .62172 .64591 L p 0 .312 .948 r
F P
0 g
s
.6077 .63006 m .59244 .6353 L .57853 .61958 L p 0 .312 .948 r
F P
0 g
s
.57853 .61958 m .59367 .61418 L .6077 .63006 L p 0 .312 .948 r
F P
0 g
s
.59367 .61418 m .57853 .61958 L .56461 .60383 L p 0 .312 .948 r
F P
0 g
s
.56461 .60383 m .55065 .58807 L .56554 .58235 L p 0 .312 .948 r
F P
0 g
s
.56554 .58235 m .57962 .59828 L .56461 .60383 L p 0 .312 .948 r
F P
0 g
s
.56461 .60383 m .57962 .59828 L .59367 .61418 L p 0 .312 .948 r
F P
0 g
s
.55427 .5696 m .62172 .64591 L .60009 .66819 L p .858 0 0 r
F P
0 g
s
.53543 .61462 m .52172 .59916 L .53605 .59367 L p 0 .312 .948 r
F P
0 g
s
.53605 .59367 m .54988 .60928 L .53543 .61462 L p 0 .312 .948 r
F P
0 g
s
.54988 .60928 m .53605 .59367 L .55065 .58807 L p 0 .312 .948 r
F P
0 g
s
.55065 .58807 m .56461 .60383 L .54988 .60928 L p 0 .312 .948 r
F P
0 g
s
.62172 .64591 m .55427 .5696 L .53232 .59168 L .858 0 0 r
F
.6232 .64511 m .55427 .5696 L .62172 .64591 L .674 0 0 r
F
.57643 .66087 m .56279 .64548 L .57747 .64044 L p 0 .312 .948 r
F P
0 g
s
.57747 .64044 m .59124 .65598 L .57643 .66087 L p 0 .312 .948 r
F P
0 g
s
.54654 .69151 m .57643 .66087 L .59124 .65598 L p 0 .05 .218 r
F P
0 g
s
.56279 .64548 m .54912 .63006 L .56369 .62487 L p 0 .312 .948 r
F P
0 g
s
.56369 .62487 m .57747 .64044 L .56279 .64548 L p 0 .312 .948 r
F P
0 g
s
.54912 .63006 m .53543 .61462 L .54988 .60928 L p 0 .312 .948 r
F P
0 g
s
.54988 .60928 m .56369 .62487 L .54912 .63006 L p 0 .312 .948 r
F P
0 g
s
.59124 .65598 m .56113 .68689 L .54654 .69151 L p 0 .05 .218 r
F P
0 g
s
.576 .68218 m .56113 .68689 L .59124 .65598 L p 0 .05 .218 r
F P
0 g
s
.60009 .66819 m .53232 .59168 L .55427 .5696 L p .858 0 0 r
F P
0 g
s
.55524 .56921 m .53232 .59168 L .55427 .5696 L .191 0 0 r
F
.53767 .57725 m .55427 .5696 L .53405 .58089 L F
.53767 .57725 m .53405 .58089 L .51418 .59199 L F
.52315 .59184 m .55427 .5696 L .53232 .59168 L F
.51418 .59199 m .53405 .58089 L .52315 .59184 L F
.53405 .58089 m .55427 .5696 L .52315 .59184 L F
.52497 .58116 m .53948 .57543 L .52138 .58477 L F
.53948 .57543 m .55427 .5696 L p .53767 .57725 L F P
0 g
s
.53948 .57543 m .53767 .57725 L .52138 .58477 L .191 0 0 r
F
.60305 .52172 m .55963 .56542 L .62711 .64181 L p .858 0 0 r
F P
0 g
s
.59328 .59106 m .58189 .57397 L .58499 .59413 L .541 0 0 r
F
.58189 .57397 m .57274 .56023 L .57821 .57538 L F
.58189 .57397 m .57821 .57538 L .58499 .59413 L F
.57274 .56023 m .55963 .56542 L p .56887 .55613 L .191 0 0 r
F P
0 g
s
.58142 .54349 m .57643 .5531 L .56887 .55613 L .191 0 0 r
F
.57643 .5531 m .57274 .56023 L .56887 .55613 L F
.57091 .57819 m .57274 .56023 L .55963 .56542 L .541 0 0 r
F
.58499 .59413 m .57821 .57538 L .57091 .57819 L F
.57821 .57538 m .57274 .56023 L .57091 .57819 L F
.62711 .64181 m .59328 .59106 L .58499 .59413 L F
.59672 .52977 m .58801 .54083 L .59392 .53091 L .191 0 0 r
F
.58801 .54083 m .57274 .56023 L .58624 .54154 L F
.58801 .54083 m .58624 .54154 L .59392 .53091 L F
.59392 .53091 m .58624 .54154 L .58142 .54349 L F
.58624 .54154 m .57274 .56023 L .58142 .54349 L F
.60724 .52546 m .57274 .56023 L p .59672 .52977 L F P
0 g
s
.60305 .52172 m .60724 .52546 L .59672 .52977 L .191 0 0 r
F
.59392 .53091 m .60305 .52172 L p .59672 .52977 L F P
0 g
s
.64074 .63729 m .62711 .64181 L .58499 .59413 L p .541 0 0 r
F P
0 g
s
.58499 .59413 m .57091 .57819 L p .5883 .59291 L .541 0 0 r
F P
0 g
s
.5883 .59291 m .64074 .63729 L .58499 .59413 L .541 0 0 r
F
.57091 .57819 m .55963 .56542 L p .57309 .57735 L F P
0 g
s
.57309 .57735 m .64074 .63729 L .57091 .57819 L .541 0 0 r
F
.50767 .60455 m .49406 .58922 L .508 .58368 L p 0 .312 .948 r
F P
0 g
s
.51074 .58678 m .52497 .58116 L p .50539 .59214 L .191 0 0 r
F P
0 g
s
.52497 .58116 m .52138 .58477 L .50539 .59214 L .191 0 0 r
F
.50539 .59214 m .52138 .58477 L .51418 .59199 L F
.47546 .61362 m .49678 .59229 L p .50539 .59214 L F P
0 g
s
.53232 .59168 m .48927 .60829 L p .50539 .59214 L .191 0 0 r
F P
0 g
s
.48927 .60829 m .47546 .61362 L p .50539 .59214 L .191 0 0 r
F P
0 g
s
.49678 .59229 m .51074 .58678 L p .50539 .59214 L .191 0 0 r
F P
0 g
s
.62172 .64591 m .53232 .59168 L .60009 .66819 L .858 0 0 r
F
.64091 .64703 m .63682 .66301 L .62172 .64591 L closepath p 0 .35 .78 r
F P
0 g
s
.60608 .67274 m .6209 .68947 L .60584 .69404 L p 0 .312 .948 r
F P
0 g
s
.6209 .68947 m .60584 .69404 L .57614 .72479 L p 0 .05 .248 r
F P
0 g
s
.60584 .69404 m .6209 .68947 L .60608 .67274 L p 0 .312 .948 r
F P
0 g
s
.60584 .69404 m .59106 .69852 L .56156 .72901 L p 0 .05 .248 r
F P
0 g
s
.56156 .72901 m .57614 .72479 L .60584 .69404 L p 0 .05 .248 r
F P
0 g
s
.57614 .72479 m .59099 .7205 L .6209 .68947 L p 0 .05 .248 r
F P
0 g
s
.59099 .7205 m .6209 .68947 L .60608 .67274 L p 0 .349 .781 r
F P
0 g
s
.64025 .65876 m .64516 .66432 L .6209 .68947 L p 0 .349 .781 r
F P
0 g
s
.66068 .65944 m .64516 .66432 L .6209 .68947 L p 0 .05 .248 r
F P
0 g
s
.6209 .68947 m .63626 .68482 L .66068 .65944 L p 0 .05 .248 r
F P
0 g
s
.60608 .67274 m .6209 .68947 L .63626 .68482 L p 0 .312 .948 r
F P
0 g
s
.6209 .68947 m .60608 .67274 L .62131 .66792 L p 0 .312 .948 r
F P
0 g
s
.62131 .66792 m .63626 .68482 L .6209 .68947 L p 0 .312 .948 r
F P
0 g
s
.60608 .67274 m .6209 .68947 L .59099 .7205 L p 0 .349 .781 r
F P
0 g
s
.63626 .68482 m .62131 .66792 L .60608 .67274 L p 0 .312 .948 r
F P
0 g
s
.6765 .65447 m .66068 .65944 L .63626 .68482 L p 0 .05 .248 r
F P
0 g
s
.63626 .68482 m .65191 .68008 L .6765 .65447 L p 0 .05 .248 r
F P
0 g
s
.62131 .66792 m .63626 .68482 L .65191 .68008 L p 0 .312 .948 r
F P
0 g
s
.65191 .68008 m .63626 .68482 L .62131 .66792 L p 0 .312 .948 r
F P
0 g
s
.65191 .68008 m .63682 .66301 L .62131 .66792 L p 0 .312 .948 r
F P
0 g
s
.62131 .66792 m .63682 .66301 L .65191 .68008 L p 0 .312 .948 r
F P
0 g
s
.62172 .64591 m .63682 .66301 L .60638 .69453 L p 0 .35 .78 r
F P
0 g
s
.58483 .69467 m .60608 .67274 L p .5805 .68978 L 0 .349 .781 r
F P
0 g
s
.60608 .67274 m .57607 .70371 L .59099 .7205 L p 0 .349 .781 r
F P
0 g
s
.59099 .7205 m .57607 .70371 L .60608 .67274 L p 0 .349 .781 r
F P
0 g
s
.60638 .69453 m .59117 .67738 L .62172 .64591 L p 0 .35 .78 r
F P
0 g
s
.6232 .64511 m .62172 .64591 L .60009 .66819 L .262 0 0 r
F
.6232 .64511 m .60009 .66819 L .61118 .66224 L F
.61118 .66224 m .60009 .66819 L .53232 .59168 L .671 0 0 r
F
.61118 .66224 m .57723 .62388 L .56627 .63001 L F
.57723 .62388 m .53232 .59168 L .54316 .58538 L F
.61118 .66224 m .57174 .62695 L .57723 .62388 L F
.57174 .62695 m .53232 .59168 L .57723 .62388 L F
.62517 .64361 m .6232 .64511 L .61118 .66224 L .262 0 0 r
F
.62517 .64361 m .61118 .66224 L .62609 .65091 L F
.62609 .65091 m .61118 .66224 L .54316 .58538 L .776 0 0 r
F
.62609 .65091 m .5921 .61245 L .57723 .62388 L F
.5921 .61245 m .54316 .58538 L .55798 .57384 L F
.62609 .65091 m .58466 .61817 L .5921 .61245 L F
.58466 .61817 m .54316 .58538 L .5921 .61245 L F
.62517 .64361 m .55571 .56875 L .6232 .64511 L F
.62711 .64181 m .55768 .56722 L .62517 .64361 L .832 0 0 r
F
.62711 .64181 m .55963 .56542 L .55768 .56722 L F
.62711 .64181 m .64074 .63729 L .57274 .56023 L .541 0 0 r
F
.62517 .64361 m .55768 .56722 L .55571 .56875 L .776 0 0 r
F
.55963 .56542 m .57274 .56023 L .64074 .63729 L p .541 0 0 r
F P
0 g
s
.64074 .63729 m .55798 .57384 L .57274 .56023 L .832 0 0 r
F
.62711 .64181 m .62609 .65091 L .64074 .63729 L .262 0 0 r
F
.62711 .64181 m .62517 .64361 L .62609 .65091 L F
.64074 .63729 m .62609 .65091 L .55798 .57384 L .832 0 0 r
F
.64074 .63729 m .6068 .59883 L .5921 .61245 L F
.6068 .59883 m .60403 .60328 L .5921 .61245 L .228 0 0 r
F
.64074 .63729 m .5921 .61245 L .62609 .65091 L .832 0 0 r
F
.60403 .60328 m .59288 .6212 L .5921 .61245 L .228 0 0 r
F
.5921 .61245 m .58606 .61895 L .57723 .62388 L F
.56627 .63001 m .60009 .66819 L p .53669 .64043 L .533 0 0 r
F P
0 g
s
.60009 .66819 m .56627 .63001 L .53669 .64043 L p .533 0 0 r
F P
0 g
s
.58038 .65956 m .56191 .66567 L p .60009 .66819 L .262 0 0 r
F P
0 g
s
.57643 .66087 m .54654 .69151 L .53222 .69604 L p 0 .05 .218 r
F P
0 g
s
.55332 .65916 m .60009 .66819 L .53669 .64043 L .533 0 0 r
F
.56191 .66567 m .54088 .68717 L .60009 .66819 L p .262 0 0 r
F P
0 g
s
.56992 .67787 m .60009 .66819 L p .55332 .65916 L .533 0 0 r
F P
0 g
s
.60009 .66819 m .56992 .67787 L p .53669 .64043 L .533 0 0 r
F P
0 g
s
.53178 .75979 m .56156 .72901 L .5469 .71254 L p 0 .349 .782 r
F P
0 g
s
.57607 .70371 m .56113 .68689 L p .5522 .71482 L 0 .349 .781 r
F P
0 g
s
.54576 .73498 m .55847 .72187 L p .5522 .71482 L 0 .349 .781 r
F P
0 g
s
.55847 .72187 m .57607 .70371 L p .5522 .71482 L 0 .349 .781 r
F P
0 g
s
.54088 .68717 m .50716 .7114 L .51481 .71385 L .262 0 0 r
F
.54088 .68717 m .53704 .68613 L .50716 .7114 L F
.51481 .71385 m .54088 .68717 L .50823 .65046 L p .856 0 0 r
F P
0 g
s
.54088 .68717 m .51481 .71385 L .48197 .67703 L .856 0 0 r
F
.50823 .65046 m .48197 .67703 L .51481 .71385 L p F P
0 g
s
.51481 .71385 m .48197 .67703 L p .52678 .68626 L .524 0 0 r
F P
0 g
s
.51702 .74327 m .5469 .71254 L .53222 .69604 L p 0 .349 .782 r
F P
0 g
s
.53222 .69604 m .50224 .72671 L .51702 .74327 L p 0 .349 .782 r
F P
0 g
s
.56113 .68689 m .57607 .70371 L .55847 .72187 L p 0 .349 .781 r
F P
0 g
s
.55847 .72187 m .54576 .73498 L p .5522 .71482 L 0 .349 .781 r
F P
0 g
s
.56113 .68689 m .55847 .72187 L .5522 .71482 L 0 .349 .781 r
F
.5469 .71254 m .51702 .74327 L .53178 .75979 L p 0 .349 .782 r
F P
0 g
s
.56113 .68689 m .53072 .71811 L .54576 .73498 L p 0 .349 .781 r
F P
0 g
s
.54576 .73498 m .53072 .71811 L .56113 .68689 L p 0 .349 .781 r
F P
0 g
s
.54088 .68717 m .53927 .68883 L p .57326 .69583 L .262 0 0 r
F P
0 g
s
.53927 .68883 m .51481 .71385 L p .57326 .69583 L .262 0 0 r
F P
0 g
s
.5601 .68101 m .54088 .68717 L p .57326 .69583 L .262 0 0 r
F P
0 g
s
.57326 .69583 m .60009 .66819 L .5601 .68101 L p .262 0 0 r
F P
0 g
s
.50823 .65046 m .54088 .68717 L .56992 .67787 L p .533 0 0 r
F P
0 g
s
.50823 .65046 m .56992 .67787 L .55332 .65916 L .533 0 0 r
F
.56992 .67787 m .54088 .68717 L p .53669 .64043 L F P
0 g
s
.54088 .68717 m .48197 .67703 L .50823 .65046 L .856 0 0 r
F
.51634 .72245 m .54654 .69151 L .56113 .68689 L p 0 .05 .218 r
F P
0 g
s
.56113 .68689 m .53072 .71811 L .51634 .72245 L p 0 .05 .218 r
F P
0 g
s
.54537 .71368 m .53072 .71811 L .56113 .68689 L p 0 .05 .218 r
F P
0 g
s
.56113 .68689 m .576 .68218 L .54537 .71368 L p 0 .05 .218 r
F P
0 g
s
.56031 .70916 m .54537 .71368 L .576 .68218 L p 0 .05 .218 r
F P
0 g
s
.576 .68218 m .59117 .67738 L .56031 .70916 L p 0 .05 .218 r
F P
0 g
s
.53923 .65753 m .57326 .69583 L p .52678 .68626 L .524 0 0 r
F P
0 g
s
.48197 .67703 m .51005 .66747 L p .52678 .68626 L .524 0 0 r
F P
0 g
s
.51005 .66747 m .53923 .65753 L p .52678 .68626 L .524 0 0 r
F P
0 g
s
.50224 .72671 m .53222 .69604 L .54654 .69151 L p 0 .05 .218 r
F P
0 g
s
.54654 .69151 m .51634 .72245 L .50224 .72671 L p 0 .05 .218 r
F P
0 g
s
.57326 .69583 m .54347 .70501 L p .52678 .68626 L .524 0 0 r
F P
0 g
s
.54347 .70501 m .51481 .71385 L p .52678 .68626 L .524 0 0 r
F P
0 g
s
.56627 .63001 m .60009 .66819 L .57326 .69583 L p .858 0 0 r
F P
0 g
s
.53669 .64043 m .50823 .65046 L p .55332 .65916 L .533 0 0 r
F P
0 g
s
.60009 .66819 m .56627 .63001 L .53923 .65753 L .858 0 0 r
F
.61118 .66224 m .56627 .63001 L .60009 .66819 L .671 0 0 r
F
.57326 .69583 m .53923 .65753 L .56627 .63001 L p .858 0 0 r
F P
0 g
s
.62609 .65091 m .57723 .62388 L .61118 .66224 L .776 0 0 r
F
.58606 .61895 m .56186 .645 L .57723 .62388 L .228 0 0 r
F
.57723 .62388 m .57299 .62764 L .56627 .63001 L F
.57299 .62764 m .53923 .65753 L .56627 .63001 L F
.53232 .59168 m .56627 .63001 L p .53669 .64043 L .533 0 0 r
F P
0 g
s
.47546 .61362 m .50334 .60286 L p .53669 .64043 L .533 0 0 r
F P
0 g
s
.52126 .61987 m .50767 .60455 L .52172 .59916 L p 0 .312 .948 r
F P
0 g
s
.50334 .60286 m .53232 .59168 L p .53669 .64043 L .533 0 0 r
F P
0 g
s
.57607 .70371 m .58483 .69467 L p .5805 .68978 L 0 .349 .781 r
F P
0 g
s
.53923 .65753 m .53895 .65762 L p .50823 .65046 L .228 0 0 r
F P
0 g
s
.53895 .65762 m .48197 .67703 L .50823 .65046 L p .228 0 0 r
F P
0 g
s
.50823 .65046 m .50146 .65541 L .50455 .6496 L .228 0 0 r
F
.50146 .65541 m .47466 .67497 L .50455 .6496 L F
.50639 .65003 m .50455 .6496 L .47195 .61295 L .1 0 0 r
F
.50455 .6496 m .48285 .65994 L .49959 .64845 L .228 0 0 r
F
0 g
.48353 .65917 m
.49419 .64719 L
s
.49419 .64719 m
.49829 .64257 L
s
.50455 .6496 m .47466 .67497 L .48285 .65994 L .228 0 0 r
F
0 g
.48285 .65994 m
.48353 .65917 L
s
.47268 .25214 m .48621 .24353 L .48623 .22194 L p 0 .181 .719 r
F P
0 g
s
.48621 .24353 m .47268 .25214 L .47265 .27358 L p 0 .181 .719 r
F P
0 g
s
.44356 .24034 m .45812 .25697 L .47268 .25214 L p 0 .349 .782 r
F P
0 g
s
.47265 .27358 m .47268 .25214 L .45812 .25697 L closepath p 0 .349 .782 r
F P
0 g
s
.47265 .27358 m .4862 .26516 L .50084 .25132 L p 0 .05 .1 r
F P
0 g
s
.47268 .25214 m .48621 .24353 L .4862 .26516 L p 0 .181 .719 r
F P
0 g
s
.4862 .26516 m .47265 .27358 L .47268 .25214 L p 0 .181 .719 r
F P
0 g
s
.47265 .27358 m .4862 .26516 L .48621 .24353 L p 0 .181 .719 r
F P
0 g
s
.4862 .26516 m .47265 .27358 L .45812 .25697 L p 0 .318 .938 r
F P
0 g
s
.45812 .25697 m .47265 .27358 L .4862 .26516 L p 0 .318 .938 r
F P
0 g
s
.76712 .51951 m .78362 .52071 L .75582 .54954 L closepath p 0 .349 .781 r
F P
0 g
s
.76712 .51951 m .78362 .52071 L .80008 .51461 L p 0 .458 1 r
F P
0 g
s
.78362 .52071 m .76712 .51951 L .78345 .51338 L p 0 .458 1 r
F P
0 g
s
.78345 .51338 m .80008 .51461 L .78362 .52071 L p 0 .458 1 r
F P
0 g
s
.7721 .54368 m .80008 .51461 L .78362 .52071 L p 0 .05 .248 r
F P
0 g
s
.78362 .52071 m .75582 .54954 L .7721 .54368 L p 0 .05 .248 r
F P
0 g
s
.75582 .54954 m .78362 .52071 L .76712 .51951 L closepath p 0 .349 .781 r
F P
0 g
s
.48881 .59726 m
.49022 .59885 L
s
.47154 .24839 m .45812 .25697 L .44356 .24034 L p 0 .318 .938 r
F P
0 g
s
.45812 .25697 m .47154 .24839 L .4862 .26516 L p 0 .318 .938 r
F P
0 g
s
.4282 .28509 m .45812 .25697 L .44356 .24034 L p 0 .349 .782 r
F P
0 g
s
.44356 .24034 m .45812 .25697 L .47154 .24839 L p 0 .318 .938 r
F P
0 g
s
.45812 .25697 m .4282 .28509 L .44283 .30176 L p 0 .349 .782 r
F P
0 g
s
.4862 .26516 m .47154 .24839 L .45812 .25697 L p 0 .318 .938 r
F P
0 g
s
.33235 .46535 m
.33235 .46535 L
s
.33235 .46535 m
.3367 .46092 L
s
.32302 .41057 m .31015 .41813 L .34274 .45479 L .541 0 0 r
F
.34274 .45479 m .31015 .41813 L .32302 .41057 L p F P
0 g
s
.34213 .4554 m
.34274 .45479 L
s
.34274 .45479 m
.34926 .45123 L
s
.44356 .24034 m .45685 .2316 L .47154 .24839 L p 0 .318 .938 r
F P
0 g
s
.44356 .24034 m .41355 .2684 L .4282 .28509 L p 0 .349 .782 r
F P
0 g
s
.47154 .24839 m .45685 .2316 L .44356 .24034 L p 0 .318 .938 r
F P
0 g
s
.44356 .24034 m .45685 .2316 L .42663 .25988 L p 0 .05 .1 r
F P
0 g
s
.42663 .25988 m .41355 .2684 L .44356 .24034 L p 0 .05 .1 r
F P
0 g
s
.80008 .51461 m .77123 .48144 L .75502 .48786 L p 0 .319 .936 r
F P
0 g
s
.77123 .48144 m .75502 .48786 L .74106 .50219 L p 0 .05 .218 r
F P
0 g
s
.72579 .45429 m .75502 .48786 L .77123 .48144 L p 0 .319 .936 r
F P
0 g
s
.74106 .50219 m .75502 .48786 L .77123 .48144 L p 0 .05 .218 r
F P
0 g
s
.80008 .51461 m .78345 .51338 L .76712 .51951 L p 0 .458 1 r
F P
0 g
s
.7633 .51189 m .78345 .51338 L .76712 .51951 L p 0 .458 1 r
F P
0 g
s
.60404 .46585 m .62572 .49056 L .56624 .51593 L p .562 0 0 r
F P
0 g
s
.54623 .4932 m
.56624 .51593 L
s
.5559 .51531 m
.56624 .51593 L
s
.54543 .54362 m
.54664 .545 L
s
.55594 .52898 m
.56627 .52277 L
s
.55258 .53647 m
.56627 .52277 L
s
.32302 .41057 m .28749 .4407 L .31015 .41813 L .1 0 0 r
F
0 g
.29964 .42859 m
.29964 .42859 L
s
.31185 .42004 m
.34274 .45479 L
s
.36637 .36964 m .32302 .41057 L .31015 .41813 L p .1 0 0 r
F P
0 g
s
.29964 .42859 m
.31015 .41813 L
s
.5154 .23755 m .54501 .27151 L .55927 .26305 L p 0 .319 .936 r
F P
0 g
s
.77123 .48144 m .74175 .44754 L .72579 .45429 L p 0 .319 .936 r
F P
0 g
s
.54263 .49481 m .53052 .48107 L .54467 .47457 L p 0 .316 .943 r
F P
0 g
s
.54467 .47457 m .55688 .48844 L .54263 .49481 L p 0 .316 .943 r
F P
0 g
s
.53052 .48107 m .54263 .49481 L .55688 .48844 L p 0 .316 .943 r
F P
0 g
s
.54263 .49481 m .5421 .49534 L p .55149 .4938 L 0 .05 .112 r
F P
0 g
s
.55149 .4938 m .55688 .48844 L .54263 .49481 L p 0 .05 .112 r
F P
0 g
s
.5421 .49534 m .54263 .49481 L .53052 .48107 L p 0 .349 .782 r
F P
0 g
s
.5319 .49392 m .5401 .49887 L .5421 .49534 L p 0 .332 .562 r
F P
0 g
s
.52549 .48932 m .5319 .49392 L p .5421 .49534 L 0 .332 .562 r
F P
0 g
s
.5421 .49534 m .52999 .4816 L .52549 .48932 L p 0 .332 .562 r
F P
0 g
s
.5421 .49534 m .5401 .49887 L .55149 .4938 L p 0 .05 .112 r
F P
0 g
s
.53052 .48107 m .52999 .4816 L .5421 .49534 L p 0 .349 .782 r
F P
0 g
s
.49319 .59174 m
.49548 .59083 L
s
.74106 .50219 m .75718 .49588 L .77123 .48144 L p 0 .05 .218 r
F P
0 g
s
.75718 .49588 m .74106 .50219 L .72704 .51658 L p 0 .05 .218 r
F P
0 g
s
.69762 .4829 m .72704 .51658 L .74106 .50219 L p 0 .349 .781 r
F P
0 g
s
.77123 .48144 m .75718 .49588 L .74106 .50219 L p 0 .05 .218 r
F P
0 g
s
.72704 .51658 m .74106 .50219 L .75718 .49588 L p 0 .05 .218 r
F P
0 g
s
.74106 .50219 m .72704 .51658 L .69762 .4829 L p 0 .349 .781 r
F P
0 g
s
.53052 .48107 m .5184 .46731 L .53244 .46067 L p 0 .316 .943 r
F P
0 g
s
.53244 .46067 m .54467 .47457 L .53052 .48107 L p 0 .316 .943 r
F P
0 g
s
.55688 .48844 m .54467 .47457 L .53052 .48107 L p 0 .316 .943 r
F P
0 g
s
.52999 .4816 m .53052 .48107 L .54467 .47457 L p 0 .05 .1 r
F P
0 g
s
.5184 .46731 m .53052 .48107 L .54467 .47457 L p 0 .316 .943 r
F P
0 g
s
.53052 .48107 m .52999 .4816 L p .53339 .48572 L 0 .05 .1 r
F P
0 g
s
.53339 .48572 m .54467 .47457 L .53052 .48107 L p 0 .05 .1 r
F P
0 g
s
.52999 .4816 m .53052 .48107 L .5184 .46731 L p 0 .349 .782 r
F P
0 g
s
.52549 .48932 m .52999 .4816 L p .54467 .47457 L 0 .05 .1 r
F P
0 g
s
.52999 .4816 m .52549 .48932 L .53339 .48572 L p 0 .05 .1 r
F P
0 g
s
.5184 .46731 m .51786 .46784 L .52999 .4816 L p 0 .349 .782 r
F P
0 g
s
.52467 .48874 m .52549 .48932 L .52999 .4816 L p 0 .332 .562 r
F P
0 g
s
.51821 .48319 m .52467 .48874 L p .52999 .4816 L 0 .332 .562 r
F P
0 g
s
.51232 .47711 m .51821 .48319 L p .52999 .4816 L 0 .332 .562 r
F P
0 g
s
.52999 .4816 m .51786 .46784 L .51232 .47711 L p 0 .332 .562 r
F P
0 g
s
.48624 .2041 m .5154 .23755 L .52941 .22875 L p 0 .319 .936 r
F P
0 g
s
.55927 .26305 m .52941 .22875 L .5154 .23755 L p 0 .319 .936 r
F P
0 g
s
.5154 .23755 m .52941 .22875 L .51474 .24264 L p 0 .05 .1 r
F P
0 g
s
.51474 .24264 m .52941 .22875 L .5154 .23755 L p 0 .05 .1 r
F P
0 g
s
.51474 .24264 m .50084 .25132 L .5154 .23755 L p 0 .05 .1 r
F P
0 g
s
.5154 .23755 m .50084 .25132 L .51474 .24264 L p 0 .05 .1 r
F P
0 g
s
.74144 .53308 m .75582 .54954 L .7721 .54368 L p 0 .318 .938 r
F P
0 g
s
.7721 .54368 m .75582 .54954 L .72724 .57919 L p 0 .05 .248 r
F P
0 g
s
.75759 .52705 m .7721 .54368 L .75582 .54954 L p 0 .318 .938 r
F P
0 g
s
.75582 .54954 m .74144 .53308 L .75759 .52705 L p 0 .318 .938 r
F P
0 g
s
.54467 .47457 m .53244 .46067 L .5184 .46731 L p 0 .316 .943 r
F P
0 g
s
.51786 .46784 m .5184 .46731 L .53244 .46067 L p 0 .05 .1 r
F P
0 g
s
.5202 .44676 m .53244 .46067 L .5184 .46731 L p 0 .316 .943 r
F P
0 g
s
.5184 .46731 m .50626 .45353 L .5202 .44676 L p 0 .316 .943 r
F P
0 g
s
.50626 .45353 m .5184 .46731 L .53244 .46067 L p 0 .316 .943 r
F P
0 g
s
.51886 .47404 m .53244 .46067 L .5184 .46731 L p 0 .05 .1 r
F P
0 g
s
.51232 .47711 m .51886 .47404 L p .5184 .46731 L 0 .05 .1 r
F P
0 g
s
.5184 .46731 m .51786 .46784 L .51232 .47711 L p 0 .05 .1 r
F P
0 g
s
.51786 .46784 m .5184 .46731 L .50626 .45353 L p 0 .349 .782 r
F P
0 g
s
.51232 .47711 m .51786 .46784 L p .53244 .46067 L 0 .05 .1 r
F P
0 g
s
.50626 .45353 m .50572 .45406 L .51786 .46784 L p 0 .349 .782 r
F P
0 g
s
.51786 .46784 m .50572 .45406 L .50107 .46163 L p 0 .332 .562 r
F P
0 g
s
.51232 .47711 m .51786 .46784 L p .50107 .46163 L 0 .332 .562 r
F P
0 g
s
.38045 .35692 m
.38051 .35687 L
s
.37919 .36139 m .36637 .36964 L .38045 .35692 L .1 0 0 r
F
.38103 .35986 m .37919 .36139 L .38045 .35692 L F
0 g
.38045 .35692 m
.38051 .35687 L
s
.41299 .65605 m .38418 .62918 L .35101 .66197 L .83 0 0 r
F
.41206 .63965 m .38418 .62918 L .41299 .65605 L .521 0 0 r
F
.4119 .63684 m .40878 .63598 L .41206 .63965 L F
.40878 .63598 m .38418 .62918 L .41206 .63965 L F
.43091 .59098 m .38835 .54319 L p .37642 .59976 L .856 0 0 r
F P
0 g
s
.4119 .63684 m .39783 .62372 L .38418 .62918 L .521 0 0 r
F
.39783 .62372 m .35101 .66197 L .38418 .62918 L .157 0 0 r
F
.36439 .65681 m .39783 .62372 L .38418 .62918 L p F P
0 g
s
.38418 .62918 m .35101 .66197 L .36439 .65681 L p .157 0 0 r
F P
0 g
s
.35101 .66197 m .38418 .62918 L .34171 .5817 L p .855 0 0 r
F P
0 g
s
.34171 .5817 m .38418 .62918 L .39185 .62611 L p .521 0 0 r
F P
0 g
s
.39185 .62611 m .39783 .62372 L p .38071 .61091 L .521 0 0 r
F P
0 g
s
.34171 .5817 m .39185 .62611 L .38071 .61091 L .521 0 0 r
F
.34171 .5817 m .28592 .58427 L .30823 .61432 L .879 0 0 r
F
.34171 .5817 m .31965 .55168 L .28592 .58427 L F
.35038 .57781 m .31965 .55168 L .34171 .5817 L .521 0 0 r
F
.35496 .57575 m .34784 .5709 L .35038 .57781 L F
.34784 .5709 m .31965 .55168 L .35038 .57781 L F
.33415 .56156 m .33575 .55785 L .31965 .55168 L F
.33575 .55785 m .31008 .52619 L .31965 .55168 L F
.34423 .5611 m .33737 .55409 L .33575 .55785 L F
.33737 .55409 m .31008 .52619 L .33575 .55785 L F
.37334 .51614 m .3764 .50928 L .34258 .54201 L .94 0 0 r
F
.34423 .5611 m .33967 .54875 L .33537 .54547 L .521 0 0 r
F
.33099 .54757 m .33537 .54547 L .31008 .52619 L F
.34423 .5611 m .33537 .54547 L .33099 .54757 L F
.33967 .54875 m .3158 .51201 L .31008 .52619 L F
.33967 .54875 m .34258 .54201 L .3158 .51201 L F
.34113 .54539 m .34258 .54201 L .3084 .5751 L .94 0 0 r
F
.37334 .51614 m .34258 .54201 L .34113 .54539 L F
.33967 .54875 m .3084 .5751 L .30564 .58171 L F
.37334 .51614 m .34113 .54539 L .33967 .54875 L F
.34113 .54539 m .3084 .5751 L .33967 .54875 L F
.34784 .5709 m .34423 .5611 L .33575 .55785 L .521 0 0 r
F
.34784 .5709 m .33575 .55785 L .33415 .56156 L F
.37774 .52855 m .37334 .51614 L .33967 .54875 L .94 0 0 r
F
.34195 .55494 m .33967 .54875 L .30564 .58171 L F
.37774 .52855 m .33967 .54875 L .34195 .55494 L F
.37774 .52855 m .34195 .55494 L .34423 .5611 L F
.34195 .55494 m .30564 .58171 L .34423 .5611 L F
.35496 .57575 m .34423 .5611 L .34784 .5709 L .521 0 0 r
F
.38835 .54319 m .37774 .52855 L .31035 .59399 L .88 0 0 r
F
.34423 .5611 m .30564 .58171 L .33967 .54875 L .94 0 0 r
F
.39953 .53802 m .37774 .52855 L .38835 .54319 L .532 0 0 r
F
.39811 .53606 m .37334 .51614 L .37774 .52855 L F
.39953 .53802 m .39811 .53606 L .37774 .52855 L F
.39695 .53397 m .3764 .50928 L .37334 .51614 L F
.39753 .5344 m .3971 .5339 L .39695 .53397 L F
.3971 .5339 m .3764 .50928 L .39695 .53397 L F
.41314 .54472 m .4137 .54418 L .4013 .53024 L p 0 .349 .782 r
F P
0 g
s
.4013 .53024 m .4137 .54418 L .43056 .53072 L p 0 .346 .852 r
F P
0 g
s
.4013 .53024 m .40074 .53078 L .41314 .54472 L p 0 .349 .782 r
F P
0 g
s
.42146 .52725 m .40893 .52412 L .4013 .53024 L p 0 .346 .852 r
F P
0 g
s
.43056 .53072 m .42146 .52725 L p .4013 .53024 L 0 .346 .852 r
F P
0 g
s
.40893 .52412 m .42146 .52725 L .43014 .52324 L p 0 .4 1 r
F P
0 g
s
.41314 .54472 m .40074 .53078 L .41389 .52464 L p 0 .311 .95 r
F P
0 g
s
.43172 .53117 m .43056 .53072 L .4137 .54418 L p 0 .346 .852 r
F P
0 g
s
.43999 .53599 m .43172 .53117 L p .4137 .54418 L 0 .346 .852 r
F P
0 g
s
.43056 .53072 m .4137 .54418 L p .4264 .53872 L 0 .05 .1 r
F P
0 g
s
.43056 .53072 m .43172 .53117 L .43906 .52782 L p 0 .379 1 r
F P
0 g
s
.43906 .52782 m .43805 .5273 L .43056 .53072 L p 0 .379 1 r
F P
0 g
s
.43172 .53117 m .43999 .53599 L .44655 .53304 L p 0 .354 1 r
F P
0 g
s
.44655 .53304 m .43906 .52782 L .43172 .53117 L p 0 .354 1 r
F P
0 g
s
.4137 .54418 m .43056 .53072 L .43805 .5273 L p 0 .05 .1 r
F P
0 g
s
.42553 .55865 m .42608 .5581 L .4137 .54418 L p 0 .349 .782 r
F P
0 g
s
.4137 .54418 m .42608 .5581 L .44652 .54187 L p 0 .346 .852 r
F P
0 g
s
.4137 .54418 m .41314 .54472 L .42553 .55865 L p 0 .349 .782 r
F P
0 g
s
.44652 .54187 m .43999 .53599 L p .4137 .54418 L 0 .346 .852 r
F P
0 g
s
.41314 .54472 m .4137 .54418 L p .43805 .5273 L 0 .05 .1 r
F P
0 g
s
.43805 .5273 m .4264 .53872 L .41314 .54472 L p 0 .05 .1 r
F P
0 g
s
.4264 .53872 m .41389 .52464 L .40074 .53078 L p 0 .311 .95 r
F P
0 g
s
.40074 .53078 m .41389 .52464 L p .40844 .52862 L 0 .05 .1 r
F P
0 g
s
.38835 .54319 m .3496 .56843 L .35496 .57575 L .88 0 0 r
F
.38835 .54319 m .43091 .59098 L .44241 .58622 L p .532 0 0 r
F P
0 g
s
.34171 .5817 m .30823 .61432 L .35101 .66197 L p .855 0 0 r
F P
0 g
s
.39783 .62372 m .35496 .57575 L .34171 .5817 L p .521 0 0 r
F P
0 g
s
.39783 .62372 m .36439 .65681 L .35101 .66197 L .157 0 0 r
F
.38835 .54319 m .32121 .60866 L .36439 .65681 L p .856 0 0 r
F P
0 g
s
.35496 .57575 m .39783 .62372 L .36439 .65681 L p .856 0 0 r
F P
0 g
s
.36439 .65681 m .32121 .60866 L .35496 .57575 L p .856 0 0 r
F P
0 g
s
.36439 .65681 m .39783 .62372 L p .37642 .59976 L .856 0 0 r
F P
0 g
s
.39783 .62372 m .43091 .59098 L p .37642 .59976 L .856 0 0 r
F P
0 g
s
.44494 .60401 m .43091 .59098 L .36439 .65681 L .831 0 0 r
F
.4443 .58797 m .43091 .59098 L .44494 .60401 L .532 0 0 r
F
.4443 .58797 m .44241 .58622 L .43091 .59098 L F
.4119 .63684 m .36439 .65681 L .39783 .62372 L .831 0 0 r
F
.44241 .58622 m .36439 .65681 L .43091 .59098 L .157 0 0 r
F
.41299 .65605 m .35101 .66197 L .37992 .68903 L .83 0 0 r
F
.44494 .60401 m .36439 .65681 L .37852 .67003 L .831 0 0 r
F
.4119 .63684 m .37852 .67003 L .36439 .65681 L F
.44241 .58622 m .43091 .59098 L p .42182 .60108 L .157 0 0 r
F P
0 g
s
.44144 .67318 m .41299 .65605 L .37992 .68903 L .765 0 0 r
F
.42804 .64922 m .41299 .65605 L .44144 .67318 L .521 0 0 r
F
.42576 .64513 m .41551 .6539 L .42804 .64922 L F
.41551 .6539 m .41299 .65605 L .42804 .64922 L F
.43573 .64635 m .44144 .67318 L .46217 .67596 L F
.43573 .64635 m .42576 .64513 L .44144 .67318 L F
.44144 .67318 m .37992 .68903 L .40833 .70645 L .765 0 0 r
F
.46217 .67596 m .44144 .67318 L .40833 .70645 L .589 0 0 r
F
.46217 .67596 m .40833 .70645 L .42885 .70956 L F
.42885 .70956 m .46217 .67596 L .43573 .64635 L p .856 0 0 r
F P
0 g
s
.50823 .65046 m .48197 .67703 L .47466 .67497 L .228 0 0 r
F
.43573 .64635 m .46217 .67596 L .46243 .67587 L p .521 0 0 r
F P
0 g
s
.46243 .67587 m .51878 .65638 L p .47658 .65128 L .521 0 0 r
F P
0 g
s
.43573 .64635 m .46243 .67587 L .47658 .65128 L .521 0 0 r
F
.4963 .59221 m .47195 .61295 L .47595 .60592 L .191 0 0 r
F
.49678 .59229 m .47195 .61295 L .4963 .59221 L F
.49678 .59229 m .47546 .61362 L .47195 .61295 L F
.50823 .65046 m .56627 .63001 L .53923 .65753 L p .228 0 0 r
F P
0 g
s
.49138 .62556 m .43573 .64635 L p .47658 .65128 L .521 0 0 r
F P
0 g
s
.51878 .65638 m .49138 .62556 L p .47658 .65128 L .521 0 0 r
F P
0 g
s
.49978 .62243 m .51878 .65638 L .52696 .64299 L .521 0 0 r
F
.49138 .62556 m .52552 .59125 L p .46301 .63616 L .187 0 0 r
F P
0 g
s
.52552 .59125 m .46888 .61322 L p .46301 .63616 L .187 0 0 r
F P
0 g
s
.44749 .58918 m .46888 .61322 L .48264 .60788 L p .532 0 0 r
F P
0 g
s
.44749 .58918 m .48264 .60788 L .46646 .58969 L .532 0 0 r
F
.46384 .58085 m .45025 .58645 L p .45019 .58808 L 0 .05 .112 r
F P
0 g
s
.44749 .58918 m .45881 .61215 L .46888 .61322 L .532 0 0 r
F
.42576 .64513 m .4119 .63684 L .41299 .65605 L .521 0 0 r
F
.45881 .61215 m .44494 .60401 L .37852 .67003 L .765 0 0 r
F
.44616 .58905 m .44494 .60401 L .45881 .61215 L .532 0 0 r
F
.44616 .58905 m .4443 .58797 L .44494 .60401 L F
.45881 .61215 m .37852 .67003 L .39235 .67845 L .765 0 0 r
F
.46888 .61322 m .45881 .61215 L .39235 .67845 L .582 0 0 r
F
.44749 .58918 m .44616 .58905 L .45881 .61215 L .532 0 0 r
F
.42576 .64513 m .37852 .67003 L .4119 .63684 L .765 0 0 r
F
.46888 .61322 m .39235 .67845 L .40222 .67983 L .582 0 0 r
F
.42576 .64513 m .39235 .67845 L .37852 .67003 L .765 0 0 r
F
.43573 .64635 m .39235 .67845 L .42576 .64513 L .582 0 0 r
F
.43573 .64635 m .40222 .67983 L .39235 .67845 L F
.44749 .58918 m .38052 .65561 L .40222 .67983 L p .856 0 0 r
F P
0 g
s
.40222 .67983 m .46888 .61322 L .44749 .58918 L p .856 0 0 r
F P
0 g
s
.44749 .58918 m .46888 .61322 L .40222 .67983 L .856 0 0 r
F
.51849 .5648 m .5063 .57698 L .52033 .57134 L p 0 .05 .14 r
F P
0 g
s
.5063 .57698 m .51849 .5648 L .5326 .55905 L p 0 .05 .14 r
F P
0 g
s
.50576 .57637 m .5063 .57698 L .51849 .5648 L p 0 .349 .782 r
F P
0 g
s
.51849 .5648 m .51795 .56419 L .50576 .57637 L p 0 .349 .782 r
F P
0 g
s
.50576 .57637 m .51795 .56419 L .51237 .54635 L p 0 .432 .873 r
F P
0 g
s
.49406 .58922 m .5063 .57698 L .52033 .57134 L p 0 .05 .14 r
F P
0 g
s
.5063 .57698 m .49406 .58922 L .508 .58368 L p 0 .05 .14 r
F P
0 g
s
.508 .58368 m .52033 .57134 L .5063 .57698 L p 0 .05 .14 r
F P
0 g
s
.5326 .55905 m .52033 .57134 L .5063 .57698 L p 0 .05 .14 r
F P
0 g
s
.50576 .57637 m .5063 .57698 L .52033 .57134 L p 0 .313 .947 r
F P
0 g
s
.49351 .5886 m .49406 .58922 L .5063 .57698 L p 0 .349 .782 r
F P
0 g
s
.5063 .57698 m .50576 .57637 L .49351 .5886 L p 0 .349 .782 r
F P
0 g
s
.51237 .54635 m .50688 .55269 L p .50576 .57637 L 0 .432 .873 r
F P
0 g
s
.5063 .57698 m .50576 .57637 L p .5089 .55843 L 0 .313 .947 r
F P
0 g
s
.5089 .55843 m .52033 .57134 L .5063 .57698 L p 0 .313 .947 r
F P
0 g
s
.50166 .56058 m .50108 .56167 L .50576 .57637 L p 0 .432 .873 r
F P
0 g
s
.50688 .55269 m .50166 .56058 L p .50576 .57637 L 0 .432 .873 r
F P
0 g
s
.50108 .56167 m .50576 .57637 L p .52033 .57134 L 0 .313 .947 r
F P
0 g
s
.50576 .57637 m .50108 .56167 L .5089 .55843 L p 0 .313 .947 r
F P
0 g
s
.49351 .5886 m .50576 .57637 L .50108 .56167 L p 0 .432 .873 r
F P
0 g
s
.52033 .57134 m .508 .58368 L .49406 .58922 L p 0 .05 .14 r
F P
0 g
s
.49406 .58922 m .49351 .5886 L p .5025 .57748 L 0 .312 .948 r
F P
0 g
s
.5025 .57748 m .508 .58368 L .49406 .58922 L p 0 .312 .948 r
F P
0 g
s
.49653 .57025 m .49137 .58197 L .49351 .5886 L p 0 .432 .873 r
F P
0 g
s
.50108 .56167 m .49653 .57025 L p .49351 .5886 L 0 .432 .873 r
F P
0 g
s
.49351 .5886 m .49137 .58197 L .5025 .57748 L p 0 .312 .948 r
F P
0 g
s
.49137 .58197 m .49653 .57025 L .50562 .56653 L p 0 .118 .59 r
F P
0 g
s
.50562 .56653 m .5025 .57748 L .49137 .58197 L p 0 .118 .59 r
F P
0 g
s
.52033 .57134 m .5089 .55843 L .50108 .56167 L p 0 .313 .947 r
F P
0 g
s
.49653 .57025 m .50108 .56167 L .5089 .55843 L p 0 .086 .523 r
F P
0 g
s
.5089 .55843 m .50562 .56653 L .49653 .57025 L p 0 .086 .523 r
F P
0 g
s
.508 .58368 m .52033 .57134 L .53462 .56558 L p 0 .05 .14 r
F P
0 g
s
.5089 .55843 m .52033 .57134 L .508 .58368 L p 0 .349 .781 r
F P
0 g
s
.52033 .57134 m .508 .58368 L .5222 .57803 L p 0 .05 .14 r
F P
0 g
s
.5025 .57748 m .508 .58368 L .52033 .57134 L p 0 .349 .781 r
F P
0 g
s
.50562 .56653 m .5025 .57748 L p .52033 .57134 L 0 .349 .781 r
F P
0 g
s
.50562 .56653 m .5089 .55843 L p .508 .58368 L 0 .349 .781 r
F P
0 g
s
.508 .58368 m .5025 .57748 L .50562 .56653 L p 0 .349 .781 r
F P
0 g
s
.51795 .56419 m .53009 .55205 L .52555 .5373 L p 0 .432 .873 r
F P
0 g
s
.51849 .5648 m .53064 .55266 L .54484 .54681 L p 0 .05 .14 r
F P
0 g
s
.53064 .55266 m .51849 .5648 L .5326 .55905 L p 0 .05 .14 r
F P
0 g
s
.51795 .56419 m .51849 .5648 L .53064 .55266 L p 0 .349 .782 r
F P
0 g
s
.53064 .55266 m .53009 .55205 L .51795 .56419 L p 0 .349 .782 r
F P
0 g
s
.54484 .54681 m .5326 .55905 L .51849 .5648 L p 0 .05 .14 r
F P
0 g
s
.51237 .54635 m .51795 .56419 L p .52555 .5373 L 0 .432 .873 r
F P
0 g
s
.51893 .54358 m .5326 .55905 L .51849 .5648 L p 0 .314 .946 r
F P
0 g
s
.51237 .54635 m .51893 .54358 L p .51849 .5648 L 0 .314 .946 r
F P
0 g
s
.51849 .5648 m .51795 .56419 L .51237 .54635 L p 0 .314 .946 r
F P
0 g
s
.51237 .54635 m .51795 .56419 L p .5326 .55905 L 0 .314 .946 r
F P
0 g
s
.52033 .57134 m .5326 .55905 L .51849 .5648 L p 0 .05 .14 r
F P
0 g
s
.51795 .56419 m .51849 .5648 L .5326 .55905 L p 0 .314 .946 r
F P
0 g
s
.5089 .55843 m .52033 .57134 L .5326 .55905 L p 0 .349 .781 r
F P
0 g
s
.5326 .55905 m .51893 .54358 L .51237 .54635 L p 0 .314 .946 r
F P
0 g
s
.51371 .54984 m .51893 .54358 L p .52033 .57134 L 0 .349 .781 r
F P
0 g
s
.50932 .55741 m .51371 .54984 L p .52033 .57134 L 0 .349 .781 r
F P
0 g
s
.52033 .57134 m .5326 .55905 L .54699 .55319 L p 0 .05 .14 r
F P
0 g
s
.51893 .54358 m .5326 .55905 L .52033 .57134 L p 0 .349 .781 r
F P
0 g
s
.5326 .55905 m .52033 .57134 L .53462 .56558 L p 0 .05 .14 r
F P
0 g
s
.52033 .57134 m .5089 .55843 L .50932 .55741 L p 0 .349 .781 r
F P
0 g
s
.54699 .55319 m .53462 .56558 L .52033 .57134 L p 0 .05 .14 r
F P
0 g
s
.5089 .55843 m .52033 .57134 L .53462 .56558 L p 0 .313 .947 r
F P
0 g
s
.52033 .57134 m .5089 .55843 L .50562 .56653 L p 0 .349 .781 r
F P
0 g
s
.50932 .55741 m .5089 .55843 L p .5326 .55905 L 0 .349 .781 r
F P
0 g
s
.51371 .54984 m .50932 .55741 L p .5326 .55905 L 0 .349 .781 r
F P
0 g
s
.5326 .55905 m .51893 .54358 L .51371 .54984 L p 0 .349 .781 r
F P
0 g
s
.52033 .57134 m .5089 .55843 L .52309 .55255 L p 0 .313 .947 r
F P
0 g
s
.53462 .56558 m .52309 .55255 L .5089 .55843 L p 0 .313 .947 r
F P
0 g
s
.5025 .57748 m .50562 .56653 L .51979 .56072 L p 0 .118 .59 r
F P
0 g
s
.508 .58368 m .5025 .57748 L .51666 .57177 L p 0 .312 .948 r
F P
0 g
s
.53462 .56558 m .5222 .57803 L .508 .58368 L p 0 .05 .14 r
F P
0 g
s
.51666 .57177 m .5222 .57803 L .508 .58368 L p 0 .312 .948 r
F P
0 g
s
.51979 .56072 m .51666 .57177 L .5025 .57748 L p 0 .118 .59 r
F P
0 g
s
.45847 .57986 m .4508 .5859 L .45025 .58645 L p 0 .05 .112 r
F P
0 g
s
.45025 .58645 m .4508 .5859 L .43845 .57201 L p 0 .349 .782 r
F P
0 g
s
.43845 .57201 m .4508 .5859 L .45847 .57986 L p 0 .346 .852 r
F P
0 g
s
.45025 .58645 m .46384 .58085 L p .45847 .57986 L 0 .05 .112 r
F P
0 g
s
.45535 .55864 m .43845 .57201 L p .45847 .57986 L 0 .346 .852 r
F P
0 g
s
.46384 .58085 m .46939 .57534 L .45847 .57986 L p 0 .05 .112 r
F P
0 g
s
.45847 .57986 m .45739 .56769 L .45535 .55864 L p 0 .346 .852 r
F P
0 g
s
.45739 .56769 m .45847 .57986 L .46939 .57534 L p 0 .232 .816 r
F P
0 g
s
.45138 .56683 m .46384 .58085 L .45025 .58645 L p 0 .311 .95 r
F P
0 g
s
.43845 .57201 m .4379 .57256 L .45025 .58645 L p 0 .349 .782 r
F P
0 g
s
.46384 .58085 m .45138 .56683 L .4379 .57256 L p 0 .311 .95 r
F P
0 g
s
.46384 .58085 m .45138 .56683 L p .45109 .57239 L 0 .349 .781 r
F P
0 g
s
.46106 .58361 m .44749 .58918 L p .46646 .58969 L .532 0 0 r
F P
0 g
s
.44992 .59468 m .45027 .58804 L p .45019 .58808 L 0 .05 .112 r
F P
0 g
s
.46106 .58361 m .46384 .58085 L p .45019 .58808 L 0 .05 .112 r
F P
0 g
s
.4379 .57256 m .45025 .58645 L .46384 .58085 L p 0 .311 .95 r
F P
0 g
s
.48012 .55808 m .47679 .54943 L .46297 .55537 L p 0 .25 .847 r
F P
0 g
s
.46297 .55537 m .46627 .56393 L .48012 .55808 L p 0 .25 .847 r
F P
0 g
s
.48328 .56959 m .48012 .55808 L .46627 .56393 L p 0 .232 .816 r
F P
0 g
s
.47679 .54943 m .48012 .55808 L .49425 .5521 L p 0 .25 .847 r
F P
0 g
s
.46627 .56393 m .46939 .57534 L .48328 .56959 L p 0 .232 .816 r
F P
0 g
s
.47769 .57515 m .48328 .56959 L .46939 .57534 L p 0 .05 .112 r
F P
0 g
s
.48012 .55808 m .47679 .54943 L p .47769 .57515 L 0 .349 .781 r
F P
0 g
s
.46627 .56393 m .46297 .55537 L .45535 .55864 L p 0 .25 .847 r
F P
0 g
s
.45535 .55864 m .45739 .56769 L .46627 .56393 L p 0 .25 .847 r
F P
0 g
s
.45138 .56683 m .46297 .55537 L .46627 .56393 L p 0 .349 .781 r
F P
0 g
s
.46939 .57534 m .46627 .56393 L .45739 .56769 L p 0 .232 .816 r
F P
0 g
s
.46627 .56393 m .46297 .55537 L p .46384 .58085 L 0 .349 .781 r
F P
0 g
s
.46512 .56099 m .47679 .54943 L .48012 .55808 L p 0 .349 .781 r
F P
0 g
s
.47769 .57515 m .48328 .56959 L .48012 .55808 L p 0 .349 .781 r
F P
0 g
s
.49744 .56373 m .49425 .5521 L .48012 .55808 L p 0 .232 .816 r
F P
0 g
s
.48012 .55808 m .48328 .56959 L .49744 .56373 L p 0 .232 .816 r
F P
0 g
s
.48012 .55808 m .48328 .56959 L p .46512 .56099 L 0 .349 .781 r
F P
0 g
s
.49181 .56934 m .49744 .56373 L .48328 .56959 L p 0 .05 .112 r
F P
0 g
s
.48328 .56959 m .47769 .57515 L .49181 .56934 L p 0 .05 .112 r
F P
0 g
s
.48328 .56959 m .47769 .57515 L .46512 .56099 L p 0 .349 .781 r
F P
0 g
s
.47912 .55503 m .49181 .56934 L .47769 .57515 L p 0 .311 .95 r
F P
0 g
s
.47679 .54943 m .46512 .56099 L .47769 .57515 L p 0 .349 .781 r
F P
0 g
s
.49181 .56934 m .47912 .55503 L .46512 .56099 L p 0 .311 .95 r
F P
0 g
s
.49181 .56934 m .47912 .55503 L p .47884 .5607 L 0 .349 .781 r
F P
0 g
s
.48899 .57215 m .47489 .57793 L p .49998 .58453 L .532 0 0 r
F P
0 g
s
.47489 .57793 m .46106 .58361 L p .48215 .58611 L .532 0 0 r
F P
0 g
s
.48215 .58611 m .50363 .58866 L .47489 .57793 L .532 0 0 r
F
.50363 .58866 m .52552 .59125 L .49998 .58453 L F
.50363 .58866 m .49998 .58453 L .47489 .57793 L F
.46627 .56393 m .46939 .57534 L p .45138 .56683 L 0 .349 .781 r
F P
0 g
s
.46384 .58085 m .46939 .57534 L .46627 .56393 L p 0 .349 .781 r
F P
0 g
s
.46939 .57534 m .46384 .58085 L .45138 .56683 L p 0 .349 .781 r
F P
0 g
s
.46939 .57534 m .46384 .58085 L .47769 .57515 L p 0 .05 .112 r
F P
0 g
s
.46512 .56099 m .47769 .57515 L .46384 .58085 L p 0 .311 .95 r
F P
0 g
s
.46297 .55537 m .45138 .56683 L .46384 .58085 L p 0 .349 .781 r
F P
0 g
s
.47769 .57515 m .46512 .56099 L .45138 .56683 L p 0 .311 .95 r
F P
0 g
s
.47769 .57515 m .46512 .56099 L p .46483 .5666 L 0 .349 .781 r
F P
0 g
s
.46646 .58969 m .48578 .5902 L .46106 .58361 L .532 0 0 r
F
.48578 .5902 m .52552 .59125 L .48215 .58611 L F
.48578 .5902 m .48215 .58611 L .46106 .58361 L F
.46366 .5891 m .47489 .57793 L p .46381 .58248 L 0 .05 .112 r
F P
0 g
s
.46384 .58085 m .44992 .59468 L .46366 .5891 L p 0 .05 .112 r
F P
0 g
s
.44958 .60311 m .46366 .5891 L .44992 .59468 L p 0 .05 .112 r
F P
0 g
s
.44749 .58918 m .40222 .67983 L .38052 .65561 L .856 0 0 r
F
.44992 .59468 m .43593 .60857 L .44958 .60311 L p 0 .05 .112 r
F P
0 g
s
.46106 .58361 m .47489 .57793 L p .45447 .59283 L .161 0 0 r
F P
0 g
s
.46106 .58361 m .45447 .59283 L .44992 .59468 L .161 0 0 r
F
.45447 .59283 m .46366 .5891 L .44433 .60023 L F
.47489 .57793 m .46366 .5891 L .45447 .59283 L F
.43643 .60016 m .44992 .59468 L p .45019 .58808 L 0 .05 .112 r
F P
0 g
s
.44749 .58918 m .43643 .60016 L p .45019 .58808 L 0 .05 .112 r
F P
0 g
s
.44749 .58918 m .46106 .58361 L p .44992 .59468 L .161 0 0 r
F P
0 g
s
.43593 .60857 m .44992 .59468 L .43643 .60016 L p 0 .05 .112 r
F P
0 g
s
.44539 .59652 m .44992 .59468 L .44433 .60023 L .161 0 0 r
F
.44749 .58918 m .44992 .59468 L .44539 .59652 L F
.44749 .58918 m .37921 .65544 L .44616 .58905 L .576 0 0 r
F
.43135 .59717 m .44241 .58622 L p .42182 .60108 L .157 0 0 r
F P
0 g
s
.4153 .56464 m .43092 .57707 L .41946 .56282 L .532 0 0 r
F
.43336 .57604 m .42099 .56215 L p .43092 .57707 L F P
0 g
s
.42099 .56215 m .39953 .53802 L p .41946 .56282 L .532 0 0 r
F P
0 g
s
.43092 .57707 m .42099 .56215 L .41946 .56282 L .532 0 0 r
F
.4379 .57256 m .43845 .57201 L .42608 .5581 L p 0 .349 .782 r
F P
0 g
s
.42608 .5581 m .43845 .57201 L .45535 .55864 L p 0 .346 .852 r
F P
0 g
s
.44241 .58622 m .43336 .57604 L p .43092 .57707 L .532 0 0 r
F P
0 g
s
.39953 .53802 m .38835 .54319 L p .4153 .56464 L .532 0 0 r
F P
0 g
s
.4153 .56464 m .41946 .56282 L .39953 .53802 L .532 0 0 r
F
.42182 .60108 m .40754 .61494 L .41036 .6138 L .157 0 0 r
F
.43091 .59098 m .41992 .60186 L p .42182 .60108 L F P
0 g
s
.41992 .60186 m .36439 .65681 L p .42182 .60108 L .157 0 0 r
F P
0 g
s
.39953 .53802 m .43747 .58066 L p .41437 .60744 L .856 0 0 r
F P
0 g
s
.36439 .65681 m .37546 .65255 L p .41036 .6138 L .157 0 0 r
F P
0 g
s
.40754 .61494 m .36439 .65681 L .41036 .6138 L .157 0 0 r
F
.4443 .58797 m .37736 .65432 L .37546 .65255 L .831 0 0 r
F
.44616 .58905 m .37736 .65432 L .4443 .58797 L .764 0 0 r
F
.44616 .58905 m .37921 .65544 L .37736 .65432 L F
.38052 .65561 m .42255 .61393 L p .42832 .62425 L .161 0 0 r
F P
0 g
s
.40692 .64553 m .38052 .65561 L p .42832 .62425 L .161 0 0 r
F P
0 g
s
.44749 .58918 m .38052 .65561 L .37921 .65544 L .576 0 0 r
F
.4132 .61265 m .37546 .65255 L .36439 .65681 L .157 0 0 r
F
.41605 .6115 m .37546 .65255 L .4132 .61265 L F
.43135 .59717 m .41747 .61092 L .42944 .59796 L F
.41747 .61092 m .37546 .65255 L .41605 .6115 L F
.41747 .61092 m .41605 .6115 L .42944 .59796 L F
.42944 .59796 m .41605 .6115 L .4132 .61265 L F
.39953 .53802 m .41437 .60744 L .39055 .58074 L .856 0 0 r
F
.44241 .58622 m .43135 .59717 L .42944 .59796 L .157 0 0 r
F
.42182 .60108 m .41036 .6138 L .43135 .59717 L F
.37546 .65255 m .41747 .61092 L p .41036 .6138 L F P
0 g
s
.41747 .61092 m .43135 .59717 L p .41036 .6138 L .157 0 0 r
F P
0 g
s
.43688 .5917 m .37546 .65255 L p .43747 .58066 L .856 0 0 r
F P
0 g
s
.4443 .58797 m .37546 .65255 L .44241 .58622 L .831 0 0 r
F
.42404 .58625 m .41012 .59999 L .42255 .61393 L p 0 .349 .782 r
F P
0 g
s
.41012 .59999 m .42339 .5945 L p .42277 .60879 L 0 .31 .951 r
F P
0 g
s
.42255 .61393 m .41924 .61021 L p .42277 .60879 L 0 .31 .951 r
F P
0 g
s
.41924 .61021 m .41012 .59999 L p .42277 .60879 L 0 .31 .951 r
F P
0 g
s
.39055 .58074 m .41437 .60744 L .37546 .65255 L .856 0 0 r
F
.38052 .65561 m .39459 .64166 L .38209 .62768 L p 0 .349 .782 r
F P
0 g
s
.40777 .63654 m .39459 .64166 L .38052 .65561 L p 0 .05 .112 r
F P
0 g
s
.43573 .64635 m .46217 .67596 L .42885 .70956 L .856 0 0 r
F
.43573 .64635 m .40222 .67983 L .42885 .70956 L p F P
0 g
s
.43573 .64635 m .42885 .70956 L .40222 .67983 L .856 0 0 r
F
.40222 .67983 m .429 .67024 L p .46301 .63616 L .187 0 0 r
F P
0 g
s
.429 .67024 m .45685 .66026 L p .46301 .63616 L .187 0 0 r
F P
0 g
s
.46217 .67596 m .42885 .70956 L .45611 .70056 L p .217 0 0 r
F P
0 g
s
.45611 .70056 m .48446 .6912 L p .47307 .68341 L .217 0 0 r
F P
0 g
s
.46217 .67596 m .45611 .70056 L .47307 .68341 L .217 0 0 r
F
.45463 .71964 m .4552 .71946 L .45469 .71889 L p 0 .307 .954 r
F P
0 g
s
.45469 .71889 m .42445 .6851 L p .45463 .71964 L 0 .307 .954 r
F P
0 g
s
.44159 .72378 m .45463 .71964 L p .42445 .6851 L 0 .307 .954 r
F P
0 g
s
.50224 .72671 m .47197 .75769 L .48684 .7743 L p 0 .349 .782 r
F P
0 g
s
.48684 .7743 m .51702 .74327 L .50224 .72671 L p 0 .349 .782 r
F P
0 g
s
.47197 .75769 m .50224 .72671 L .51634 .72245 L p 0 .05 .218 r
F P
0 g
s
.51634 .72245 m .48585 .7537 L .47197 .75769 L p 0 .05 .218 r
F P
0 g
s
.47197 .75769 m .48585 .7537 L .4552 .71946 L p 0 .307 .954 r
F P
0 g
s
.4552 .71946 m .44159 .72378 L .47197 .75769 L p 0 .307 .954 r
F P
0 g
s
.46908 .71505 m .4552 .71946 L .48585 .7537 L p 0 .307 .954 r
F P
0 g
s
.4552 .71946 m .46908 .71505 L .43805 .68035 L p 0 .307 .954 r
F P
0 g
s
.43805 .68035 m .42445 .6851 L .4552 .71946 L p 0 .307 .954 r
F P
0 g
s
.45378 .73059 m .46908 .71505 L .45611 .70056 L p 0 .349 .781 r
F P
0 g
s
.48446 .6912 m .42885 .70956 L .40222 .67983 L p .509 0 0 r
F P
0 g
s
.51481 .71385 m .50716 .7114 L .47466 .67497 L .1 0 0 r
F
.51481 .71385 m .47466 .67497 L .48197 .67703 L F
.48446 .6912 m .51878 .65638 L .46217 .67596 L p .217 0 0 r
F P
0 g
s
.40222 .67983 m .45685 .66026 L .48446 .6912 L p .509 0 0 r
F P
0 g
s
.45611 .70056 m .43805 .68035 L p .4472 .70957 L 0 .349 .781 r
F P
0 g
s
.4472 .70957 m .45378 .73059 L .45611 .70056 L 0 .349 .781 r
F
.42445 .6851 m .4111 .68975 L .44159 .72378 L p 0 .307 .954 r
F P
0 g
s
.43573 .64635 m .40222 .67983 L p .46301 .63616 L .187 0 0 r
F P
0 g
s
.40222 .67983 m .43573 .64635 L p .44606 .65315 L .187 0 0 r
F P
0 g
s
.45685 .66026 m .429 .67024 L p .44606 .65315 L .187 0 0 r
F P
0 g
s
.429 .67024 m .40222 .67983 L p .44606 .65315 L .187 0 0 r
F P
0 g
s
.42445 .6851 m .43805 .68035 L p .42263 .681 L 0 .307 .954 r
F P
0 g
s
.43805 .68035 m .40692 .64553 L p .42263 .681 L 0 .307 .954 r
F P
0 g
s
.4198 .68672 m .42445 .6851 L .42085 .68107 L p 0 .307 .954 r
F P
0 g
s
.42085 .68107 m .39359 .65062 L p .4198 .68672 L 0 .307 .954 r
F P
0 g
s
.4111 .68975 m .4198 .68672 L p .39359 .65062 L 0 .307 .954 r
F P
0 g
s
.40692 .64553 m .39359 .65062 L .42445 .6851 L p 0 .307 .954 r
F P
0 g
s
.43805 .68035 m .42265 .69583 L p .41807 .68119 L 0 .349 .781 r
F P
0 g
s
.45685 .66026 m .40222 .67983 L .38052 .65561 L p .509 0 0 r
F P
0 g
s
.46888 .61322 m .43573 .64635 L p .46301 .63616 L .187 0 0 r
F P
0 g
s
.43573 .64635 m .49138 .62556 L .45685 .66026 L p .187 0 0 r
F P
0 g
s
.38052 .65561 m .43436 .63505 L .45685 .66026 L p .509 0 0 r
F P
0 g
s
.40692 .64553 m .429 .67024 L p .41807 .68119 L 0 .349 .781 r
F P
0 g
s
.429 .67024 m .43805 .68035 L p .41807 .68119 L 0 .349 .781 r
F P
0 g
s
.42265 .69583 m .43805 .68035 L .429 .67024 L p 0 .349 .781 r
F P
0 g
s
.429 .67024 m .40692 .64553 L p .41807 .68119 L 0 .349 .781 r
F P
0 g
s
.41807 .68119 m .42265 .69583 L .429 .67024 L 0 .349 .781 r
F
.39359 .65062 m .38052 .65561 L .4111 .68975 L p 0 .307 .954 r
F P
0 g
s
.37546 .65255 m .33195 .60398 L .39953 .53802 L p .856 0 0 r
F P
0 g
s
.38209 .62768 m .36798 .64162 L .38052 .65561 L p 0 .349 .782 r
F P
0 g
s
.38052 .65561 m .39359 .65062 L .40777 .63654 L p 0 .05 .112 r
F P
0 g
s
.38052 .65561 m .39359 .65062 L .38094 .63649 L p 0 .307 .954 r
F P
0 g
s
.37852 .67003 m .35101 .66197 L .36439 .65681 L .509 0 0 r
F
.37852 .67003 m .37992 .68903 L .35101 .66197 L F
.37736 .65432 m .37852 .67003 L .36439 .65681 L F
.37921 .65544 m .37852 .67003 L .37736 .65432 L F
.37921 .65544 m .39235 .67845 L .37852 .67003 L F
.38052 .65561 m .39235 .67845 L .37921 .65544 L F
.38052 .65561 m .40222 .67983 L .39235 .67845 L F
.39235 .67845 m .37992 .68903 L .37852 .67003 L F
.39235 .67845 m .40833 .70645 L .37992 .68903 L F
.40222 .67983 m .40833 .70645 L .39235 .67845 L F
.40222 .67983 m .42885 .70956 L .40833 .70645 L F
.39594 .70495 m .4111 .68975 L .38052 .65561 L p 0 .349 .782 r
F P
0 g
s
.38052 .65561 m .36526 .67076 L .39594 .70495 L p 0 .349 .782 r
F P
0 g
s
.39359 .65062 m .38052 .65561 L .36526 .67076 L p 0 .05 .112 r
F P
0 g
s
.38094 .63649 m .39359 .65062 L .38052 .65561 L p 0 .307 .954 r
F P
0 g
s
.36526 .67076 m .38052 .65561 L .39359 .65062 L p 0 .05 .112 r
F P
0 g
s
.36526 .67076 m .37821 .6659 L .39359 .65062 L p 0 .05 .112 r
F P
0 g
s
.39359 .65062 m .37821 .6659 L .36526 .67076 L p 0 .05 .112 r
F P
0 g
s
.4212 .63133 m .40777 .63654 L .39359 .65062 L p 0 .05 .112 r
F P
0 g
s
.39359 .65062 m .40692 .64553 L .4212 .63133 L p 0 .05 .112 r
F P
0 g
s
.39614 .61381 m .38209 .62768 L .39459 .64166 L p 0 .349 .782 r
F P
0 g
s
.39359 .65062 m .38094 .63649 L .39415 .63126 L p 0 .307 .954 r
F P
0 g
s
.39459 .64166 m .4086 .62776 L .39614 .61381 L p 0 .349 .782 r
F P
0 g
s
.42188 .62252 m .4086 .62776 L .39459 .64166 L p 0 .05 .112 r
F P
0 g
s
.39459 .64166 m .40777 .63654 L .42188 .62252 L p 0 .05 .112 r
F P
0 g
s
.39415 .63126 m .40692 .64553 L .39359 .65062 L p 0 .307 .954 r
F P
0 g
s
.39359 .65062 m .40692 .64553 L .39415 .63126 L p 0 .307 .954 r
F P
0 g
s
.39415 .63126 m .38094 .63649 L .39359 .65062 L p 0 .307 .954 r
F P
0 g
s
.40692 .64553 m .39359 .65062 L .37821 .6659 L p 0 .05 .112 r
F P
0 g
s
.37821 .6659 m .39359 .65062 L .40692 .64553 L p 0 .05 .112 r
F P
0 g
s
.37821 .6659 m .39142 .66095 L .40692 .64553 L p 0 .05 .112 r
F P
0 g
s
.40692 .64553 m .39142 .66095 L .37821 .6659 L p 0 .05 .112 r
F P
0 g
s
.38718 .64442 m .40692 .64553 L .39142 .66095 L closepath p 0 .349 .781 r
F P
0 g
s
.43436 .63505 m .40692 .64553 L p .42832 .62425 L .161 0 0 r
F P
0 g
s
.43643 .60016 m .44749 .58918 L p .44539 .59652 L .161 0 0 r
F P
0 g
s
.43747 .58066 m .44241 .58622 L .43688 .5917 L p .856 0 0 r
F P
0 g
s
.43643 .60016 m .45025 .58645 L .4379 .57256 L p 0 .349 .782 r
F P
0 g
s
.4379 .57256 m .42404 .58625 L .43643 .60016 L p 0 .349 .782 r
F P
0 g
s
.44992 .59468 m .43643 .60016 L p .43669 .59499 L 0 .31 .951 r
F P
0 g
s
.43643 .60016 m .42255 .61393 L .43593 .60857 L p 0 .05 .112 r
F P
0 g
s
.42255 .61393 m .43643 .60016 L p .4406 .60393 L .161 0 0 r
F P
0 g
s
.4406 .60393 m .43593 .60857 L .42255 .61393 L .161 0 0 r
F
.44539 .59652 m .44433 .60023 L .43643 .60016 L F
.44433 .60023 m .44272 .60585 L .4406 .60393 L F
.44433 .60023 m .4406 .60393 L .43643 .60016 L F
.43742 .58063 m .44659 .59094 L p .43669 .59499 L 0 .31 .951 r
F P
0 g
s
.44659 .59094 m .44992 .59468 L p .43669 .59499 L 0 .31 .951 r
F P
0 g
s
.42404 .58625 m .43742 .58063 L p .43669 .59499 L 0 .31 .951 r
F P
0 g
s
.43643 .60016 m .43313 .59645 L p .43669 .59499 L 0 .31 .951 r
F P
0 g
s
.43313 .59645 m .42404 .58625 L p .43669 .59499 L 0 .31 .951 r
F P
0 g
s
.43643 .60016 m .44992 .59468 L p .44297 .59242 L 0 .31 .951 r
F P
0 g
s
.42404 .58625 m .43313 .59645 L p .44297 .59242 L 0 .31 .951 r
F P
0 g
s
.43313 .59645 m .43643 .60016 L p .44297 .59242 L 0 .31 .951 r
F P
0 g
s
.42255 .61393 m .43643 .60016 L .42404 .58625 L p 0 .349 .782 r
F P
0 g
s
.44992 .59468 m .43742 .58063 L .42404 .58625 L p 0 .31 .951 r
F P
0 g
s
.43593 .60857 m .44992 .59468 L .43742 .58063 L p 0 .349 .781 r
F P
0 g
s
.44992 .59468 m .43593 .60857 L .42339 .5945 L p 0 .349 .781 r
F P
0 g
s
.4406 .60393 m .44272 .60585 L .43593 .60857 L .161 0 0 r
F
.44272 .60585 m .43436 .63505 L .42255 .61393 L F
.43593 .60857 m .42255 .61393 L p .42277 .60879 L 0 .31 .951 r
F P
0 g
s
.42339 .5945 m .43259 .60482 L p .42277 .60879 L 0 .31 .951 r
F P
0 g
s
.43259 .60482 m .43593 .60857 L p .42277 .60879 L 0 .31 .951 r
F P
0 g
s
.42339 .5945 m .41012 .59999 L .41924 .61021 L p 0 .31 .951 r
F P
0 g
s
.41924 .61021 m .42255 .61393 L p .42277 .60879 L 0 .31 .951 r
F P
0 g
s
.42339 .5945 m .41924 .61021 L .42277 .60879 L 0 .31 .951 r
F
.42404 .58625 m .4379 .57256 L .42553 .55865 L p 0 .349 .782 r
F P
0 g
s
.42608 .5581 m .42553 .55865 L .4379 .57256 L p 0 .349 .782 r
F P
0 g
s
.44652 .54187 m .42608 .5581 L p .45535 .55864 L 0 .346 .852 r
F P
0 g
s
.4379 .57256 m .42553 .55865 L .4389 .55278 L p 0 .311 .95 r
F P
0 g
s
.4379 .57256 m .43845 .57201 L .45535 .55864 L p 0 .05 .1 r
F P
0 g
s
.45535 .55864 m .43845 .57201 L .4379 .57256 L p 0 .05 .1 r
F P
0 g
s
.46297 .55537 m .45138 .56683 L .4379 .57256 L p 0 .05 .1 r
F P
0 g
s
.45535 .55864 m .46297 .55537 L p .4379 .57256 L 0 .05 .1 r
F P
0 g
s
.4379 .57256 m .45138 .56683 L p .45535 .55864 L 0 .05 .1 r
F P
0 g
s
.42553 .55865 m .4379 .57256 L .45138 .56683 L p 0 .311 .95 r
F P
0 g
s
.45138 .56683 m .4389 .55278 L .42553 .55865 L p 0 .311 .95 r
F P
0 g
s
.42553 .55865 m .41163 .57232 L .42404 .58625 L p 0 .349 .782 r
F P
0 g
s
.4389 .55278 m .42553 .55865 L p .42541 .56022 L 0 .05 .1 r
F P
0 g
s
.4249 .56657 m .43611 .55553 L p .42541 .56022 L 0 .05 .1 r
F P
0 g
s
.43611 .55553 m .4389 .55278 L p .42541 .56022 L 0 .05 .1 r
F P
0 g
s
.41163 .57232 m .4249 .56657 L p .42541 .56022 L 0 .05 .1 r
F P
0 g
s
.42553 .55865 m .42276 .56138 L p .42541 .56022 L 0 .05 .1 r
F P
0 g
s
.42276 .56138 m .41163 .57232 L p .42541 .56022 L 0 .05 .1 r
F P
0 g
s
.45025 .58645 m .4379 .57256 L .45138 .56683 L p 0 .311 .95 r
F P
0 g
s
.4379 .57256 m .45138 .56683 L p .44588 .57073 L 0 .05 .1 r
F P
0 g
s
.42404 .58625 m .43513 .57529 L p .44588 .57073 L 0 .05 .1 r
F P
0 g
s
.43513 .57529 m .4379 .57256 L p .44588 .57073 L 0 .05 .1 r
F P
0 g
s
.44992 .59468 m .46106 .58361 L p .45109 .57239 L 0 .349 .781 r
F P
0 g
s
.46106 .58361 m .46384 .58085 L p .45109 .57239 L 0 .349 .781 r
F P
0 g
s
.47769 .57515 m .46384 .58085 L p .46381 .58248 L 0 .05 .112 r
F P
0 g
s
.47489 .57793 m .47769 .57515 L p .46381 .58248 L 0 .05 .112 r
F P
0 g
s
.45025 .58645 m .44749 .58918 L p .45019 .58808 L 0 .05 .112 r
F P
0 g
s
.44992 .59468 m .43742 .58063 L p .45857 .58081 L 0 .349 .781 r
F P
0 g
s
.46384 .58085 m .46106 .58361 L p .45857 .58081 L 0 .349 .781 r
F P
0 g
s
.46106 .58361 m .44992 .59468 L p .45857 .58081 L 0 .349 .781 r
F P
0 g
s
.45138 .56683 m .46384 .58085 L .47769 .57515 L p 0 .311 .95 r
F P
0 g
s
.43742 .58063 m .45138 .56683 L .46384 .58085 L p 0 .349 .781 r
F P
0 g
s
.46384 .58085 m .45138 .56683 L .46512 .56099 L p 0 .311 .95 r
F P
0 g
s
.46512 .56099 m .45105 .57491 L .46366 .5891 L p 0 .349 .781 r
F P
0 g
s
.45105 .57491 m .46366 .5891 L .44992 .59468 L p 0 .31 .951 r
F P
0 g
s
.45138 .56683 m .43742 .58063 L .44992 .59468 L p 0 .349 .781 r
F P
0 g
s
.43742 .58063 m .44992 .59468 L .46366 .5891 L p 0 .31 .951 r
F P
0 g
s
.44992 .59468 m .45447 .59283 L .44433 .60023 L .161 0 0 r
F
.52552 .59125 m .50336 .56624 L .48899 .57215 L p .532 0 0 r
F P
0 g
s
.49998 .58453 m .52552 .59125 L .48899 .57215 L .532 0 0 r
F
.48264 .60788 m .52552 .59125 L p .46646 .58969 L F P
0 g
s
.50621 .56341 m .49181 .56934 L p .49184 .57097 L 0 .05 .112 r
F P
0 g
s
.49197 .57761 m .50336 .56624 L p .49184 .57097 L 0 .05 .112 r
F P
0 g
s
.50336 .56624 m .50621 .56341 L p .49184 .57097 L 0 .05 .112 r
F P
0 g
s
.50448 .56578 m .52552 .59125 L .52948 .5845 L .532 0 0 r
F
.49181 .56934 m .47768 .58341 L .49197 .57761 L p 0 .05 .112 r
F P
0 g
s
.47767 .59187 m .49197 .57761 L .47768 .58341 L p 0 .05 .112 r
F P
0 g
s
.47768 .58341 m .46348 .59754 L .47767 .59187 L p 0 .05 .112 r
F P
0 g
s
.47054 .59472 m .48877 .5789 L .47528 .59282 L .161 0 0 r
F
.49197 .57761 m .43436 .63505 L p .48877 .5789 L F P
0 g
s
.47768 .58341 m .49181 .56934 L .47769 .57515 L p 0 .05 .112 r
F P
0 g
s
.47769 .57515 m .46366 .5891 L .47768 .58341 L p 0 .05 .112 r
F P
0 g
s
.46348 .59754 m .47768 .58341 L .46366 .5891 L p 0 .05 .112 r
F P
0 g
s
.46366 .5891 m .44958 .60311 L .46348 .59754 L p 0 .05 .112 r
F P
0 g
s
.46366 .5891 m .48334 .57777 L .47768 .58341 L .161 0 0 r
F
.46366 .5891 m .45105 .57491 L p .47238 .5751 L 0 .349 .781 r
F P
0 g
s
.47489 .57793 m .46366 .5891 L p .47238 .5751 L 0 .349 .781 r
F P
0 g
s
.46366 .5891 m .47489 .57793 L p .46483 .5666 L 0 .349 .781 r
F P
0 g
s
.47489 .57793 m .48899 .57215 L p .46366 .5891 L .161 0 0 r
F P
0 g
s
.48899 .57215 m .50336 .56624 L p .48334 .57777 L .161 0 0 r
F P
0 g
s
.48899 .57215 m .48334 .57777 L .46366 .5891 L .161 0 0 r
F
.46512 .56099 m .47769 .57515 L .49181 .56934 L p 0 .311 .95 r
F P
0 g
s
.48899 .57215 m .47768 .58341 L p .48645 .56928 L 0 .349 .781 r
F P
0 g
s
.45105 .57491 m .46366 .5891 L .47768 .58341 L p 0 .31 .951 r
F P
0 g
s
.44433 .60023 m .46366 .5891 L .45381 .5989 L .161 0 0 r
F
.44433 .60023 m .45381 .5989 L .44272 .60585 L F
.45381 .5989 m .46348 .59754 L .44958 .60311 L F
.45381 .5989 m .44958 .60311 L .44272 .60585 L F
.42339 .5945 m .43742 .58063 L .44992 .59468 L p 0 .349 .781 r
F P
0 g
s
.44992 .59468 m .43742 .58063 L .45105 .57491 L p 0 .31 .951 r
F P
0 g
s
.46366 .5891 m .45105 .57491 L .43742 .58063 L p 0 .31 .951 r
F P
0 g
s
.43742 .58063 m .42339 .5945 L .43593 .60857 L p 0 .349 .781 r
F P
0 g
s
.45105 .57491 m .43693 .5889 L .44958 .60311 L p 0 .349 .781 r
F P
0 g
s
.46366 .5891 m .44958 .60311 L .43693 .5889 L p 0 .349 .781 r
F P
0 g
s
.45381 .5989 m .46366 .5891 L .46348 .59754 L .161 0 0 r
F
.46366 .5891 m .47768 .58341 L .46348 .59754 L F
.44272 .60585 m .46348 .59754 L .43777 .62315 L F
.43693 .5889 m .44958 .60311 L .43593 .60857 L p 0 .31 .951 r
F P
0 g
s
.48334 .57777 m .50336 .56624 L .48877 .5789 L .161 0 0 r
F
.47768 .58341 m .48877 .5789 L .43777 .62315 L F
.48334 .57777 m .48877 .5789 L .47768 .58341 L F
.50336 .56624 m .49197 .57761 L p .48877 .5789 L F P
0 g
s
.47769 .57515 m .47489 .57793 L p .47238 .5751 L 0 .349 .781 r
F P
0 g
s
.47489 .57793 m .47769 .57515 L p .46483 .5666 L 0 .349 .781 r
F P
0 g
s
.47769 .57515 m .46512 .56099 L .47912 .55503 L p 0 .311 .95 r
F P
0 g
s
.45105 .57491 m .46512 .56099 L .47769 .57515 L p 0 .349 .781 r
F P
0 g
s
.47768 .58341 m .46496 .56908 L p .48645 .56928 L 0 .349 .781 r
F P
0 g
s
.47768 .58341 m .48899 .57215 L p .47884 .5607 L 0 .349 .781 r
F P
0 g
s
.46496 .56908 m .47912 .55503 L .49181 .56934 L p 0 .349 .781 r
F P
0 g
s
.49197 .57761 m .47768 .58341 L p .47806 .57804 L 0 .31 .951 r
F P
0 g
s
.48855 .57375 m .49197 .57761 L p .47806 .57804 L 0 .31 .951 r
F P
0 g
s
.46496 .56908 m .47768 .58341 L .46366 .5891 L p 0 .31 .951 r
F P
0 g
s
.47768 .58341 m .46496 .56908 L .45105 .57491 L p 0 .31 .951 r
F P
0 g
s
.46348 .59754 m .47768 .58341 L .46496 .56908 L p 0 .349 .781 r
F P
0 g
s
.44958 .60311 m .46366 .5891 L .45105 .57491 L p 0 .349 .781 r
F P
0 g
s
.46366 .5891 m .45105 .57491 L .46496 .56908 L p 0 .31 .951 r
F P
0 g
s
.43693 .5889 m .45105 .57491 L .46366 .5891 L p 0 .349 .781 r
F P
0 g
s
.47768 .58341 m .46348 .59754 L .45072 .58319 L p 0 .349 .781 r
F P
0 g
s
.47767 .59187 m .46348 .59754 L p .46383 .59221 L 0 .31 .951 r
F P
0 g
s
.45072 .58319 m .46496 .56908 L .47768 .58341 L p 0 .349 .781 r
F P
0 g
s
.46479 .57737 m .47424 .588 L p .46383 .59221 L 0 .31 .951 r
F P
0 g
s
.47424 .588 m .47767 .59187 L p .46383 .59221 L 0 .31 .951 r
F P
0 g
s
.43777 .62315 m .47054 .59472 L .43436 .63505 L .161 0 0 r
F
.47054 .59472 m .47528 .59282 L .43436 .63505 L F
.4633 .6062 m .47767 .59187 L .46348 .59754 L p 0 .05 .112 r
F P
0 g
s
.46348 .59754 m .44922 .61175 L .4633 .6062 L p 0 .05 .112 r
F P
0 g
s
.46348 .59754 m .47767 .59187 L p .47043 .58954 L 0 .31 .951 r
F P
0 g
s
.46496 .56908 m .45072 .58319 L .46348 .59754 L p 0 .349 .781 r
F P
0 g
s
.45072 .58319 m .46008 .59372 L p .47043 .58954 L 0 .31 .951 r
F P
0 g
s
.46008 .59372 m .46348 .59754 L p .47043 .58954 L 0 .31 .951 r
F P
0 g
s
.47912 .55503 m .46496 .56908 L .47768 .58341 L p 0 .349 .781 r
F P
0 g
s
.47768 .58341 m .49197 .57761 L p .48472 .57532 L 0 .31 .951 r
F P
0 g
s
.46496 .56908 m .47429 .57959 L p .48472 .57532 L 0 .31 .951 r
F P
0 g
s
.47429 .57959 m .47768 .58341 L p .48472 .57532 L 0 .31 .951 r
F P
0 g
s
.50621 .56341 m .49197 .57761 L .48855 .57375 L p 0 .35 .78 r
F P
0 g
s
.49181 .56934 m .48899 .57215 L p .48645 .56928 L 0 .349 .781 r
F P
0 g
s
.48899 .57215 m .49181 .56934 L p .47884 .5607 L 0 .349 .781 r
F P
0 g
s
.49425 .5521 m .49088 .54337 L .47679 .54943 L p 0 .25 .847 r
F P
0 g
s
.49088 .54337 m .47912 .55503 L .49181 .56934 L p 0 .349 .781 r
F P
0 g
s
.49425 .5521 m .49088 .54337 L p .49181 .56934 L 0 .349 .781 r
F P
0 g
s
.50166 .56058 m .50688 .55269 L .51371 .54984 L p 0 .05 .416 r
F P
0 g
s
.50108 .56167 m .50166 .56058 L .50932 .55741 L p 0 .086 .523 r
F P
0 g
s
.50932 .55741 m .5089 .55843 L .50108 .56167 L p 0 .086 .523 r
F P
0 g
s
.51371 .54984 m .50932 .55741 L .50166 .56058 L p 0 .05 .416 r
F P
0 g
s
.50562 .56653 m .5089 .55843 L .52309 .55255 L p 0 .086 .523 r
F P
0 g
s
.49425 .5521 m .49744 .56373 L .50897 .55895 L p 0 .232 .816 r
F P
0 g
s
.49181 .56934 m .49744 .56373 L .49425 .5521 L p 0 .349 .781 r
F P
0 g
s
.49425 .5521 m .49744 .56373 L p .47912 .55503 L 0 .349 .781 r
F P
0 g
s
.50677 .56284 m .50897 .55895 L .49744 .56373 L p 0 .05 .112 r
F P
0 g
s
.50621 .56341 m .50677 .56284 L p .49744 .56373 L 0 .05 .112 r
F P
0 g
s
.49744 .56373 m .49181 .56934 L .50621 .56341 L p 0 .05 .112 r
F P
0 g
s
.49744 .56373 m .49181 .56934 L .47912 .55503 L p 0 .349 .781 r
F P
0 g
s
.47912 .55503 m .49181 .56934 L .50621 .56341 L p 0 .311 .95 r
F P
0 g
s
.49088 .54337 m .49425 .5521 L .50359 .54815 L p 0 .25 .847 r
F P
0 g
s
.47912 .55503 m .49088 .54337 L .49425 .5521 L p 0 .349 .781 r
F P
0 g
s
.50897 .55895 m .50359 .54815 L .49425 .5521 L p 0 .232 .816 r
F P
0 g
s
.49341 .54896 m .50621 .56341 L .49181 .56934 L p 0 .311 .95 r
F P
0 g
s
.49181 .56934 m .47912 .55503 L .49341 .54896 L p 0 .311 .95 r
F P
0 g
s
.48855 .57375 m .47913 .56313 L p .499 .56334 L 0 .35 .78 r
F P
0 g
s
.499 .56334 m .50621 .56341 L .48855 .57375 L 0 .35 .78 r
F
.50387 .56533 m .50431 .56585 L .50448 .56578 L .532 0 0 r
F
.50431 .56585 m .52552 .59125 L .50448 .56578 L F
.50621 .56341 m .49341 .54896 L .47912 .55503 L p 0 .311 .95 r
F P
0 g
s
.50359 .54815 m .49888 .53993 L .49088 .54337 L p 0 .25 .847 r
F P
0 g
s
.49888 .53993 m .50359 .54815 L p .50677 .56284 L 0 .332 .56 r
F P
0 g
s
.50677 .56284 m .49397 .54839 L .49888 .53993 L p 0 .332 .56 r
F P
0 g
s
.50359 .54815 m .50897 .55895 L .50677 .56284 L p 0 .332 .56 r
F P
0 g
s
.45685 .66026 m .49138 .62556 L p .46301 .63616 L .187 0 0 r
F P
0 g
s
.50336 .56624 m .52552 .59125 L .45685 .66026 L p .858 0 0 r
F P
0 g
s
.50336 .56624 m .45685 .66026 L .52552 .59125 L .858 0 0 r
F
.50387 .56533 m .50336 .56624 L .52552 .59125 L .532 0 0 r
F
.50677 .56284 m .50621 .56341 L .49341 .54896 L p 0 .35 .78 r
F P
0 g
s
.49341 .54896 m .49397 .54839 L .50677 .56284 L p 0 .35 .78 r
F P
0 g
s
.47913 .56313 m .49341 .54896 L .50621 .56341 L p 0 .35 .78 r
F P
0 g
s
.45685 .66026 m .43436 .63505 L .50336 .56624 L p .858 0 0 r
F P
0 g
s
.50336 .56624 m .43436 .63505 L .45685 .66026 L .858 0 0 r
F
.50387 .56533 m .49239 .57685 L .50336 .56624 L .89 0 0 r
F
.47913 .56313 m .46496 .56908 L p .48472 .57532 L 0 .31 .951 r
F P
0 g
s
.49197 .57761 m .48855 .57375 L p .48472 .57532 L 0 .31 .951 r
F P
0 g
s
.48855 .57375 m .47913 .56313 L p .48472 .57532 L 0 .31 .951 r
F P
0 g
s
.46479 .57737 m .45072 .58319 L p .47043 .58954 L 0 .31 .951 r
F P
0 g
s
.47767 .59187 m .47424 .588 L p .47043 .58954 L 0 .31 .951 r
F P
0 g
s
.47424 .588 m .46479 .57737 L p .47043 .58954 L 0 .31 .951 r
F P
0 g
s
.44886 .62059 m .4633 .6062 L .44922 .61175 L p 0 .05 .112 r
F P
0 g
s
.44922 .61175 m .4349 .62601 L .44886 .62059 L p 0 .05 .112 r
F P
0 g
s
.43436 .63505 m .44886 .62059 L .4349 .62601 L p 0 .05 .112 r
F P
0 g
s
.47913 .56313 m .48855 .57375 L p .47806 .57804 L 0 .31 .951 r
F P
0 g
s
.47768 .58341 m .46496 .56908 L .47913 .56313 L p 0 .31 .951 r
F P
0 g
s
.49197 .57761 m .47767 .59187 L .46479 .57737 L p 0 .35 .78 r
F P
0 g
s
.46479 .57737 m .47913 .56313 L .49197 .57761 L p 0 .35 .78 r
F P
0 g
s
.46479 .57737 m .47767 .59187 L .4633 .6062 L p 0 .35 .78 r
F P
0 g
s
.45072 .58319 m .46348 .59754 L .44958 .60311 L p 0 .31 .951 r
F P
0 g
s
.44922 .61175 m .46348 .59754 L .44958 .60311 L p 0 .05 .112 r
F P
0 g
s
.43693 .5889 m .44958 .60311 L .46348 .59754 L p 0 .31 .951 r
F P
0 g
s
.46348 .59754 m .45072 .58319 L .43693 .5889 L p 0 .31 .951 r
F P
0 g
s
.46348 .59754 m .45072 .58319 L .46479 .57737 L p 0 .31 .951 r
F P
0 g
s
.4633 .6062 m .45038 .59168 L .46479 .57737 L p 0 .35 .78 r
F P
0 g
s
.45038 .59168 m .4633 .6062 L .44886 .62059 L p 0 .35 .78 r
F P
0 g
s
.44958 .60311 m .43593 .60857 L .42188 .62252 L p 0 .05 .112 r
F P
0 g
s
.43593 .60857 m .44958 .60311 L .43693 .5889 L p 0 .31 .951 r
F P
0 g
s
.43693 .5889 m .42339 .5945 L .43593 .60857 L p 0 .31 .951 r
F P
0 g
s
.43593 .60857 m .42339 .5945 L .43693 .5889 L p 0 .31 .951 r
F P
0 g
s
.42188 .62252 m .43542 .61719 L .44958 .60311 L p 0 .05 .112 r
F P
0 g
s
.44958 .60311 m .43693 .5889 L .45072 .58319 L p 0 .31 .951 r
F P
0 g
s
.42255 .61393 m .43593 .60857 L .43259 .60482 L p 0 .31 .951 r
F P
0 g
s
.43593 .60857 m .42255 .61393 L .4086 .62776 L p 0 .05 .112 r
F P
0 g
s
.4086 .62776 m .42188 .62252 L .43593 .60857 L p 0 .05 .112 r
F P
0 g
s
.43693 .5889 m .44958 .60311 L .43542 .61719 L p 0 .349 .781 r
F P
0 g
s
.44958 .60311 m .43542 .61719 L .44922 .61175 L p 0 .05 .112 r
F P
0 g
s
.43542 .61719 m .44958 .60311 L .43693 .5889 L p 0 .349 .781 r
F P
0 g
s
.43259 .60482 m .42339 .5945 L p .42277 .60879 L 0 .31 .951 r
F P
0 g
s
.42277 .60879 m .42255 .61393 L .43259 .60482 L 0 .31 .951 r
F
.43542 .61719 m .42273 .60296 L .43693 .5889 L p 0 .349 .781 r
F P
0 g
s
.43693 .5889 m .42273 .60296 L .43542 .61719 L p 0 .349 .781 r
F P
0 g
s
.4349 .62601 m .44922 .61175 L .43542 .61719 L p 0 .05 .112 r
F P
0 g
s
.44886 .62059 m .4359 .60605 L .45038 .59168 L p 0 .35 .78 r
F P
0 g
s
.43542 .61719 m .42188 .62252 L .40777 .63654 L p 0 .05 .112 r
F P
0 g
s
.40777 .63654 m .4212 .63133 L .43542 .61719 L p 0 .05 .112 r
F P
0 g
s
.4086 .62776 m .42255 .61393 L .41012 .59999 L p 0 .349 .782 r
F P
0 g
s
.42273 .60296 m .43542 .61719 L .4212 .63133 L p 0 .349 .781 r
F P
0 g
s
.43542 .61719 m .4212 .63133 L .4349 .62601 L p 0 .05 .112 r
F P
0 g
s
.4212 .63133 m .43542 .61719 L .42273 .60296 L p 0 .349 .781 r
F P
0 g
s
.4205 .64035 m .4349 .62601 L .4212 .63133 L p 0 .05 .112 r
F P
0 g
s
.4349 .62601 m .4205 .64035 L .43436 .63505 L p 0 .05 .112 r
F P
0 g
s
.4359 .60605 m .44886 .62059 L .43436 .63505 L p 0 .35 .78 r
F P
0 g
s
.4869 .58055 m .43483 .63418 L .49505 .57413 L .95 0 0 r
F
.4869 .58055 m .49505 .57413 L .50387 .56533 L F
.50333 .56363 m .4869 .58055 L .50387 .56533 L F
.49239 .57685 m .49197 .57761 L .50336 .56624 L .89 0 0 r
F
.50387 .56533 m .43483 .63418 L .43436 .63505 L F
.41012 .59999 m .39614 .61381 L .4086 .62776 L p 0 .349 .782 r
F P
0 g
s
.4212 .63133 m .40848 .61707 L .42273 .60296 L p 0 .349 .781 r
F P
0 g
s
.42273 .60296 m .40848 .61707 L .4212 .63133 L p 0 .349 .781 r
F P
0 g
s
.43436 .63505 m .42136 .62049 L .4359 .60605 L p 0 .35 .78 r
F P
0 g
s
.50333 .56363 m .43424 .63249 L .43483 .63418 L .95 0 0 r
F
.50188 .56159 m .43424 .63249 L .50333 .56363 L .885 0 0 r
F
.49256 .5721 m .48082 .58535 L .50309 .56779 L .157 0 0 r
F
.49239 .57685 m .43436 .63505 L .49197 .57761 L .89 0 0 r
F
.445 .62573 m .48867 .58217 L p .48082 .58535 L .157 0 0 r
F P
0 g
s
.48867 .58217 m .50309 .56779 L p .48082 .58535 L .157 0 0 r
F P
0 g
s
.52309 .55255 m .51979 .56072 L .50562 .56653 L p 0 .086 .523 r
F P
0 g
s
.50333 .56363 m .50387 .56533 L .52948 .5845 L .532 0 0 r
F
.5222 .57803 m .53462 .56558 L .52033 .57134 L p 0 .05 .14 r
F P
0 g
s
.52309 .55255 m .53462 .56558 L .52033 .57134 L p 0 .313 .947 r
F P
0 g
s
.5222 .57803 m .53462 .56558 L .54919 .55972 L p 0 .05 .14 r
F P
0 g
s
.53462 .56558 m .5222 .57803 L .53668 .57227 L p 0 .05 .14 r
F P
0 g
s
.51666 .57177 m .5222 .57803 L .53462 .56558 L p 0 .349 .781 r
F P
0 g
s
.51979 .56072 m .51666 .57177 L p .53462 .56558 L 0 .349 .781 r
F P
0 g
s
.52309 .55255 m .53462 .56558 L .5222 .57803 L p 0 .349 .781 r
F P
0 g
s
.51979 .56072 m .52309 .55255 L p .5222 .57803 L 0 .349 .781 r
F P
0 g
s
.5326 .55905 m .54484 .54681 L .53064 .55266 L p 0 .05 .14 r
F P
0 g
s
.53064 .55266 m .54273 .54057 L .55702 .53462 L p 0 .05 .14 r
F P
0 g
s
.54273 .54057 m .53064 .55266 L .54484 .54681 L p 0 .05 .14 r
F P
0 g
s
.53009 .55205 m .53064 .55266 L .54273 .54057 L p 0 .349 .782 r
F P
0 g
s
.54273 .54057 m .54219 .53996 L .53009 .55205 L p 0 .349 .782 r
F P
0 g
s
.53009 .55205 m .54219 .53996 L .54017 .53327 L p 0 .432 .873 r
F P
0 g
s
.55702 .53462 m .54484 .54681 L .53064 .55266 L p 0 .05 .14 r
F P
0 g
s
.52555 .5373 m .53009 .55205 L p .54017 .53327 L 0 .432 .873 r
F P
0 g
s
.54017 .53327 m .53197 .53493 L .52555 .5373 L p 0 .432 .873 r
F P
0 g
s
.53197 .53493 m .54017 .53327 L .55158 .52845 L p 0 .478 .97 r
F P
0 g
s
.55158 .52845 m .54122 .53101 L .53197 .53493 L p 0 .478 .97 r
F P
0 g
s
.52555 .5373 m .53197 .53493 L .54122 .53101 L p 0 .446 .815 r
F P
0 g
s
.54122 .53101 m .53347 .53394 L .52555 .5373 L p 0 .446 .815 r
F P
0 g
s
.53347 .53394 m .54484 .54681 L .53064 .55266 L p 0 .314 .946 r
F P
0 g
s
.53064 .55266 m .54484 .54681 L p .52555 .5373 L 0 .314 .946 r
F P
0 g
s
.54484 .54681 m .53347 .53394 L .52555 .5373 L p 0 .314 .946 r
F P
0 g
s
.53347 .53394 m .54484 .54681 L .5326 .55905 L p 0 .349 .781 r
F P
0 g
s
.52555 .5373 m .53347 .53394 L p .53064 .55266 L 0 .314 .946 r
F P
0 g
s
.53064 .55266 m .53009 .55205 L .52555 .5373 L p 0 .314 .946 r
F P
0 g
s
.52555 .5373 m .53009 .55205 L .53064 .55266 L p 0 .314 .946 r
F P
0 g
s
.51893 .54358 m .5326 .55905 L .54484 .54681 L p 0 .349 .781 r
F P
0 g
s
.52473 .5376 m .52555 .5373 L .53347 .53394 L p 0 .446 .815 r
F P
0 g
s
.53347 .53394 m .53248 .53431 L .52473 .5376 L p 0 .446 .815 r
F P
0 g
s
.53248 .53431 m .53347 .53394 L p .5326 .55905 L 0 .349 .781 r
F P
0 g
s
.52513 .53846 m .53248 .53431 L p .5326 .55905 L 0 .349 .781 r
F P
0 g
s
.5326 .55905 m .51893 .54358 L .52513 .53846 L p 0 .349 .781 r
F P
0 g
s
.5326 .55905 m .54484 .54681 L .55931 .54084 L p 0 .05 .14 r
F P
0 g
s
.54484 .54681 m .5326 .55905 L .54699 .55319 L p 0 .05 .14 r
F P
0 g
s
.52513 .53846 m .51893 .54358 L p .54484 .54681 L 0 .349 .781 r
F P
0 g
s
.53248 .53431 m .52513 .53846 L p .54484 .54681 L 0 .349 .781 r
F P
0 g
s
.55931 .54084 m .54699 .55319 L .5326 .55905 L p 0 .05 .14 r
F P
0 g
s
.53319 .53757 m .54699 .55319 L .5326 .55905 L p 0 .314 .946 r
F P
0 g
s
.5326 .55905 m .51893 .54358 L .53319 .53757 L p 0 .314 .946 r
F P
0 g
s
.51893 .54358 m .5326 .55905 L .54699 .55319 L p 0 .314 .946 r
F P
0 g
s
.53462 .56558 m .54699 .55319 L .5326 .55905 L p 0 .05 .14 r
F P
0 g
s
.52309 .55255 m .53462 .56558 L .54699 .55319 L p 0 .349 .781 r
F P
0 g
s
.54699 .55319 m .53319 .53757 L .51893 .54358 L p 0 .314 .946 r
F P
0 g
s
.53319 .53757 m .54699 .55319 L .53462 .56558 L p 0 .349 .781 r
F P
0 g
s
.52794 .54388 m .53319 .53757 L p .53462 .56558 L 0 .349 .781 r
F P
0 g
s
.52351 .55152 m .52794 .54388 L p .53462 .56558 L 0 .349 .781 r
F P
0 g
s
.54699 .55319 m .53462 .56558 L .54919 .55972 L p 0 .05 .14 r
F P
0 g
s
.53462 .56558 m .54699 .55319 L .56165 .54722 L p 0 .05 .14 r
F P
0 g
s
.56165 .54722 m .54919 .55972 L .53462 .56558 L p 0 .05 .14 r
F P
0 g
s
.53462 .56558 m .52309 .55255 L .52351 .55152 L p 0 .349 .781 r
F P
0 g
s
.52309 .55255 m .53462 .56558 L .54919 .55972 L p 0 .313 .947 r
F P
0 g
s
.53462 .56558 m .52309 .55255 L .51979 .56072 L p 0 .349 .781 r
F P
0 g
s
.52351 .55152 m .52309 .55255 L p .54699 .55319 L 0 .349 .781 r
F P
0 g
s
.52794 .54388 m .52351 .55152 L p .54699 .55319 L 0 .349 .781 r
F P
0 g
s
.54699 .55319 m .53319 .53757 L .52794 .54388 L p 0 .349 .781 r
F P
0 g
s
.53462 .56558 m .52309 .55255 L .53756 .54656 L p 0 .313 .947 r
F P
0 g
s
.54919 .55972 m .53756 .54656 L .52309 .55255 L p 0 .313 .947 r
F P
0 g
s
.5222 .57803 m .51666 .57177 L .51979 .56072 L p 0 .349 .781 r
F P
0 g
s
.51666 .57177 m .51979 .56072 L .53424 .5548 L p 0 .118 .59 r
F P
0 g
s
.5222 .57803 m .51666 .57177 L .53109 .56595 L p 0 .312 .948 r
F P
0 g
s
.54919 .55972 m .53668 .57227 L .5222 .57803 L p 0 .05 .14 r
F P
0 g
s
.53109 .56595 m .53668 .57227 L .5222 .57803 L p 0 .312 .948 r
F P
0 g
s
.53424 .5548 m .53109 .56595 L .51666 .57177 L p 0 .118 .59 r
F P
0 g
s
.50333 .56363 m .52948 .5845 L .5255 .57172 L .532 0 0 r
F
.50188 .56159 m .50333 .56363 L .5255 .57172 L F
.50188 .56159 m .5255 .57172 L .51458 .55633 L F
.51458 .55633 m .50188 .56159 L p .49256 .5721 L .157 0 0 r
F P
0 g
s
.50309 .56779 m .51458 .55633 L p .49256 .5721 L .157 0 0 r
F P
0 g
s
.50188 .56159 m .51458 .55633 L .50309 .56779 L .157 0 0 r
F
.49256 .5721 m .50309 .56779 L .445 .62573 L F
.50188 .56159 m .50309 .56779 L .49256 .5721 L F
.50188 .56159 m .43276 .63045 L .43424 .63249 L .885 0 0 r
F
.49256 .5721 m .48082 .58535 L .49047 .57296 L .157 0 0 r
F
.48082 .58535 m .445 .62573 L .47925 .58598 L F
.48082 .58535 m .47925 .58598 L .49047 .57296 L F
.47614 .58723 m .445 .62573 L .43276 .63045 L F
.49047 .57296 m .47925 .58598 L .47614 .58723 L F
.47925 .58598 m .445 .62573 L .47614 .58723 L F
.50188 .56159 m .49256 .5721 L .49047 .57296 L F
.52948 .5845 m .49327 .62227 L .49518 .61895 L .875 0 0 r
F
.52948 .5845 m .52552 .59125 L .49138 .62556 L F
.52948 .5845 m .49138 .62556 L .49327 .62227 L F
.49518 .61895 m .49783 .62315 L .49978 .62243 L .521 0 0 r
F
.49783 .62315 m .51878 .65638 L .49978 .62243 L F
.49518 .61895 m .45685 .66026 L .4605 .65379 L .875 0 0 r
F
.49327 .62227 m .45685 .66026 L .49518 .61895 L F
.49327 .62227 m .49138 .62556 L .45685 .66026 L F
.39921 .55837 m .38522 .57207 L .39768 .58604 L p 0 .349 .782 r
F P
0 g
s
.39921 .55837 m .38522 .57207 L .39827 .56631 L p 0 .05 .1 r
F P
0 g
s
.37726 .554 m .38835 .54319 L p .3791 .55316 L .1 0 0 r
F P
0 g
s
.38835 .54319 m .39953 .53802 L .38836 .54892 L p .1 0 0 r
F P
0 g
s
.38836 .54892 m .37436 .56259 L p .3791 .55316 L .1 0 0 r
F P
0 g
s
.3791 .55316 m .37436 .56259 L .36745 .56572 L .1 0 0 r
F
.36334 .56758 m .37726 .554 L p .36608 .56634 L F P
0 g
s
.3791 .55316 m .36745 .56572 L .37726 .554 L .1 0 0 r
F
.36745 .56572 m .33195 .60398 L .36608 .56634 L F
.36745 .56572 m .36608 .56634 L .37726 .554 L F
.39953 .53802 m .38835 .54319 L .32121 .60866 L F
.37436 .56259 m .33195 .60398 L p .36745 .56572 L F P
0 g
s
.38835 .54319 m .38836 .54892 L .3791 .55316 L .1 0 0 r
F
.33195 .60398 m .32121 .60866 L .36334 .56758 L p F P
0 g
s
.36608 .56634 m .33195 .60398 L .36334 .56758 L .1 0 0 r
F
.38836 .54892 m .32121 .60866 L .33195 .60398 L F
.39953 .53802 m .3865 .54977 L .38836 .54892 L F
.3865 .54977 m .32121 .60866 L .38836 .54892 L F
.39953 .53802 m .38813 .54859 L .39811 .53606 L .881 0 0 r
F
.38813 .54859 m .3305 .60201 L .38694 .54695 L F
.38813 .54859 m .38694 .54695 L .39811 .53606 L F
.39953 .53802 m .33195 .60398 L .3305 .60201 L F
.39811 .53606 m .39753 .5344 L .37334 .51614 L .532 0 0 r
F
.39811 .53606 m .32988 .60038 L .39753 .5344 L .941 0 0 r
F
.39811 .53606 m .3305 .60201 L .32988 .60038 L F
.35496 .57575 m .34171 .5817 L .30823 .61432 L .1 0 0 r
F
.32121 .60866 m .30823 .61432 L .34171 .5817 L p F P
0 g
s
.34171 .5817 m .35496 .57575 L .32121 .60866 L p .1 0 0 r
F P
0 g
s
.35496 .57575 m .30823 .61432 L .32121 .60866 L .1 0 0 r
F
.35496 .57575 m .31035 .59399 L .32121 .60866 L .88 0 0 r
F
.3496 .56843 m .31035 .59399 L .35496 .57575 L F
.35496 .57575 m .31035 .59399 L .34423 .5611 L F
.35496 .57575 m .32121 .60866 L .31035 .59399 L F
.39753 .5344 m .39795 .5335 L .3764 .50928 L .532 0 0 r
F
.39753 .5344 m .33026 .59951 L .39795 .5335 L .931 0 0 r
F
.39753 .5344 m .32988 .60038 L .33026 .59951 L F
.40074 .53078 m .38677 .5444 L .39921 .55837 L p 0 .349 .782 r
F P
0 g
s
.39982 .53838 m .38677 .5444 L p .39355 .54654 L 0 .31 .951 r
F P
0 g
s
.41314 .54472 m .39921 .55837 L .41163 .57232 L p 0 .349 .782 r
F P
0 g
s
.41314 .54472 m .39921 .55837 L .41237 .55248 L p 0 .05 .1 r
F P
0 g
s
.39921 .55837 m .41314 .54472 L .40074 .53078 L p 0 .349 .782 r
F P
0 g
s
.42553 .55865 m .41314 .54472 L .4264 .53872 L p 0 .311 .95 r
F P
0 g
s
.42608 .5581 m .42553 .55865 L .4389 .55278 L p 0 .05 .1 r
F P
0 g
s
.44652 .54187 m .42608 .5581 L p .4389 .55278 L 0 .05 .1 r
F P
0 g
s
.42553 .55865 m .42608 .5581 L .44652 .54187 L p 0 .05 .1 r
F P
0 g
s
.4515 .54896 m .44652 .54187 L p .45535 .55864 L 0 .346 .852 r
F P
0 g
s
.44652 .54187 m .4515 .54896 L .45811 .54607 L p 0 .298 .927 r
F P
0 g
s
.45811 .54607 m .45284 .53906 L .44652 .54187 L p 0 .298 .927 r
F P
0 g
s
.45284 .53906 m .4389 .55278 L .42553 .55865 L p 0 .05 .1 r
F P
0 g
s
.44652 .54187 m .45284 .53906 L p .42553 .55865 L 0 .05 .1 r
F P
0 g
s
.41314 .54472 m .42553 .55865 L .4389 .55278 L p 0 .311 .95 r
F P
0 g
s
.41163 .57232 m .42553 .55865 L .41314 .54472 L p 0 .349 .782 r
F P
0 g
s
.4389 .55278 m .4264 .53872 L .41314 .54472 L p 0 .311 .95 r
F P
0 g
s
.39921 .55837 m .41314 .54472 L .4264 .53872 L p 0 .05 .1 r
F P
0 g
s
.4264 .53872 m .41237 .55248 L .39921 .55837 L p 0 .05 .1 r
F P
0 g
s
.41237 .55248 m .40317 .54214 L p .39355 .54654 L 0 .31 .951 r
F P
0 g
s
.40317 .54214 m .39982 .53838 L p .39355 .54654 L 0 .31 .951 r
F P
0 g
s
.38677 .5444 m .37274 .55809 L .38522 .57207 L p 0 .349 .782 r
F P
0 g
s
.38568 .55218 m .37274 .55809 L p .3795 .56026 L 0 .31 .951 r
F P
0 g
s
.38522 .57207 m .39921 .55837 L .38677 .5444 L p 0 .349 .782 r
F P
0 g
s
.39493 .56256 m .38904 .55595 L p .38605 .5573 L 0 .31 .951 r
F P
0 g
s
.39493 .56256 m .38605 .5573 L .3795 .56026 L 0 .31 .951 r
F
.41163 .57232 m .42553 .55865 L .4389 .55278 L p 0 .05 .1 r
F P
0 g
s
.4389 .55278 m .4249 .56657 L .41163 .57232 L p 0 .05 .1 r
F P
0 g
s
.39921 .55837 m .41163 .57232 L .4249 .56657 L p 0 .31 .951 r
F P
0 g
s
.39768 .58604 m .41163 .57232 L .39921 .55837 L p 0 .349 .782 r
F P
0 g
s
.41163 .57232 m .39921 .55837 L .41237 .55248 L p 0 .31 .951 r
F P
0 g
s
.4249 .56657 m .41237 .55248 L .39921 .55837 L p 0 .31 .951 r
F P
0 g
s
.38522 .57207 m .39921 .55837 L .41237 .55248 L p 0 .05 .1 r
F P
0 g
s
.41237 .55248 m .39827 .56631 L .38522 .57207 L p 0 .05 .1 r
F P
0 g
s
.39827 .56631 m .39493 .56256 L p .3795 .56026 L 0 .31 .951 r
F P
0 g
s
.38904 .55595 m .38568 .55218 L p .3795 .56026 L 0 .31 .951 r
F P
0 g
s
.37274 .55809 m .38568 .55218 L p .38556 .55752 L 0 .31 .951 r
F P
0 g
s
.38522 .57207 m .37607 .56182 L p .38556 .55752 L 0 .31 .951 r
F P
0 g
s
.37607 .56182 m .37274 .55809 L p .38556 .55752 L 0 .31 .951 r
F P
0 g
s
.38677 .5444 m .39982 .53838 L p .39965 .54375 L 0 .31 .951 r
F P
0 g
s
.39921 .55837 m .39009 .54813 L p .39965 .54375 L 0 .31 .951 r
F P
0 g
s
.39009 .54813 m .38677 .5444 L p .39965 .54375 L 0 .31 .951 r
F P
0 g
s
.38522 .57207 m .39827 .56631 L p .3795 .56026 L 0 .31 .951 r
F P
0 g
s
.37274 .55809 m .37607 .56182 L p .3795 .56026 L 0 .31 .951 r
F P
0 g
s
.37607 .56182 m .38522 .57207 L p .3795 .56026 L 0 .31 .951 r
F P
0 g
s
.39921 .55837 m .41237 .55248 L p .39355 .54654 L 0 .31 .951 r
F P
0 g
s
.38677 .5444 m .39009 .54813 L p .39355 .54654 L 0 .31 .951 r
F P
0 g
s
.39009 .54813 m .39921 .55837 L p .39355 .54654 L 0 .31 .951 r
F P
0 g
s
.4137 .54418 m .41314 .54472 L .4264 .53872 L p 0 .05 .1 r
F P
0 g
s
.40074 .53078 m .41314 .54472 L .4264 .53872 L p 0 .311 .95 r
F P
0 g
s
.38677 .5444 m .39795 .5335 L p .40844 .52862 L 0 .05 .1 r
F P
0 g
s
.39795 .5335 m .40074 .53078 L p .40844 .52862 L 0 .05 .1 r
F P
0 g
s
.33967 .54875 m .3084 .5751 L .34258 .54201 L .94 0 0 r
F
.33967 .54875 m .30564 .58171 L .3084 .5751 L F
.39795 .5335 m .3084 .5751 L .3764 .50928 L .856 0 0 r
F
.33026 .59951 m .39795 .5335 L .3764 .50928 L p F P
0 g
s
.34423 .5611 m .30564 .58171 L .31035 .59399 L .94 0 0 r
F
.34423 .5611 m .31035 .59399 L .30564 .58171 L F
.3764 .50928 m .3084 .5751 L .33026 .59951 L p .856 0 0 r
F P
0 g
s
.34258 .54201 m .3084 .5751 L .33349 .56341 L p .1 0 0 r
F P
0 g
s
.33349 .56341 m .35958 .55125 L p .35089 .54653 L .1 0 0 r
F P
0 g
s
.34258 .54201 m .33349 .56341 L .35089 .54653 L .1 0 0 r
F
.39795 .5335 m .33026 .59951 L .3084 .5751 L .856 0 0 r
F
.39768 .58604 m .38522 .57207 L .37116 .58584 L p 0 .349 .782 r
F P
0 g
s
.35864 .57183 m .37116 .58584 L .38522 .57207 L p 0 .349 .782 r
F P
0 g
s
.38522 .57207 m .37274 .55809 L .35864 .57183 L p 0 .349 .782 r
F P
0 g
s
.38568 .55218 m .39827 .56631 L .38522 .57207 L p 0 .31 .951 r
F P
0 g
s
.35864 .57183 m .37274 .55809 L .38568 .55218 L p 0 .05 .1 r
F P
0 g
s
.34449 .58564 m .35704 .59967 L .37116 .58584 L p 0 .349 .782 r
F P
0 g
s
.37116 .58584 m .35864 .57183 L .34449 .58564 L p 0 .349 .782 r
F P
0 g
s
.34449 .58564 m .35864 .57183 L .37148 .56604 L p 0 .05 .1 r
F P
0 g
s
.38568 .55218 m .37148 .56604 L .35864 .57183 L p 0 .05 .1 r
F P
0 g
s
.35704 .59967 m .34449 .58564 L .33026 .59951 L p 0 .349 .782 r
F P
0 g
s
.33026 .59951 m .34449 .58564 L .35721 .57997 L p 0 .05 .1 r
F P
0 g
s
.37148 .56604 m .35721 .57997 L .34449 .58564 L p 0 .05 .1 r
F P
0 g
s
.39827 .56631 m .41237 .55248 L .39921 .55837 L p 0 .05 .1 r
F P
0 g
s
.39982 .53838 m .41237 .55248 L .39921 .55837 L p 0 .31 .951 r
F P
0 g
s
.41237 .55248 m .39827 .56631 L .38568 .55218 L p 0 .349 .781 r
F P
0 g
s
.38568 .55218 m .39982 .53838 L .41237 .55248 L p 0 .349 .781 r
F P
0 g
s
.35721 .57997 m .34288 .59396 L .33026 .59951 L p 0 .05 .1 r
F P
0 g
s
.39982 .53838 m .38568 .55218 L .39827 .56631 L p 0 .349 .781 r
F P
0 g
s
.41237 .55248 m .4249 .56657 L .41163 .57232 L p 0 .31 .951 r
F P
0 g
s
.39827 .56631 m .41237 .55248 L .4249 .56657 L p 0 .349 .781 r
F P
0 g
s
.41163 .57232 m .39768 .58604 L .41012 .59999 L p 0 .349 .782 r
F P
0 g
s
.41163 .57232 m .39768 .58604 L .41084 .58041 L p 0 .05 .1 r
F P
0 g
s
.4379 .57256 m .42404 .58625 L .43742 .58063 L p 0 .05 .1 r
F P
0 g
s
.45138 .56683 m .43742 .58063 L .42404 .58625 L p 0 .05 .1 r
F P
0 g
s
.41163 .57232 m .42404 .58625 L .43742 .58063 L p 0 .31 .951 r
F P
0 g
s
.41012 .59999 m .42404 .58625 L .41163 .57232 L p 0 .349 .782 r
F P
0 g
s
.42404 .58625 m .41163 .57232 L .4249 .56657 L p 0 .31 .951 r
F P
0 g
s
.43742 .58063 m .4249 .56657 L .41163 .57232 L p 0 .31 .951 r
F P
0 g
s
.39768 .58604 m .41163 .57232 L .4249 .56657 L p 0 .05 .1 r
F P
0 g
s
.4249 .56657 m .41084 .58041 L .39768 .58604 L p 0 .05 .1 r
F P
0 g
s
.41237 .55248 m .39827 .56631 L .41084 .58041 L p 0 .349 .781 r
F P
0 g
s
.41237 .55248 m .39827 .56631 L .41157 .56043 L p 0 .05 .1 r
F P
0 g
s
.39827 .56631 m .41237 .55248 L .39982 .53838 L p 0 .349 .781 r
F P
0 g
s
.4264 .53872 m .4389 .55278 L .42553 .55865 L p 0 .311 .95 r
F P
0 g
s
.4389 .55278 m .4249 .56657 L .41237 .55248 L p 0 .349 .781 r
F P
0 g
s
.41237 .55248 m .4264 .53872 L .4389 .55278 L p 0 .349 .781 r
F P
0 g
s
.4264 .53872 m .41237 .55248 L .4249 .56657 L p 0 .349 .781 r
F P
0 g
s
.4389 .55278 m .45138 .56683 L .4379 .57256 L p 0 .311 .95 r
F P
0 g
s
.4249 .56657 m .4389 .55278 L .45138 .56683 L p 0 .349 .781 r
F P
0 g
s
.4389 .55278 m .4249 .56657 L .43742 .58063 L p 0 .349 .781 r
F P
0 g
s
.4389 .55278 m .4249 .56657 L .43843 .56071 L p 0 .05 .1 r
F P
0 g
s
.4249 .56657 m .4389 .55278 L .4264 .53872 L p 0 .349 .781 r
F P
0 g
s
.45535 .55864 m .45509 .55749 L .4515 .54896 L p 0 .346 .852 r
F P
0 g
s
.46297 .55537 m .46255 .55428 L .45509 .55749 L p 0 .25 .847 r
F P
0 g
s
.4515 .54896 m .45509 .55749 L .46255 .55428 L p 0 .272 .885 r
F P
0 g
s
.46255 .55428 m .46297 .55537 L p .4389 .55278 L 0 .349 .781 r
F P
0 g
s
.46255 .55428 m .45811 .54607 L .4515 .54896 L p 0 .272 .885 r
F P
0 g
s
.45811 .54607 m .46255 .55428 L p .4389 .55278 L 0 .349 .781 r
F P
0 g
s
.45138 .56683 m .46297 .55537 L .45535 .55864 L p 0 .05 .1 r
F P
0 g
s
.45509 .55749 m .45535 .55864 L .46297 .55537 L p 0 .25 .847 r
F P
0 g
s
.46297 .55537 m .45138 .56683 L .4389 .55278 L p 0 .349 .781 r
F P
0 g
s
.4389 .55278 m .45284 .53906 L .45811 .54607 L p 0 .349 .781 r
F P
0 g
s
.45811 .54607 m .45284 .53906 L p .45138 .56683 L 0 .349 .781 r
F P
0 g
s
.45284 .53906 m .4389 .55278 L .45138 .56683 L p 0 .349 .781 r
F P
0 g
s
.43742 .58063 m .45138 .56683 L .4379 .57256 L p 0 .05 .1 r
F P
0 g
s
.43742 .58063 m .45138 .56683 L .4389 .55278 L p 0 .349 .781 r
F P
0 g
s
.45138 .56683 m .4389 .55278 L .45253 .5468 L p 0 .311 .95 r
F P
0 g
s
.46255 .55428 m .45811 .54607 L p .45138 .56683 L 0 .349 .781 r
F P
0 g
s
.45138 .56683 m .46297 .55537 L .46255 .55428 L p 0 .349 .781 r
F P
0 g
s
.45138 .56683 m .46297 .55537 L .47679 .54943 L p 0 .05 .1 r
F P
0 g
s
.46297 .55537 m .45138 .56683 L .46512 .56099 L p 0 .05 .1 r
F P
0 g
s
.47679 .54943 m .46512 .56099 L .45138 .56683 L p 0 .05 .1 r
F P
0 g
s
.4389 .55278 m .45138 .56683 L .46512 .56099 L p 0 .311 .95 r
F P
0 g
s
.46512 .56099 m .45253 .5468 L .4389 .55278 L p 0 .311 .95 r
F P
0 g
s
.4249 .56657 m .4389 .55278 L .45253 .5468 L p 0 .05 .1 r
F P
0 g
s
.45253 .5468 m .43843 .56071 L .4249 .56657 L p 0 .05 .1 r
F P
0 g
s
.41237 .55248 m .4249 .56657 L .43843 .56071 L p 0 .31 .951 r
F P
0 g
s
.41084 .58041 m .4249 .56657 L .41163 .57232 L p 0 .05 .1 r
F P
0 g
s
.41084 .58041 m .4249 .56657 L .41237 .55248 L p 0 .349 .781 r
F P
0 g
s
.4249 .56657 m .41237 .55248 L .42578 .54648 L p 0 .31 .951 r
F P
0 g
s
.43843 .56071 m .42578 .54648 L .41237 .55248 L p 0 .31 .951 r
F P
0 g
s
.39827 .56631 m .41237 .55248 L .42578 .54648 L p 0 .05 .1 r
F P
0 g
s
.42578 .54648 m .41157 .56043 L .39827 .56631 L p 0 .05 .1 r
F P
0 g
s
.38568 .55218 m .39827 .56631 L .41157 .56043 L p 0 .31 .951 r
F P
0 g
s
.39827 .56631 m .38568 .55218 L .39887 .54616 L p 0 .31 .951 r
F P
0 g
s
.41157 .56043 m .39887 .54616 L .38568 .55218 L p 0 .31 .951 r
F P
0 g
s
.37148 .56604 m .38568 .55218 L .39887 .54616 L p 0 .05 .1 r
F P
0 g
s
.35721 .57997 m .37148 .56604 L .38456 .56014 L p 0 .05 .1 r
F P
0 g
s
.39887 .54616 m .38456 .56014 L .37148 .56604 L p 0 .05 .1 r
F P
0 g
s
.34288 .59396 m .35721 .57997 L .37019 .57419 L p 0 .05 .1 r
F P
0 g
s
.38456 .56014 m .37019 .57419 L .35721 .57997 L p 0 .05 .1 r
F P
0 g
s
.37019 .57419 m .35575 .58831 L .34288 .59396 L p 0 .05 .1 r
F P
0 g
s
.39887 .54616 m .41157 .56043 L .39827 .56631 L p 0 .31 .951 r
F P
0 g
s
.38456 .56014 m .39887 .54616 L .41157 .56043 L p 0 .349 .781 r
F P
0 g
s
.39768 .58604 m .38522 .57207 L .39827 .56631 L p 0 .31 .951 r
F P
0 g
s
.39827 .56631 m .41084 .58041 L .39768 .58604 L p 0 .31 .951 r
F P
0 g
s
.41084 .58041 m .39827 .56631 L .38522 .57207 L p 0 .31 .951 r
F P
0 g
s
.4249 .56657 m .41084 .58041 L .39827 .56631 L p 0 .349 .781 r
F P
0 g
s
.4249 .56657 m .43742 .58063 L .42404 .58625 L p 0 .31 .951 r
F P
0 g
s
.41084 .58041 m .4249 .56657 L .43742 .58063 L p 0 .349 .781 r
F P
0 g
s
.41012 .59999 m .42404 .58625 L .43742 .58063 L p 0 .05 .1 r
F P
0 g
s
.42404 .58625 m .41012 .59999 L .42339 .5945 L p 0 .05 .1 r
F P
0 g
s
.43742 .58063 m .42339 .5945 L .41012 .59999 L p 0 .05 .1 r
F P
0 g
s
.4249 .56657 m .41084 .58041 L .42339 .5945 L p 0 .349 .781 r
F P
0 g
s
.4249 .56657 m .41084 .58041 L .42426 .57467 L p 0 .05 .1 r
F P
0 g
s
.45138 .56683 m .43742 .58063 L .4249 .56657 L p 0 .349 .781 r
F P
0 g
s
.43742 .58063 m .45138 .56683 L .46512 .56099 L p 0 .05 .1 r
F P
0 g
s
.45138 .56683 m .43742 .58063 L .45105 .57491 L p 0 .05 .1 r
F P
0 g
s
.46512 .56099 m .45105 .57491 L .43742 .58063 L p 0 .05 .1 r
F P
0 g
s
.4249 .56657 m .43742 .58063 L .45105 .57491 L p 0 .31 .951 r
F P
0 g
s
.42339 .5945 m .43742 .58063 L .42404 .58625 L p 0 .05 .1 r
F P
0 g
s
.42339 .5945 m .43742 .58063 L .4249 .56657 L p 0 .349 .781 r
F P
0 g
s
.43742 .58063 m .4249 .56657 L .43843 .56071 L p 0 .31 .951 r
F P
0 g
s
.45105 .57491 m .43843 .56071 L .4249 .56657 L p 0 .31 .951 r
F P
0 g
s
.41084 .58041 m .4249 .56657 L .43843 .56071 L p 0 .05 .1 r
F P
0 g
s
.43843 .56071 m .42426 .57467 L .41084 .58041 L p 0 .05 .1 r
F P
0 g
s
.39827 .56631 m .41084 .58041 L .42426 .57467 L p 0 .31 .951 r
F P
0 g
s
.41084 .58041 m .39827 .56631 L .41157 .56043 L p 0 .31 .951 r
F P
0 g
s
.42426 .57467 m .41157 .56043 L .39827 .56631 L p 0 .31 .951 r
F P
0 g
s
.41157 .56043 m .3973 .57443 L .38456 .56014 L p 0 .349 .781 r
F P
0 g
s
.38456 .56014 m .3973 .57443 L .41157 .56043 L p 0 .349 .781 r
F P
0 g
s
.41157 .56043 m .39887 .54616 L .38456 .56014 L p 0 .349 .781 r
F P
0 g
s
.39791 .55413 m .38456 .56014 L .39887 .54616 L p 0 .05 .1 r
F P
0 g
s
.38522 .57207 m .39768 .58604 L .41084 .58041 L p 0 .31 .951 r
F P
0 g
s
.37019 .57419 m .38456 .56014 L .3973 .57443 L p 0 .349 .781 r
F P
0 g
s
.37116 .58584 m .38366 .59983 L .39768 .58604 L p 0 .349 .782 r
F P
0 g
s
.3973 .57443 m .38297 .58851 L .37019 .57419 L p 0 .349 .781 r
F P
0 g
s
.37019 .57419 m .38297 .58851 L .3973 .57443 L p 0 .349 .781 r
F P
0 g
s
.3973 .57443 m .38456 .56014 L .37019 .57419 L p 0 .349 .781 r
F P
0 g
s
.38342 .5683 m .37019 .57419 L .38456 .56014 L p 0 .05 .1 r
F P
0 g
s
.38456 .56014 m .39791 .55413 L .38342 .5683 L p 0 .05 .1 r
F P
0 g
s
.38366 .59983 m .37116 .58584 L .35704 .59967 L p 0 .349 .782 r
F P
0 g
s
.35575 .58831 m .37019 .57419 L .38297 .58851 L p 0 .349 .781 r
F P
0 g
s
.38297 .58851 m .37019 .57419 L .35575 .58831 L p 0 .349 .781 r
F P
0 g
s
.36887 .58254 m .35575 .58831 L .37019 .57419 L p 0 .05 .1 r
F P
0 g
s
.37019 .57419 m .38342 .5683 L .36887 .58254 L p 0 .05 .1 r
F P
0 g
s
.39692 .56229 m .38342 .5683 L .39791 .55413 L p 0 .05 .1 r
F P
0 g
s
.38225 .57666 m .36887 .58254 L .38342 .5683 L p 0 .05 .1 r
F P
0 g
s
.38342 .5683 m .39692 .56229 L .38225 .57666 L p 0 .05 .1 r
F P
0 g
s
.39795 .5335 m .33026 .59951 L .38225 .57666 L p .1 0 0 r
F P
0 g
s
.33026 .59951 m .34285 .61356 L .35704 .59967 L p 0 .349 .782 r
F P
0 g
s
.36957 .61368 m .35704 .59967 L .34285 .61356 L p 0 .349 .782 r
F P
0 g
s
.35559 .60815 m .34285 .61356 L .33026 .59951 L p 0 .307 .954 r
F P
0 g
s
.34285 .61356 m .35559 .60815 L .34288 .59396 L p 0 .307 .954 r
F P
0 g
s
.34288 .59396 m .33026 .59951 L .34285 .61356 L p 0 .307 .954 r
F P
0 g
s
.33026 .59951 m .34288 .59396 L .35559 .60815 L p 0 .307 .954 r
F P
0 g
s
.33195 .60398 m .32121 .60866 L .31035 .59399 L .509 0 0 r
F
.32121 .60866 m .33195 .60398 L .37546 .65255 L p F P
0 g
s
.3305 .60201 m .31035 .59399 L .30564 .58171 L .509 0 0 r
F
.33195 .60398 m .31035 .59399 L .3305 .60201 L F
.3305 .60201 m .30564 .58171 L .32988 .60038 L F
.30823 .61432 m .32121 .60866 L .36439 .65681 L p F P
0 g
s
.37546 .65255 m .36439 .65681 L .32121 .60866 L p .509 0 0 r
F P
0 g
s
.34285 .61356 m .33026 .59951 L .33009 .61994 L closepath p 0 .349 .782 r
F P
0 g
s
.32121 .60866 m .30823 .61432 L .28592 .58427 L .509 0 0 r
F
.32121 .60866 m .28592 .58427 L .31035 .59399 L F
.32988 .60038 m .30564 .58171 L .3084 .5751 L F
.32988 .60038 m .3084 .5751 L .33026 .59951 L F
.33026 .59951 m .31483 .61456 L .33009 .61994 L closepath p 0 .349 .782 r
F P
0 g
s
.33026 .59951 m .34288 .59396 L .32733 .60914 L p 0 .05 .1 r
F P
0 g
s
.34288 .59396 m .33026 .59951 L .31483 .61456 L p 0 .05 .1 r
F P
0 g
s
.3084 .5751 m .34258 .54201 L p .35089 .54653 L .1 0 0 r
F P
0 g
s
.35958 .55125 m .33349 .56341 L p .35089 .54653 L .1 0 0 r
F P
0 g
s
.33349 .56341 m .3084 .5751 L p .35089 .54653 L .1 0 0 r
F P
0 g
s
.31965 .55168 m .27602 .5589 L .28592 .58427 L .938 0 0 r
F
.31965 .55168 m .31008 .52619 L .27602 .5589 L F
.31008 .52619 m .28142 .54498 L .27602 .5589 L .949 0 0 r
F
.34258 .54201 m .3084 .5751 L .28142 .54498 L .856 0 0 r
F
.3084 .5751 m .34258 .54201 L .3158 .51201 L p F P
0 g
s
.31008 .52619 m .3158 .51201 L .28142 .54498 L .949 0 0 r
F
.3158 .51201 m .28142 .54498 L .3084 .5751 L p .856 0 0 r
F P
0 g
s
.29941 .56507 m .33026 .59951 L .34288 .59396 L p 0 .307 .954 r
F P
0 g
s
.38225 .57666 m .33026 .59951 L .3084 .5751 L p .509 0 0 r
F P
0 g
s
.3084 .5751 m .35958 .55125 L .38225 .57666 L p .509 0 0 r
F P
0 g
s
.31458 .57515 m .31774 .57868 L p .31862 .57783 L 0 .349 .781 r
F P
0 g
s
.34288 .59396 m .31176 .55918 L .29941 .56507 L p 0 .307 .954 r
F P
0 g
s
.32233 .57423 m .31458 .57515 L .31862 .57783 L 0 .349 .781 r
F
.35958 .55125 m .3084 .5751 L .28142 .54498 L p .509 0 0 r
F P
0 g
s
.30856 .56843 m .31458 .57515 L p .32233 .57423 L 0 .349 .781 r
F P
0 g
s
.31483 .61456 m .32733 .60914 L .34288 .59396 L p 0 .05 .1 r
F P
0 g
s
.35704 .59967 m .36957 .61368 L .38366 .59983 L p 0 .349 .782 r
F P
0 g
s
.36857 .60264 m .35559 .60815 L .34288 .59396 L p 0 .307 .954 r
F P
0 g
s
.35575 .58831 m .34288 .59396 L .35559 .60815 L p 0 .307 .954 r
F P
0 g
s
.34288 .59396 m .35575 .58831 L .36857 .60264 L p 0 .307 .954 r
F P
0 g
s
.34008 .60362 m .32733 .60914 L .34288 .59396 L p 0 .05 .1 r
F P
0 g
s
.34288 .59396 m .35575 .58831 L .34008 .60362 L p 0 .05 .1 r
F P
0 g
s
.35575 .58831 m .34288 .59396 L .32733 .60914 L p 0 .05 .1 r
F P
0 g
s
.31176 .55918 m .34288 .59396 L .35575 .58831 L p 0 .307 .954 r
F P
0 g
s
.32733 .60914 m .34008 .60362 L .35575 .58831 L p 0 .05 .1 r
F P
0 g
s
.34008 .60362 m .35575 .58831 L p .32233 .57423 L 0 .349 .781 r
F P
0 g
s
.31774 .57868 m .34008 .60362 L p .32233 .57423 L 0 .349 .781 r
F P
0 g
s
.34258 .54201 m .3764 .50928 L p .3682 .52974 L .1 0 0 r
F P
0 g
s
.41389 .52464 m .4264 .53872 L .41314 .54472 L p 0 .311 .95 r
F P
0 g
s
.43014 .52324 m .4195 .51916 L .40893 .52412 L p 0 .4 1 r
F P
0 g
s
.4013 .53024 m .40893 .52412 L .4195 .51916 L p 0 .05 .1 r
F P
0 g
s
.40074 .53078 m .4013 .53024 L p .4195 .51916 L 0 .05 .1 r
F P
0 g
s
.4195 .51916 m .41389 .52464 L .40074 .53078 L p 0 .05 .1 r
F P
0 g
s
.41389 .52464 m .39982 .53838 L .38677 .5444 L p 0 .05 .1 r
F P
0 g
s
.42146 .52725 m .43056 .53072 L .43805 .5273 L p 0 .379 1 r
F P
0 g
s
.43805 .5273 m .43014 .52324 L .42146 .52725 L p 0 .379 1 r
F P
0 g
s
.4264 .53872 m .43805 .5273 L .43056 .53072 L p 0 .05 .1 r
F P
0 g
s
.43805 .5273 m .4264 .53872 L .41389 .52464 L p 0 .349 .781 r
F P
0 g
s
.43014 .52324 m .43805 .5273 L p .41389 .52464 L 0 .349 .781 r
F P
0 g
s
.4195 .51916 m .43014 .52324 L .44367 .51697 L p 0 .4 1 r
F P
0 g
s
.41389 .52464 m .4195 .51916 L .43014 .52324 L p 0 .349 .781 r
F P
0 g
s
.43014 .52324 m .4195 .51916 L p .4264 .53872 L 0 .349 .781 r
F P
0 g
s
.4195 .51916 m .41389 .52464 L .4264 .53872 L p 0 .349 .781 r
F P
0 g
s
.44367 .51697 m .43295 .51285 L .4195 .51916 L p 0 .4 1 r
F P
0 g
s
.41389 .52464 m .4195 .51916 L .43295 .51285 L p 0 .05 .1 r
F P
0 g
s
.3764 .50928 m .39795 .5335 L .41108 .52738 L p .532 0 0 r
F P
0 g
s
.41389 .52464 m .4264 .53872 L p .4211 .53865 L 0 .349 .781 r
F P
0 g
s
.41108 .52738 m .41389 .52464 L p .4211 .53865 L 0 .349 .781 r
F P
0 g
s
.43906 .52782 m .44655 .53304 L p .4264 .53872 L 0 .349 .781 r
F P
0 g
s
.43999 .53599 m .44652 .54187 L .45284 .53906 L p 0 .326 .97 r
F P
0 g
s
.45284 .53906 m .44655 .53304 L .43999 .53599 L p 0 .326 .97 r
F P
0 g
s
.44655 .53304 m .43906 .52782 L p .4389 .55278 L 0 .349 .781 r
F P
0 g
s
.4264 .53872 m .43805 .5273 L .43906 .52782 L p 0 .349 .781 r
F P
0 g
s
.43906 .52782 m .43805 .5273 L p .4389 .55278 L 0 .349 .781 r
F P
0 g
s
.43805 .5273 m .4264 .53872 L .4389 .55278 L p 0 .349 .781 r
F P
0 g
s
.43805 .5273 m .4264 .53872 L .43992 .5326 L p 0 .05 .1 r
F P
0 g
s
.4264 .53872 m .43805 .5273 L .43014 .52324 L p 0 .349 .781 r
F P
0 g
s
.43906 .52782 m .44655 .53304 L .46022 .52688 L p 0 .354 1 r
F P
0 g
s
.46022 .52688 m .45267 .5216 L .43906 .52782 L p 0 .354 1 r
F P
0 g
s
.43805 .5273 m .43906 .52782 L .45267 .5216 L p 0 .379 1 r
F P
0 g
s
.45267 .5216 m .45166 .52108 L .43805 .5273 L p 0 .379 1 r
F P
0 g
s
.4264 .53872 m .43805 .5273 L .45166 .52108 L p 0 .05 .1 r
F P
0 g
s
.45166 .52108 m .43992 .5326 L .4264 .53872 L p 0 .05 .1 r
F P
0 g
s
.41389 .52464 m .4264 .53872 L .43992 .5326 L p 0 .311 .95 r
F P
0 g
s
.41237 .55248 m .4264 .53872 L .41314 .54472 L p 0 .05 .1 r
F P
0 g
s
.41237 .55248 m .4264 .53872 L .41389 .52464 L p 0 .349 .781 r
F P
0 g
s
.4264 .53872 m .41389 .52464 L .4273 .51838 L p 0 .311 .95 r
F P
0 g
s
.43014 .52324 m .43805 .5273 L .45166 .52108 L p 0 .379 1 r
F P
0 g
s
.45166 .52108 m .44367 .51697 L .43014 .52324 L p 0 .379 1 r
F P
0 g
s
.4273 .51838 m .43992 .5326 L .4264 .53872 L p 0 .311 .95 r
F P
0 g
s
.43992 .5326 m .4273 .51838 L .41389 .52464 L p 0 .311 .95 r
F P
0 g
s
.39982 .53838 m .41108 .52738 L p .4211 .53865 L 0 .349 .781 r
F P
0 g
s
.41389 .52464 m .39982 .53838 L .41237 .55248 L p 0 .349 .781 r
F P
0 g
s
.39982 .53838 m .41389 .52464 L .4273 .51838 L p 0 .05 .1 r
F P
0 g
s
.43295 .51285 m .4273 .51838 L .41389 .52464 L p 0 .05 .1 r
F P
0 g
s
.4273 .51838 m .41312 .53224 L .39982 .53838 L p 0 .05 .1 r
F P
0 g
s
.43992 .5326 m .45166 .52108 L .43805 .5273 L p 0 .05 .1 r
F P
0 g
s
.45166 .52108 m .43992 .5326 L .4273 .51838 L p 0 .349 .781 r
F P
0 g
s
.44367 .51697 m .45166 .52108 L p .4273 .51838 L 0 .349 .781 r
F P
0 g
s
.43295 .51285 m .44367 .51697 L .45747 .51059 L p 0 .4 1 r
F P
0 g
s
.44367 .51697 m .43295 .51285 L p .43992 .5326 L 0 .349 .781 r
F P
0 g
s
.4273 .51838 m .43295 .51285 L .44367 .51697 L p 0 .349 .781 r
F P
0 g
s
.43295 .51285 m .4273 .51838 L .43992 .5326 L p 0 .349 .781 r
F P
0 g
s
.45747 .51059 m .44666 .50642 L .43295 .51285 L p 0 .4 1 r
F P
0 g
s
.4273 .51838 m .43295 .51285 L .44666 .50642 L p 0 .05 .1 r
F P
0 g
s
.4389 .55278 m .45284 .53906 L .44652 .54187 L p 0 .05 .1 r
F P
0 g
s
.45284 .53906 m .45811 .54607 L .47189 .54004 L p 0 .298 .927 r
F P
0 g
s
.44655 .53304 m .45284 .53906 L .46657 .53296 L p 0 .326 .97 r
F P
0 g
s
.45284 .53906 m .4389 .55278 L .4264 .53872 L p 0 .349 .781 r
F P
0 g
s
.44655 .53304 m .45284 .53906 L p .4264 .53872 L 0 .349 .781 r
F P
0 g
s
.45284 .53906 m .4389 .55278 L .45253 .5468 L p 0 .05 .1 r
F P
0 g
s
.47189 .54004 m .46657 .53296 L .45284 .53906 L p 0 .298 .927 r
F P
0 g
s
.45253 .5468 m .46657 .53296 L .45284 .53906 L p 0 .05 .1 r
F P
0 g
s
.4389 .55278 m .45284 .53906 L .44655 .53304 L p 0 .349 .781 r
F P
0 g
s
.4389 .55278 m .45284 .53906 L .46657 .53296 L p 0 .05 .1 r
F P
0 g
s
.46657 .53296 m .46022 .52688 L .44655 .53304 L p 0 .326 .97 r
F P
0 g
s
.46657 .53296 m .45253 .5468 L .4389 .55278 L p 0 .05 .1 r
F P
0 g
s
.46022 .52688 m .45267 .5216 L p .45253 .5468 L 0 .349 .781 r
F P
0 g
s
.45267 .5216 m .46022 .52688 L p .43992 .5326 L 0 .349 .781 r
F P
0 g
s
.45267 .5216 m .45166 .52108 L p .45253 .5468 L 0 .349 .781 r
F P
0 g
s
.43992 .5326 m .45166 .52108 L .45267 .5216 L p 0 .349 .781 r
F P
0 g
s
.45166 .52108 m .43992 .5326 L .45253 .5468 L p 0 .349 .781 r
F P
0 g
s
.45166 .52108 m .43992 .5326 L .4537 .52636 L p 0 .05 .1 r
F P
0 g
s
.43992 .5326 m .45166 .52108 L .44367 .51697 L p 0 .349 .781 r
F P
0 g
s
.45267 .5216 m .46022 .52688 L .47417 .5206 L p 0 .354 1 r
F P
0 g
s
.47417 .5206 m .46655 .51527 L .45267 .5216 L p 0 .354 1 r
F P
0 g
s
.45166 .52108 m .45267 .5216 L .46655 .51527 L p 0 .379 1 r
F P
0 g
s
.46655 .51527 m .46552 .51474 L .45166 .52108 L p 0 .379 1 r
F P
0 g
s
.43992 .5326 m .45166 .52108 L .46552 .51474 L p 0 .05 .1 r
F P
0 g
s
.46552 .51474 m .4537 .52636 L .43992 .5326 L p 0 .05 .1 r
F P
0 g
s
.4273 .51838 m .43992 .5326 L .4537 .52636 L p 0 .311 .95 r
F P
0 g
s
.43992 .5326 m .4273 .51838 L p .42699 .52399 L 0 .349 .781 r
F P
0 g
s
.4264 .53872 m .4389 .55278 L .45253 .5468 L p 0 .311 .95 r
F P
0 g
s
.4389 .55278 m .4264 .53872 L .43992 .5326 L p 0 .311 .95 r
F P
0 g
s
.4264 .53872 m .41237 .55248 L .39982 .53838 L p 0 .349 .781 r
F P
0 g
s
.4264 .53872 m .41237 .55248 L .42578 .54648 L p 0 .05 .1 r
F P
0 g
s
.45253 .5468 m .43992 .5326 L .4264 .53872 L p 0 .311 .95 r
F P
0 g
s
.42578 .54648 m .43992 .5326 L .4264 .53872 L p 0 .05 .1 r
F P
0 g
s
.41237 .55248 m .4264 .53872 L .43992 .5326 L p 0 .05 .1 r
F P
0 g
s
.43992 .5326 m .42578 .54648 L .41237 .55248 L p 0 .05 .1 r
F P
0 g
s
.42578 .54648 m .4371 .53537 L p .42699 .52399 L 0 .349 .781 r
F P
0 g
s
.4371 .53537 m .43992 .5326 L p .42699 .52399 L 0 .349 .781 r
F P
0 g
s
.41108 .52738 m .42447 .52115 L p .39478 .50904 L .532 0 0 r
F P
0 g
s
.43992 .5326 m .4273 .51838 L .44096 .512 L p 0 .311 .95 r
F P
0 g
s
.44367 .51697 m .45166 .52108 L .46552 .51474 L p 0 .379 1 r
F P
0 g
s
.46552 .51474 m .45747 .51059 L .44367 .51697 L p 0 .379 1 r
F P
0 g
s
.44096 .512 m .4537 .52636 L .43992 .5326 L p 0 .311 .95 r
F P
0 g
s
.41312 .53224 m .4273 .51838 L .43992 .5326 L p 0 .349 .781 r
F P
0 g
s
.4537 .52636 m .44096 .512 L .4273 .51838 L p 0 .311 .95 r
F P
0 g
s
.4273 .51838 m .41312 .53224 L .42578 .54648 L p 0 .349 .781 r
F P
0 g
s
.41312 .53224 m .4273 .51838 L .44096 .512 L p 0 .05 .1 r
F P
0 g
s
.44666 .50642 m .44096 .512 L .4273 .51838 L p 0 .05 .1 r
F P
0 g
s
.44096 .512 m .42668 .52598 L .41312 .53224 L p 0 .05 .1 r
F P
0 g
s
.4537 .52636 m .46552 .51474 L .45166 .52108 L p 0 .05 .1 r
F P
0 g
s
.46552 .51474 m .4537 .52636 L .44096 .512 L p 0 .349 .781 r
F P
0 g
s
.45747 .51059 m .46552 .51474 L p .44096 .512 L 0 .349 .781 r
F P
0 g
s
.44666 .50642 m .45747 .51059 L .4666 .50637 L p 0 .4 1 r
F P
0 g
s
.45747 .51059 m .44666 .50642 L p .4537 .52636 L 0 .349 .781 r
F P
0 g
s
.44096 .512 m .44666 .50642 L .45747 .51059 L p 0 .349 .781 r
F P
0 g
s
.4666 .50637 m .45782 .50119 L .44666 .50642 L p 0 .4 1 r
F P
0 g
s
.44666 .50642 m .44096 .512 L .4537 .52636 L p 0 .349 .781 r
F P
0 g
s
.44096 .512 m .44666 .50642 L .45782 .50119 L p 0 .05 .1 r
F P
0 g
s
.46657 .53296 m .47189 .54004 L .48594 .53389 L p 0 .298 .927 r
F P
0 g
s
.45811 .54607 m .46255 .55428 L .47637 .54833 L p 0 .272 .885 r
F P
0 g
s
.47679 .54943 m .47637 .54833 L .46255 .55428 L p 0 .25 .847 r
F P
0 g
s
.46255 .55428 m .46297 .55537 L .47679 .54943 L p 0 .25 .847 r
F P
0 g
s
.46512 .56099 m .47679 .54943 L .46297 .55537 L p 0 .05 .1 r
F P
0 g
s
.47637 .54833 m .47189 .54004 L .45811 .54607 L p 0 .272 .885 r
F P
0 g
s
.47189 .54004 m .46657 .53296 L p .46512 .56099 L 0 .349 .781 r
F P
0 g
s
.45253 .5468 m .46657 .53296 L .47189 .54004 L p 0 .349 .781 r
F P
0 g
s
.46022 .52688 m .46657 .53296 L .48056 .52675 L p 0 .326 .97 r
F P
0 g
s
.46657 .53296 m .45253 .5468 L .46512 .56099 L p 0 .349 .781 r
F P
0 g
s
.46657 .53296 m .45253 .5468 L .46642 .54071 L p 0 .05 .1 r
F P
0 g
s
.48594 .53389 m .48056 .52675 L .46657 .53296 L p 0 .298 .927 r
F P
0 g
s
.46642 .54071 m .48056 .52675 L .46657 .53296 L p 0 .05 .1 r
F P
0 g
s
.45253 .5468 m .46657 .53296 L .46022 .52688 L p 0 .349 .781 r
F P
0 g
s
.45253 .5468 m .46657 .53296 L .48056 .52675 L p 0 .05 .1 r
F P
0 g
s
.46657 .53296 m .45253 .5468 L .43992 .5326 L p 0 .349 .781 r
F P
0 g
s
.46022 .52688 m .46657 .53296 L p .43992 .5326 L 0 .349 .781 r
F P
0 g
s
.48056 .52675 m .47417 .5206 L .46022 .52688 L p 0 .326 .97 r
F P
0 g
s
.48056 .52675 m .46642 .54071 L .45253 .5468 L p 0 .05 .1 r
F P
0 g
s
.47417 .5206 m .46655 .51527 L p .46642 .54071 L 0 .349 .781 r
F P
0 g
s
.46655 .51527 m .47417 .5206 L p .4537 .52636 L 0 .349 .781 r
F P
0 g
s
.46655 .51527 m .46552 .51474 L p .46642 .54071 L 0 .349 .781 r
F P
0 g
s
.4537 .52636 m .46552 .51474 L .46655 .51527 L p 0 .349 .781 r
F P
0 g
s
.46552 .51474 m .4537 .52636 L .46642 .54071 L p 0 .349 .781 r
F P
0 g
s
.46552 .51474 m .4537 .52636 L .46775 .52 L p 0 .05 .1 r
F P
0 g
s
.4537 .52636 m .46552 .51474 L .45747 .51059 L p 0 .349 .781 r
F P
0 g
s
.46655 .51527 m .47417 .5206 L .48105 .5175 L p 0 .354 1 r
F P
0 g
s
.46552 .51474 m .46655 .51527 L .47426 .51175 L p 0 .379 1 r
F P
0 g
s
.48105 .5175 m .47426 .51175 L .46655 .51527 L p 0 .354 1 r
F P
0 g
s
.47426 .51175 m .4734 .51114 L .46552 .51474 L p 0 .379 1 r
F P
0 g
s
.4537 .52636 m .46552 .51474 L .4734 .51114 L p 0 .05 .1 r
F P
0 g
s
.46775 .52 m .4537 .52636 L p .4734 .51114 L 0 .05 .1 r
F P
0 g
s
.44096 .512 m .4537 .52636 L .46775 .52 L p 0 .311 .95 r
F P
0 g
s
.4537 .52636 m .44096 .512 L p .44066 .51766 L 0 .349 .781 r
F P
0 g
s
.43992 .5326 m .45253 .5468 L .4389 .55278 L p 0 .311 .95 r
F P
0 g
s
.43992 .5326 m .45253 .5468 L .46642 .54071 L p 0 .311 .95 r
F P
0 g
s
.43843 .56071 m .45253 .5468 L .4389 .55278 L p 0 .05 .1 r
F P
0 g
s
.43843 .56071 m .45253 .5468 L .43992 .5326 L p 0 .349 .781 r
F P
0 g
s
.45253 .5468 m .43992 .5326 L .4537 .52636 L p 0 .311 .95 r
F P
0 g
s
.42578 .54648 m .43992 .5326 L .45253 .5468 L p 0 .349 .781 r
F P
0 g
s
.43992 .5326 m .42578 .54648 L .43843 .56071 L p 0 .349 .781 r
F P
0 g
s
.43992 .5326 m .42578 .54648 L .43945 .54036 L p 0 .05 .1 r
F P
0 g
s
.46642 .54071 m .4537 .52636 L .43992 .5326 L p 0 .311 .95 r
F P
0 g
s
.43945 .54036 m .4537 .52636 L .43992 .5326 L p 0 .05 .1 r
F P
0 g
s
.42578 .54648 m .43992 .5326 L .4537 .52636 L p 0 .05 .1 r
F P
0 g
s
.43992 .5326 m .42578 .54648 L .41312 .53224 L p 0 .349 .781 r
F P
0 g
s
.4537 .52636 m .43945 .54036 L .42578 .54648 L p 0 .05 .1 r
F P
0 g
s
.43945 .54036 m .45086 .52916 L p .44066 .51766 L 0 .349 .781 r
F P
0 g
s
.45086 .52916 m .4537 .52636 L p .44066 .51766 L 0 .349 .781 r
F P
0 g
s
.42447 .52115 m .43811 .51479 L p .4135 .5088 L .532 0 0 r
F P
0 g
s
.42668 .52598 m .44096 .512 L .4537 .52636 L p 0 .349 .781 r
F P
0 g
s
.4537 .52636 m .44096 .512 L .4549 .50549 L p 0 .311 .95 r
F P
0 g
s
.45747 .51059 m .46552 .51474 L .4734 .51114 L p 0 .379 1 r
F P
0 g
s
.4734 .51114 m .4666 .50637 L .45747 .51059 L p 0 .379 1 r
F P
0 g
s
.46775 .52 m .4549 .50549 L .44096 .512 L p 0 .311 .95 r
F P
0 g
s
.4549 .50549 m .44096 .512 L p .45782 .50119 L 0 .05 .1 r
F P
0 g
s
.44096 .512 m .42668 .52598 L .43945 .54036 L p 0 .349 .781 r
F P
0 g
s
.42668 .52598 m .44096 .512 L .4549 .50549 L p 0 .05 .1 r
F P
0 g
s
.4405 .51959 m .42668 .52598 L p .44922 .50961 L 0 .05 .1 r
F P
0 g
s
.4549 .50549 m .45202 .5083 L p .44922 .50961 L 0 .05 .1 r
F P
0 g
s
.45202 .5083 m .4405 .51959 L p .44922 .50961 L 0 .05 .1 r
F P
0 g
s
.4549 .50549 m .46775 .52 L .4537 .52636 L p 0 .311 .95 r
F P
0 g
s
.4405 .51959 m .4549 .50549 L .46775 .52 L p 0 .35 .78 r
F P
0 g
s
.45202 .5083 m .45342 .50839 L .45311 .5078 L .532 0 0 r
F
.45202 .5083 m .45311 .5078 L .44012 .4836 L F
.43811 .51479 m .45202 .5083 L p .43258 .50855 L F P
0 g
s
.4135 .5088 m .43811 .51479 L .43258 .50855 L .532 0 0 r
F
.39478 .50904 m .42447 .52115 L .4135 .5088 L F
.3764 .50928 m .41108 .52738 L .39478 .50904 L F
.35958 .55125 m .39483 .51698 L .34258 .54201 L p .1 0 0 r
F P
0 g
s
.3682 .52974 m .35958 .55125 L .34258 .54201 L .1 0 0 r
F
.50793 .43283 m .5202 .44676 L .50626 .45353 L p 0 .316 .943 r
F P
0 g
s
.53244 .46067 m .5202 .44676 L .50626 .45353 L p 0 .316 .943 r
F P
0 g
s
.50885 .45788 m .5202 .44676 L .50626 .45353 L p 0 .05 .1 r
F P
0 g
s
.50107 .46163 m .50885 .45788 L p .50626 .45353 L 0 .05 .1 r
F P
0 g
s
.50626 .45353 m .50572 .45406 L .50107 .46163 L p 0 .05 .1 r
F P
0 g
s
.50626 .45353 m .5202 .44676 L p .50107 .46163 L 0 .05 .1 r
F P
0 g
s
.50107 .46163 m .50572 .45406 L .50626 .45353 L p 0 .05 .1 r
F P
0 g
s
.7721 .54368 m .75759 .52705 L .74144 .53308 L p 0 .318 .938 r
F P
0 g
s
.74306 .5104 m .75759 .52705 L .74144 .53308 L p 0 .318 .938 r
F P
0 g
s
.398 .31348 m .4282 .28509 L .41355 .2684 L p 0 .349 .782 r
F P
0 g
s
.4282 .28509 m .398 .31348 L .41273 .3302 L p 0 .349 .782 r
F P
0 g
s
.32302 .41057 m .36637 .36964 L .37729 .3631 L p .1 0 0 r
F P
0 g
s
.36787 .37134 m
.36819 .3717 L
s
.37919 .36139 m .37729 .3631 L .36637 .36964 L .1 0 0 r
F
0 g
.35316 .37756 m
.36637 .36964 L
s
.36637 .36964 m
.38045 .35692 L
s
.36637 .36964 m
.38045 .35692 L
s
.54484 .54681 m .55702 .53462 L .54273 .54057 L p 0 .05 .14 r
F P
0 g
s
.54273 .54057 m .55702 .53462 L p .54017 .53327 L 0 .315 .945 r
F P
0 g
s
.54017 .53327 m .54219 .53996 L .54273 .54057 L p 0 .315 .945 r
F P
0 g
s
.48624 .2041 m .48623 .22194 L .5 .21298 L p 0 .181 .719 r
F P
0 g
s
.52941 .22875 m .5 .19497 L .48624 .2041 L p 0 .319 .936 r
F P
0 g
s
.5 .21298 m .5 .19497 L .48624 .2041 L p 0 .181 .719 r
F P
0 g
s
.48623 .22194 m .48624 .2041 L .5 .19497 L p 0 .181 .719 r
F P
0 g
s
.45685 .2316 m .48624 .2041 L .5 .19497 L p 0 .05 .1 r
F P
0 g
s
.5401 .49887 m .5319 .49392 L .54113 .48976 L p 0 .399 1 r
F P
0 g
s
.54113 .48976 m .55149 .4938 L .5401 .49887 L p 0 .399 1 r
F P
0 g
s
.72704 .51658 m .74306 .5104 L .75718 .49588 L p 0 .05 .218 r
F P
0 g
s
.75718 .49588 m .74306 .5104 L .72704 .51658 L p 0 .05 .218 r
F P
0 g
s
.74306 .5104 m .72704 .51658 L .69762 .4829 L p 0 .318 .938 r
F P
0 g
s
.41355 .2684 m .38325 .29673 L .398 .31348 L p 0 .349 .782 r
F P
0 g
s
.41355 .2684 m .42663 .25988 L .39611 .28843 L p 0 .05 .1 r
F P
0 g
s
.39611 .28843 m .38325 .29673 L .41355 .2684 L p 0 .05 .1 r
F P
0 g
s
.40403 .33842 m
.4129 .33004 L
s
.50084 .25132 m .51474 .24264 L .5 .25659 L p 0 .05 .1 r
F P
0 g
s
.5 .25659 m .51474 .24264 L .50084 .25132 L p 0 .05 .1 r
F P
0 g
s
.5 .25659 m .4862 .26516 L .50084 .25132 L p 0 .05 .1 r
F P
0 g
s
.50084 .25132 m .4862 .26516 L .5 .25659 L p 0 .05 .1 r
F P
0 g
s
.50716 .7114 m
.51481 .71385 L
s
.48623 .22194 m .48621 .24353 L .5 .23476 L p 0 .181 .719 r
F P
0 g
s
.5 .23476 m .5 .21298 L .48623 .22194 L p 0 .181 .719 r
F P
0 g
s
.5 .19497 m .5 .21298 L .48623 .22194 L p 0 .181 .719 r
F P
0 g
s
.48621 .24353 m .48623 .22194 L .5 .21298 L p 0 .181 .719 r
F P
0 g
s
.28749 .4407 m .31042 .49087 L .32033 .47756 L .964 0 0 r
F
0 g
.32033 .47756 m
.33235 .46535 L
s
.53005 .291 m .51599 .29924 L .4862 .26516 L p 0 .318 .938 r
F P
0 g
s
.69762 .4829 m .7134 .47639 L .74306 .5104 L p 0 .318 .938 r
F P
0 g
s
.55702 .53462 m .55158 .52845 L .54017 .53327 L p 0 .315 .945 r
F P
0 g
s
.48621 .24353 m .4862 .26516 L .5 .25659 L p 0 .181 .719 r
F P
0 g
s
.5 .25659 m .5 .23476 L .48621 .24353 L p 0 .181 .719 r
F P
0 g
s
.5 .21298 m .5 .23476 L .48621 .24353 L p 0 .181 .719 r
F P
0 g
s
.4862 .26516 m .48621 .24353 L .5 .23476 L p 0 .181 .719 r
F P
0 g
s
.5319 .49392 m .52549 .48932 L .53339 .48572 L p 0 .379 1 r
F P
0 g
s
.53339 .48572 m .54113 .48976 L .5319 .49392 L p 0 .379 1 r
F P
0 g
s
.36411 .45685 m
.37777 .47223 L
s
.37777 .47223 m
.38868 .48451 L
s
.38868 .48451 m
.39699 .48032 L
s
.28749 .4407 m .27723 .45366 L .31042 .49087 L .964 0 0 r
F
.31202 .42154 m .27723 .45366 L .28749 .4407 L .1 0 0 r
F
.32302 .41057 m .31202 .42154 L .28749 .4407 L F
0 g
.28749 .4407 m
.29964 .42859 L
s
.5 .23476 m .5 .25659 L .4862 .26516 L p 0 .181 .719 r
F P
0 g
s
.4862 .26516 m .47154 .24839 L .48521 .23965 L p 0 .318 .938 r
F P
0 g
s
.48521 .23965 m .5 .25659 L .4862 .26516 L p 0 .318 .938 r
F P
0 g
s
.4862 .26516 m .5 .25659 L .53005 .291 L p 0 .318 .938 r
F P
0 g
s
.47154 .24839 m .4862 .26516 L .5 .25659 L p 0 .318 .938 r
F P
0 g
s
.46975 .28521 m .5 .25659 L .4862 .26516 L p 0 .05 .1 r
F P
0 g
s
.78775 .47489 m .77123 .48144 L .80008 .51461 L p 0 .319 .936 r
F P
0 g
s
.80008 .51461 m .81684 .50839 L .78775 .47489 L p 0 .319 .936 r
F P
0 g
s
.80009 .50713 m .78345 .51338 L .80008 .51461 L p 0 .458 1 r
F P
0 g
s
.80008 .51461 m .81684 .50839 L .80009 .50713 L p 0 .458 1 r
F P
0 g
s
.81684 .50839 m .80008 .51461 L .78345 .51338 L p 0 .458 1 r
F P
0 g
s
.81684 .50839 m .80008 .51461 L .7721 .54368 L p 0 .05 .248 r
F P
0 g
s
.74332 .57358 m .72724 .57919 L .69837 .60913 L p 0 .05 .248 r
F P
0 g
s
.72724 .57919 m .74332 .57358 L .7721 .54368 L p 0 .05 .248 r
F P
0 g
s
.47154 .24839 m .45685 .2316 L .4704 .22269 L p 0 .318 .938 r
F P
0 g
s
.4704 .22269 m .48521 .23965 L .47154 .24839 L p 0 .318 .938 r
F P
0 g
s
.45685 .2316 m .47154 .24839 L .48521 .23965 L p 0 .318 .938 r
F P
0 g
s
.5 .25659 m .48521 .23965 L .47154 .24839 L p 0 .318 .938 r
F P
0 g
s
.54467 .47457 m .53339 .48572 L .52549 .48932 L p 0 .05 .1 r
F P
0 g
s
.52549 .48932 m .52467 .48874 L .5324 .48521 L p 0 .379 1 r
F P
0 g
s
.5324 .48521 m .53339 .48572 L .52549 .48932 L p 0 .379 1 r
F P
0 g
s
.52467 .48874 m .51821 .48319 L .52505 .48002 L p 0 .355 1 r
F P
0 g
s
.52505 .48002 m .5324 .48521 L .52467 .48874 L p 0 .355 1 r
F P
0 g
s
.35473 .66546 m
.37992 .68903 L
s
.36439 .65681 m .35101 .66197 L .30823 .61432 L p .509 0 0 r
F P
0 g
s
.35101 .66197 m
.35473 .66546 L
s
.35101 .66197 m
.36439 .65681 L
s
.3675 .34215 m .398 .31348 L .38325 .29673 L p 0 .349 .782 r
F P
0 g
s
.50248 .43816 m .50558 .44941 L .49655 .45382 L p 0 .238 .818 r
F P
0 g
s
.50107 .46163 m .49655 .45382 L .50558 .44941 L p 0 .255 .848 r
F P
0 g
s
.57381 .25443 m .55927 .26305 L .58904 .29723 L p 0 .319 .936 r
F P
0 g
s
.58904 .29723 m .60383 .28895 L .57381 .25443 L p 0 .319 .936 r
F P
0 g
s
.32302 .41057 m .35591 .44761 L .34504 .45867 L .883 0 0 r
F
0 g
.35591 .44761 m
.36411 .45685 L
s
.5 .19497 m .4704 .22269 L .45685 .2316 L p 0 .05 .1 r
F P
0 g
s
.48521 .23965 m .4704 .22269 L .45685 .2316 L p 0 .318 .938 r
F P
0 g
s
.45685 .2316 m .4704 .22269 L .43995 .25119 L p 0 .05 .1 r
F P
0 g
s
.43995 .25119 m .42663 .25988 L .45685 .2316 L p 0 .05 .1 r
F P
0 g
s
.78775 .47489 m .77123 .48144 L .75718 .49588 L p 0 .05 .218 r
F P
0 g
s
.74175 .44754 m .77123 .48144 L .78775 .47489 L p 0 .319 .936 r
F P
0 g
s
.77361 .48946 m .75718 .49588 L .77123 .48144 L p 0 .05 .218 r
F P
0 g
s
.77123 .48144 m .78775 .47489 L .77361 .48946 L p 0 .05 .218 r
F P
0 g
s
.77979 .50562 m .7633 .51189 L .78345 .51338 L p 0 .458 1 r
F P
0 g
s
.78345 .51338 m .80009 .50713 L .77979 .50562 L p 0 .458 1 r
F P
0 g
s
.78345 .51338 m .80009 .50713 L .81684 .50839 L p 0 .458 1 r
F P
0 g
s
.80009 .50713 m .78345 .51338 L .7633 .51189 L p 0 .458 1 r
F P
0 g
s
.38325 .29673 m .35266 .32534 L .3675 .34215 L p 0 .349 .782 r
F P
0 g
s
.38325 .29673 m .39611 .28843 L .36529 .31727 L p 0 .05 .1 r
F P
0 g
s
.36529 .31727 m .35266 .32534 L .38325 .29673 L p 0 .05 .1 r
F P
0 g
s
.51821 .48319 m .51232 .47711 L .51886 .47404 L p 0 .329 .964 r
F P
0 g
s
.51886 .47404 m .52505 .48002 L .51821 .48319 L p 0 .329 .964 r
F P
0 g
s
.5202 .44676 m .50885 .45788 L .50107 .46163 L p 0 .05 .1 r
F P
0 g
s
.50558 .44941 m .50885 .45788 L .50107 .46163 L p 0 .255 .848 r
F P
0 g
s
.50685 .47032 m .51232 .47711 L p .50107 .46163 L 0 .332 .562 r
F P
0 g
s
.50107 .46163 m .50165 .46263 L .50685 .47032 L p 0 .332 .562 r
F P
0 g
s
.50165 .46263 m .50107 .46163 L .50885 .45788 L p 0 .255 .848 r
F P
0 g
s
.50885 .45788 m .50927 .45896 L .50165 .46263 L p 0 .255 .848 r
F P
0 g
s
.50685 .47032 m .50165 .46263 L .50927 .45896 L p 0 .277 .884 r
F P
0 g
s
.37992 .68903 m
.38376 .69138 L
s
.39971 .70117 m
.40833 .70645 L
s
.53244 .46067 m .51886 .47404 L .51232 .47711 L p 0 .05 .1 r
F P
0 g
s
.51365 .46709 m .51886 .47404 L .51232 .47711 L p 0 .302 .924 r
F P
0 g
s
.51232 .47711 m .50685 .47032 L .51365 .46709 L p 0 .302 .924 r
F P
0 g
s
.50927 .45896 m .51365 .46709 L .50685 .47032 L p 0 .277 .884 r
F P
0 g
s
.32302 .41057 m .31202 .42154 L .37794 .49568 L .883 0 0 r
F
0 g
.37472 .50035 m
.37794 .49568 L
s
.37794 .49568 m
.38868 .48451 L
s
.54369 .21979 m .52941 .22875 L .55927 .26305 L p 0 .319 .936 r
F P
0 g
s
.55927 .26305 m .57381 .25443 L .54369 .21979 L p 0 .319 .936 r
F P
0 g
s
.5447 .27699 m .55927 .26305 L .52941 .22875 L p 0 .349 .781 r
F P
0 g
s
.52941 .22875 m .55927 .26305 L .5447 .27699 L p 0 .349 .781 r
F P
0 g
s
.78775 .47489 m .75802 .44066 L .74175 .44754 L p 0 .319 .936 r
F P
0 g
s
.71218 .41354 m .74175 .44754 L .75802 .44066 L p 0 .319 .936 r
F P
0 g
s
.51826 .54137 m .51237 .54635 L p .52555 .5373 L 0 .432 .873 r
F P
0 g
s
.52555 .5373 m .52473 .5376 L .51826 .54137 L p 0 .432 .873 r
F P
0 g
s
.32302 .41057 m .34504 .45867 L .31202 .42154 L .883 0 0 r
F
0 g
.34504 .45867 m
.35591 .44761 L
s
.33366 .40432 m .31202 .42154 L .32302 .41057 L .1 0 0 r
F
0 g
.32417 .41187 m
.35591 .44761 L
s
.32417 .41187 m
.35591 .44761 L
s
.37729 .3631 m .33366 .40432 L .32302 .41057 L p .1 0 0 r
F P
0 g
s
.31015 .41813 m
.32302 .41057 L
s
.37729 .3631 m
.37758 .36342 L
s
.36637 .36964 m
.37729 .3631 L
s
.30823 .61432 m
.3206 .60893 L
s
.51826 .54137 m .52473 .5376 L .53248 .53431 L p 0 .05 .1 r
F P
0 g
s
.53339 .48572 m .54467 .47457 L .55688 .48844 L p 0 .349 .781 r
F P
0 g
s
.54113 .48976 m .53339 .48572 L p .55688 .48844 L 0 .349 .781 r
F P
0 g
s
.55688 .48844 m .55149 .4938 L .54113 .48976 L p 0 .349 .781 r
F P
0 g
s
.54467 .47457 m .55688 .48844 L .5714 .48195 L p 0 .316 .943 r
F P
0 g
s
.55688 .48844 m .55149 .4938 L .56597 .48735 L p 0 .05 .112 r
F P
0 g
s
.56597 .48735 m .5714 .48195 L .55688 .48844 L p 0 .05 .112 r
F P
0 g
s
.55149 .4938 m .55688 .48844 L .54467 .47457 L p 0 .349 .781 r
F P
0 g
s
.55688 .48844 m .54467 .47457 L .55909 .46794 L p 0 .316 .943 r
F P
0 g
s
.55909 .46794 m .5714 .48195 L .55688 .48844 L p 0 .316 .943 r
F P
0 g
s
.75718 .49588 m .77361 .48946 L .78775 .47489 L p 0 .05 .218 r
F P
0 g
s
.77361 .48946 m .75718 .49588 L .74306 .5104 L p 0 .05 .218 r
F P
0 g
s
.7594 .5041 m .74306 .5104 L .75718 .49588 L p 0 .05 .218 r
F P
0 g
s
.75718 .49588 m .77361 .48946 L .7594 .5041 L p 0 .05 .218 r
F P
0 g
s
.57614 .72479 m .56156 .72901 L .53178 .75979 L p 0 .05 .248 r
F P
0 g
s
.7594 .5041 m .74306 .5104 L .7633 .51189 L p 0 .458 1 r
F P
0 g
s
.7633 .51189 m .77979 .50562 L .7594 .5041 L p 0 .458 1 r
F P
0 g
s
.7633 .51189 m .77979 .50562 L .80009 .50713 L p 0 .458 1 r
F P
0 g
s
.77979 .50562 m .7633 .51189 L .74306 .5104 L p 0 .458 1 r
F P
0 g
s
.5714 .48195 m .55909 .46794 L .54467 .47457 L p 0 .316 .943 r
F P
0 g
s
.54113 .48976 m .55149 .4938 L p .54467 .47457 L 0 .349 .781 r
F P
0 g
s
.54467 .47457 m .53339 .48572 L .54113 .48976 L p 0 .349 .781 r
F P
0 g
s
.53339 .48572 m .54467 .47457 L .55909 .46794 L p 0 .05 .1 r
F P
0 g
s
.54467 .47457 m .53244 .46067 L .54675 .45391 L p 0 .316 .943 r
F P
0 g
s
.54675 .45391 m .55909 .46794 L .54467 .47457 L p 0 .316 .943 r
F P
0 g
s
.51886 .47404 m .53244 .46067 L .54467 .47457 L p 0 .349 .781 r
F P
0 g
s
.52505 .48002 m .51886 .47404 L p .54467 .47457 L 0 .349 .781 r
F P
0 g
s
.5324 .48521 m .52505 .48002 L p .54467 .47457 L 0 .349 .781 r
F P
0 g
s
.54467 .47457 m .53339 .48572 L .5324 .48521 L p 0 .349 .781 r
F P
0 g
s
.53244 .46067 m .54467 .47457 L .55909 .46794 L p 0 .316 .943 r
F P
0 g
s
.54467 .47457 m .53339 .48572 L .54772 .47919 L p 0 .05 .1 r
F P
0 g
s
.54772 .47919 m .55909 .46794 L .54467 .47457 L p 0 .05 .1 r
F P
0 g
s
.53339 .48572 m .54467 .47457 L .53244 .46067 L p 0 .349 .781 r
F P
0 g
s
.37729 .3631 m
.37919 .36139 L
s
.37919 .36139 m
.38103 .35986 L
s
.55149 .4938 m .54113 .48976 L .55553 .48327 L p 0 .399 1 r
F P
0 g
s
.55553 .48327 m .56597 .48735 L .55149 .4938 L p 0 .399 1 r
F P
0 g
s
.52941 .22875 m .51474 .24264 L .5447 .27699 L p 0 .349 .781 r
F P
0 g
s
.5447 .27699 m .51474 .24264 L .52941 .22875 L p 0 .349 .781 r
F P
0 g
s
.51474 .24264 m .52941 .22875 L .54369 .21979 L p 0 .05 .1 r
F P
0 g
s
.5 .21298 m .5 .19497 L .52941 .22875 L closepath p 0 .349 .781 r
F P
0 g
s
.5 .21298 m .52941 .22875 L .51474 .24264 L p 0 .349 .781 r
F P
0 g
s
.5 .19497 m .52941 .22875 L .54369 .21979 L p 0 .319 .936 r
F P
0 g
s
.52941 .22875 m .5 .19497 L .5 .21298 L closepath p 0 .349 .781 r
F P
0 g
s
.54369 .21979 m .52891 .23378 L .51474 .24264 L p 0 .05 .1 r
F P
0 g
s
.52891 .23378 m .54369 .21979 L .52941 .22875 L p 0 .05 .1 r
F P
0 g
s
.52941 .22875 m .51474 .24264 L .52891 .23378 L p 0 .05 .1 r
F P
0 g
s
.5 .23476 m .51474 .24264 L .52941 .22875 L p 0 .349 .781 r
F P
0 g
s
.52941 .22875 m .5 .21298 L .5 .23476 L p 0 .349 .781 r
F P
0 g
s
.34169 .46322 m
.34504 .45867 L
s
.7721 .54368 m .78868 .53771 L .81684 .50839 L p 0 .05 .248 r
F P
0 g
s
.75759 .52705 m .7721 .54368 L .78868 .53771 L p 0 .318 .938 r
F P
0 g
s
.78868 .53771 m .7721 .54368 L .74332 .57358 L p 0 .05 .248 r
F P
0 g
s
.78868 .53771 m .7721 .54368 L .75759 .52705 L p 0 .318 .938 r
F P
0 g
s
.75802 .44066 m .7282 .40633 L .71218 .41354 L p 0 .319 .936 r
F P
0 g
s
.55909 .46794 m .54675 .45391 L .53244 .46067 L p 0 .316 .943 r
F P
0 g
s
.5324 .48521 m .53339 .48572 L p .53244 .46067 L 0 .349 .781 r
F P
0 g
s
.52505 .48002 m .5324 .48521 L p .53244 .46067 L 0 .349 .781 r
F P
0 g
s
.53244 .46067 m .51886 .47404 L .52505 .48002 L p 0 .349 .781 r
F P
0 g
s
.51886 .47404 m .53244 .46067 L .54675 .45391 L p 0 .05 .1 r
F P
0 g
s
.5344 .43986 m .54675 .45391 L .53244 .46067 L p 0 .316 .943 r
F P
0 g
s
.53244 .46067 m .5202 .44676 L .5344 .43986 L p 0 .316 .943 r
F P
0 g
s
.50885 .45788 m .5202 .44676 L .53244 .46067 L p 0 .349 .781 r
F P
0 g
s
.50927 .45896 m .50885 .45788 L p .53244 .46067 L 0 .349 .781 r
F P
0 g
s
.51365 .46709 m .50927 .45896 L p .53244 .46067 L 0 .349 .781 r
F P
0 g
s
.53244 .46067 m .51886 .47404 L .51365 .46709 L p 0 .349 .781 r
F P
0 g
s
.5202 .44676 m .53244 .46067 L .54675 .45391 L p 0 .316 .943 r
F P
0 g
s
.53307 .46739 m .54675 .45391 L .53244 .46067 L p 0 .05 .1 r
F P
0 g
s
.53244 .46067 m .51886 .47404 L .53307 .46739 L p 0 .05 .1 r
F P
0 g
s
.51886 .47404 m .53244 .46067 L .5202 .44676 L p 0 .349 .781 r
F P
0 g
s
.51237 .54635 m .51826 .54137 L .52513 .53846 L p 0 .05 .1 r
F P
0 g
s
.53248 .53431 m .52513 .53846 L .51826 .54137 L p 0 .05 .1 r
F P
0 g
s
.69837 .60913 m .71426 .60377 L .74332 .57358 L p 0 .05 .248 r
F P
0 g
s
.38232 .35893 m .3675 .34215 L .3632 .35726 L closepath p 0 .349 .782 r
F P
0 g
s
.39521 .3512 m .38232 .35893 L .3698 .37076 L p 0 .05 .1 r
F P
0 g
s
.38348 .36023 m
.38666 .36384 L
s
.3698 .37076 m .38232 .35893 L .3632 .35726 L closepath p 0 .349 .782 r
F P
0 g
s
.38026 .33425 m .3675 .34215 L .38232 .35893 L p 0 .315 .945 r
F P
0 g
s
.38232 .35893 m .39521 .3512 L .38026 .33425 L p 0 .315 .945 r
F P
0 g
s
.38232 .35893 m .39521 .3512 L .3826 .36313 L p 0 .05 .1 r
F P
0 g
s
.3826 .36313 m .3698 .37076 L .38232 .35893 L p 0 .05 .1 r
F P
0 g
s
.39521 .3512 m .38232 .35893 L .3675 .34215 L p 0 .315 .945 r
F P
0 g
s
.53005 .291 m .5447 .27699 L .51474 .24264 L p 0 .349 .781 r
F P
0 g
s
.51474 .24264 m .5447 .27699 L .53005 .291 L p 0 .349 .781 r
F P
0 g
s
.54113 .48976 m .53339 .48572 L .54772 .47919 L p 0 .379 1 r
F P
0 g
s
.54772 .47919 m .55553 .48327 L .54113 .48976 L p 0 .379 1 r
F P
0 g
s
.52203 .42579 m .5344 .43986 L .5202 .44676 L p 0 .316 .943 r
F P
0 g
s
.5202 .44676 m .50793 .43283 L .52203 .42579 L p 0 .316 .943 r
F P
0 g
s
.50248 .43816 m .50793 .43283 L .5202 .44676 L p 0 .349 .781 r
F P
0 g
s
.50558 .44941 m .50248 .43816 L p .5202 .44676 L 0 .349 .781 r
F P
0 g
s
.5202 .44676 m .50885 .45788 L .50558 .44941 L p 0 .349 .781 r
F P
0 g
s
.50793 .43283 m .5202 .44676 L .5344 .43986 L p 0 .316 .943 r
F P
0 g
s
.54675 .45391 m .5344 .43986 L .5202 .44676 L p 0 .316 .943 r
F P
0 g
s
.52297 .45108 m .5344 .43986 L .5202 .44676 L p 0 .05 .1 r
F P
0 g
s
.51365 .46709 m .51886 .47404 L p .5202 .44676 L 0 .349 .781 r
F P
0 g
s
.50927 .45896 m .51365 .46709 L p .5202 .44676 L 0 .349 .781 r
F P
0 g
s
.5202 .44676 m .50885 .45788 L .50927 .45896 L p 0 .349 .781 r
F P
0 g
s
.5202 .44676 m .50885 .45788 L .52297 .45108 L p 0 .05 .1 r
F P
0 g
s
.50885 .45788 m .5202 .44676 L .50793 .43283 L p 0 .349 .781 r
F P
0 g
s
.50885 .45788 m .5202 .44676 L .5344 .43986 L p 0 .05 .1 r
F P
0 g
s
.78868 .53771 m .77405 .52091 L .75759 .52705 L p 0 .318 .938 r
F P
0 g
s
.74306 .5104 m .75759 .52705 L .77405 .52091 L p 0 .318 .938 r
F P
0 g
s
.75759 .52705 m .77405 .52091 L .78868 .53771 L p 0 .318 .938 r
F P
0 g
s
.77405 .52091 m .75759 .52705 L .74306 .5104 L p 0 .318 .938 r
F P
0 g
s
.54484 .54681 m .55702 .53462 L .57157 .52855 L p 0 .05 .14 r
F P
0 g
s
.55158 .52845 m .55702 .53462 L .54484 .54681 L p 0 .349 .781 r
F P
0 g
s
.55931 .54084 m .57157 .52855 L .55702 .53462 L p 0 .05 .14 r
F P
0 g
s
.55702 .53462 m .54484 .54681 L .55931 .54084 L p 0 .05 .14 r
F P
0 g
s
.55158 .52845 m .55702 .53462 L .57157 .52855 L p 0 .315 .945 r
F P
0 g
s
.53347 .53394 m .54484 .54681 L .55702 .53462 L p 0 .349 .781 r
F P
0 g
s
.54122 .53101 m .53347 .53394 L p .55702 .53462 L 0 .349 .781 r
F P
0 g
s
.55702 .53462 m .55158 .52845 L .54122 .53101 L p 0 .349 .781 r
F P
0 g
s
.344 .35559 m .3632 .35726 L .3675 .34215 L p 0 .349 .782 r
F P
0 g
s
.3675 .34215 m .35266 .32534 L .344 .35559 L p 0 .349 .782 r
F P
0 g
s
.3675 .34215 m .38026 .33425 L .36529 .31727 L p 0 .315 .945 r
F P
0 g
s
.36529 .31727 m .35266 .32534 L .3675 .34215 L p 0 .315 .945 r
F P
0 g
s
.38026 .33425 m .3675 .34215 L .35266 .32534 L p 0 .315 .945 r
F P
0 g
s
.3675 .34215 m .38026 .33425 L .39521 .3512 L p 0 .315 .945 r
F P
0 g
s
.55909 .46794 m .54772 .47919 L .53339 .48572 L p 0 .05 .1 r
F P
0 g
s
.53339 .48572 m .5324 .48521 L .54673 .47867 L p 0 .379 1 r
F P
0 g
s
.54673 .47867 m .54772 .47919 L .53339 .48572 L p 0 .379 1 r
F P
0 g
s
.5324 .48521 m .52505 .48002 L .53932 .47343 L p 0 .355 1 r
F P
0 g
s
.53932 .47343 m .54673 .47867 L .5324 .48521 L p 0 .355 1 r
F P
0 g
s
.54122 .53101 m .55158 .52845 L p .54484 .54681 L 0 .349 .781 r
F P
0 g
s
.57157 .52855 m .56609 .52232 L .55158 .52845 L p 0 .315 .945 r
F P
0 g
s
.54122 .53101 m .55158 .52845 L .56609 .52232 L p 0 .478 .97 r
F P
0 g
s
.5344 .43986 m .52203 .42579 L .50793 .43283 L p 0 .316 .943 r
F P
0 g
s
.50558 .44941 m .50885 .45788 L p .50793 .43283 L 0 .349 .781 r
F P
0 g
s
.50793 .43283 m .50248 .43816 L .50558 .44941 L p 0 .349 .781 r
F P
0 g
s
.50248 .43816 m .50793 .43283 L .52203 .42579 L p 0 .05 .1 r
F P
0 g
s
.4704 .22269 m .5 .19497 L .5 .21298 L closepath p 0 .349 .781 r
F P
0 g
s
.5 .19497 m .5 .21298 L .51403 .20384 L p 0 .181 .719 r
F P
0 g
s
.54369 .21979 m .51402 .18567 L .5 .19497 L p 0 .319 .936 r
F P
0 g
s
.51403 .20384 m .51402 .18567 L .5 .19497 L p 0 .181 .719 r
F P
0 g
s
.5 .21298 m .5 .19497 L .4704 .22269 L closepath p 0 .349 .781 r
F P
0 g
s
.5 .21298 m .5 .19497 L .51402 .18567 L p 0 .181 .719 r
F P
0 g
s
.4704 .22269 m .5 .19497 L .51402 .18567 L p 0 .05 .1 r
F P
0 g
s
.52513 .53846 m .51893 .54358 L .51237 .54635 L p 0 .05 .1 r
F P
0 g
s
.50688 .55269 m .51237 .54635 L .51893 .54358 L p 0 .05 .243 r
F P
0 g
s
.74306 .5104 m .7594 .5041 L .77361 .48946 L p 0 .05 .218 r
F P
0 g
s
.7594 .5041 m .74306 .5104 L .7134 .47639 L p 0 .318 .938 r
F P
0 g
s
.74306 .5104 m .7594 .5041 L .77979 .50562 L p 0 .458 1 r
F P
0 g
s
.77405 .52091 m .7594 .5041 L .74306 .5104 L p 0 .318 .938 r
F P
0 g
s
.74306 .5104 m .7594 .5041 L .77405 .52091 L p 0 .318 .938 r
F P
0 g
s
.7141 .54018 m .74306 .5104 L .7594 .5041 L p 0 .05 .218 r
F P
0 g
s
.42663 .25988 m .43995 .25119 L .40921 .27998 L p 0 .05 .1 r
F P
0 g
s
.40921 .27998 m .39611 .28843 L .42663 .25988 L p 0 .05 .1 r
F P
0 g
s
.31202 .42154 m .30717 .42772 L .27723 .45366 L .1 0 0 r
F
.33219 .40578 m .30717 .42772 L .31202 .42154 L F
.33366 .40432 m .33219 .40578 L .31202 .42154 L F
0 g
.31202 .42154 m
.32302 .41057 L
s
.31202 .42154 m
.32302 .41057 L
s
.52505 .48002 m .51886 .47404 L .53307 .46739 L p 0 .329 .964 r
F P
0 g
s
.53307 .46739 m .53932 .47343 L .52505 .48002 L p 0 .329 .964 r
F P
0 g
s
.33238 .35457 m .344 .35559 L .35266 .32534 L p 0 .349 .782 r
F P
0 g
s
.35266 .32534 m .3274 .34895 L .33238 .35457 L p 0 .349 .782 r
F P
0 g
s
.35266 .32534 m .36529 .31727 L .38026 .33425 L p 0 .315 .945 r
F P
0 g
s
.35266 .32534 m .36529 .31727 L .33984 .34108 L p 0 .05 .1 r
F P
0 g
s
.33984 .34108 m .3274 .34895 L .35266 .32534 L p 0 .05 .1 r
F P
0 g
s
.51893 .54358 m .51371 .54984 L .50688 .55269 L p 0 .05 .243 r
F P
0 g
s
.51474 .24264 m .5 .25659 L .53005 .291 L p 0 .349 .781 r
F P
0 g
s
.53005 .291 m .5 .25659 L .51474 .24264 L p 0 .349 .781 r
F P
0 g
s
.5 .25659 m .51474 .24264 L .52891 .23378 L p 0 .05 .1 r
F P
0 g
s
.51474 .24264 m .5 .23476 L .5 .21298 L p 0 .349 .781 r
F P
0 g
s
.51474 .24264 m .5 .25659 L .5 .23476 L closepath p 0 .349 .781 r
F P
0 g
s
.5 .23476 m .5 .25659 L .51474 .24264 L closepath p 0 .349 .781 r
F P
0 g
s
.52891 .23378 m .51406 .24785 L .5 .25659 L p 0 .05 .1 r
F P
0 g
s
.51406 .24785 m .52891 .23378 L .51474 .24264 L p 0 .05 .1 r
F P
0 g
s
.51474 .24264 m .5 .25659 L .51406 .24785 L p 0 .05 .1 r
F P
0 g
s
.52203 .42579 m .51654 .43116 L .50248 .43816 L p 0 .05 .1 r
F P
0 g
s
.50558 .44941 m .50248 .43816 L .51654 .43116 L p 0 .238 .818 r
F P
0 g
s
.54675 .45391 m .53307 .46739 L .51886 .47404 L p 0 .05 .1 r
F P
0 g
s
.52782 .46037 m .53307 .46739 L .51886 .47404 L p 0 .302 .924 r
F P
0 g
s
.51886 .47404 m .51365 .46709 L .52782 .46037 L p 0 .302 .924 r
F P
0 g
s
.4704 .22269 m .5 .21298 L .5 .23476 L p 0 .349 .781 r
F P
0 g
s
.5 .21298 m .5 .23476 L .51405 .22582 L p 0 .181 .719 r
F P
0 g
s
.51405 .22582 m .51403 .20384 L .5 .21298 L p 0 .181 .719 r
F P
0 g
s
.51402 .18567 m .51403 .20384 L .5 .21298 L p 0 .181 .719 r
F P
0 g
s
.5 .23476 m .5 .21298 L .51403 .20384 L p 0 .181 .719 r
F P
0 g
s
.5 .21298 m .4704 .22269 L .48521 .23965 L p 0 .349 .781 r
F P
0 g
s
.48521 .23965 m .5 .23476 L .5 .21298 L p 0 .349 .781 r
F P
0 g
s
.36993 .3751 m .3826 .36313 L .3698 .37076 L p 0 .05 .1 r
F P
0 g
s
.3698 .37076 m .35723 .38264 L .36993 .3751 L p 0 .05 .1 r
F P
0 g
s
.35723 .38264 m .3698 .37076 L .3632 .35726 L p 0 .349 .782 r
F P
0 g
s
.3698 .37076 m .3826 .36313 L .39521 .3512 L p 0 .05 .1 r
F P
0 g
s
.3698 .37076 m .3826 .36313 L .36993 .3751 L p 0 .05 .1 r
F P
0 g
s
.36993 .3751 m .35723 .38264 L .3698 .37076 L p 0 .05 .1 r
F P
0 g
s
.3632 .35726 m .344 .35559 L .35723 .38264 L p 0 .349 .782 r
F P
0 g
s
.51654 .43116 m .51967 .44252 L .50558 .44941 L p 0 .238 .818 r
F P
0 g
s
.50885 .45788 m .50558 .44941 L .51967 .44252 L p 0 .255 .848 r
F P
0 g
s
.52339 .45216 m .52782 .46037 L .51365 .46709 L p 0 .277 .884 r
F P
0 g
s
.51365 .46709 m .50927 .45896 L .52339 .45216 L p 0 .277 .884 r
F P
0 g
s
.31035 .59399 m .28592 .58427 L .27602 .5589 L .509 0 0 r
F
0 g
.28592 .58427 m
.30823 .61432 L
s
.5344 .43986 m .52297 .45108 L .50885 .45788 L p 0 .05 .1 r
F P
0 g
s
.51967 .44252 m .52297 .45108 L .50885 .45788 L p 0 .255 .848 r
F P
0 g
s
.50927 .45896 m .50885 .45788 L .52297 .45108 L p 0 .255 .848 r
F P
0 g
s
.52297 .45108 m .52339 .45216 L .50927 .45896 L p 0 .255 .848 r
F P
0 g
s
.56609 .52232 m .55565 .5249 L .54122 .53101 L p 0 .478 .97 r
F P
0 g
s
.54484 .54681 m .53347 .53394 L .54122 .53101 L p 0 .349 .781 r
F P
0 g
s
.53347 .53394 m .54122 .53101 L .55565 .5249 L p 0 .446 .815 r
F P
0 g
s
.51406 .24785 m .54438 .2826 L .53005 .291 L p 0 .318 .938 r
F P
0 g
s
.53005 .291 m .5 .25659 L .51406 .24785 L p 0 .318 .938 r
F P
0 g
s
.57157 .52855 m .55931 .54084 L .54484 .54681 L p 0 .05 .14 r
F P
0 g
s
.55565 .5249 m .54784 .52785 L .53347 .53394 L p 0 .446 .815 r
F P
0 g
s
.54784 .52785 m .55931 .54084 L .54484 .54681 L p 0 .314 .946 r
F P
0 g
s
.54484 .54681 m .53347 .53394 L .54784 .52785 L p 0 .314 .946 r
F P
0 g
s
.54699 .55319 m .55931 .54084 L .54484 .54681 L p 0 .05 .14 r
F P
0 g
s
.53347 .53394 m .54484 .54681 L .55931 .54084 L p 0 .314 .946 r
F P
0 g
s
.54484 .54681 m .53347 .53394 L .53248 .53431 L p 0 .349 .781 r
F P
0 g
s
.7134 .47639 m .72948 .46975 L .7594 .5041 L p 0 .318 .938 r
F P
0 g
s
.5 .23476 m .48521 .23965 L .4704 .22269 L p 0 .349 .781 r
F P
0 g
s
.5 .23476 m .5 .25659 L .48521 .23965 L closepath p 0 .349 .781 r
F P
0 g
s
.5 .23476 m .5 .25659 L .51406 .24785 L p 0 .181 .719 r
F P
0 g
s
.51406 .24785 m .51405 .22582 L .5 .23476 L p 0 .181 .719 r
F P
0 g
s
.48521 .23965 m .5 .25659 L .5 .23476 L closepath p 0 .349 .781 r
F P
0 g
s
.51403 .20384 m .51405 .22582 L .5 .23476 L p 0 .181 .719 r
F P
0 g
s
.5 .25659 m .5 .23476 L .51405 .22582 L p 0 .181 .719 r
F P
0 g
s
.34036 .46503 m .31042 .49087 L .316 .49093 L .1 0 0 r
F
.27723 .45366 m .316 .49093 L .31042 .49087 L F
0 g
.31273 .48778 m
.32033 .47756 L
s
.34461 .39457 m .35842 .41015 L .371 .3982 L p 0 .349 .782 r
F P
0 g
s
.371 .3982 m .35723 .38264 L .34461 .39457 L p 0 .349 .782 r
F P
0 g
s
.48979 .68579 m
.51481 .71385 L
s
.55931 .54084 m .54784 .52785 L .53347 .53394 L p 0 .314 .946 r
F P
0 g
s
.53248 .53431 m .53347 .53394 L .54784 .52785 L p 0 .446 .815 r
F P
0 g
s
.54784 .52785 m .54685 .52823 L .53248 .53431 L p 0 .446 .815 r
F P
0 g
s
.52513 .53846 m .53248 .53431 L .54685 .52823 L p 0 .05 .1 r
F P
0 g
s
.5017 .79088 m .53178 .75979 L .51702 .74327 L p 0 .349 .782 r
F P
0 g
s
.54614 .75585 m .53178 .75979 L .5017 .79088 L p 0 .05 .248 r
F P
0 g
s
.53178 .75979 m .54614 .75585 L .57614 .72479 L p 0 .05 .248 r
F P
0 g
s
.33156 .4066 m .39781 .48124 L .39822 .48124 L .1 0 0 r
F
0 g
.39799 .48097 m
.39799 .48097 L
s
.32302 .41057 m
.32917 .40696 L
s
.39781 .48124 m .37644 .50229 L .39822 .48124 L .1 0 0 r
F
.35961 .43773 m .37342 .45329 L .38598 .44125 L p 0 .349 .782 r
F P
0 g
s
.38598 .44125 m .37221 .42571 L .35961 .43773 L p 0 .349 .782 r
F P
0 g
s
.61891 .2805 m .60383 .28895 L .63376 .32336 L p 0 .319 .936 r
F P
0 g
s
.63376 .32336 m .64909 .31526 L .61891 .2805 L p 0 .319 .936 r
F P
0 g
s
.63376 .32336 m .64909 .31526 L .63451 .32955 L p 0 .05 .1 r
F P
0 g
s
.35723 .38264 m .36993 .3751 L .34486 .34676 L p 0 .314 .946 r
F P
0 g
s
.35723 .38264 m .344 .35559 L .33238 .35457 L closepath p 0 .349 .782 r
F P
0 g
s
.34486 .34676 m .33238 .35457 L .35723 .38264 L p 0 .314 .946 r
F P
0 g
s
.33238 .35457 m .33228 .36659 L .35723 .38264 L closepath p 0 .349 .782 r
F P
0 g
s
.35723 .38264 m .34461 .39457 L .35721 .38713 L p 0 .05 .1 r
F P
0 g
s
.35721 .38713 m .36993 .3751 L .35723 .38264 L p 0 .05 .1 r
F P
0 g
s
.34461 .39457 m .35723 .38264 L .36993 .3751 L p 0 .05 .1 r
F P
0 g
s
.34461 .39457 m .35723 .38264 L .33228 .36659 L p 0 .349 .782 r
F P
0 g
s
.36993 .3751 m .35723 .38264 L .33238 .35457 L p 0 .314 .946 r
F P
0 g
s
.49915 .23074 m .48521 .23965 L .5 .25659 L p 0 .318 .938 r
F P
0 g
s
.51405 .22582 m .51406 .24785 L .5 .25659 L p 0 .181 .719 r
F P
0 g
s
.5 .25659 m .51406 .24785 L .49915 .23074 L p 0 .318 .938 r
F P
0 g
s
.46975 .28521 m .5 .25659 L .48521 .23965 L p 0 .349 .781 r
F P
0 g
s
.51406 .24785 m .5 .25659 L .46975 .28521 L p 0 .05 .1 r
F P
0 g
s
.5 .25659 m .48521 .23965 L .49915 .23074 L p 0 .318 .938 r
F P
0 g
s
.49915 .23074 m .51406 .24785 L .5 .25659 L p 0 .318 .938 r
F P
0 g
s
.48521 .23965 m .5 .25659 L .46975 .28521 L p 0 .349 .781 r
F P
0 g
s
.80009 .50713 m .81684 .50839 L .78868 .53771 L closepath p 0 .35 .78 r
F P
0 g
s
.78775 .47489 m .81684 .50839 L .80009 .50713 L closepath p 0 .35 .78 r
F P
0 g
s
.33156 .4066 m .39822 .48124 L .33193 .40654 L .1 0 0 r
F
.33193 .40654 m .39822 .48124 L .37644 .50229 L .856 0 0 r
F
.34578 .42215 m .35961 .43773 L .37221 .42571 L p 0 .349 .782 r
F P
0 g
s
.37221 .42571 m .35842 .41015 L .34578 .42215 L p 0 .349 .782 r
F P
0 g
s
.33193 .40654 m .34578 .42215 L .35842 .41015 L p 0 .349 .782 r
F P
0 g
s
.35842 .41015 m .34461 .39457 L .33193 .40654 L p 0 .349 .782 r
F P
0 g
s
.35719 .39172 m .37006 .37955 L .38412 .39544 L p 0 .349 .781 r
F P
0 g
s
.38412 .39544 m .37129 .40764 L .35719 .39172 L p 0 .349 .781 r
F P
0 g
s
.35719 .39172 m .37129 .40764 L .38412 .39544 L p 0 .349 .781 r
F P
0 g
s
.38412 .39544 m .37006 .37955 L .35719 .39172 L p 0 .349 .781 r
F P
0 g
s
.38345 .37632 m .33193 .40654 L .39822 .48124 L p .54 0 0 r
F P
0 g
s
.37644 .50229 m .39822 .48124 L .33193 .40654 L p .856 0 0 r
F P
0 g
s
.397 .48242 m
.39822 .48124 L
s
.32917 .40696 m
.33306 .40467 L
s
.39929 .637 m
.41359 .62281 L
s
.74332 .57358 m .75971 .56786 L .78868 .53771 L p 0 .05 .248 r
F P
0 g
s
.75971 .56786 m .74332 .57358 L .71426 .60377 L p 0 .05 .248 r
F P
0 g
s
.51893 .54358 m .52513 .53846 L .53944 .53241 L p 0 .05 .1 r
F P
0 g
s
.54685 .52823 m .53944 .53241 L .52513 .53846 L p 0 .05 .1 r
F P
0 g
s
.51702 .74327 m .48684 .7743 L .5017 .79088 L p 0 .349 .782 r
F P
0 g
s
.27723 .45366 m .28244 .4533 L .316 .49093 L .1 0 0 r
F
.30717 .42772 m .28244 .4533 L .27723 .45366 L F
0 g
.27723 .45366 m
.28749 .4407 L
s
.4842 .21361 m .4704 .22269 L .48521 .23965 L p 0 .318 .938 r
F P
0 g
s
.48521 .23965 m .49915 .23074 L .4842 .21361 L p 0 .318 .938 r
F P
0 g
s
.45486 .26822 m .48521 .23965 L .4704 .22269 L p 0 .349 .781 r
F P
0 g
s
.48521 .23965 m .45486 .26822 L .46975 .28521 L p 0 .349 .781 r
F P
0 g
s
.48521 .23965 m .4704 .22269 L .4842 .21361 L p 0 .318 .938 r
F P
0 g
s
.4842 .21361 m .49915 .23074 L .48521 .23965 L p 0 .318 .938 r
F P
0 g
s
.46975 .28521 m .45486 .26822 L .48521 .23965 L p 0 .349 .781 r
F P
0 g
s
.4704 .22269 m .48521 .23965 L .45486 .26822 L p 0 .349 .781 r
F P
0 g
s
.3863 .44641 m .40021 .4621 L .38721 .46883 L p 0 .312 .948 r
F P
0 g
s
.38721 .46883 m .37342 .45329 L .3863 .44641 L p 0 .312 .948 r
F P
0 g
s
.38721 .46883 m
.39822 .48124 L
s
.37342 .45329 m
.38721 .46883 L
s
.3274 .34895 m .33238 .35457 L .34486 .34676 L p 0 .314 .946 r
F P
0 g
s
.33228 .36659 m .33238 .35457 L .3274 .34895 L p 0 .349 .782 r
F P
0 g
s
.33238 .35457 m .34486 .34676 L .36993 .3751 L p 0 .314 .946 r
F P
0 g
s
.33984 .34108 m .34486 .34676 L .33238 .35457 L p 0 .314 .946 r
F P
0 g
s
.33238 .35457 m .3274 .34895 L .33984 .34108 L p 0 .314 .946 r
F P
0 g
s
.53944 .53241 m .53319 .53757 L .51893 .54358 L p 0 .05 .1 r
F P
0 g
s
.51371 .54984 m .51893 .54358 L .53319 .53757 L p 0 .05 .243 r
F P
0 g
s
.58862 .24564 m .57381 .25443 L .60383 .28895 L p 0 .319 .936 r
F P
0 g
s
.60383 .28895 m .61891 .2805 L .58862 .24564 L p 0 .319 .936 r
F P
0 g
s
.34486 .34676 m .33984 .34108 L .3274 .34895 L p 0 .314 .946 r
F P
0 g
s
.3274 .34895 m .30195 .37276 L .33228 .36659 L p 0 .349 .782 r
F P
0 g
s
.3274 .34895 m .33984 .34108 L .31419 .36508 L p 0 .05 .1 r
F P
0 g
s
.31419 .36508 m .30195 .37276 L .3274 .34895 L p 0 .05 .1 r
F P
0 g
s
.3863 .44641 m .37342 .45329 L .35961 .43773 L p 0 .312 .948 r
F P
0 g
s
.36514 .44396 m
.37342 .45329 L
s
.4704 .22269 m .43995 .25119 L .45486 .26822 L p 0 .349 .781 r
F P
0 g
s
.45486 .26822 m .43995 .25119 L .4704 .22269 L p 0 .349 .781 r
F P
0 g
s
.43995 .25119 m .4704 .22269 L .4842 .21361 L p 0 .05 .1 r
F P
0 g
s
.51402 .18567 m .4842 .21361 L .4704 .22269 L p 0 .05 .1 r
F P
0 g
s
.77361 .48946 m .78775 .47489 L .80009 .50713 L p 0 .35 .78 r
F P
0 g
s
.78775 .47489 m .77361 .48946 L .74379 .45517 L p 0 .35 .78 r
F P
0 g
s
.74379 .45517 m .75802 .44066 L .78775 .47489 L p 0 .35 .78 r
F P
0 g
s
.43821 .4786 m .43921 .47823 L .43189 .48183 L p 0 .475 .892 r
F P
0 g
s
.43189 .48183 m .43073 .48228 L .43821 .4786 L p 0 .475 .892 r
F P
0 g
s
.40909 .48925 m .42163 .48576 L .43073 .48228 L p 0 .275 .686 r
F P
0 g
s
.43029 .4815 m .43821 .4786 L .43073 .48228 L p 0 .475 .892 r
F P
0 g
s
.43073 .48228 m .42163 .48576 L .43029 .4815 L p 0 .475 .892 r
F P
0 g
s
.36815 .66034 m
.37207 .664 L
s
.37736 .65432 m .36439 .65681 L .37546 .65255 L .509 0 0 r
F
0 g
.36439 .65681 m
.36815 .66034 L
s
.36439 .65681 m
.37546 .65255 L
s
.37546 .65255 m
.37669 .65133 L
s
.36439 .65681 m
.36815 .66034 L
s
.42163 .48576 m .40909 .48925 L .41965 .48403 L p 0 .492 1 r
F P
0 g
s
.33228 .36659 m .3321 .38655 L .34461 .39457 L p 0 .349 .782 r
F P
0 g
s
.3321 .38655 m .33228 .36659 L .30195 .37276 L p 0 .349 .782 r
F P
0 g
s
.41965 .48403 m .43029 .4815 L .42163 .48576 L p 0 .492 1 r
F P
0 g
s
.33193 .40654 m .34461 .39457 L .35721 .38713 L p 0 .05 .1 r
F P
0 g
s
.36993 .3751 m .35721 .38713 L .34461 .39457 L p 0 .05 .1 r
F P
0 g
s
.35721 .38713 m .34461 .39457 L .33193 .40654 L p 0 .05 .1 r
F P
0 g
s
.33219 .40578 m .33156 .4066 L .30717 .42772 L .1 0 0 r
F
.3321 .38655 m .33193 .40654 L .34461 .39457 L closepath p 0 .349 .782 r
F P
0 g
s
.7594 .5041 m .73024 .53413 L .7141 .54018 L p 0 .05 .218 r
F P
0 g
s
.77979 .50562 m .80009 .50713 L .78868 .53771 L p 0 .35 .78 r
F P
0 g
s
.80009 .50713 m .77979 .50562 L .77361 .48946 L p 0 .35 .78 r
F P
0 g
s
.39611 .28843 m .40921 .27998 L .37815 .30905 L p 0 .05 .1 r
F P
0 g
s
.37815 .30905 m .36529 .31727 L .39611 .28843 L p 0 .05 .1 r
F P
0 g
s
.30717 .42772 m .30984 .42741 L .28244 .4533 L .1 0 0 r
F
.33156 .4066 m .30984 .42741 L .30717 .42772 L F
0 g
.30717 .42772 m
.31202 .42154 L
s
.30717 .42772 m
.31202 .42154 L
s
.53319 .53757 m .52794 .54388 L .51371 .54984 L p 0 .05 .243 r
F P
0 g
s
.50932 .55741 m .51371 .54984 L .52794 .54388 L p 0 .05 .416 r
F P
0 g
s
.37237 .4307 m .35961 .43773 L .34578 .42215 L p 0 .312 .948 r
F P
0 g
s
.35961 .43773 m .37237 .4307 L .3863 .44641 L p 0 .312 .948 r
F P
0 g
s
.30195 .37276 m .31695 .38966 L .3321 .38655 L p 0 .349 .782 r
F P
0 g
s
.3321 .38655 m .31695 .38966 L .33193 .40654 L closepath p 0 .349 .782 r
F P
0 g
s
.36896 .56177 m
.37274 .55809 L
s
.39982 .53838 m .41237 .55248 L .42578 .54648 L p 0 .31 .951 r
F P
0 g
s
.41237 .55248 m .39982 .53838 L .41312 .53224 L p 0 .31 .951 r
F P
0 g
s
.41312 .53224 m .42578 .54648 L .41237 .55248 L p 0 .31 .951 r
F P
0 g
s
.42578 .54648 m .41312 .53224 L .39982 .53838 L p 0 .31 .951 r
F P
0 g
s
.41312 .53224 m .42578 .54648 L .43945 .54036 L p 0 .31 .951 r
F P
0 g
s
.41157 .56043 m .42578 .54648 L .41237 .55248 L p 0 .05 .1 r
F P
0 g
s
.41157 .56043 m .42578 .54648 L .41312 .53224 L p 0 .349 .781 r
F P
0 g
s
.42578 .54648 m .41312 .53224 L .42668 .52598 L p 0 .31 .951 r
F P
0 g
s
.42668 .52598 m .43945 .54036 L .42578 .54648 L p 0 .31 .951 r
F P
0 g
s
.42578 .54648 m .41157 .56043 L .39887 .54616 L p 0 .349 .781 r
F P
0 g
s
.39887 .54616 m .41312 .53224 L .42578 .54648 L p 0 .349 .781 r
F P
0 g
s
.43945 .54036 m .42668 .52598 L .41312 .53224 L p 0 .31 .951 r
F P
0 g
s
.41312 .53224 m .39887 .54616 L .41157 .56043 L p 0 .349 .781 r
F P
0 g
s
.41157 .56043 m .39887 .54616 L .41232 .54002 L p 0 .31 .951 r
F P
0 g
s
.42578 .54648 m .43843 .56071 L .4249 .56657 L p 0 .31 .951 r
F P
0 g
s
.41157 .56043 m .42578 .54648 L .43843 .56071 L p 0 .349 .781 r
F P
0 g
s
.42578 .54648 m .41157 .56043 L .42426 .57467 L p 0 .349 .781 r
F P
0 g
s
.42578 .54648 m .41157 .56043 L .42514 .55443 L p 0 .05 .1 r
F P
0 g
s
.45253 .5468 m .43843 .56071 L .42578 .54648 L p 0 .349 .781 r
F P
0 g
s
.45253 .5468 m .46512 .56099 L .45138 .56683 L p 0 .311 .95 r
F P
0 g
s
.45105 .57491 m .46512 .56099 L .45138 .56683 L p 0 .05 .1 r
F P
0 g
s
.45105 .57491 m .46512 .56099 L .45253 .5468 L p 0 .349 .781 r
F P
0 g
s
.43843 .56071 m .45253 .5468 L .46512 .56099 L p 0 .349 .781 r
F P
0 g
s
.45253 .5468 m .43843 .56071 L .45105 .57491 L p 0 .349 .781 r
F P
0 g
s
.45253 .5468 m .43843 .56071 L .45221 .55473 L p 0 .05 .1 r
F P
0 g
s
.47637 .54833 m .47679 .54943 L p .45253 .5468 L 0 .349 .781 r
F P
0 g
s
.47189 .54004 m .47637 .54833 L p .45253 .5468 L 0 .349 .781 r
F P
0 g
s
.47679 .54943 m .46512 .56099 L .45253 .5468 L p 0 .349 .781 r
F P
0 g
s
.47637 .54833 m .47189 .54004 L p .46512 .56099 L 0 .349 .781 r
F P
0 g
s
.46512 .56099 m .47679 .54943 L .47637 .54833 L p 0 .349 .781 r
F P
0 g
s
.46512 .56099 m .47679 .54943 L .49088 .54337 L p 0 .05 .1 r
F P
0 g
s
.47679 .54943 m .46512 .56099 L .47912 .55503 L p 0 .05 .1 r
F P
0 g
s
.49088 .54337 m .47912 .55503 L .46512 .56099 L p 0 .05 .1 r
F P
0 g
s
.45253 .5468 m .46512 .56099 L .47912 .55503 L p 0 .311 .95 r
F P
0 g
s
.46512 .56099 m .45253 .5468 L .46642 .54071 L p 0 .311 .95 r
F P
0 g
s
.47912 .55503 m .46642 .54071 L .45253 .5468 L p 0 .311 .95 r
F P
0 g
s
.43843 .56071 m .45253 .5468 L .46642 .54071 L p 0 .05 .1 r
F P
0 g
s
.46642 .54071 m .45221 .55473 L .43843 .56071 L p 0 .05 .1 r
F P
0 g
s
.42578 .54648 m .43843 .56071 L .45221 .55473 L p 0 .31 .951 r
F P
0 g
s
.42426 .57467 m .43843 .56071 L .4249 .56657 L p 0 .05 .1 r
F P
0 g
s
.42426 .57467 m .43843 .56071 L .42578 .54648 L p 0 .349 .781 r
F P
0 g
s
.43843 .56071 m .42578 .54648 L .43945 .54036 L p 0 .31 .951 r
F P
0 g
s
.45221 .55473 m .43945 .54036 L .42578 .54648 L p 0 .31 .951 r
F P
0 g
s
.41157 .56043 m .42578 .54648 L .43945 .54036 L p 0 .05 .1 r
F P
0 g
s
.43945 .54036 m .42514 .55443 L .41157 .56043 L p 0 .05 .1 r
F P
0 g
s
.41232 .54002 m .42514 .55443 L .41157 .56043 L p 0 .31 .951 r
F P
0 g
s
.41232 .54002 m .39887 .54616 L .41157 .56043 L p 0 .31 .951 r
F P
0 g
s
.41157 .56043 m .42514 .55443 L .41232 .54002 L p 0 .31 .951 r
F P
0 g
s
.39887 .54616 m .41232 .54002 L .39791 .55413 L p 0 .05 .1 r
F P
0 g
s
.4537 .52636 m .43945 .54036 L .42668 .52598 L p 0 .349 .781 r
F P
0 g
s
.4537 .52636 m .46642 .54071 L .45253 .5468 L p 0 .311 .95 r
F P
0 g
s
.45221 .55473 m .46642 .54071 L .45253 .5468 L p 0 .05 .1 r
F P
0 g
s
.45221 .55473 m .46642 .54071 L .4537 .52636 L p 0 .349 .781 r
F P
0 g
s
.43945 .54036 m .4537 .52636 L .46642 .54071 L p 0 .349 .781 r
F P
0 g
s
.4537 .52636 m .43945 .54036 L .45221 .55473 L p 0 .349 .781 r
F P
0 g
s
.4537 .52636 m .43945 .54036 L .4534 .53412 L p 0 .05 .1 r
F P
0 g
s
.48056 .52675 m .46642 .54071 L .4537 .52636 L p 0 .349 .781 r
F P
0 g
s
.47417 .5206 m .48056 .52675 L p .4537 .52636 L 0 .349 .781 r
F P
0 g
s
.46642 .54071 m .4537 .52636 L .46775 .52 L p 0 .311 .95 r
F P
0 g
s
.47189 .54004 m .47637 .54833 L .49045 .54226 L p 0 .272 .885 r
F P
0 g
s
.49088 .54337 m .49045 .54226 L .47637 .54833 L p 0 .25 .847 r
F P
0 g
s
.47637 .54833 m .47679 .54943 L .49088 .54337 L p 0 .25 .847 r
F P
0 g
s
.47912 .55503 m .49088 .54337 L .47679 .54943 L p 0 .05 .1 r
F P
0 g
s
.49045 .54226 m .48594 .53389 L .47189 .54004 L p 0 .272 .885 r
F P
0 g
s
.48594 .53389 m .48056 .52675 L p .47912 .55503 L 0 .349 .781 r
F P
0 g
s
.46642 .54071 m .48056 .52675 L .48594 .53389 L p 0 .349 .781 r
F P
0 g
s
.48056 .52675 m .46642 .54071 L .47912 .55503 L p 0 .349 .781 r
F P
0 g
s
.48056 .52675 m .46642 .54071 L .48059 .53449 L p 0 .05 .1 r
F P
0 g
s
.46642 .54071 m .48056 .52675 L .47417 .5206 L p 0 .349 .781 r
F P
0 g
s
.48056 .52675 m .48594 .53389 L .49287 .53086 L p 0 .298 .927 r
F P
0 g
s
.49287 .53086 m .48719 .5238 L .48056 .52675 L p 0 .298 .927 r
F P
0 g
s
.46642 .54071 m .48056 .52675 L .48719 .5238 L p 0 .05 .1 r
F P
0 g
s
.48116 .53392 m .48059 .53449 L .46642 .54071 L p 0 .05 .1 r
F P
0 g
s
.48719 .5238 m .48116 .53392 L p .46642 .54071 L 0 .05 .1 r
F P
0 g
s
.4537 .52636 m .46642 .54071 L .48059 .53449 L p 0 .311 .95 r
F P
0 g
s
.48059 .53449 m .46775 .52 L .4537 .52636 L p 0 .311 .95 r
F P
0 g
s
.4537 .52636 m .46775 .52 L p .46206 .5241 L 0 .05 .1 r
F P
0 g
s
.43945 .54036 m .45086 .52916 L p .46206 .5241 L 0 .05 .1 r
F P
0 g
s
.45086 .52916 m .4537 .52636 L p .46206 .5241 L 0 .05 .1 r
F P
0 g
s
.5089 .55843 m .50932 .55741 L .52351 .55152 L p 0 .086 .523 r
F P
0 g
s
.52794 .54388 m .52351 .55152 L .50932 .55741 L p 0 .05 .416 r
F P
0 g
s
.52351 .55152 m .52309 .55255 L .5089 .55843 L p 0 .086 .523 r
F P
0 g
s
.48594 .53389 m .49045 .54226 L .49829 .53889 L p 0 .272 .885 r
F P
0 g
s
.49888 .53993 m .49829 .53889 L .49045 .54226 L p 0 .25 .847 r
F P
0 g
s
.49045 .54226 m .49088 .54337 L .49888 .53993 L p 0 .25 .847 r
F P
0 g
s
.49045 .54226 m .48594 .53389 L p .47912 .55503 L 0 .349 .781 r
F P
0 g
s
.47912 .55503 m .49088 .54337 L .49045 .54226 L p 0 .349 .781 r
F P
0 g
s
.49045 .54226 m .49088 .54337 L p .46642 .54071 L 0 .349 .781 r
F P
0 g
s
.48594 .53389 m .49045 .54226 L p .46642 .54071 L 0 .349 .781 r
F P
0 g
s
.47912 .55503 m .49088 .54337 L .49888 .53993 L p 0 .05 .1 r
F P
0 g
s
.49397 .54839 m .49888 .53993 L .49088 .54337 L p 0 .05 .1 r
F P
0 g
s
.49341 .54896 m .49397 .54839 L p .49088 .54337 L 0 .05 .1 r
F P
0 g
s
.49088 .54337 m .47912 .55503 L .49341 .54896 L p 0 .05 .1 r
F P
0 g
s
.49088 .54337 m .47912 .55503 L .46642 .54071 L p 0 .349 .781 r
F P
0 g
s
.49829 .53889 m .49287 .53086 L .48594 .53389 L p 0 .272 .885 r
F P
0 g
s
.48719 .5238 m .48056 .52675 L p .48059 .53449 L 0 .05 .1 r
F P
0 g
s
.46496 .56908 m .47912 .55503 L .49341 .54896 L p 0 .05 .1 r
F P
0 g
s
.49397 .54839 m .49341 .54896 L .47912 .55503 L p 0 .05 .1 r
F P
0 g
s
.49888 .53993 m .49397 .54839 L p .47912 .55503 L 0 .05 .1 r
F P
0 g
s
.49341 .54896 m .47912 .55503 L p .47913 .55664 L 0 .05 .1 r
F P
0 g
s
.47913 .56313 m .49056 .55179 L p .47913 .55664 L 0 .05 .1 r
F P
0 g
s
.49056 .55179 m .49341 .54896 L p .47913 .55664 L 0 .05 .1 r
F P
0 g
s
.50188 .56159 m .51458 .55633 L p .50241 .54676 L .532 0 0 r
F P
0 g
s
.48059 .53449 m .49341 .54896 L .47912 .55503 L p 0 .311 .95 r
F P
0 g
s
.47912 .55503 m .46642 .54071 L .48059 .53449 L p 0 .311 .95 r
F P
0 g
s
.46642 .54071 m .47912 .55503 L .49341 .54896 L p 0 .311 .95 r
F P
0 g
s
.46775 .52 m .48059 .53449 L .46642 .54071 L p 0 .311 .95 r
F P
0 g
s
.46642 .54071 m .47912 .55503 L .46512 .56099 L p 0 .311 .95 r
F P
0 g
s
.45105 .57491 m .46512 .56099 L .47912 .55503 L p 0 .05 .1 r
F P
0 g
s
.46496 .56908 m .47912 .55503 L .46512 .56099 L p 0 .05 .1 r
F P
0 g
s
.47912 .55503 m .46496 .56908 L .45105 .57491 L p 0 .05 .1 r
F P
0 g
s
.46496 .56908 m .47912 .55503 L .46642 .54071 L p 0 .349 .781 r
F P
0 g
s
.45221 .55473 m .46642 .54071 L .47912 .55503 L p 0 .349 .781 r
F P
0 g
s
.49341 .54896 m .48059 .53449 L .46642 .54071 L p 0 .311 .95 r
F P
0 g
s
.48059 .53449 m .46642 .54071 L p .46639 .54228 L 0 .05 .1 r
F P
0 g
s
.46627 .54864 m .47773 .53731 L p .46639 .54228 L 0 .05 .1 r
F P
0 g
s
.47773 .53731 m .48059 .53449 L p .46639 .54228 L 0 .05 .1 r
F P
0 g
s
.47913 .56313 m .46496 .56908 L p .48768 .55301 L 0 .05 .1 r
F P
0 g
s
.49341 .54896 m .49056 .55179 L p .48768 .55301 L 0 .05 .1 r
F P
0 g
s
.49056 .55179 m .47913 .56313 L p .48768 .55301 L 0 .05 .1 r
F P
0 g
s
.46512 .56099 m .45105 .57491 L .46496 .56908 L p 0 .05 .1 r
F P
0 g
s
.46512 .56099 m .45105 .57491 L .43843 .56071 L p 0 .349 .781 r
F P
0 g
s
.46642 .54071 m .45221 .55473 L .46496 .56908 L p 0 .349 .781 r
F P
0 g
s
.45221 .55473 m .46642 .54071 L .48059 .53449 L p 0 .05 .1 r
F P
0 g
s
.46627 .54864 m .45221 .55473 L p .47488 .53856 L 0 .05 .1 r
F P
0 g
s
.48059 .53449 m .47773 .53731 L p .47488 .53856 L 0 .05 .1 r
F P
0 g
s
.47773 .53731 m .46627 .54864 L p .47488 .53856 L 0 .05 .1 r
F P
0 g
s
.46627 .54864 m .48059 .53449 L .49341 .54896 L p 0 .35 .78 r
F P
0 g
s
.48059 .53449 m .48116 .53392 L .48719 .5238 L p 0 .05 .1 r
F P
0 g
s
.48116 .53392 m .48059 .53449 L .46775 .52 L p 0 .35 .78 r
F P
0 g
s
.46775 .52 m .46832 .51944 L .48116 .53392 L p 0 .35 .78 r
F P
0 g
s
.46642 .54071 m .45221 .55473 L .46627 .54864 L p 0 .05 .1 r
F P
0 g
s
.46642 .54071 m .45221 .55473 L .43945 .54036 L p 0 .349 .781 r
F P
0 g
s
.48059 .53449 m .46627 .54864 L .4534 .53412 L p 0 .35 .78 r
F P
0 g
s
.4534 .53412 m .46775 .52 L .48059 .53449 L p 0 .35 .78 r
F P
0 g
s
.46678 .52196 m .47964 .53648 L p .46939 .52079 L .532 0 0 r
F P
0 g
s
.47912 .55503 m .46496 .56908 L .47913 .56313 L p 0 .05 .1 r
F P
0 g
s
.47912 .55503 m .46496 .56908 L .45221 .55473 L p 0 .349 .781 r
F P
0 g
s
.49341 .54896 m .47913 .56313 L .46627 .54864 L p 0 .35 .78 r
F P
0 g
s
.47964 .53648 m .49248 .55097 L p .48095 .5359 L .532 0 0 r
F P
0 g
s
.47964 .53648 m .48095 .5359 L .46939 .52079 L .532 0 0 r
F
.49248 .55097 m .50188 .56159 L p .49319 .55067 L F P
0 g
s
.49248 .55097 m .49319 .55067 L .46939 .52079 L .532 0 0 r
F
.49287 .53086 m .49829 .53889 L p .49397 .54839 L 0 .332 .56 r
F P
0 g
s
.48719 .5238 m .49287 .53086 L p .49397 .54839 L 0 .332 .56 r
F P
0 g
s
.49397 .54839 m .48116 .53392 L .48719 .5238 L p 0 .332 .56 r
F P
0 g
s
.49829 .53889 m .49888 .53993 L .49397 .54839 L p 0 .332 .56 r
F P
0 g
s
.49397 .54839 m .49341 .54896 L .48059 .53449 L p 0 .35 .78 r
F P
0 g
s
.48059 .53449 m .48116 .53392 L .49397 .54839 L p 0 .35 .78 r
F P
0 g
s
.48587 .53375 m .49319 .55067 L .50241 .54676 L .532 0 0 r
F
.47417 .5206 m .48056 .52675 L .48719 .5238 L p 0 .326 .97 r
F P
0 g
s
.48719 .5238 m .48105 .5175 L .47417 .5206 L p 0 .326 .97 r
F P
0 g
s
.48719 .5238 m .48116 .53392 L p .4734 .51114 L 0 .332 .56 r
F P
0 g
s
.48116 .53392 m .46832 .51944 L .4734 .51114 L p 0 .332 .56 r
F P
0 g
s
.46939 .52079 m .4813 .53575 L .48587 .53375 L .532 0 0 r
F
.4813 .53575 m .49319 .55067 L .48587 .53375 L F
.49319 .55067 m .50188 .56159 L .50241 .54676 L F
.4734 .51114 m .46552 .51474 L p .46775 .52 L 0 .05 .1 r
F P
0 g
s
.4534 .53412 m .46775 .52 L .4537 .52636 L p 0 .05 .1 r
F P
0 g
s
.46775 .52 m .4534 .53412 L .43945 .54036 L p 0 .05 .1 r
F P
0 g
s
.46775 .52 m .46832 .51944 L .4734 .51114 L p 0 .05 .1 r
F P
0 g
s
.4734 .51114 m .46832 .51944 L .46775 .52 L p 0 .05 .1 r
F P
0 g
s
.46832 .51944 m .46775 .52 L .4549 .50549 L p 0 .35 .78 r
F P
0 g
s
.46775 .52 m .4534 .53412 L .4405 .51959 L p 0 .35 .78 r
F P
0 g
s
.45734 .51131 m .46678 .52196 L p .46939 .52079 L .532 0 0 r
F P
0 g
s
.43945 .54036 m .4534 .53412 L p .43375 .52813 L 0 .31 .951 r
F P
0 g
s
.42668 .52598 m .43009 .52981 L p .43375 .52813 L 0 .31 .951 r
F P
0 g
s
.43009 .52981 m .43945 .54036 L p .43375 .52813 L 0 .31 .951 r
F P
0 g
s
.41157 .56043 m .42426 .57467 L .41084 .58041 L p 0 .31 .951 r
F P
0 g
s
.43843 .56071 m .42426 .57467 L .41157 .56043 L p 0 .349 .781 r
F P
0 g
s
.42426 .57467 m .41157 .56043 L .42514 .55443 L p 0 .31 .951 r
F P
0 g
s
.3973 .57443 m .41157 .56043 L .42426 .57467 L p 0 .349 .781 r
F P
0 g
s
.41012 .59999 m .42339 .5945 L .41084 .58041 L p 0 .31 .951 r
F P
0 g
s
.41084 .58041 m .39768 .58604 L .41012 .59999 L p 0 .31 .951 r
F P
0 g
s
.41084 .58041 m .42339 .5945 L .41012 .59999 L p 0 .31 .951 r
F P
0 g
s
.41012 .59999 m .39768 .58604 L .41084 .58041 L p 0 .31 .951 r
F P
0 g
s
.39614 .61381 m .41012 .59999 L .39768 .58604 L p 0 .349 .782 r
F P
0 g
s
.39768 .58604 m .38366 .59983 L .39614 .61381 L p 0 .349 .782 r
F P
0 g
s
.41084 .58041 m .39768 .58604 L .38366 .59983 L p 0 .05 .1 r
F P
0 g
s
.38366 .59983 m .39768 .58604 L .41084 .58041 L p 0 .05 .1 r
F P
0 g
s
.38366 .59983 m .39672 .59432 L .41084 .58041 L p 0 .05 .1 r
F P
0 g
s
.41084 .58041 m .39672 .59432 L .38366 .59983 L p 0 .05 .1 r
F P
0 g
s
.43742 .58063 m .42339 .5945 L .41084 .58041 L p 0 .349 .781 r
F P
0 g
s
.42426 .57467 m .41084 .58041 L .42339 .5945 L p 0 .31 .951 r
F P
0 g
s
.42339 .5945 m .41084 .58041 L .42426 .57467 L p 0 .31 .951 r
F P
0 g
s
.42426 .57467 m .41084 .58041 L .39672 .59432 L p 0 .05 .1 r
F P
0 g
s
.39672 .59432 m .41084 .58041 L .42426 .57467 L p 0 .05 .1 r
F P
0 g
s
.39672 .59432 m .41003 .5887 L .42426 .57467 L p 0 .05 .1 r
F P
0 g
s
.42426 .57467 m .41003 .5887 L .39672 .59432 L p 0 .05 .1 r
F P
0 g
s
.42426 .57467 m .41003 .5887 L .3973 .57443 L p 0 .349 .781 r
F P
0 g
s
.3973 .57443 m .41003 .5887 L .42426 .57467 L p 0 .349 .781 r
F P
0 g
s
.42426 .57467 m .41157 .56043 L .3973 .57443 L p 0 .349 .781 r
F P
0 g
s
.42514 .55443 m .41157 .56043 L .42426 .57467 L p 0 .31 .951 r
F P
0 g
s
.38297 .58851 m .3973 .57443 L .41003 .5887 L p 0 .349 .781 r
F P
0 g
s
.41003 .5887 m .3973 .57443 L .38297 .58851 L p 0 .349 .781 r
F P
0 g
s
.42514 .55443 m .43945 .54036 L .42578 .54648 L p 0 .05 .1 r
F P
0 g
s
.42514 .55443 m .43945 .54036 L .42668 .52598 L p 0 .349 .781 r
F P
0 g
s
.43945 .54036 m .42514 .55443 L .41232 .54002 L p 0 .349 .781 r
F P
0 g
s
.41232 .54002 m .42668 .52598 L .43945 .54036 L p 0 .349 .781 r
F P
0 g
s
.42668 .52598 m .4405 .51959 L p .44022 .52517 L 0 .31 .951 r
F P
0 g
s
.43945 .54036 m .43009 .52981 L p .44022 .52517 L 0 .31 .951 r
F P
0 g
s
.43009 .52981 m .42668 .52598 L p .44022 .52517 L 0 .31 .951 r
F P
0 g
s
.4734 .51114 m .46832 .51944 L p .45782 .50119 L 0 .332 .56 r
F P
0 g
s
.45782 .50119 m .4666 .50637 L .4734 .51114 L p 0 .332 .56 r
F P
0 g
s
.46832 .51944 m .45547 .50493 L .45782 .50119 L p 0 .332 .56 r
F P
0 g
s
.42339 .5945 m .43742 .58063 L .45105 .57491 L p 0 .05 .1 r
F P
0 g
s
.43693 .5889 m .45105 .57491 L .43742 .58063 L p 0 .05 .1 r
F P
0 g
s
.43843 .56071 m .45105 .57491 L .43742 .58063 L p 0 .31 .951 r
F P
0 g
s
.45105 .57491 m .43693 .5889 L .42339 .5945 L p 0 .05 .1 r
F P
0 g
s
.43693 .5889 m .45105 .57491 L .46496 .56908 L p 0 .05 .1 r
F P
0 g
s
.45072 .58319 m .46496 .56908 L .45105 .57491 L p 0 .05 .1 r
F P
0 g
s
.45105 .57491 m .43693 .5889 L .45072 .58319 L p 0 .05 .1 r
F P
0 g
s
.43843 .56071 m .45105 .57491 L .46496 .56908 L p 0 .31 .951 r
F P
0 g
s
.43742 .58063 m .42339 .5945 L .43693 .5889 L p 0 .05 .1 r
F P
0 g
s
.43693 .5889 m .45105 .57491 L .43843 .56071 L p 0 .349 .781 r
F P
0 g
s
.45221 .55473 m .46496 .56908 L .45105 .57491 L p 0 .31 .951 r
F P
0 g
s
.45105 .57491 m .43843 .56071 L .45221 .55473 L p 0 .31 .951 r
F P
0 g
s
.45105 .57491 m .43693 .5889 L .42426 .57467 L p 0 .349 .781 r
F P
0 g
s
.42426 .57467 m .43843 .56071 L .45105 .57491 L p 0 .349 .781 r
F P
0 g
s
.46496 .56908 m .45221 .55473 L .43843 .56071 L p 0 .31 .951 r
F P
0 g
s
.43843 .56071 m .42426 .57467 L .43693 .5889 L p 0 .349 .781 r
F P
0 g
s
.43794 .56882 m .45221 .55473 L .43843 .56071 L p 0 .05 .1 r
F P
0 g
s
.43945 .54036 m .45221 .55473 L .43843 .56071 L p 0 .31 .951 r
F P
0 g
s
.42426 .57467 m .43843 .56071 L .45221 .55473 L p 0 .05 .1 r
F P
0 g
s
.46496 .56908 m .45072 .58319 L .43693 .5889 L p 0 .05 .1 r
F P
0 g
s
.43794 .56882 m .45072 .58319 L .43693 .5889 L p 0 .31 .951 r
F P
0 g
s
.42426 .57467 m .43693 .5889 L .45072 .58319 L p 0 .31 .951 r
F P
0 g
s
.45221 .55473 m .43794 .56882 L .42426 .57467 L p 0 .05 .1 r
F P
0 g
s
.45072 .58319 m .43794 .56882 L .42426 .57467 L p 0 .31 .951 r
F P
0 g
s
.45072 .58319 m .46496 .56908 L .47913 .56313 L p 0 .05 .1 r
F P
0 g
s
.46479 .57737 m .47913 .56313 L .46496 .56908 L p 0 .05 .1 r
F P
0 g
s
.46496 .56908 m .45072 .58319 L .46479 .57737 L p 0 .05 .1 r
F P
0 g
s
.45221 .55473 m .46496 .56908 L .47913 .56313 L p 0 .31 .951 r
F P
0 g
s
.45072 .58319 m .46496 .56908 L .45221 .55473 L p 0 .349 .781 r
F P
0 g
s
.46496 .56908 m .45072 .58319 L .43794 .56882 L p 0 .349 .781 r
F P
0 g
s
.43794 .56882 m .45221 .55473 L .46496 .56908 L p 0 .349 .781 r
F P
0 g
s
.46627 .54864 m .47913 .56313 L .46496 .56908 L p 0 .31 .951 r
F P
0 g
s
.46496 .56908 m .45221 .55473 L .46627 .54864 L p 0 .31 .951 r
F P
0 g
s
.43945 .54036 m .45221 .55473 L .46627 .54864 L p 0 .31 .951 r
F P
0 g
s
.45221 .55473 m .43794 .56882 L .45072 .58319 L p 0 .349 .781 r
F P
0 g
s
.45221 .55473 m .43794 .56882 L .45189 .56285 L p 0 .05 .1 r
F P
0 g
s
.47913 .56313 m .46627 .54864 L .45221 .55473 L p 0 .31 .951 r
F P
0 g
s
.45189 .56285 m .46627 .54864 L .45221 .55473 L p 0 .05 .1 r
F P
0 g
s
.43843 .56071 m .42426 .57467 L .43794 .56882 L p 0 .05 .1 r
F P
0 g
s
.43794 .56882 m .45221 .55473 L .43945 .54036 L p 0 .349 .781 r
F P
0 g
s
.45221 .55473 m .43794 .56882 L .42514 .55443 L p 0 .349 .781 r
F P
0 g
s
.42514 .55443 m .43945 .54036 L .45221 .55473 L p 0 .349 .781 r
F P
0 g
s
.45221 .55473 m .43945 .54036 L .4534 .53412 L p 0 .31 .951 r
F P
0 g
s
.4534 .53412 m .46627 .54864 L .45221 .55473 L p 0 .31 .951 r
F P
0 g
s
.43794 .56882 m .45221 .55473 L .46627 .54864 L p 0 .05 .1 r
F P
0 g
s
.46627 .54864 m .4534 .53412 L .43945 .54036 L p 0 .31 .951 r
F P
0 g
s
.43945 .54036 m .42514 .55443 L .43794 .56882 L p 0 .349 .781 r
F P
0 g
s
.43898 .54832 m .4534 .53412 L .43945 .54036 L p 0 .05 .1 r
F P
0 g
s
.4534 .53412 m .43945 .54036 L p .44022 .52517 L 0 .31 .951 r
F P
0 g
s
.4405 .51959 m .44394 .52347 L p .44022 .52517 L 0 .31 .951 r
F P
0 g
s
.44394 .52347 m .4534 .53412 L p .44022 .52517 L 0 .31 .951 r
F P
0 g
s
.42514 .55443 m .43945 .54036 L .4534 .53412 L p 0 .05 .1 r
F P
0 g
s
.4405 .51959 m .42668 .52598 L p .43375 .52813 L 0 .31 .951 r
F P
0 g
s
.4534 .53412 m .44394 .52347 L p .43375 .52813 L 0 .31 .951 r
F P
0 g
s
.44394 .52347 m .4405 .51959 L p .43375 .52813 L 0 .31 .951 r
F P
0 g
s
.42668 .52598 m .41232 .54002 L .42514 .55443 L p 0 .349 .781 r
F P
0 g
s
.41232 .54002 m .42604 .53376 L p .4258 .53931 L 0 .31 .951 r
F P
0 g
s
.42514 .55443 m .41574 .54386 L p .4258 .53931 L 0 .31 .951 r
F P
0 g
s
.41574 .54386 m .41232 .54002 L p .4258 .53931 L 0 .31 .951 r
F P
0 g
s
.42339 .5945 m .43693 .5889 L .42426 .57467 L p 0 .31 .951 r
F P
0 g
s
.42426 .57467 m .43693 .5889 L .42339 .5945 L p 0 .31 .951 r
F P
0 g
s
.38209 .62768 m .39614 .61381 L .38366 .59983 L p 0 .349 .782 r
F P
0 g
s
.38366 .59983 m .36957 .61368 L .38209 .62768 L p 0 .349 .782 r
F P
0 g
s
.41003 .5887 m .39672 .59432 L .38253 .60829 L p 0 .05 .1 r
F P
0 g
s
.38253 .60829 m .39672 .59432 L .41003 .5887 L p 0 .05 .1 r
F P
0 g
s
.38253 .60829 m .39573 .6028 L .41003 .5887 L p 0 .05 .1 r
F P
0 g
s
.41003 .5887 m .39573 .6028 L .38253 .60829 L p 0 .05 .1 r
F P
0 g
s
.43693 .5889 m .42426 .57467 L .43794 .56882 L p 0 .31 .951 r
F P
0 g
s
.42426 .57467 m .43693 .5889 L .42273 .60296 L p 0 .349 .781 r
F P
0 g
s
.42273 .60296 m .43693 .5889 L .42426 .57467 L p 0 .349 .781 r
F P
0 g
s
.42514 .55443 m .43794 .56882 L .42426 .57467 L p 0 .31 .951 r
F P
0 g
s
.42273 .60296 m .41003 .5887 L .42426 .57467 L p 0 .349 .781 r
F P
0 g
s
.42426 .57467 m .41003 .5887 L .42273 .60296 L p 0 .349 .781 r
F P
0 g
s
.4236 .58298 m .43794 .56882 L .42426 .57467 L p 0 .05 .1 r
F P
0 g
s
.42426 .57467 m .41003 .5887 L .4236 .58298 L p 0 .05 .1 r
F P
0 g
s
.42426 .57467 m .43794 .56882 L .42514 .55443 L p 0 .31 .951 r
F P
0 g
s
.4236 .58298 m .41003 .5887 L .42426 .57467 L p 0 .05 .1 r
F P
0 g
s
.42426 .57467 m .43794 .56882 L .4236 .58298 L p 0 .05 .1 r
F P
0 g
s
.41003 .5887 m .42273 .60296 L .40848 .61707 L p 0 .349 .781 r
F P
0 g
s
.40848 .61707 m .42273 .60296 L .41003 .5887 L p 0 .349 .781 r
F P
0 g
s
.39672 .59432 m .38366 .59983 L .36957 .61368 L p 0 .05 .1 r
F P
0 g
s
.36957 .61368 m .38366 .59983 L .39672 .59432 L p 0 .05 .1 r
F P
0 g
s
.36957 .61368 m .38253 .60829 L .39672 .59432 L p 0 .05 .1 r
F P
0 g
s
.39672 .59432 m .38253 .60829 L .36957 .61368 L p 0 .05 .1 r
F P
0 g
s
.41003 .5887 m .39573 .6028 L .38297 .58851 L p 0 .349 .781 r
F P
0 g
s
.40848 .61707 m .39573 .6028 L .41003 .5887 L p 0 .349 .781 r
F P
0 g
s
.38297 .58851 m .39573 .6028 L .41003 .5887 L p 0 .349 .781 r
F P
0 g
s
.41003 .5887 m .39573 .6028 L .40848 .61707 L p 0 .349 .781 r
F P
0 g
s
.40919 .5972 m .4236 .58298 L .41003 .5887 L p 0 .05 .1 r
F P
0 g
s
.41003 .5887 m .39573 .6028 L .40919 .5972 L p 0 .05 .1 r
F P
0 g
s
.40919 .5972 m .39573 .6028 L .41003 .5887 L p 0 .05 .1 r
F P
0 g
s
.41003 .5887 m .4236 .58298 L .40919 .5972 L p 0 .05 .1 r
F P
0 g
s
.39573 .6028 m .40848 .61707 L .39415 .63126 L p 0 .349 .781 r
F P
0 g
s
.39415 .63126 m .40848 .61707 L .39573 .6028 L p 0 .349 .781 r
F P
0 g
s
.39415 .63126 m .38137 .61696 L .39573 .6028 L p 0 .349 .781 r
F P
0 g
s
.39573 .6028 m .38137 .61696 L .39415 .63126 L p 0 .349 .781 r
F P
0 g
s
.39472 .61148 m .40919 .5972 L .39573 .6028 L p 0 .05 .1 r
F P
0 g
s
.39573 .6028 m .40919 .5972 L .39472 .61148 L p 0 .05 .1 r
F P
0 g
s
.43945 .54036 m .42514 .55443 L .43898 .54832 L p 0 .05 .1 r
F P
0 g
s
.45072 .58319 m .43794 .56882 L .45189 .56285 L p 0 .31 .951 r
F P
0 g
s
.47913 .56313 m .46479 .57737 L .45072 .58319 L p 0 .05 .1 r
F P
0 g
s
.43794 .56882 m .45072 .58319 L .46479 .57737 L p 0 .31 .951 r
F P
0 g
s
.43794 .56882 m .42514 .55443 L .43898 .54832 L p 0 .31 .951 r
F P
0 g
s
.46627 .54864 m .45189 .56285 L .43794 .56882 L p 0 .05 .1 r
F P
0 g
s
.43898 .54832 m .45189 .56285 L .43794 .56882 L p 0 .31 .951 r
F P
0 g
s
.46479 .57737 m .45189 .56285 L .43794 .56882 L p 0 .31 .951 r
F P
0 g
s
.43744 .57713 m .45189 .56285 L .43794 .56882 L p 0 .05 .1 r
F P
0 g
s
.43794 .56882 m .4236 .58298 L .43744 .57713 L p 0 .05 .1 r
F P
0 g
s
.43898 .54832 m .42514 .55443 L .43794 .56882 L p 0 .31 .951 r
F P
0 g
s
.43794 .56882 m .45189 .56285 L .43898 .54832 L p 0 .31 .951 r
F P
0 g
s
.43744 .57713 m .4236 .58298 L .43794 .56882 L p 0 .05 .1 r
F P
0 g
s
.43794 .56882 m .45189 .56285 L .43744 .57713 L p 0 .05 .1 r
F P
0 g
s
.4534 .53412 m .43898 .54832 L .42514 .55443 L p 0 .05 .1 r
F P
0 g
s
.43898 .54832 m .42514 .55443 L p .4258 .53931 L 0 .31 .951 r
F P
0 g
s
.42604 .53376 m .42949 .53764 L p .4258 .53931 L 0 .31 .951 r
F P
0 g
s
.42949 .53764 m .43898 .54832 L p .4258 .53931 L 0 .31 .951 r
F P
0 g
s
.42604 .53376 m .41232 .54002 L .41574 .54386 L p 0 .31 .951 r
F P
0 g
s
.41574 .54386 m .42514 .55443 L p .4258 .53931 L 0 .31 .951 r
F P
0 g
s
.4258 .53931 m .42604 .53376 L .41574 .54386 L 0 .31 .951 r
F
.42514 .55443 m .43898 .54832 L .42604 .53376 L p F P
0 g
s
.42293 .59148 m .43744 .57713 L .4236 .58298 L p 0 .05 .1 r
F P
0 g
s
.4236 .58298 m .40919 .5972 L .42293 .59148 L p 0 .05 .1 r
F P
0 g
s
.42293 .59148 m .40919 .5972 L .4236 .58298 L p 0 .05 .1 r
F P
0 g
s
.4236 .58298 m .43744 .57713 L .42293 .59148 L p 0 .05 .1 r
F P
0 g
s
.40834 .6059 m .42293 .59148 L .40919 .5972 L p 0 .05 .1 r
F P
0 g
s
.40919 .5972 m .39472 .61148 L .40834 .6059 L p 0 .05 .1 r
F P
0 g
s
.40834 .6059 m .39472 .61148 L .40919 .5972 L p 0 .05 .1 r
F P
0 g
s
.40919 .5972 m .42293 .59148 L .40834 .6059 L p 0 .05 .1 r
F P
0 g
s
.46627 .54864 m .45189 .56285 L .43898 .54832 L p 0 .35 .78 r
F P
0 g
s
.43898 .54832 m .4534 .53412 L .46627 .54864 L p 0 .35 .78 r
F P
0 g
s
.4534 .53412 m .43898 .54832 L .42604 .53376 L p 0 .35 .78 r
F P
0 g
s
.42604 .53376 m .4405 .51959 L .4534 .53412 L p 0 .35 .78 r
F P
0 g
s
.42449 .56257 m .43898 .54832 L .45189 .56285 L p 0 .35 .78 r
F P
0 g
s
.45189 .56285 m .43744 .57713 L .42449 .56257 L p 0 .35 .78 r
F P
0 g
s
.45189 .56285 m .46479 .57737 L .45072 .58319 L p 0 .31 .951 r
F P
0 g
s
.45038 .59168 m .43744 .57713 L .45189 .56285 L p 0 .35 .78 r
F P
0 g
s
.41151 .54799 m .42604 .53376 L .43898 .54832 L p 0 .35 .78 r
F P
0 g
s
.43898 .54832 m .42449 .56257 L .41151 .54799 L p 0 .35 .78 r
F P
0 g
s
.43744 .57713 m .45038 .59168 L .4359 .60605 L p 0 .35 .78 r
F P
0 g
s
.40993 .5769 m .42449 .56257 L .43744 .57713 L p 0 .35 .78 r
F P
0 g
s
.43744 .57713 m .42293 .59148 L .40993 .5769 L p 0 .35 .78 r
F P
0 g
s
.4359 .60605 m .42293 .59148 L .43744 .57713 L p 0 .35 .78 r
F P
0 g
s
.39692 .56229 m .41151 .54799 L .42449 .56257 L p 0 .35 .78 r
F P
0 g
s
.42449 .56257 m .40993 .5769 L .39692 .56229 L p 0 .35 .78 r
F P
0 g
s
.42293 .59148 m .4359 .60605 L .42136 .62049 L p 0 .35 .78 r
F P
0 g
s
.3953 .59129 m .40993 .5769 L .42293 .59148 L p 0 .35 .78 r
F P
0 g
s
.42293 .59148 m .40834 .6059 L .3953 .59129 L p 0 .35 .78 r
F P
0 g
s
.42136 .62049 m .40834 .6059 L .42293 .59148 L p 0 .35 .78 r
F P
0 g
s
.38225 .57666 m .39692 .56229 L .40993 .5769 L p 0 .35 .78 r
F P
0 g
s
.40993 .5769 m .3953 .59129 L .38225 .57666 L p 0 .35 .78 r
F P
0 g
s
.45734 .51131 m .38754 .57977 L .43276 .63045 L p .858 0 0 r
F P
0 g
s
.44784 .52168 m .43589 .53475 L .44581 .52261 L .1 0 0 r
F
.43589 .53475 m .42866 .54264 L .43437 .53543 L F
.42866 .54264 m .42745 .54318 L .43437 .53543 L F
.43589 .53475 m .43437 .53543 L .44581 .52261 L F
.43135 .5368 m .44581 .52261 L p .43437 .53543 L F P
0 g
s
.43437 .53543 m .39942 .5746 L .43135 .5368 L .1 0 0 r
F
.44581 .52261 m .43135 .5368 L .44784 .52168 L F
.43135 .5368 m .38754 .57977 L .43286 .53612 L F
.43135 .5368 m .43286 .53612 L .44784 .52168 L F
.42866 .54264 m .38754 .57977 L .39942 .5746 L F
.44784 .52168 m .42384 .54481 L .42866 .54264 L F
.42384 .54481 m .38754 .57977 L .42866 .54264 L F
.47913 .56313 m .46479 .57737 L .45189 .56285 L p 0 .35 .78 r
F P
0 g
s
.45189 .56285 m .46627 .54864 L .47913 .56313 L p 0 .35 .78 r
F P
0 g
s
.45189 .56285 m .46479 .57737 L .45038 .59168 L p 0 .35 .78 r
F P
0 g
s
.43276 .63045 m .50188 .56159 L .45734 .51131 L p .858 0 0 r
F P
0 g
s
.44784 .52168 m .39942 .5746 L .45808 .517 L .1 0 0 r
F
.45808 .517 m .39942 .5746 L p .44784 .52168 L F P
0 g
s
.41151 .54799 m .39791 .55413 L .41232 .54002 L p 0 .05 .1 r
F P
0 g
s
.41232 .54002 m .42604 .53376 L .41151 .54799 L p 0 .05 .1 r
F P
0 g
s
.39791 .55413 m .41151 .54799 L .39692 .56229 L p 0 .05 .1 r
F P
0 g
s
.38225 .57666 m .45202 .5083 L .39795 .5335 L p .1 0 0 r
F P
0 g
s
.45202 .5083 m .42969 .4831 L .3764 .50928 L p .532 0 0 r
F P
0 g
s
.39887 .54616 m .41312 .53224 L .42668 .52598 L p 0 .05 .1 r
F P
0 g
s
.42668 .52598 m .41232 .54002 L .39887 .54616 L p 0 .05 .1 r
F P
0 g
s
.41232 .54002 m .42668 .52598 L .4405 .51959 L p 0 .05 .1 r
F P
0 g
s
.4405 .51959 m .42604 .53376 L .41232 .54002 L p 0 .05 .1 r
F P
0 g
s
.38568 .55218 m .39982 .53838 L .41312 .53224 L p 0 .05 .1 r
F P
0 g
s
.41312 .53224 m .39887 .54616 L .38568 .55218 L p 0 .05 .1 r
F P
0 g
s
.42969 .4831 m .45202 .5083 L .38225 .57666 L p .858 0 0 r
F P
0 g
s
.45202 .5083 m .38362 .57678 L .45342 .50839 L .554 0 0 r
F
.45202 .5083 m .38225 .57666 L .38362 .57678 L F
.37274 .55809 m .38677 .5444 L .39982 .53838 L p 0 .05 .1 r
F P
0 g
s
.39982 .53838 m .38568 .55218 L .37274 .55809 L p 0 .05 .1 r
F P
0 g
s
.45202 .5083 m .35958 .55125 L .38225 .57666 L .858 0 0 r
F
.45202 .5083 m .42969 .4831 L .35958 .55125 L F
.45342 .50839 m .38556 .57792 L .45537 .50949 L .761 0 0 r
F
.45342 .50839 m .38362 .57678 L .38556 .57792 L F
.45537 .50949 m .38754 .57977 L .45734 .51131 L .832 0 0 r
F
.45537 .50949 m .38556 .57792 L .38754 .57977 L F
.38225 .57666 m .35958 .55125 L .42969 .4831 L p .858 0 0 r
F P
0 g
s
.45202 .5083 m .44012 .4836 L .42969 .4831 L .532 0 0 r
F
.42969 .4831 m .44012 .4836 L .40515 .51765 L .547 0 0 r
F
.39998 .51731 m .40515 .51765 L .36979 .55208 L F
.42969 .4831 m .40515 .51765 L .39998 .51731 L F
.39942 .5746 m .38754 .57977 L p .43135 .5368 L .1 0 0 r
F P
0 g
s
.45342 .50839 m .45478 .49183 L .44012 .4836 L .532 0 0 r
F
.45478 .49183 m .39942 .5746 L .38439 .56063 L .832 0 0 r
F
.42866 .54264 m .39942 .5746 L .42745 .54318 L .1 0 0 r
F
.45734 .51131 m .44581 .52261 L .44784 .52168 L F
.4549 .50549 m .45547 .50493 L .46832 .51944 L p 0 .35 .78 r
F P
0 g
s
.48105 .5175 m .48719 .5238 L p .4734 .51114 L 0 .332 .56 r
F P
0 g
s
.4734 .51114 m .47426 .51175 L .48105 .5175 L p 0 .332 .56 r
F P
0 g
s
.51458 .55633 m .46968 .5056 L .45734 .51131 L p .532 0 0 r
F P
0 g
s
.45734 .51131 m .44784 .52168 L .46968 .5056 L .1 0 0 r
F
.44784 .52168 m .45808 .517 L .46968 .5056 L F
.45734 .51131 m .46968 .5056 L .45808 .517 L p F P
0 g
s
.45734 .51131 m .45808 .517 L .44784 .52168 L .1 0 0 r
F
.44581 .52261 m .45734 .51131 L p .44784 .52168 L F P
0 g
s
.45782 .50119 m .45547 .50493 L .4549 .50549 L p 0 .05 .1 r
F P
0 g
s
.45342 .50839 m .45537 .50949 L .45478 .49183 L .532 0 0 r
F
.45537 .50949 m .46968 .5056 L .45478 .49183 L F
.45537 .50949 m .45734 .51131 L .46968 .5056 L F
.45478 .49183 m .46968 .5056 L .39942 .5746 L .832 0 0 r
F
.50188 .56159 m .43276 .63045 L .445 .62573 L p .157 0 0 r
F P
0 g
s
.445 .62573 m .39942 .5746 L .43475 .53991 L p .859 0 0 r
F P
0 g
s
.43475 .53991 m .46968 .5056 L p .45739 .5654 L .859 0 0 r
F P
0 g
s
.45739 .5654 m .445 .62573 L .43475 .53991 L .859 0 0 r
F
.42172 .52524 m .44994 .53308 L .43539 .5196 L .521 0 0 r
F
.41978 .52604 m .42312 .52681 L .42172 .52524 L F
.42312 .52681 m .44994 .53308 L .42172 .52524 L F
.44012 .4836 m .38439 .56063 L .36979 .55208 L .76 0 0 r
F
.44012 .4836 m .45478 .49183 L .38439 .56063 L F
.41941 .51857 m .43539 .5196 L .41869 .50413 L .521 0 0 r
F
.41978 .52604 m .43539 .5196 L .41941 .51857 L F
.41978 .52604 m .43475 .53991 L .44994 .53308 L F
.55824 .21066 m .54369 .21979 L .57381 .25443 L p 0 .319 .936 r
F P
0 g
s
.57381 .25443 m .58862 .24564 L .55824 .21066 L p 0 .319 .936 r
F P
0 g
s
.35842 .41496 m .34578 .42215 L .33193 .40654 L p 0 .312 .948 r
F P
0 g
s
.34578 .42215 m .35842 .41496 L .37237 .4307 L p 0 .312 .948 r
F P
0 g
s
.33156 .4066 m .33193 .40654 L .30984 .42741 L .1 0 0 r
F
0 g
.33156 .4066 m
.33176 .40635 L
s
.75802 .44066 m .74379 .45517 L .71386 .42078 L p 0 .35 .78 r
F P
0 g
s
.71386 .42078 m .7282 .40633 L .75802 .44066 L p 0 .35 .78 r
F P
0 g
s
.55909 .46794 m .5714 .48195 L .5862 .47533 L p 0 .316 .943 r
F P
0 g
s
.5714 .48195 m .56597 .48735 L .58073 .48078 L p 0 .05 .112 r
F P
0 g
s
.58073 .48078 m .5862 .47533 L .5714 .48195 L p 0 .05 .112 r
F P
0 g
s
.56597 .48735 m .5714 .48195 L .55909 .46794 L p 0 .349 .781 r
F P
0 g
s
.5714 .48195 m .55909 .46794 L .57378 .46118 L p 0 .316 .943 r
F P
0 g
s
.57378 .46118 m .5862 .47533 L .5714 .48195 L p 0 .316 .943 r
F P
0 g
s
.54772 .47919 m .55909 .46794 L .5714 .48195 L p 0 .349 .781 r
F P
0 g
s
.55553 .48327 m .54772 .47919 L p .5714 .48195 L 0 .349 .781 r
F P
0 g
s
.5714 .48195 m .56597 .48735 L .55553 .48327 L p 0 .349 .781 r
F P
0 g
s
.33193 .40654 m .30984 .42741 L .37644 .50229 L p .856 0 0 r
F P
0 g
s
.39943 .4394 m .41346 .45525 L .40021 .4621 L p 0 .312 .948 r
F P
0 g
s
.40021 .4621 m .3863 .44641 L .39943 .4394 L p 0 .312 .948 r
F P
0 g
s
.39943 .4394 m .3863 .44641 L .37237 .4307 L p 0 .312 .948 r
F P
0 g
s
.38537 .42353 m .37237 .4307 L .35842 .41496 L p 0 .312 .948 r
F P
0 g
s
.37237 .4307 m .38537 .42353 L .39943 .4394 L p 0 .312 .948 r
F P
0 g
s
.37129 .40764 m .35842 .41496 L .34444 .3992 L p 0 .312 .948 r
F P
0 g
s
.35842 .41496 m .37129 .40764 L .38537 .42353 L p 0 .312 .948 r
F P
0 g
s
.34444 .3992 m .35719 .39172 L .37129 .40764 L p 0 .312 .948 r
F P
0 g
s
.39526 .43695 m .42972 .47585 L p .36873 .45121 L .533 0 0 r
F P
0 g
s
.39943 .4394 m .38537 .42353 L .39863 .41623 L p 0 .312 .948 r
F P
0 g
s
.38442 .40017 m .39863 .41623 L .38537 .42353 L p 0 .312 .948 r
F P
0 g
s
.38537 .42353 m .37129 .40764 L .38442 .40017 L p 0 .312 .948 r
F P
0 g
s
.3702 .38409 m .38442 .40017 L .37129 .40764 L p 0 .312 .948 r
F P
0 g
s
.37129 .40764 m .35719 .39172 L .3702 .38409 L p 0 .312 .948 r
F P
0 g
s
.38442 .40017 m .3702 .38409 L .38345 .37632 L p 0 .312 .948 r
F P
0 g
s
.36068 .3979 m .38345 .37632 L p .40659 .42608 L .858 0 0 r
F P
0 g
s
.42972 .47585 m .39526 .43695 L p .40659 .42608 L .858 0 0 r
F P
0 g
s
.39526 .43695 m .36068 .3979 L p .40659 .42608 L .858 0 0 r
F P
0 g
s
.38345 .37632 m .36068 .3979 L .42972 .47585 L .858 0 0 r
F
.36068 .3979 m .44016 .469 L .42972 .47585 L .671 0 0 r
F
.36068 .3979 m .37086 .39069 L .44016 .469 L F
.39526 .43695 m .40312 .43273 L .40558 .42992 L .1 0 0 r
F
.39526 .43695 m .38847 .44944 L .40312 .43273 L F
.42972 .47585 m .37644 .50229 L p .36873 .45121 L .533 0 0 r
F P
0 g
s
.36068 .3979 m .39526 .43695 L p .36873 .45121 L .533 0 0 r
F P
0 g
s
.33193 .40654 m .37644 .50229 L .30984 .42741 L .856 0 0 r
F
.33193 .40654 m .34444 .3992 L .35842 .41496 L p 0 .312 .948 r
F P
0 g
s
.37644 .50229 m .30984 .42741 L .33477 .41295 L p .533 0 0 r
F P
0 g
s
.28565 .41908 m .30073 .43602 L .33193 .40654 L p 0 .349 .782 r
F P
0 g
s
.33193 .40654 m .31695 .38966 L .28565 .41908 L p 0 .349 .782 r
F P
0 g
s
.30984 .42741 m .3432 .46492 L .316 .49093 L .856 0 0 r
F
.30984 .42741 m .3432 .46492 L p .35176 .43209 L .533 0 0 r
F P
0 g
s
.36068 .3979 m .33477 .41295 L p .35176 .43209 L .533 0 0 r
F P
0 g
s
.33477 .41295 m .30984 .42741 L p .35176 .43209 L .533 0 0 r
F P
0 g
s
.316 .49093 m .3432 .46492 L .30984 .42741 L p .856 0 0 r
F P
0 g
s
.30984 .42741 m .28244 .4533 L .316 .49093 L p .856 0 0 r
F P
0 g
s
.30984 .42741 m .316 .49093 L .28244 .4533 L .856 0 0 r
F
.32113 .41675 m .30073 .43602 L p .32219 .41795 L 0 .05 .1 r
F P
0 g
s
.34444 .3992 m .32113 .41675 L .32219 .41795 L 0 .05 .1 r
F
.34444 .3992 m .33193 .40654 L .32113 .41675 L p F P
0 g
s
.30984 .42741 m .33193 .40654 L .38345 .37632 L p .1 0 0 r
F P
0 g
s
.33477 .41295 m .36068 .3979 L p .36873 .45121 L .533 0 0 r
F P
0 g
s
.37644 .50229 m .33477 .41295 L .36873 .45121 L .533 0 0 r
F
.28244 .4533 m .30984 .42741 L .36068 .3979 L p .1 0 0 r
F P
0 g
s
.38345 .37632 m .36068 .3979 L .30984 .42741 L p .1 0 0 r
F P
0 g
s
.30073 .43602 m .31301 .42893 L .34444 .3992 L p 0 .05 .1 r
F P
0 g
s
.35719 .39172 m .34444 .3992 L .31301 .42893 L p 0 .05 .1 r
F P
0 g
s
.31301 .42893 m .32552 .4217 L .35719 .39172 L p 0 .05 .1 r
F P
0 g
s
.32552 .4217 m .31017 .40442 L p .3239 .40071 L 0 .349 .781 r
F P
0 g
s
.35721 .38713 m .34444 .3992 L .33193 .40654 L p 0 .05 .1 r
F P
0 g
s
.33193 .40654 m .34444 .3992 L .35721 .38713 L p 0 .05 .1 r
F P
0 g
s
.34444 .3992 m .33193 .40654 L .31695 .38966 L p 0 .312 .948 r
F P
0 g
s
.31695 .38966 m .33193 .40654 L .34444 .3992 L p 0 .312 .948 r
F P
0 g
s
.31695 .38966 m .32933 .38216 L .34444 .3992 L p 0 .312 .948 r
F P
0 g
s
.34444 .3992 m .32933 .38216 L .31695 .38966 L p 0 .312 .948 r
F P
0 g
s
.34444 .3992 m .35721 .38713 L .37006 .37955 L p 0 .05 .1 r
F P
0 g
s
.37006 .37955 m .35721 .38713 L .34444 .3992 L p 0 .05 .1 r
F P
0 g
s
.37006 .37955 m .35719 .39172 L .34444 .3992 L p 0 .05 .1 r
F P
0 g
s
.34444 .3992 m .35719 .39172 L .37006 .37955 L p 0 .05 .1 r
F P
0 g
s
.35719 .39172 m .34444 .3992 L .32933 .38216 L p 0 .312 .948 r
F P
0 g
s
.32933 .38216 m .34444 .3992 L .35719 .39172 L p 0 .312 .948 r
F P
0 g
s
.35719 .39172 m .33477 .41295 L p .3239 .40071 L 0 .349 .781 r
F P
0 g
s
.33477 .41295 m .32552 .4217 L p .3239 .40071 L 0 .349 .781 r
F P
0 g
s
.31017 .40442 m .32552 .4217 L .33477 .41295 L p 0 .349 .781 r
F P
0 g
s
.33477 .41295 m .35719 .39172 L p .3239 .40071 L 0 .349 .781 r
F P
0 g
s
.3239 .40071 m .31017 .40442 L .33477 .41295 L 0 .349 .781 r
F
0 g
.37343 .50221 m
.37644 .50229 L
s
.31832 .60476 m
.32107 .60847 L
s
.77361 .48946 m .77979 .50562 L .7594 .5041 L closepath p 0 .35 .78 r
F P
0 g
s
.77361 .48946 m .7594 .5041 L .72948 .46975 L p 0 .35 .78 r
F P
0 g
s
.72948 .46975 m .74379 .45517 L .77361 .48946 L p 0 .35 .78 r
F P
0 g
s
.3764 .50928 m .39483 .51698 L .3682 .52974 L .1 0 0 r
F
.3158 .51201 m .34258 .54201 L .39483 .51698 L p .521 0 0 r
F P
0 g
s
.3764 .50928 m .42969 .4831 L .39483 .51698 L p .1 0 0 r
F P
0 g
s
.39483 .51698 m .35958 .55125 L p .3682 .52974 L .1 0 0 r
F P
0 g
s
.37005 .51542 m
.3764 .50928 L
s
.59099 .7205 m .57614 .72479 L .54614 .75585 L p 0 .05 .248 r
F P
0 g
s
.78868 .53771 m .77405 .52091 L .77979 .50562 L p 0 .35 .78 r
F P
0 g
s
.7594 .5041 m .77979 .50562 L .77405 .52091 L closepath p 0 .35 .78 r
F P
0 g
s
.5862 .47533 m .57378 .46118 L .55909 .46794 L p 0 .316 .943 r
F P
0 g
s
.55553 .48327 m .56597 .48735 L p .55909 .46794 L 0 .349 .781 r
F P
0 g
s
.55909 .46794 m .54772 .47919 L .55553 .48327 L p 0 .349 .781 r
F P
0 g
s
.54772 .47919 m .55909 .46794 L .57378 .46118 L p 0 .05 .1 r
F P
0 g
s
.55909 .46794 m .54772 .47919 L .56233 .47253 L p 0 .05 .1 r
F P
0 g
s
.56233 .47253 m .57378 .46118 L .55909 .46794 L p 0 .05 .1 r
F P
0 g
s
.54772 .47919 m .55909 .46794 L .54675 .45391 L p 0 .349 .781 r
F P
0 g
s
.55909 .46794 m .54675 .45391 L .56133 .44702 L p 0 .316 .943 r
F P
0 g
s
.56133 .44702 m .57378 .46118 L .55909 .46794 L p 0 .316 .943 r
F P
0 g
s
.54675 .45391 m .55909 .46794 L .57378 .46118 L p 0 .316 .943 r
F P
0 g
s
.53307 .46739 m .54675 .45391 L .55909 .46794 L p 0 .349 .781 r
F P
0 g
s
.53932 .47343 m .53307 .46739 L p .55909 .46794 L 0 .349 .781 r
F P
0 g
s
.54673 .47867 m .53932 .47343 L p .55909 .46794 L 0 .349 .781 r
F P
0 g
s
.55909 .46794 m .54772 .47919 L .54673 .47867 L p 0 .349 .781 r
F P
0 g
s
.5017 .79088 m .48684 .7743 L .50086 .77047 L p 0 .307 .954 r
F P
0 g
s
.5017 .79088 m .51584 .78722 L .54614 .75585 L p 0 .05 .248 r
F P
0 g
s
.50086 .77047 m .51584 .78722 L .5017 .79088 L p 0 .307 .954 r
F P
0 g
s
.51584 .78722 m .5017 .79088 L .47188 .8217 L p 0 .05 .248 r
F P
0 g
s
.4719 .80291 m .47188 .8217 L .5017 .79088 L closepath p 0 .349 .782 r
F P
0 g
s
.5017 .79088 m .51584 .78722 L .50086 .77047 L p 0 .307 .954 r
F P
0 g
s
.50086 .77047 m .48684 .7743 L .5017 .79088 L p 0 .307 .954 r
F P
0 g
s
.5017 .79088 m .48684 .7743 L .47193 .78027 L p 0 .349 .782 r
F P
0 g
s
.47193 .78027 m .4719 .80291 L .5017 .79088 L p 0 .349 .782 r
F P
0 g
s
.56597 .48735 m .55553 .48327 L .5702 .47665 L p 0 .399 1 r
F P
0 g
s
.5702 .47665 m .58073 .48078 L .56597 .48735 L p 0 .399 1 r
F P
0 g
s
.32933 .38216 m .31695 .38966 L .30195 .37276 L p 0 .312 .948 r
F P
0 g
s
.27055 .40211 m .28565 .41908 L .31695 .38966 L p 0 .349 .782 r
F P
0 g
s
.30984 .42741 m
.32113 .41675 L
s
.31695 .38966 m .30195 .37276 L .27055 .40211 L p 0 .349 .782 r
F P
0 g
s
.30195 .37276 m .31695 .38966 L .32933 .38216 L p 0 .312 .948 r
F P
0 g
s
.64516 .66432 m .66068 .65944 L .65573 .65383 L p 0 .314 .946 r
F P
0 g
s
.65573 .65383 m .64025 .65876 L .64516 .66432 L p 0 .314 .946 r
F P
0 g
s
.66068 .65944 m .64516 .66432 L .64025 .65876 L p 0 .314 .946 r
F P
0 g
s
.52891 .23378 m .54369 .21979 L .55824 .21066 L p 0 .05 .1 r
F P
0 g
s
.52831 .1762 m .51402 .18567 L .54369 .21979 L p 0 .319 .936 r
F P
0 g
s
.54369 .21979 m .55824 .21066 L .52831 .1762 L p 0 .319 .936 r
F P
0 g
s
.55824 .21066 m .54369 .21979 L .52891 .23378 L p 0 .05 .1 r
F P
0 g
s
.78868 .53771 m .75971 .56786 L .74498 .55101 L p 0 .35 .78 r
F P
0 g
s
.74498 .55101 m .77405 .52091 L .78868 .53771 L p 0 .35 .78 r
F P
0 g
s
.7282 .40633 m .71386 .42078 L .68384 .38626 L p 0 .35 .78 r
F P
0 g
s
.68384 .38626 m .69827 .37188 L .7282 .40633 L p 0 .35 .78 r
F P
0 g
s
.57378 .46118 m .56133 .44702 L .54675 .45391 L p 0 .316 .943 r
F P
0 g
s
.54673 .47867 m .54772 .47919 L p .54675 .45391 L 0 .349 .781 r
F P
0 g
s
.53932 .47343 m .54673 .47867 L p .54675 .45391 L 0 .349 .781 r
F P
0 g
s
.54675 .45391 m .53307 .46739 L .53932 .47343 L p 0 .349 .781 r
F P
0 g
s
.53307 .46739 m .54675 .45391 L .56133 .44702 L p 0 .05 .1 r
F P
0 g
s
.54887 .43283 m .56133 .44702 L .54675 .45391 L p 0 .316 .943 r
F P
0 g
s
.54675 .45391 m .5344 .43986 L .54887 .43283 L p 0 .316 .943 r
F P
0 g
s
.54756 .46061 m .56133 .44702 L .54675 .45391 L p 0 .05 .1 r
F P
0 g
s
.54675 .45391 m .53307 .46739 L .54756 .46061 L p 0 .05 .1 r
F P
0 g
s
.53307 .46739 m .54675 .45391 L .5344 .43986 L p 0 .349 .781 r
F P
0 g
s
.5344 .43986 m .54675 .45391 L .56133 .44702 L p 0 .316 .943 r
F P
0 g
s
.4836 .2767 m .46975 .28521 L .4392 .31412 L p 0 .05 .1 r
F P
0 g
s
.46975 .28521 m .4836 .2767 L .51406 .24785 L p 0 .05 .1 r
F P
0 g
s
.52297 .45108 m .5344 .43986 L .54675 .45391 L p 0 .349 .781 r
F P
0 g
s
.52339 .45216 m .52297 .45108 L p .54675 .45391 L 0 .349 .781 r
F P
0 g
s
.52782 .46037 m .52339 .45216 L p .54675 .45391 L 0 .349 .781 r
F P
0 g
s
.54675 .45391 m .53307 .46739 L .52782 .46037 L p 0 .349 .781 r
F P
0 g
s
.64025 .65876 m .65573 .65383 L .66068 .65944 L p 0 .314 .946 r
F P
0 g
s
.45486 .26822 m .46975 .28521 L .4392 .31412 L p 0 .349 .781 r
F P
0 g
s
.71426 .60377 m .73045 .59832 L .75971 .56786 L p 0 .05 .248 r
F P
0 g
s
.48684 .7743 m .47197 .75769 L .48585 .7537 L p 0 .307 .954 r
F P
0 g
s
.48585 .7537 m .50086 .77047 L .48684 .7743 L p 0 .307 .954 r
F P
0 g
s
.47197 .75769 m .47193 .78027 L .48684 .7743 L closepath p 0 .349 .782 r
F P
0 g
s
.48684 .7743 m .50086 .77047 L .48585 .7537 L p 0 .307 .954 r
F P
0 g
s
.48585 .7537 m .47197 .75769 L .48684 .7743 L p 0 .307 .954 r
F P
0 g
s
.40835 .34332 m .39521 .3512 L .3826 .36313 L p 0 .05 .1 r
F P
0 g
s
.39521 .3512 m .40835 .34332 L .39564 .35534 L p 0 .05 .1 r
F P
0 g
s
.39564 .35534 m .3826 .36313 L .39521 .3512 L p 0 .05 .1 r
F P
0 g
s
.55553 .48327 m .54772 .47919 L .56233 .47253 L p 0 .379 1 r
F P
0 g
s
.56233 .47253 m .5702 .47665 L .55553 .48327 L p 0 .379 1 r
F P
0 g
s
.30195 .37276 m .31419 .36508 L .32933 .38216 L p 0 .312 .948 r
F P
0 g
s
.32933 .38216 m .31419 .36508 L .30195 .37276 L p 0 .312 .948 r
F P
0 g
s
.27055 .40211 m .30195 .37276 L .31419 .36508 L p 0 .05 .1 r
F P
0 g
s
.3432 .46492 m .39526 .43695 L .36068 .3979 L p .533 0 0 r
F P
0 g
s
.39526 .43695 m .3432 .46492 L .316 .49093 L p .1 0 0 r
F P
0 g
s
.34734 .46958 m
.37644 .50229 L
s
.31338 .43139 m
.3432 .46492 L
s
.53639 .41862 m .54887 .43283 L .5344 .43986 L p 0 .316 .943 r
F P
0 g
s
.5344 .43986 m .52203 .42579 L .53639 .41862 L p 0 .316 .943 r
F P
0 g
s
.52203 .42579 m .5344 .43986 L .54887 .43283 L p 0 .316 .943 r
F P
0 g
s
.56133 .44702 m .54887 .43283 L .5344 .43986 L p 0 .316 .943 r
F P
0 g
s
.53737 .44414 m .54887 .43283 L .5344 .43986 L p 0 .05 .1 r
F P
0 g
s
.52782 .46037 m .53307 .46739 L p .5344 .43986 L 0 .349 .781 r
F P
0 g
s
.52339 .45216 m .52782 .46037 L p .5344 .43986 L 0 .349 .781 r
F P
0 g
s
.5344 .43986 m .52297 .45108 L .52339 .45216 L p 0 .349 .781 r
F P
0 g
s
.5344 .43986 m .52297 .45108 L .53737 .44414 L p 0 .05 .1 r
F P
0 g
s
.52297 .45108 m .5344 .43986 L .52203 .42579 L p 0 .349 .781 r
F P
0 g
s
.52297 .45108 m .5344 .43986 L .54887 .43283 L p 0 .05 .1 r
F P
0 g
s
.51654 .43116 m .52203 .42579 L .5344 .43986 L p 0 .349 .781 r
F P
0 g
s
.51967 .44252 m .51654 .43116 L p .5344 .43986 L 0 .349 .781 r
F P
0 g
s
.5344 .43986 m .52297 .45108 L .51967 .44252 L p 0 .349 .781 r
F P
0 g
s
.77405 .52091 m .74498 .55101 L .73024 .53413 L p 0 .35 .78 r
F P
0 g
s
.73024 .53413 m .7594 .5041 L .77405 .52091 L p 0 .35 .78 r
F P
0 g
s
.74379 .45517 m .72948 .46975 L .69946 .43529 L p 0 .35 .78 r
F P
0 g
s
.69946 .43529 m .71386 .42078 L .74379 .45517 L p 0 .35 .78 r
F P
0 g
s
.42422 .29706 m .45486 .26822 L .43995 .25119 L p 0 .349 .781 r
F P
0 g
s
.45486 .26822 m .42422 .29706 L .4392 .31412 L p 0 .349 .781 r
F P
0 g
s
.43995 .25119 m .45486 .26822 L .42422 .29706 L p 0 .349 .781 r
F P
0 g
s
.4392 .31412 m .42422 .29706 L .45486 .26822 L p 0 .349 .781 r
F P
0 g
s
.31035 .59399 m .27602 .5589 L .30564 .58171 L .509 0 0 r
F
0 g
.31035 .59399 m
.31832 .60476 L
s
.31035 .59399 m
.31832 .60476 L
s
.57405 .53476 m .58641 .52236 L .57157 .52855 L p 0 .05 .14 r
F P
0 g
s
.57157 .52855 m .55931 .54084 L .57405 .53476 L p 0 .05 .14 r
F P
0 g
s
.55931 .54084 m .57157 .52855 L .58641 .52236 L p 0 .05 .14 r
F P
0 g
s
.56609 .52232 m .57157 .52855 L .58641 .52236 L p 0 .315 .945 r
F P
0 g
s
.54784 .52785 m .55931 .54084 L .57157 .52855 L p 0 .349 .781 r
F P
0 g
s
.55565 .5249 m .54784 .52785 L p .57157 .52855 L 0 .349 .781 r
F P
0 g
s
.57157 .52855 m .56609 .52232 L .55565 .5249 L p 0 .349 .781 r
F P
0 g
s
.56609 .52232 m .57157 .52855 L .55931 .54084 L p 0 .349 .781 r
F P
0 g
s
.47197 .75769 m .48585 .7537 L .48583 .7765 L p 0 .181 .719 r
F P
0 g
s
.48583 .7765 m .47193 .78027 L .47197 .75769 L p 0 .181 .719 r
F P
0 g
s
.457 .77301 m .47193 .78027 L .47197 .75769 L closepath p 0 .349 .782 r
F P
0 g
s
.48585 .7537 m .47197 .75769 L .47193 .78027 L p 0 .181 .719 r
F P
0 g
s
.47197 .75769 m .48585 .7537 L .47077 .76916 L p 0 .05 .218 r
F P
0 g
s
.47077 .76916 m .457 .77301 L .47197 .75769 L p 0 .05 .218 r
F P
0 g
s
.457 .77301 m .47197 .75769 L .44159 .72378 L p 0 .349 .782 r
F P
0 g
s
.48585 .7537 m .47197 .75769 L .457 .77301 L p 0 .05 .218 r
F P
0 g
s
.36529 .31727 m .38026 .33425 L .39326 .3262 L p 0 .315 .945 r
F P
0 g
s
.39326 .3262 m .38026 .33425 L .36529 .31727 L p 0 .315 .945 r
F P
0 g
s
.30564 .58171 m .27602 .5589 L .28142 .54498 L .509 0 0 r
F
0 g
.27602 .5589 m
.28592 .58427 L
s
.57378 .46118 m .56233 .47253 L .54772 .47919 L p 0 .05 .1 r
F P
0 g
s
.54772 .47919 m .54673 .47867 L .56133 .47201 L p 0 .379 1 r
F P
0 g
s
.56133 .47201 m .56233 .47253 L .54772 .47919 L p 0 .379 1 r
F P
0 g
s
.54673 .47867 m .53932 .47343 L .55385 .46671 L p 0 .355 1 r
F P
0 g
s
.55385 .46671 m .56133 .47201 L .54673 .47867 L p 0 .355 1 r
F P
0 g
s
.58641 .52236 m .58088 .51608 L .56609 .52232 L p 0 .315 .945 r
F P
0 g
s
.55565 .5249 m .56609 .52232 L .58088 .51608 L p 0 .478 .97 r
F P
0 g
s
.54887 .43283 m .53639 .41862 L .52203 .42579 L p 0 .316 .943 r
F P
0 g
s
.51967 .44252 m .52297 .45108 L p .52203 .42579 L 0 .349 .781 r
F P
0 g
s
.52203 .42579 m .51654 .43116 L .51967 .44252 L p 0 .349 .781 r
F P
0 g
s
.51654 .43116 m .52203 .42579 L .53639 .41862 L p 0 .05 .1 r
F P
0 g
s
.55565 .5249 m .56609 .52232 L p .55931 .54084 L 0 .349 .781 r
F P
0 g
s
.52831 .1762 m .51402 .18567 L .51403 .20384 L p 0 .181 .719 r
F P
0 g
s
.49827 .20435 m .4842 .21361 L .51402 .18567 L p 0 .05 .1 r
F P
0 g
s
.52834 .19453 m .51403 .20384 L .51402 .18567 L p 0 .181 .719 r
F P
0 g
s
.51402 .18567 m .52831 .1762 L .52834 .19453 L p 0 .181 .719 r
F P
0 g
s
.51402 .18567 m .52831 .1762 L .49827 .20435 L p 0 .05 .1 r
F P
0 g
s
.43995 .25119 m .40921 .27998 L .42422 .29706 L p 0 .349 .781 r
F P
0 g
s
.42422 .29706 m .40921 .27998 L .43995 .25119 L p 0 .349 .781 r
F P
0 g
s
.40921 .27998 m .43995 .25119 L .45353 .24234 L p 0 .05 .1 r
F P
0 g
s
.4842 .21361 m .45353 .24234 L .43995 .25119 L p 0 .05 .1 r
F P
0 g
s
.67372 .3436 m .69827 .37188 L .66899 .36048 L p 0 .35 .78 r
F P
0 g
s
.53932 .47343 m .53307 .46739 L .54756 .46061 L p 0 .329 .964 r
F P
0 g
s
.54756 .46061 m .55385 .46671 L .53932 .47343 L p 0 .329 .964 r
F P
0 g
s
.45178 .47193 m .45279 .47156 L .43921 .47823 L p 0 .475 .892 r
F P
0 g
s
.43921 .47823 m .43821 .4786 L .45178 .47193 L p 0 .475 .892 r
F P
0 g
s
.39326 .3262 m .37815 .30905 L .36529 .31727 L p 0 .315 .945 r
F P
0 g
s
.36529 .31727 m .37815 .30905 L .39326 .3262 L p 0 .315 .945 r
F P
0 g
s
.36529 .31727 m .37815 .30905 L .35252 .33306 L p 0 .05 .1 r
F P
0 g
s
.35252 .33306 m .33984 .34108 L .36529 .31727 L p 0 .05 .1 r
F P
0 g
s
.44379 .47485 m .45178 .47193 L .43821 .4786 L p 0 .475 .892 r
F P
0 g
s
.43821 .4786 m .43029 .4815 L .44379 .47485 L p 0 .475 .892 r
F P
0 g
s
.55824 .21066 m .54336 .22476 L .52891 .23378 L p 0 .05 .1 r
F P
0 g
s
.51406 .24785 m .52891 .23378 L .54336 .22476 L p 0 .05 .1 r
F P
0 g
s
.52891 .23378 m .54336 .22476 L .55824 .21066 L p 0 .05 .1 r
F P
0 g
s
.54336 .22476 m .52891 .23378 L .51406 .24785 L p 0 .05 .1 r
F P
0 g
s
.56133 .44702 m .54756 .46061 L .53307 .46739 L p 0 .05 .1 r
F P
0 g
s
.53639 .41862 m .53086 .42403 L .51654 .43116 L p 0 .05 .1 r
F P
0 g
s
.54226 .45352 m .54756 .46061 L .53307 .46739 L p 0 .302 .924 r
F P
0 g
s
.53307 .46739 m .52782 .46037 L .54226 .45352 L p 0 .302 .924 r
F P
0 g
s
.51967 .44252 m .51654 .43116 L .53086 .42403 L p 0 .238 .818 r
F P
0 g
s
.47193 .78027 m .48583 .7765 L .48582 .79935 L p 0 .181 .719 r
F P
0 g
s
.48582 .79935 m .4719 .80291 L .47193 .78027 L p 0 .181 .719 r
F P
0 g
s
.4719 .80291 m .47193 .78027 L .457 .77301 L p 0 .349 .782 r
F P
0 g
s
.48583 .7765 m .47193 .78027 L .4719 .80291 L p 0 .181 .719 r
F P
0 g
s
.47193 .78027 m .48583 .7765 L .48585 .7537 L p 0 .181 .719 r
F P
0 g
s
.51403 .20384 m .52834 .19453 L .52831 .1762 L p 0 .181 .719 r
F P
0 g
s
.52834 .19453 m .51403 .20384 L .51405 .22582 L p 0 .181 .719 r
F P
0 g
s
.52837 .21671 m .51405 .22582 L .51403 .20384 L p 0 .181 .719 r
F P
0 g
s
.51403 .20384 m .52834 .19453 L .52837 .21671 L p 0 .181 .719 r
F P
0 g
s
.39564 .35534 m .3826 .36313 L .36993 .3751 L p 0 .05 .1 r
F P
0 g
s
.3826 .36313 m .39564 .35534 L .40835 .34332 L p 0 .05 .1 r
F P
0 g
s
.3826 .36313 m .39564 .35534 L .38288 .36742 L p 0 .05 .1 r
F P
0 g
s
.38288 .36742 m .36993 .3751 L .3826 .36313 L p 0 .05 .1 r
F P
0 g
s
.53779 .44524 m .54226 .45352 L .52782 .46037 L p 0 .277 .884 r
F P
0 g
s
.52782 .46037 m .52339 .45216 L .53779 .44524 L p 0 .277 .884 r
F P
0 g
s
.53086 .42403 m .53403 .4355 L .51967 .44252 L p 0 .238 .818 r
F P
0 g
s
.52297 .45108 m .51967 .44252 L .53403 .4355 L p 0 .255 .848 r
F P
0 g
s
.52339 .45216 m .52297 .45108 L .53737 .44414 L p 0 .255 .848 r
F P
0 g
s
.54887 .43283 m .53737 .44414 L .52297 .45108 L p 0 .05 .1 r
F P
0 g
s
.53403 .4355 m .53737 .44414 L .52297 .45108 L p 0 .255 .848 r
F P
0 g
s
.53737 .44414 m .53779 .44524 L .52339 .45216 L p 0 .255 .848 r
F P
0 g
s
.58088 .51608 m .57035 .51867 L .55565 .5249 L p 0 .478 .97 r
F P
0 g
s
.54784 .52785 m .55565 .5249 L .57035 .51867 L p 0 .446 .815 r
F P
0 g
s
.55931 .54084 m .54784 .52785 L .55565 .5249 L p 0 .349 .781 r
F P
0 g
s
.44159 .72378 m .42652 .73904 L .457 .77301 L p 0 .349 .782 r
F P
0 g
s
.42652 .73904 m .44159 .72378 L .4111 .68975 L p 0 .349 .782 r
F P
0 g
s
.40833 .70645 m
.41672 .70772 L
s
.5284 .23894 m .55898 .27404 L .54438 .2826 L p 0 .318 .938 r
F P
0 g
s
.54438 .2826 m .51406 .24785 L .5284 .23894 L p 0 .318 .938 r
F P
0 g
s
.64909 .31526 m .67372 .3436 L .66889 .34838 L p 0 .35 .78 r
F P
0 g
s
.66899 .36048 m .66889 .34838 L .67372 .3436 L p 0 .35 .78 r
F P
0 g
s
.54699 .55319 m .55931 .54084 L .57405 .53476 L p 0 .05 .14 r
F P
0 g
s
.58641 .52236 m .57405 .53476 L .55931 .54084 L p 0 .05 .14 r
F P
0 g
s
.57035 .51867 m .56249 .52164 L .54784 .52785 L p 0 .446 .815 r
F P
0 g
s
.56249 .52164 m .57405 .53476 L .55931 .54084 L p 0 .314 .946 r
F P
0 g
s
.55931 .54084 m .54784 .52785 L .56249 .52164 L p 0 .314 .946 r
F P
0 g
s
.56165 .54722 m .57405 .53476 L .55931 .54084 L p 0 .05 .14 r
F P
0 g
s
.55931 .54084 m .54699 .55319 L .56165 .54722 L p 0 .05 .14 r
F P
0 g
s
.54784 .52785 m .55931 .54084 L .57405 .53476 L p 0 .314 .946 r
F P
0 g
s
.53319 .53757 m .54699 .55319 L .55931 .54084 L p 0 .349 .781 r
F P
0 g
s
.53944 .53241 m .53319 .53757 L p .55931 .54084 L 0 .349 .781 r
F P
0 g
s
.54685 .52823 m .53944 .53241 L p .55931 .54084 L 0 .349 .781 r
F P
0 g
s
.55931 .54084 m .54784 .52785 L .54685 .52823 L p 0 .349 .781 r
F P
0 g
s
.54784 .52785 m .55931 .54084 L .54699 .55319 L p 0 .349 .781 r
F P
0 g
s
.43307 .47739 m .44379 .47485 L .43029 .4815 L p 0 .492 1 r
F P
0 g
s
.43029 .4815 m .41965 .48403 L .43307 .47739 L p 0 .492 1 r
F P
0 g
s
.44195 .7884 m .47188 .8217 L .4719 .80291 L closepath p 0 .349 .782 r
F P
0 g
s
.457 .77301 m .44195 .7884 L .4719 .80291 L p 0 .349 .782 r
F P
0 g
s
.47188 .8217 m .4858 .81832 L .51584 .78722 L p 0 .05 .248 r
F P
0 g
s
.4719 .80291 m .48582 .79935 L .4858 .81832 L p 0 .181 .719 r
F P
0 g
s
.4858 .81832 m .47188 .8217 L .4719 .80291 L p 0 .181 .719 r
F P
0 g
s
.48582 .79935 m .4719 .80291 L .47188 .8217 L p 0 .181 .719 r
F P
0 g
s
.4719 .80291 m .48582 .79935 L .48583 .7765 L p 0 .181 .719 r
F P
0 g
s
.51405 .22582 m .52837 .21671 L .52834 .19453 L p 0 .181 .719 r
F P
0 g
s
.52837 .21671 m .51405 .22582 L .51406 .24785 L p 0 .181 .719 r
F P
0 g
s
.54336 .22476 m .5284 .23894 L .51406 .24785 L p 0 .05 .1 r
F P
0 g
s
.51406 .24785 m .5284 .23894 L .54336 .22476 L p 0 .05 .1 r
F P
0 g
s
.5284 .23894 m .51406 .24785 L .51405 .22582 L p 0 .181 .719 r
F P
0 g
s
.51405 .22582 m .52837 .21671 L .5284 .23894 L p 0 .181 .719 r
F P
0 g
s
.457 .77301 m .47077 .76916 L .45561 .78469 L p 0 .05 .218 r
F P
0 g
s
.45561 .78469 m .44195 .7884 L .457 .77301 L p 0 .05 .218 r
F P
0 g
s
.44195 .7884 m .457 .77301 L .42652 .73904 L p 0 .349 .782 r
F P
0 g
s
.47077 .76916 m .457 .77301 L .44195 .7884 L p 0 .05 .218 r
F P
0 g
s
.457 .77301 m .47077 .76916 L .48585 .7537 L p 0 .05 .218 r
F P
0 g
s
.57405 .53476 m .56249 .52164 L .54784 .52785 L p 0 .314 .946 r
F P
0 g
s
.54685 .52823 m .54784 .52785 L .56249 .52164 L p 0 .446 .815 r
F P
0 g
s
.54685 .52823 m .54784 .52785 L p .54699 .55319 L 0 .349 .781 r
F P
0 g
s
.60613 .71612 m .63626 .68482 L .6209 .68947 L p 0 .05 .248 r
F P
0 g
s
.6209 .68947 m .59099 .7205 L .60613 .71612 L p 0 .05 .248 r
F P
0 g
s
.56249 .52164 m .56149 .52202 L .54685 .52823 L p 0 .446 .815 r
F P
0 g
s
.53944 .53241 m .54685 .52823 L p .54699 .55319 L 0 .349 .781 r
F P
0 g
s
.53944 .53241 m .54685 .52823 L .56149 .52202 L p 0 .05 .1 r
F P
0 g
s
.25405 .44879 m .26923 .46579 L .30073 .43602 L p 0 .349 .782 r
F P
0 g
s
.30073 .43602 m .28565 .41908 L .25405 .44879 L p 0 .349 .782 r
F P
0 g
s
.316 .49093 m .28244 .4533 L .30694 .43928 L p .524 0 0 r
F P
0 g
s
.30694 .43928 m .33242 .42469 L p .32404 .45848 L .524 0 0 r
F P
0 g
s
.316 .49093 m .30694 .43928 L .32404 .45848 L .524 0 0 r
F
.31301 .42893 m .30073 .43602 L .26923 .46579 L p 0 .05 .1 r
F P
0 g
s
.36068 .3979 m .33242 .42469 L .28244 .4533 L p .1 0 0 r
F P
0 g
s
.26923 .46579 m .28126 .45895 L .31301 .42893 L p 0 .05 .1 r
F P
0 g
s
.32552 .4217 m .31301 .42893 L .28126 .45895 L p 0 .05 .1 r
F P
0 g
s
.28126 .45895 m .29352 .45197 L .32552 .4217 L p 0 .05 .1 r
F P
0 g
s
.27806 .43463 m .29352 .45197 L .30694 .43928 L p 0 .349 .781 r
F P
0 g
s
.30694 .43928 m .32552 .4217 L p .29798 .4292 L 0 .349 .781 r
F P
0 g
s
.29798 .4292 m .27806 .43463 L .30694 .43928 L 0 .349 .781 r
F
.69071 .42525 m .71694 .45536 L .7269 .44033 L .578 0 0 r
F
.65839 .45773 m .71694 .45536 L .69071 .42525 L .858 0 0 r
F
.65839 .45773 m .68481 .48795 L .71694 .45536 L F
.69071 .42525 m .71694 .45536 L .68481 .48795 L p F P
0 g
s
.68481 .48795 m .7269 .44033 L .71694 .45536 L .853 0 0 r
F
.56078 .75183 m .54614 .75585 L .51584 .78722 L p 0 .05 .248 r
F P
0 g
s
.54614 .75585 m .56078 .75183 L .59099 .7205 L p 0 .05 .248 r
F P
0 g
s
.61891 .2805 m .64909 .31526 L .63451 .32955 L p 0 .35 .78 r
F P
0 g
s
.47188 .8217 m .4858 .81832 L .48582 .79935 L p 0 .181 .719 r
F P
0 g
s
.4858 .81832 m .47188 .8217 L .44195 .7884 L p 0 .305 .956 r
F P
0 g
s
.36993 .3751 m .38288 .36742 L .39564 .35534 L p 0 .05 .1 r
F P
0 g
s
.36993 .3751 m .38288 .36742 L .35758 .33879 L p 0 .314 .946 r
F P
0 g
s
.35758 .33879 m .34486 .34676 L .36993 .3751 L p 0 .314 .946 r
F P
0 g
s
.38288 .36742 m .36993 .3751 L .35721 .38713 L p 0 .05 .1 r
F P
0 g
s
.35721 .38713 m .36993 .3751 L .38288 .36742 L p 0 .05 .1 r
F P
0 g
s
.38288 .36742 m .36993 .3751 L .34486 .34676 L p 0 .314 .946 r
F P
0 g
s
.4111 .68975 m .39594 .70495 L .42652 .73904 L p 0 .349 .782 r
F P
0 g
s
.40222 .67983 m
.42885 .70956 L
s
.36798 .64162 m .38209 .62768 L .36957 .61368 L p 0 .349 .782 r
F P
0 g
s
.34258 .54201 m .28142 .54498 L .3158 .51201 L .856 0 0 r
F
.51335 .22166 m .49915 .23074 L .51406 .24785 L p 0 .318 .938 r
F P
0 g
s
.51406 .24785 m .5284 .23894 L .52837 .21671 L p 0 .181 .719 r
F P
0 g
s
.51406 .24785 m .5284 .23894 L .51335 .22166 L p 0 .318 .938 r
F P
0 g
s
.5284 .23894 m .51406 .24785 L .4836 .2767 L p 0 .05 .1 r
F P
0 g
s
.5284 .23894 m .51406 .24785 L .49915 .23074 L p 0 .318 .938 r
F P
0 g
s
.23884 .43176 m .25405 .44879 L .28565 .41908 L p 0 .349 .782 r
F P
0 g
s
.28244 .4533 m
.2891 .44701 L
s
.28565 .41908 m .27055 .40211 L .23884 .43176 L p 0 .349 .782 r
F P
0 g
s
.75971 .56786 m .73045 .59832 L .71563 .58141 L p 0 .35 .78 r
F P
0 g
s
.71563 .58141 m .74498 .55101 L .75971 .56786 L p 0 .35 .78 r
F P
0 g
s
.54699 .55319 m .53319 .53757 L .53944 .53241 L p 0 .349 .781 r
F P
0 g
s
.53319 .53757 m .53944 .53241 L .55402 .52624 L p 0 .05 .1 r
F P
0 g
s
.56149 .52202 m .55402 .52624 L .53944 .53241 L p 0 .05 .1 r
F P
0 g
s
.316 .49093 m .36721 .46386 L .39526 .43695 L p .1 0 0 r
F P
0 g
s
.33242 .42469 m .36721 .46386 L .316 .49093 L p .524 0 0 r
F P
0 g
s
.31042 .49087 m
.316 .49093 L
s
.38684 .66267 m
.40222 .67983 L
s
.45282 .30585 m .4392 .31412 L .40835 .34332 L p 0 .05 .1 r
F P
0 g
s
.4392 .31412 m .45282 .30585 L .4836 .2767 L p 0 .05 .1 r
F P
0 g
s
.37546 .65255 m
.37736 .65432 L
s
.30564 .58171 m .28142 .54498 L .3084 .5751 L .509 0 0 r
F
0 g
.30564 .58171 m
.31035 .59399 L
s
.30564 .58171 m
.31035 .59399 L
s
.37736 .65432 m
.37921 .65544 L
s
.54919 .55972 m .56165 .54722 L .54699 .55319 L p 0 .05 .14 r
F P
0 g
s
.57405 .53476 m .56165 .54722 L .54699 .55319 L p 0 .05 .14 r
F P
0 g
s
.54773 .53145 m .56165 .54722 L .54699 .55319 L p 0 .314 .946 r
F P
0 g
s
.54699 .55319 m .53319 .53757 L .54773 .53145 L p 0 .314 .946 r
F P
0 g
s
.53319 .53757 m .54699 .55319 L .56165 .54722 L p 0 .314 .946 r
F P
0 g
s
.34285 .61356 m .35543 .6276 L .36957 .61368 L p 0 .349 .782 r
F P
0 g
s
.36957 .61368 m .35543 .6276 L .36798 .64162 L p 0 .349 .782 r
F P
0 g
s
.38253 .60829 m .36957 .61368 L .35543 .6276 L p 0 .05 .1 r
F P
0 g
s
.35543 .6276 m .36957 .61368 L .38253 .60829 L p 0 .05 .1 r
F P
0 g
s
.68491 .63427 m .7009 .62907 L .68598 .61211 L p 0 .315 .945 r
F P
0 g
s
.42652 .73904 m .41137 .75437 L .44195 .7884 L p 0 .349 .782 r
F P
0 g
s
.41137 .75437 m .42652 .73904 L .39594 .70495 L p 0 .349 .782 r
F P
0 g
s
.67055 .40211 m
.67833 .41104 L
s
.66992 .40139 m
.67055 .40211 L
s
.65839 .45773 m .69071 .42525 L .69538 .41786 L .875 0 0 r
F
.65839 .45773 m .69538 .41786 L .66293 .45046 L F
.65839 .45773 m .69538 .41786 L .69071 .42525 L F
.66065 .4541 m .69538 .41786 L .65839 .45773 L F
.68481 .48795 m .65839 .45773 L .69071 .42525 L p .858 0 0 r
F P
0 g
s
.62572 .49056 m .63011 .48342 L .66293 .45046 L .875 0 0 r
F
.66065 .4541 m .66293 .45046 L .69538 .41786 L F
.62572 .49056 m .66293 .45046 L .66065 .4541 L F
.66293 .45046 m .68777 .44619 L .69449 .47318 L .57 0 0 r
F
.65839 .45773 m .66293 .45046 L .69449 .47318 L F
.62572 .49056 m .66065 .4541 L .65839 .45773 L .875 0 0 r
F
0 g
.67833 .41104 m
.68946 .42381 L
s
.69071 .42525 m .7269 .44033 L .69538 .41786 L .578 0 0 r
F
0 g
.69071 .42525 m
.71529 .45346 L
s
.49827 .20435 m .4842 .21361 L .49915 .23074 L p 0 .318 .938 r
F P
0 g
s
.49915 .23074 m .51335 .22166 L .49827 .20435 L p 0 .318 .938 r
F P
0 g
s
.51335 .22166 m .49915 .23074 L .4842 .21361 L p 0 .318 .938 r
F P
0 g
s
.49915 .23074 m .51335 .22166 L .5284 .23894 L p 0 .318 .938 r
F P
0 g
s
.23884 .43176 m .27055 .40211 L .28255 .39468 L p 0 .05 .1 r
F P
0 g
s
.31419 .36508 m .28255 .39468 L .27055 .40211 L p 0 .05 .1 r
F P
0 g
s
.35252 .33306 m .33984 .34108 L .34486 .34676 L p 0 .314 .946 r
F P
0 g
s
.34486 .34676 m .35758 .33879 L .35252 .33306 L p 0 .314 .946 r
F P
0 g
s
.34486 .34676 m .35758 .33879 L .38288 .36742 L p 0 .314 .946 r
F P
0 g
s
.35758 .33879 m .34486 .34676 L .33984 .34108 L p 0 .314 .946 r
F P
0 g
s
.48585 .7537 m .51634 .72245 L .53072 .71811 L p 0 .05 .218 r
F P
0 g
s
.39326 .3262 m .42422 .29706 L .40921 .27998 L p 0 .349 .781 r
F P
0 g
s
.42422 .29706 m .39326 .3262 L .40835 .34332 L p 0 .349 .781 r
F P
0 g
s
.40921 .27998 m .42422 .29706 L .39326 .3262 L p 0 .349 .781 r
F P
0 g
s
.40835 .34332 m .39326 .3262 L .42422 .29706 L p 0 .349 .781 r
F P
0 g
s
.55402 .52624 m .54773 .53145 L .53319 .53757 L p 0 .05 .1 r
F P
0 g
s
.56165 .54722 m .54773 .53145 L .53319 .53757 L p 0 .314 .946 r
F P
0 g
s
.52794 .54388 m .53319 .53757 L .54773 .53145 L p 0 .05 .243 r
F P
0 g
s
.58862 .24564 m .61891 .2805 L .60422 .29473 L p 0 .35 .78 r
F P
0 g
s
.63451 .32955 m .60422 .29473 L .61891 .2805 L p 0 .35 .78 r
F P
0 g
s
.44195 .7884 m .45561 .78469 L .47077 .76916 L p 0 .05 .218 r
F P
0 g
s
.44195 .7884 m .41137 .75437 L .42476 .75033 L p 0 .305 .956 r
F P
0 g
s
.42476 .75033 m .45561 .78469 L .44195 .7884 L p 0 .305 .956 r
F P
0 g
s
.44195 .7884 m .45561 .78469 L .4858 .81832 L p 0 .305 .956 r
F P
0 g
s
.28142 .54498 m .3158 .51201 L p .32352 .51586 L .1 0 0 r
F P
0 g
s
.30602 .53268 m .28142 .54498 L p .32352 .51586 L .1 0 0 r
F P
0 g
s
.26846 .53052 m .29941 .56507 L .31176 .55918 L p 0 .307 .954 r
F P
0 g
s
.28142 .54498 m .3316 .51989 L .35958 .55125 L p .509 0 0 r
F P
0 g
s
.31176 .55918 m .28052 .52429 L .26846 .53052 L p 0 .307 .954 r
F P
0 g
s
.28052 .52429 m .31176 .55918 L .32434 .55318 L p 0 .307 .954 r
F P
0 g
s
.35575 .58831 m .32434 .55318 L .31176 .55918 L p 0 .307 .954 r
F P
0 g
s
.30856 .56843 m .32434 .55318 L p .29681 .54153 L 0 .349 .781 r
F P
0 g
s
.27694 .53312 m .29018 .5479 L p .29681 .54153 L 0 .349 .781 r
F P
0 g
s
.29018 .5479 m .30856 .56843 L p .29681 .54153 L 0 .349 .781 r
F P
0 g
s
.3316 .51989 m .30602 .53268 L p .32352 .51586 L .1 0 0 r
F P
0 g
s
.39483 .51698 m .36706 .48575 L .3158 .51201 L p .521 0 0 r
F P
0 g
s
.3158 .51201 m .36706 .48575 L .3316 .51989 L p .1 0 0 r
F P
0 g
s
.29384 .53307 m
.3158 .51201 L
s
.28538 .4566 m
.316 .49093 L
s
.33984 .34108 m .35252 .33306 L .35758 .33879 L p 0 .314 .946 r
F P
0 g
s
.33984 .34108 m .35252 .33306 L .32667 .35726 L p 0 .05 .1 r
F P
0 g
s
.32667 .35726 m .31419 .36508 L .33984 .34108 L p 0 .05 .1 r
F P
0 g
s
.36111 .65454 m .36526 .67076 L .38052 .65561 L closepath p 0 .349 .782 r
F P
0 g
s
.38094 .63649 m .36798 .64162 L .38052 .65561 L p 0 .307 .954 r
F P
0 g
s
.36111 .65454 m .38052 .65561 L .36798 .64162 L closepath p 0 .349 .782 r
F P
0 g
s
.38052 .65561 m .36798 .64162 L .38094 .63649 L p 0 .307 .954 r
F P
0 g
s
.38052 .65561 m
.38052 .65561 L
s
.4842 .21361 m .49827 .20435 L .51335 .22166 L p 0 .318 .938 r
F P
0 g
s
.45353 .24234 m .4842 .21361 L .49827 .20435 L p 0 .05 .1 r
F P
0 g
s
.38288 .36742 m .37006 .37955 L .35721 .38713 L p 0 .05 .1 r
F P
0 g
s
.35721 .38713 m .37006 .37955 L .38288 .36742 L p 0 .05 .1 r
F P
0 g
s
.60484 .46505 m
.61378 .45614 L
s
.45353 .24234 m .42256 .27136 L .40921 .27998 L p 0 .05 .1 r
F P
0 g
s
.40921 .27998 m .37815 .30905 L .39326 .3262 L p 0 .349 .781 r
F P
0 g
s
.39326 .3262 m .37815 .30905 L .40921 .27998 L p 0 .349 .781 r
F P
0 g
s
.37815 .30905 m .40921 .27998 L .42256 .27136 L p 0 .05 .1 r
F P
0 g
s
.52351 .55152 m .52794 .54388 L .54244 .53781 L p 0 .05 .416 r
F P
0 g
s
.54773 .53145 m .54244 .53781 L .52794 .54388 L p 0 .05 .243 r
F P
0 g
s
.35543 .6276 m .36798 .64162 L .38094 .63649 L p 0 .307 .954 r
F P
0 g
s
.36798 .64162 m .35543 .6276 L .34161 .65346 L p 0 .349 .782 r
F P
0 g
s
.34161 .65346 m .36111 .65454 L .36798 .64162 L p 0 .349 .782 r
F P
0 g
s
.36798 .64162 m .35543 .6276 L .36827 .62233 L p 0 .307 .954 r
F P
0 g
s
.36827 .62233 m .38094 .63649 L .36798 .64162 L p 0 .307 .954 r
F P
0 g
s
.39594 .70495 m .38069 .72023 L .41137 .75437 L p 0 .349 .782 r
F P
0 g
s
.38069 .72023 m .39594 .70495 L .36526 .67076 L p 0 .349 .782 r
F P
0 g
s
.53668 .57227 m .54919 .55972 L .53462 .56558 L p 0 .05 .14 r
F P
0 g
s
.53756 .54656 m .54919 .55972 L .53462 .56558 L p 0 .313 .947 r
F P
0 g
s
.3298 .6528 m .34161 .65346 L .35543 .6276 L closepath p 0 .349 .782 r
F P
0 g
s
.38094 .63649 m .36827 .62233 L .35543 .6276 L p 0 .307 .954 r
F P
0 g
s
.36827 .62233 m .35543 .6276 L .3298 .6528 L p 0 .05 .1 r
F P
0 g
s
.35543 .6276 m .32991 .64042 L .3298 .6528 L closepath p 0 .349 .782 r
F P
0 g
s
.35543 .6276 m .36827 .62233 L .38253 .60829 L p 0 .05 .1 r
F P
0 g
s
.38253 .60829 m .36827 .62233 L .35543 .6276 L p 0 .05 .1 r
F P
0 g
s
.34285 .61356 m .35543 .6276 L .36827 .62233 L p 0 .307 .954 r
F P
0 g
s
.36827 .62233 m .35543 .6276 L .34285 .61356 L p 0 .307 .954 r
F P
0 g
s
.33009 .61994 m .32991 .64042 L .35543 .6276 L p 0 .349 .782 r
F P
0 g
s
.35543 .6276 m .34285 .61356 L .33009 .61994 L p 0 .349 .782 r
F P
0 g
s
.3298 .6528 m .34245 .64776 L .36827 .62233 L p 0 .05 .1 r
F P
0 g
s
.35543 .6276 m .36827 .62233 L .34245 .64776 L p 0 .05 .1 r
F P
0 g
s
.34245 .64776 m .3298 .6528 L .35543 .6276 L p 0 .05 .1 r
F P
0 g
s
.55824 .21066 m .58862 .24564 L .57384 .25981 L p 0 .35 .78 r
F P
0 g
s
.60422 .29473 m .57384 .25981 L .58862 .24564 L p 0 .35 .78 r
F P
0 g
s
.52309 .55255 m .52351 .55152 L .53798 .54551 L p 0 .086 .523 r
F P
0 g
s
.54244 .53781 m .53798 .54551 L .52351 .55152 L p 0 .05 .416 r
F P
0 g
s
.41137 .75437 m .38069 .72023 L .39381 .71585 L p 0 .305 .956 r
F P
0 g
s
.39381 .71585 m .42476 .75033 L .41137 .75437 L p 0 .305 .956 r
F P
0 g
s
.53798 .54551 m .53756 .54656 L .52309 .55255 L p 0 .086 .523 r
F P
0 g
s
.51979 .56072 m .52309 .55255 L .53756 .54656 L p 0 .086 .523 r
F P
0 g
s
.34285 .61356 m .35559 .60815 L .36827 .62233 L p 0 .307 .954 r
F P
0 g
s
.36827 .62233 m .35559 .60815 L .34285 .61356 L p 0 .307 .954 r
F P
0 g
s
.34991 .68598 m .36526 .67076 L .36111 .65454 L p 0 .349 .782 r
F P
0 g
s
.36111 .65454 m .34161 .65346 L .34991 .68598 L p 0 .349 .782 r
F P
0 g
s
.58073 .48078 m .5862 .47533 L .57378 .46118 L p 0 .349 .781 r
F P
0 g
s
.56233 .47253 m .57378 .46118 L .5862 .47533 L p 0 .349 .781 r
F P
0 g
s
.5702 .47665 m .56233 .47253 L p .5862 .47533 L 0 .349 .781 r
F P
0 g
s
.5862 .47533 m .58073 .48078 L .5702 .47665 L p 0 .349 .781 r
F P
0 g
s
.57378 .46118 m .5862 .47533 L .60129 .46859 L p 0 .316 .943 r
F P
0 g
s
.5862 .47533 m .57378 .46118 L .58875 .4543 L p 0 .316 .943 r
F P
0 g
s
.58875 .4543 m .60129 .46859 L .5862 .47533 L p 0 .316 .943 r
F P
0 g
s
.5862 .47533 m .58073 .48078 L .59274 .47544 L p 0 .05 .112 r
F P
0 g
s
.60129 .46859 m .5862 .47533 L p .59274 .47544 L 0 .05 .112 r
F P
0 g
s
.57384 .25981 m .60422 .29473 L .58947 .30903 L p 0 .35 .78 r
F P
0 g
s
.53756 .54656 m .53424 .5548 L .51979 .56072 L p 0 .086 .523 r
F P
0 g
s
.36526 .67076 m .34991 .68598 L .38069 .72023 L p 0 .349 .782 r
F P
0 g
s
.37821 .6659 m .36526 .67076 L .34991 .68598 L p 0 .05 .112 r
F P
0 g
s
.34991 .68598 m .36526 .67076 L .37821 .6659 L p 0 .05 .112 r
F P
0 g
s
.69446 .57098 m
.70104 .56421 L
s
.71796 .54678 m .72815 .54746 L .69485 .50938 L .212 0 0 r
F
0 g
.68933 .51406 m
.71796 .54678 L
s
.70104 .56421 m
.71796 .54678 L
s
.5757 .74774 m .60613 .71612 L .59099 .7205 L p 0 .05 .248 r
F P
0 g
s
.59099 .7205 m .56078 .75183 L .5757 .74774 L p 0 .05 .248 r
F P
0 g
s
.56078 .75183 m .59099 .7205 L .57607 .70371 L p 0 .349 .781 r
F P
0 g
s
.57607 .70371 m .59099 .7205 L .56078 .75183 L p 0 .349 .781 r
F P
0 g
s
.32733 .60914 m .31483 .61456 L .33026 .59951 L p 0 .05 .1 r
F P
0 g
s
.22212 .47879 m .23741 .49585 L .26923 .46579 L p 0 .349 .782 r
F P
0 g
s
.26923 .46579 m .25405 .44879 L .22212 .47879 L p 0 .349 .782 r
F P
0 g
s
.28126 .45895 m .26923 .46579 L .23741 .49585 L p 0 .05 .1 r
F P
0 g
s
.28388 .58006 m .31483 .61456 L .33026 .59951 L p 0 .349 .782 r
F P
0 g
s
.33026 .59951 m .29941 .56507 L .28388 .58006 L p 0 .349 .782 r
F P
0 g
s
.3084 .5751 m
.33026 .59951 L
s
.57378 .46118 m .56133 .44702 L .5762 .43999 L p 0 .316 .943 r
F P
0 g
s
.5762 .43999 m .58875 .4543 L .57378 .46118 L p 0 .316 .943 r
F P
0 g
s
.60129 .46859 m .58875 .4543 L .57378 .46118 L p 0 .316 .943 r
F P
0 g
s
.5702 .47665 m .58073 .48078 L p .57378 .46118 L 0 .349 .781 r
F P
0 g
s
.57378 .46118 m .56233 .47253 L .5702 .47665 L p 0 .349 .781 r
F P
0 g
s
.56233 .47253 m .57378 .46118 L .58875 .4543 L p 0 .05 .1 r
F P
0 g
s
.57378 .46118 m .56233 .47253 L .57063 .46875 L p 0 .05 .1 r
F P
0 g
s
.58875 .4543 m .57378 .46118 L p .57063 .46875 L 0 .05 .1 r
F P
0 g
s
.56233 .47253 m .57378 .46118 L .56133 .44702 L p 0 .349 .781 r
F P
0 g
s
.54756 .46061 m .56133 .44702 L .57378 .46118 L p 0 .349 .781 r
F P
0 g
s
.55385 .46671 m .54756 .46061 L p .57378 .46118 L 0 .349 .781 r
F P
0 g
s
.56133 .47201 m .55385 .46671 L p .57378 .46118 L 0 .349 .781 r
F P
0 g
s
.57378 .46118 m .56233 .47253 L .56133 .47201 L p 0 .349 .781 r
F P
0 g
s
.56133 .44702 m .57378 .46118 L .58875 .4543 L p 0 .316 .943 r
F P
0 g
s
.51584 .78722 m .4858 .81832 L .5 .81487 L p 0 .05 .248 r
F P
0 g
s
.5 .81487 m .53026 .78348 L .51584 .78722 L p 0 .05 .248 r
F P
0 g
s
.51584 .78722 m .53026 .78348 L .56078 .75183 L p 0 .05 .248 r
F P
0 g
s
.50086 .77047 m .51584 .78722 L .53026 .78348 L p 0 .307 .954 r
F P
0 g
s
.51584 .78722 m .50086 .77047 L .51514 .76657 L p 0 .307 .954 r
F P
0 g
s
.51514 .76657 m .53026 .78348 L .51584 .78722 L p 0 .307 .954 r
F P
0 g
s
.58073 .48078 m .5702 .47665 L .57991 .47228 L p 0 .399 1 r
F P
0 g
s
.57991 .47228 m .59274 .47544 L .58073 .48078 L p 0 .399 1 r
F P
0 g
s
.32667 .35726 m .34194 .3745 L .32933 .38216 L p 0 .312 .948 r
F P
0 g
s
.32933 .38216 m .31419 .36508 L .32667 .35726 L p 0 .312 .948 r
F P
0 g
s
.32933 .38216 m .34194 .3745 L .35719 .39172 L p 0 .312 .948 r
F P
0 g
s
.31419 .36508 m .32933 .38216 L .34194 .3745 L p 0 .312 .948 r
F P
0 g
s
.35719 .39172 m .34194 .3745 L .32933 .38216 L p 0 .312 .948 r
F P
0 g
s
.66068 .65944 m .6765 .65447 L .7009 .62907 L p 0 .05 .248 r
F P
0 g
s
.65573 .65383 m .66068 .65944 L .6765 .65447 L p 0 .314 .946 r
F P
0 g
s
.6765 .65447 m .67151 .6488 L .65573 .65383 L p 0 .314 .946 r
F P
0 g
s
.66068 .65944 m .65573 .65383 L .67151 .6488 L p 0 .314 .946 r
F P
0 g
s
.67151 .6488 m .6765 .65447 L .66068 .65944 L p 0 .314 .946 r
F P
0 g
s
.68481 .48795 m .69449 .47318 L .7269 .44033 L .853 0 0 r
F
.65839 .45773 m .69449 .47318 L .68481 .48795 L .57 0 0 r
F
0 g
.68481 .48795 m
.71694 .45536 L
s
.52834 .19453 m .52831 .1762 L .55824 .21066 L closepath p 0 .35 .78 r
F P
0 g
s
.55824 .21066 m .54336 .22476 L .52837 .21671 L p 0 .35 .78 r
F P
0 g
s
.52837 .21671 m .52834 .19453 L .55824 .21066 L p 0 .35 .78 r
F P
0 g
s
.57384 .25981 m .54336 .22476 L .55824 .21066 L p 0 .35 .78 r
F P
0 g
s
.38069 .72023 m .34991 .68598 L .36275 .68126 L p 0 .305 .956 r
F P
0 g
s
.36275 .68126 m .39381 .71585 L .38069 .72023 L p 0 .305 .956 r
F P
0 g
s
.57607 .70371 m .54576 .73498 L .56078 .75183 L p 0 .349 .781 r
F P
0 g
s
.56078 .75183 m .54576 .73498 L .57607 .70371 L p 0 .349 .781 r
F P
0 g
s
.58875 .4543 m .5762 .43999 L .56133 .44702 L p 0 .316 .943 r
F P
0 g
s
.56133 .47201 m .56233 .47253 L p .56133 .44702 L 0 .349 .781 r
F P
0 g
s
.55385 .46671 m .56133 .47201 L p .56133 .44702 L 0 .349 .781 r
F P
0 g
s
.56133 .44702 m .54756 .46061 L .55385 .46671 L p 0 .349 .781 r
F P
0 g
s
.54756 .46061 m .56133 .44702 L .5762 .43999 L p 0 .05 .1 r
F P
0 g
s
.56363 .42566 m .5762 .43999 L .56133 .44702 L p 0 .316 .943 r
F P
0 g
s
.56133 .44702 m .54887 .43283 L .56363 .42566 L p 0 .316 .943 r
F P
0 g
s
.57564 .44054 m .5762 .43999 L .56133 .44702 L p 0 .05 .1 r
F P
0 g
s
.55441 .4574 m .57564 .44054 L p .56133 .44702 L 0 .05 .1 r
F P
0 g
s
.56133 .44702 m .54756 .46061 L .55441 .4574 L p 0 .05 .1 r
F P
0 g
s
.54756 .46061 m .56133 .44702 L .54887 .43283 L p 0 .349 .781 r
F P
0 g
s
.53737 .44414 m .54887 .43283 L .56133 .44702 L p 0 .349 .781 r
F P
0 g
s
.53779 .44524 m .53737 .44414 L p .56133 .44702 L 0 .349 .781 r
F P
0 g
s
.54226 .45352 m .53779 .44524 L p .56133 .44702 L 0 .349 .781 r
F P
0 g
s
.56133 .44702 m .54756 .46061 L .54226 .45352 L p 0 .349 .781 r
F P
0 g
s
.54887 .43283 m .56133 .44702 L .5762 .43999 L p 0 .316 .943 r
F P
0 g
s
.4836 .2767 m .49771 .26803 L .5284 .23894 L p 0 .05 .1 r
F P
0 g
s
.49771 .26803 m .4836 .2767 L .45282 .30585 L p 0 .05 .1 r
F P
0 g
s
.20682 .46171 m .22212 .47879 L .25405 .44879 L p 0 .349 .782 r
F P
0 g
s
.25405 .44879 m .23884 .43176 L .20682 .46171 L p 0 .349 .782 r
F P
0 g
s
.73045 .59832 m .7009 .62907 L .68598 .61211 L p 0 .35 .78 r
F P
0 g
s
.68598 .61211 m .71563 .58141 L .73045 .59832 L p 0 .35 .78 r
F P
0 g
s
.32991 .64042 m .33009 .61994 L .31483 .61456 L p 0 .349 .782 r
F P
0 g
s
.53026 .78348 m .51514 .76657 L .50086 .77047 L p 0 .307 .954 r
F P
0 g
s
.48585 .7537 m .50086 .77047 L .51514 .76657 L p 0 .307 .954 r
F P
0 g
s
.50086 .77047 m .48585 .7537 L .5 .74964 L p 0 .307 .954 r
F P
0 g
s
.5 .74964 m .51514 .76657 L .50086 .77047 L p 0 .307 .954 r
F P
0 g
s
.40835 .34332 m .42174 .33528 L .45282 .30585 L p 0 .05 .1 r
F P
0 g
s
.40652 .31799 m .42174 .33528 L .40835 .34332 L p 0 .315 .945 r
F P
0 g
s
.40835 .34332 m .39326 .3262 L .40652 .31799 L p 0 .315 .945 r
F P
0 g
s
.38891 .34158 m .40835 .34332 L .39564 .35534 L closepath p 0 .349 .781 r
F P
0 g
s
.42174 .33528 m .40835 .34332 L .39564 .35534 L p 0 .05 .1 r
F P
0 g
s
.40835 .34332 m .42174 .33528 L .40652 .31799 L p 0 .315 .945 r
F P
0 g
s
.40652 .31799 m .39326 .3262 L .40835 .34332 L p 0 .315 .945 r
F P
0 g
s
.39564 .35534 m .40835 .34332 L .38891 .34158 L closepath p 0 .349 .781 r
F P
0 g
s
.39564 .35534 m .40835 .34332 L .42174 .33528 L p 0 .05 .1 r
F P
0 g
s
.58947 .30903 m .55898 .27404 L .57384 .25981 L p 0 .35 .78 r
F P
0 g
s
.54336 .22476 m .57384 .25981 L .55898 .27404 L p 0 .35 .78 r
F P
0 g
s
.5702 .47665 m .56233 .47253 L .57063 .46875 L p 0 .379 1 r
F P
0 g
s
.57063 .46875 m .57991 .47228 L .5702 .47665 L p 0 .379 1 r
F P
0 g
s
.34194 .3745 m .32667 .35726 L .31419 .36508 L p 0 .312 .948 r
F P
0 g
s
.28255 .39468 m .31419 .36508 L .32667 .35726 L p 0 .05 .1 r
F P
0 g
s
.55104 .41131 m .56363 .42566 L .54887 .43283 L p 0 .316 .943 r
F P
0 g
s
.54887 .43283 m .53639 .41862 L .55104 .41131 L p 0 .316 .943 r
F P
0 g
s
.53639 .41862 m .54887 .43283 L .56363 .42566 L p 0 .316 .943 r
F P
0 g
s
.5762 .43999 m .56363 .42566 L .54887 .43283 L p 0 .316 .943 r
F P
0 g
s
.56307 .42621 m .56363 .42566 L .54887 .43283 L p 0 .05 .1 r
F P
0 g
s
.54226 .45352 m .54756 .46061 L p .54887 .43283 L 0 .349 .781 r
F P
0 g
s
.53779 .44524 m .54226 .45352 L p .54887 .43283 L 0 .349 .781 r
F P
0 g
s
.54553 .4402 m .56307 .42621 L p .54887 .43283 L 0 .05 .1 r
F P
0 g
s
.54887 .43283 m .53737 .44414 L .53779 .44524 L p 0 .349 .781 r
F P
0 g
s
.54887 .43283 m .53737 .44414 L .54553 .4402 L p 0 .05 .1 r
F P
0 g
s
.53737 .44414 m .54887 .43283 L .53639 .41862 L p 0 .349 .781 r
F P
0 g
s
.53086 .42403 m .53639 .41862 L .54887 .43283 L p 0 .349 .781 r
F P
0 g
s
.53403 .4355 m .53086 .42403 L p .54887 .43283 L 0 .349 .781 r
F P
0 g
s
.54887 .43283 m .53737 .44414 L .53403 .4355 L p 0 .349 .781 r
F P
0 g
s
.53737 .44414 m .54887 .43283 L .56363 .42566 L p 0 .05 .1 r
F P
0 g
s
.32465 .65787 m .34991 .68598 L .34161 .65346 L p 0 .349 .782 r
F P
0 g
s
.34161 .65346 m .3298 .6528 L .32465 .65787 L p 0 .349 .782 r
F P
0 g
s
.63011 .48342 m .69218 .40475 L .69538 .41786 L .951 0 0 r
F
0 g
.66746 .46811 m
.68481 .48795 L
s
.65839 .45773 m
.66746 .46811 L
s
.66293 .45046 m .69538 .41786 L .69218 .40475 L .951 0 0 r
F
.69538 .41786 m .72049 .41321 L .69218 .40475 L .578 0 0 r
F
.69538 .41786 m .7269 .44033 L .72049 .41321 L F
0 g
.69071 .42525 m
.69538 .41786 L
s
.57032 .3464 m
.57269 .3441 L
s
.60924 .31892 m .57174 .28869 L .59831 .31919 L .578 0 0 r
F
0 g
.5892 .30873 m
.59831 .31919 L
s
.66796 .52647 m
.68501 .50912 L
s
.66134 .53322 m
.66796 .52647 L
s
.20682 .46171 m .23884 .43176 L .2506 .42458 L p 0 .05 .1 r
F P
0 g
s
.28255 .39468 m .2506 .42458 L .23884 .43176 L p 0 .05 .1 r
F P
0 g
s
.25283 .54545 m .28388 .58006 L .29941 .56507 L p 0 .349 .782 r
F P
0 g
s
.29941 .56507 m .26846 .53052 L .25283 .54545 L p 0 .349 .782 r
F P
0 g
s
.28142 .54498 m
.3084 .5751 L
s
.57405 .53476 m .58641 .52236 L .60153 .51606 L p 0 .05 .14 r
F P
0 g
s
.56249 .52164 m .57405 .53476 L .58641 .52236 L p 0 .349 .781 r
F P
0 g
s
.57035 .51867 m .56249 .52164 L p .58641 .52236 L 0 .349 .781 r
F P
0 g
s
.58641 .52236 m .58088 .51608 L .57035 .51867 L p 0 .349 .781 r
F P
0 g
s
.58088 .51608 m .58641 .52236 L .57405 .53476 L p 0 .349 .781 r
F P
0 g
s
.58909 .52857 m .60153 .51606 L .58641 .52236 L p 0 .05 .14 r
F P
0 g
s
.58641 .52236 m .57405 .53476 L .58909 .52857 L p 0 .05 .14 r
F P
0 g
s
.58088 .51608 m .58641 .52236 L .60153 .51606 L p 0 .315 .945 r
F P
0 g
s
.51514 .76657 m .5 .74964 L .48585 .7537 L p 0 .307 .954 r
F P
0 g
s
.48583 .7765 m .48585 .7537 L .5 .74964 L p 0 .181 .719 r
F P
0 g
s
.5 .77265 m .5 .74964 L .48585 .7537 L p 0 .181 .719 r
F P
0 g
s
.48585 .7537 m .48583 .7765 L .5 .77265 L p 0 .181 .719 r
F P
0 g
s
.47077 .76916 m .48585 .7537 L .5 .74964 L p 0 .05 .218 r
F P
0 g
s
.53072 .71811 m .5 .74964 L .48585 .7537 L p 0 .05 .218 r
F P
0 g
s
.5 .74964 m .48585 .7537 L .47077 .76916 L p 0 .05 .218 r
F P
0 g
s
.48585 .7537 m .5 .74964 L .46908 .71505 L p 0 .307 .954 r
F P
0 g
s
.39127 .30067 m .40652 .31799 L .39326 .3262 L p 0 .315 .945 r
F P
0 g
s
.39326 .3262 m .37815 .30905 L .39127 .30067 L p 0 .315 .945 r
F P
0 g
s
.37815 .30905 m .39326 .3262 L .38891 .34158 L p 0 .349 .781 r
F P
0 g
s
.37815 .30905 m .39326 .3262 L .40652 .31799 L p 0 .315 .945 r
F P
0 g
s
.39326 .3262 m .37815 .30905 L .3694 .33984 L p 0 .349 .781 r
F P
0 g
s
.3694 .33984 m .38891 .34158 L .39326 .3262 L p 0 .349 .781 r
F P
0 g
s
.57063 .46875 m .56233 .47253 L p .58875 .4543 L 0 .05 .1 r
F P
0 g
s
.56233 .47253 m .56133 .47201 L .56944 .4683 L p 0 .379 1 r
F P
0 g
s
.56944 .4683 m .57063 .46875 L .56233 .47253 L p 0 .379 1 r
F P
0 g
s
.56133 .47201 m .55385 .46671 L .56103 .4634 L p 0 .355 1 r
F P
0 g
s
.56103 .4634 m .56944 .4683 L .56133 .47201 L p 0 .355 1 r
F P
0 g
s
.3298 .6528 m .32991 .64042 L .29932 .62968 L p 0 .349 .782 r
F P
0 g
s
.31483 .61456 m .29932 .62968 L .32991 .64042 L p 0 .349 .782 r
F P
0 g
s
.57035 .51867 m .58088 .51608 L .59291 .51099 L p 0 .478 .97 r
F P
0 g
s
.57035 .51867 m .58088 .51608 L p .57405 .53476 L 0 .349 .781 r
F P
0 g
s
.60098 .51542 m .59291 .51099 L .58088 .51608 L p 0 .315 .945 r
F P
0 g
s
.60153 .51606 m .60098 .51542 L p .58088 .51608 L 0 .315 .945 r
F P
0 g
s
.56363 .42566 m .55104 .41131 L .53639 .41862 L p 0 .316 .943 r
F P
0 g
s
.53403 .4355 m .53737 .44414 L p .53639 .41862 L 0 .349 .781 r
F P
0 g
s
.53639 .41862 m .53086 .42403 L .53403 .4355 L p 0 .349 .781 r
F P
0 g
s
.53086 .42403 m .53639 .41862 L .55104 .41131 L p 0 .05 .1 r
F P
0 g
s
.49827 .20435 m .52831 .1762 L .52834 .19453 L closepath p 0 .35 .78 r
F P
0 g
s
.37821 .6659 m .36275 .68126 L .34991 .68598 L p 0 .05 .112 r
F P
0 g
s
.34991 .68598 m .36275 .68126 L .37821 .6659 L p 0 .05 .112 r
F P
0 g
s
.36275 .68126 m .34991 .68598 L .32465 .65787 L p 0 .305 .956 r
F P
0 g
s
.49827 .20435 m .46738 .23332 L .45353 .24234 L p 0 .05 .1 r
F P
0 g
s
.42256 .27136 m .45353 .24234 L .46738 .23332 L p 0 .05 .1 r
F P
0 g
s
.31483 .61456 m .32733 .60914 L .3117 .6244 L p 0 .05 .1 r
F P
0 g
s
.3117 .6244 m .29932 .62968 L .31483 .61456 L p 0 .05 .1 r
F P
0 g
s
.26827 .59512 m .29932 .62968 L .31483 .61456 L p 0 .349 .782 r
F P
0 g
s
.31483 .61456 m .28388 .58006 L .26827 .59512 L p 0 .349 .782 r
F P
0 g
s
.32733 .60914 m .31483 .61456 L .29932 .62968 L p 0 .05 .1 r
F P
0 g
s
.55385 .46671 m .54756 .46061 L .55441 .4574 L p 0 .329 .964 r
F P
0 g
s
.55441 .4574 m .56103 .4634 L .55385 .46671 L p 0 .329 .964 r
F P
0 g
s
.46561 .46513 m .46663 .46476 L .45279 .47156 L p 0 .475 .892 r
F P
0 g
s
.45279 .47156 m .45178 .47193 L .46561 .46513 L p 0 .475 .892 r
F P
0 g
s
.33726 .65287 m .34245 .64776 L .3298 .6528 L p 0 .05 .1 r
F P
0 g
s
.3298 .6528 m .32465 .65787 L .33726 .65287 L p 0 .05 .1 r
F P
0 g
s
.29932 .62968 m .32465 .65787 L .3298 .6528 L p 0 .349 .782 r
F P
0 g
s
.32465 .65787 m .3298 .6528 L .34245 .64776 L p 0 .05 .1 r
F P
0 g
s
.38891 .34158 m .3694 .33984 L .37815 .30905 L p 0 .349 .781 r
F P
0 g
s
.42256 .27136 m .39127 .30067 L .37815 .30905 L p 0 .05 .1 r
F P
0 g
s
.37815 .30905 m .3694 .33984 L .35758 .33879 L p 0 .349 .781 r
F P
0 g
s
.35758 .33879 m .35252 .33306 L .37815 .30905 L p 0 .349 .781 r
F P
0 g
s
.3694 .33984 m .37815 .30905 L .35252 .33306 L p 0 .349 .781 r
F P
0 g
s
.36544 .32488 m .35252 .33306 L .37815 .30905 L p 0 .05 .1 r
F P
0 g
s
.40652 .31799 m .39127 .30067 L .37815 .30905 L p 0 .315 .945 r
F P
0 g
s
.37815 .30905 m .39127 .30067 L .36544 .32488 L p 0 .05 .1 r
F P
0 g
s
.45757 .46807 m .46561 .46513 L .45178 .47193 L p 0 .475 .892 r
F P
0 g
s
.45178 .47193 m .44379 .47485 L .45757 .46807 L p 0 .475 .892 r
F P
0 g
s
.55898 .27404 m .5284 .23894 L .54336 .22476 L p 0 .35 .78 r
F P
0 g
s
.5284 .23894 m .52837 .21671 L .54336 .22476 L closepath p 0 .35 .78 r
F P
0 g
s
.55441 .4574 m .54756 .46061 L p .5762 .43999 L 0 .05 .1 r
F P
0 g
s
.54938 .45014 m .55441 .4574 L .54756 .46061 L p 0 .302 .924 r
F P
0 g
s
.54756 .46061 m .54226 .45352 L .54938 .45014 L p 0 .302 .924 r
F P
0 g
s
.53403 .4355 m .53086 .42403 L .54252 .41823 L p 0 .238 .818 r
F P
0 g
s
.55048 .41186 m .54252 .41823 L .53086 .42403 L p 0 .05 .1 r
F P
0 g
s
.55104 .41131 m .55048 .41186 L p .53086 .42403 L 0 .05 .1 r
F P
0 g
s
.60924 .31892 m .59422 .28783 L .57174 .28869 L .578 0 0 r
F
.56084 .32008 m .57174 .28869 L .59422 .28783 L .538 0 0 r
F
0 g
.58161 .30001 m
.5892 .30873 L
s
.58476 .33237 m
.59831 .31919 L
s
.58476 .33237 m
.59831 .31919 L
s
.56084 .32008 m .53856 .32063 L .57174 .28869 L .538 0 0 r
F
.48582 .79935 m .48583 .7765 L .5 .77265 L p 0 .181 .719 r
F P
0 g
s
.5 .74964 m .5 .77265 L .48583 .7765 L p 0 .181 .719 r
F P
0 g
s
.5 .79572 m .5 .77265 L .48583 .7765 L p 0 .181 .719 r
F P
0 g
s
.48583 .7765 m .48582 .79935 L .5 .79572 L p 0 .181 .719 r
F P
0 g
s
.52834 .19453 m .52837 .21671 L .51335 .22166 L p 0 .35 .78 r
F P
0 g
s
.51335 .22166 m .49827 .20435 L .52834 .19453 L p 0 .35 .78 r
F P
0 g
s
.38891 .34158 m .39564 .35534 L .38288 .36742 L p 0 .349 .781 r
F P
0 g
s
.40893 .34741 m .39564 .35534 L .38288 .36742 L p 0 .05 .1 r
F P
0 g
s
.39564 .35534 m .40893 .34741 L .42174 .33528 L p 0 .05 .1 r
F P
0 g
s
.3694 .33984 m .38288 .36742 L .39564 .35534 L p 0 .349 .781 r
F P
0 g
s
.39564 .35534 m .38891 .34158 L .3694 .33984 L p 0 .349 .781 r
F P
0 g
s
.42174 .33528 m .40893 .34741 L .39564 .35534 L p 0 .05 .1 r
F P
0 g
s
.38288 .36742 m .39564 .35534 L .40893 .34741 L p 0 .05 .1 r
F P
0 g
s
.38288 .36742 m .3694 .33984 L .38891 .34158 L p 0 .349 .781 r
F P
0 g
s
.54579 .44139 m .54938 .45014 L .54226 .45352 L p 0 .277 .884 r
F P
0 g
s
.54226 .45352 m .53779 .44524 L .54579 .44139 L p 0 .277 .884 r
F P
0 g
s
.54252 .41823 m .54353 .43086 L .53403 .4355 L p 0 .238 .818 r
F P
0 g
s
.53737 .44414 m .53403 .4355 L .54353 .43086 L p 0 .255 .848 r
F P
0 g
s
.56307 .42621 m .54553 .4402 L .53737 .44414 L p 0 .05 .1 r
F P
0 g
s
.56363 .42566 m .56307 .42621 L p .53737 .44414 L 0 .05 .1 r
F P
0 g
s
.54353 .43086 m .54553 .4402 L .53737 .44414 L p 0 .255 .848 r
F P
0 g
s
.53779 .44524 m .53737 .44414 L .54553 .4402 L p 0 .255 .848 r
F P
0 g
s
.54553 .4402 m .54579 .44139 L .53779 .44524 L p 0 .255 .848 r
F P
0 g
s
.22167 .51072 m .25283 .54545 L .26846 .53052 L p 0 .349 .782 r
F P
0 g
s
.26846 .53052 m .23741 .49585 L .22167 .51072 L p 0 .349 .782 r
F P
0 g
s
.23741 .49585 m .26846 .53052 L .28052 .52429 L p 0 .307 .954 r
F P
0 g
s
.59291 .51099 m .58008 .51455 L .57035 .51867 L p 0 .478 .97 r
F P
0 g
s
.56249 .52164 m .57035 .51867 L .58008 .51455 L p 0 .446 .815 r
F P
0 g
s
.57405 .53476 m .56249 .52164 L .57035 .51867 L p 0 .349 .781 r
F P
0 g
s
.34245 .64776 m .33726 .65287 L .32465 .65787 L p 0 .05 .1 r
F P
0 g
s
.33726 .65287 m .32465 .65787 L .29932 .62968 L p 0 .305 .956 r
F P
0 g
s
.32465 .65787 m .33726 .65287 L .36275 .68126 L p 0 .305 .956 r
F P
0 g
s
.56165 .54722 m .57405 .53476 L .58909 .52857 L p 0 .05 .14 r
F P
0 g
s
.60153 .51606 m .58909 .52857 L .57405 .53476 L p 0 .05 .14 r
F P
0 g
s
.58853 .52793 m .58909 .52857 L .57405 .53476 L p 0 .314 .946 r
F P
0 g
s
.58008 .51455 m .5708 .51812 L .56249 .52164 L p 0 .446 .815 r
F P
0 g
s
.5708 .51812 m .58853 .52793 L p .57405 .53476 L 0 .314 .946 r
F P
0 g
s
.57405 .53476 m .56249 .52164 L .5708 .51812 L p 0 .314 .946 r
F P
0 g
s
.57659 .54113 m .58909 .52857 L .57405 .53476 L p 0 .05 .14 r
F P
0 g
s
.57405 .53476 m .56165 .54722 L .57659 .54113 L p 0 .05 .14 r
F P
0 g
s
.56249 .52164 m .57405 .53476 L .58909 .52857 L p 0 .314 .946 r
F P
0 g
s
.54773 .53145 m .56165 .54722 L .57405 .53476 L p 0 .349 .781 r
F P
0 g
s
.55402 .52624 m .54773 .53145 L p .57405 .53476 L 0 .349 .781 r
F P
0 g
s
.56149 .52202 m .55402 .52624 L p .57405 .53476 L 0 .349 .781 r
F P
0 g
s
.57405 .53476 m .56249 .52164 L .56149 .52202 L p 0 .349 .781 r
F P
0 g
s
.56249 .52164 m .57405 .53476 L .56165 .54722 L p 0 .349 .781 r
F P
0 g
s
.44676 .47063 m .45757 .46807 L .44379 .47485 L p 0 .492 1 r
F P
0 g
s
.44379 .47485 m .43307 .47739 L .44676 .47063 L p 0 .492 1 r
F P
0 g
s
.67877 .58715 m
.69216 .57335 L
s
.66395 .54119 m
.69216 .57335 L
s
.23711 .56045 m .26827 .59512 L .28388 .58006 L p 0 .349 .782 r
F P
0 g
s
.28388 .58006 m .25283 .54545 L .23711 .56045 L p 0 .349 .782 r
F P
0 g
s
.4858 .81832 m .48582 .79935 L .5 .79572 L p 0 .181 .719 r
F P
0 g
s
.5 .77265 m .5 .79572 L .48582 .79935 L p 0 .181 .719 r
F P
0 g
s
.5 .81487 m .5 .79572 L .48582 .79935 L p 0 .181 .719 r
F P
0 g
s
.48582 .79935 m .4858 .81832 L .5 .81487 L p 0 .181 .719 r
F P
0 g
s
.51335 .22166 m .52837 .21671 L .5284 .23894 L closepath p 0 .35 .78 r
F P
0 g
s
.45561 .78469 m .47077 .76916 L .48481 .76523 L p 0 .05 .218 r
F P
0 g
s
.5 .74964 m .48481 .76523 L .47077 .76916 L p 0 .05 .218 r
F P
0 g
s
.47077 .76916 m .48481 .76523 L .5 .74964 L p 0 .05 .218 r
F P
0 g
s
.48481 .76523 m .47077 .76916 L .45561 .78469 L p 0 .05 .218 r
F P
0 g
s
.58853 .52793 m .5708 .51812 L .56249 .52164 L p 0 .314 .946 r
F P
0 g
s
.58909 .52857 m .58853 .52793 L p .56249 .52164 L 0 .314 .946 r
F P
0 g
s
.56149 .52202 m .56249 .52164 L .5708 .51812 L p 0 .446 .815 r
F P
0 g
s
.56149 .52202 m .56249 .52164 L p .56165 .54722 L 0 .349 .781 r
F P
0 g
s
.62156 .71166 m .65191 .68008 L .63626 .68482 L p 0 .05 .248 r
F P
0 g
s
.63626 .68482 m .60613 .71612 L .62156 .71166 L p 0 .05 .248 r
F P
0 g
s
.5708 .51812 m .56962 .51857 L .56149 .52202 L p 0 .446 .815 r
F P
0 g
s
.55402 .52624 m .56149 .52202 L p .56165 .54722 L 0 .349 .781 r
F P
0 g
s
.55402 .52624 m .56149 .52202 L .56962 .51857 L p 0 .05 .1 r
F P
0 g
s
.29932 .62968 m .3117 .6244 L .32733 .60914 L p 0 .05 .1 r
F P
0 g
s
.3117 .6244 m .29932 .62968 L .26827 .59512 L p 0 .305 .956 r
F P
0 g
s
.29932 .62968 m .3117 .6244 L .33726 .65287 L p 0 .305 .956 r
F P
0 g
s
.54496 .77968 m .5757 .74774 L .56078 .75183 L p 0 .05 .248 r
F P
0 g
s
.56078 .75183 m .53026 .78348 L .54496 .77968 L p 0 .05 .248 r
F P
0 g
s
.53026 .78348 m .56078 .75183 L .54576 .73498 L p 0 .349 .781 r
F P
0 g
s
.54576 .73498 m .56078 .75183 L .53026 .78348 L p 0 .349 .781 r
F P
0 g
s
.23741 .49585 m .24919 .48927 L .28126 .45895 L p 0 .05 .1 r
F P
0 g
s
.24919 .48927 m .23741 .49585 L .22212 .47879 L p 0 .307 .954 r
F P
0 g
s
.23741 .49585 m .24919 .48927 L .23377 .47204 L p 0 .307 .954 r
F P
0 g
s
.23377 .47204 m .22212 .47879 L .23741 .49585 L p 0 .307 .954 r
F P
0 g
s
.22212 .47879 m .21546 .49429 L .23741 .49585 L closepath p 0 .349 .782 r
F P
0 g
s
.28052 .52429 m .24919 .48927 L .23741 .49585 L p 0 .307 .954 r
F P
0 g
s
.22167 .51072 m .23741 .49585 L .24919 .48927 L p 0 .05 .1 r
F P
0 g
s
.24919 .48927 m .23741 .49585 L .22167 .51072 L p 0 .05 .1 r
F P
0 g
s
.23741 .49585 m .21546 .49429 L .22167 .51072 L closepath p 0 .349 .782 r
F P
0 g
s
.23741 .49585 m .24919 .48927 L .22705 .48767 L p 0 .458 1 r
F P
0 g
s
.22705 .48767 m .21546 .49429 L .23741 .49585 L p 0 .458 1 r
F P
0 g
s
.24919 .48927 m .23741 .49585 L .21546 .49429 L p 0 .458 1 r
F P
0 g
s
.5 .79572 m .5 .81487 L .4858 .81832 L p 0 .181 .719 r
F P
0 g
s
.46954 .78091 m .5 .81487 L .4858 .81832 L p 0 .305 .956 r
F P
0 g
s
.4858 .81832 m .45561 .78469 L .46954 .78091 L p 0 .305 .956 r
F P
0 g
s
.35749 .35103 m .35758 .33879 L .38288 .36742 L closepath p 0 .349 .781 r
F P
0 g
s
.35749 .35103 m .38288 .36742 L .37006 .37955 L p 0 .349 .781 r
F P
0 g
s
.38288 .36742 m .35758 .33879 L .3694 .33984 L closepath p 0 .349 .781 r
F P
0 g
s
.38288 .36742 m .35758 .33879 L .35749 .35103 L closepath p 0 .349 .781 r
F P
0 g
s
.3694 .33984 m .35758 .33879 L .38288 .36742 L closepath p 0 .349 .781 r
F P
0 g
s
.35252 .33306 m .35758 .33879 L .3694 .33984 L p 0 .349 .781 r
F P
0 g
s
.37055 .33067 m .35758 .33879 L .38288 .36742 L p 0 .314 .946 r
F P
0 g
s
.40893 .34741 m .39607 .35959 L .38288 .36742 L p 0 .05 .1 r
F P
0 g
s
.38288 .36742 m .39607 .35959 L .40893 .34741 L p 0 .05 .1 r
F P
0 g
s
.38288 .36742 m .39607 .35959 L .37055 .33067 L p 0 .314 .946 r
F P
0 g
s
.39607 .35959 m .38288 .36742 L .37006 .37955 L p 0 .05 .1 r
F P
0 g
s
.35734 .37136 m .37006 .37955 L .38288 .36742 L p 0 .349 .781 r
F P
0 g
s
.38288 .36742 m .35749 .35103 L .35734 .37136 L p 0 .349 .781 r
F P
0 g
s
.38316 .37182 m .37006 .37955 L .38288 .36742 L p 0 .05 .1 r
F P
0 g
s
.38288 .36742 m .39607 .35959 L .38316 .37182 L p 0 .05 .1 r
F P
0 g
s
.39607 .35959 m .38288 .36742 L .35758 .33879 L p 0 .314 .946 r
F P
0 g
s
.69449 .47318 m .72049 .41321 L .7269 .44033 L .954 0 0 r
F
0 g
.71694 .45536 m
.7269 .44033 L
s
.51335 .22166 m .5284 .23894 L .49771 .26803 L p 0 .35 .78 r
F P
0 g
s
.62661 .47043 m .68188 .38946 L .69218 .40475 L .885 0 0 r
F
.63011 .48342 m .62661 .47043 L .69218 .40475 L .951 0 0 r
F
.65957 .43741 m .69218 .40475 L .68188 .38946 L .885 0 0 r
F
.69218 .40475 m .69911 .38131 L .68188 .38946 L .578 0 0 r
F
.69218 .40475 m .72049 .41321 L .69911 .38131 L F
.66293 .45046 m .69218 .40475 L .65957 .43741 L .951 0 0 r
F
0 g
.69218 .40475 m
.69538 .41786 L
s
.69218 .40475 m
.69538 .41786 L
s
.56962 .51857 m .56122 .52319 L .55402 .52624 L p 0 .05 .1 r
F P
0 g
s
.56165 .54722 m .54773 .53145 L .55402 .52624 L p 0 .349 .781 r
F P
0 g
s
.54773 .53145 m .55402 .52624 L .56122 .52319 L p 0 .05 .1 r
F P
0 g
s
.54576 .73498 m .51514 .76657 L .53026 .78348 L p 0 .349 .781 r
F P
0 g
s
.51514 .76657 m .54576 .73498 L .53072 .71811 L p 0 .349 .781 r
F P
0 g
s
.53026 .78348 m .51514 .76657 L .54576 .73498 L p 0 .349 .781 r
F P
0 g
s
.53072 .71811 m .54576 .73498 L .51514 .76657 L p 0 .349 .781 r
F P
0 g
s
.46671 .29741 m .45282 .30585 L .42174 .33528 L p 0 .05 .1 r
F P
0 g
s
.45282 .30585 m .46671 .29741 L .49771 .26803 L p 0 .05 .1 r
F P
0 g
s
.20585 .52567 m .23711 .56045 L .25283 .54545 L p 0 .349 .782 r
F P
0 g
s
.25283 .54545 m .22167 .51072 L .20585 .52567 L p 0 .349 .782 r
F P
0 g
s
.22212 .47879 m .23377 .47204 L .24919 .48927 L p 0 .307 .954 r
F P
0 g
s
.23377 .47204 m .22212 .47879 L .20682 .46171 L p 0 .307 .954 r
F P
0 g
s
.19341 .49271 m .21546 .49429 L .22212 .47879 L p 0 .349 .782 r
F P
0 g
s
.22212 .47879 m .20682 .46171 L .19341 .49271 L p 0 .349 .782 r
F P
0 g
s
.22212 .47879 m .23377 .47204 L .21832 .45478 L p 0 .307 .954 r
F P
0 g
s
.21832 .45478 m .20682 .46171 L .22212 .47879 L p 0 .307 .954 r
F P
0 g
s
.56165 .54722 m .54919 .55972 L .56405 .55374 L p 0 .05 .14 r
F P
0 g
s
.56405 .55374 m .57659 .54113 L .56165 .54722 L p 0 .05 .14 r
F P
0 g
s
.58909 .52857 m .57659 .54113 L .56165 .54722 L p 0 .05 .14 r
F P
0 g
s
.57603 .54049 m .57659 .54113 L .56165 .54722 L p 0 .314 .946 r
F P
0 g
s
.55461 .52855 m .57603 .54049 L p .56165 .54722 L 0 .314 .946 r
F P
0 g
s
.56165 .54722 m .54773 .53145 L .55461 .52855 L p 0 .314 .946 r
F P
0 g
s
.54919 .55972 m .56165 .54722 L .57659 .54113 L p 0 .05 .14 r
F P
0 g
s
.54773 .53145 m .56165 .54722 L .57659 .54113 L p 0 .314 .946 r
F P
0 g
s
.53756 .54656 m .54919 .55972 L .56165 .54722 L p 0 .349 .781 r
F P
0 g
s
.53798 .54551 m .53756 .54656 L p .56165 .54722 L 0 .349 .781 r
F P
0 g
s
.54244 .53781 m .53798 .54551 L p .56165 .54722 L 0 .349 .781 r
F P
0 g
s
.56165 .54722 m .54773 .53145 L .54244 .53781 L p 0 .349 .781 r
F P
0 g
s
.54773 .53145 m .56165 .54722 L .54919 .55972 L p 0 .349 .781 r
F P
0 g
s
.39573 .6028 m .38253 .60829 L .36827 .62233 L p 0 .05 .1 r
F P
0 g
s
.36827 .62233 m .38253 .60829 L .39573 .6028 L p 0 .05 .1 r
F P
0 g
s
.68598 .61211 m .7009 .62907 L .6714 .63633 L p 0 .35 .78 r
F P
0 g
s
.67151 .6488 m .6714 .63633 L .7009 .62907 L p 0 .35 .78 r
F P
0 g
s
.7009 .62907 m .6765 .65447 L .67151 .6488 L p 0 .35 .78 r
F P
0 g
s
.49827 .20435 m .51335 .22166 L .48256 .25069 L p 0 .35 .78 r
F P
0 g
s
.49771 .26803 m .48256 .25069 L .51335 .22166 L p 0 .35 .78 r
F P
0 g
s
.62402 .32643 m .59422 .28783 L .60924 .31892 L .578 0 0 r
F
0 g
.59831 .31919 m
.60924 .31892 L
s
.59831 .31919 m
.60924 .31892 L
s
.2506 .42458 m .28255 .39468 L .29479 .38711 L p 0 .05 .1 r
F P
0 g
s
.32667 .35726 m .29479 .38711 L .28255 .39468 L p 0 .05 .1 r
F P
0 g
s
.53072 .71811 m .5 .74964 L .51514 .76657 L p 0 .349 .781 r
F P
0 g
s
.51514 .76657 m .5 .74964 L .53072 .71811 L p 0 .349 .781 r
F P
0 g
s
.51443 .7455 m .5 .74964 L .53072 .71811 L p 0 .05 .218 r
F P
0 g
s
.53072 .71811 m .54537 .71368 L .51443 .7455 L p 0 .05 .218 r
F P
0 g
s
.35252 .33306 m .35758 .33879 L .35749 .35103 L p 0 .349 .781 r
F P
0 g
s
.35758 .33879 m .37055 .33067 L .36544 .32488 L p 0 .314 .946 r
F P
0 g
s
.36544 .32488 m .35252 .33306 L .35758 .33879 L p 0 .314 .946 r
F P
0 g
s
.32667 .35726 m .35749 .35103 L .35758 .33879 L p 0 .349 .781 r
F P
0 g
s
.35758 .33879 m .35252 .33306 L .32667 .35726 L p 0 .349 .781 r
F P
0 g
s
.35758 .33879 m .37055 .33067 L .39607 .35959 L p 0 .314 .946 r
F P
0 g
s
.37055 .33067 m .35758 .33879 L .35252 .33306 L p 0 .314 .946 r
F P
0 g
s
.28037 .5895 m .26827 .59512 L .23711 .56045 L p 0 .305 .956 r
F P
0 g
s
.26827 .59512 m .28037 .5895 L .3117 .6244 L p 0 .305 .956 r
F P
0 g
s
.20682 .46171 m .21832 .45478 L .23377 .47204 L p 0 .307 .954 r
F P
0 g
s
.2506 .42458 m .21832 .45478 L .20682 .46171 L p 0 .05 .1 r
F P
0 g
s
.20682 .46171 m .17506 .4914 L .19341 .49271 L closepath p 0 .349 .782 r
F P
0 g
s
.20682 .46171 m .21832 .45478 L .18631 .48473 L p 0 .05 .1 r
F P
0 g
s
.18631 .48473 m .17506 .4914 L .20682 .46171 L p 0 .05 .1 r
F P
0 g
s
.50357 .42763 m .50891 .41547 L .49746 .42131 L p 0 .103 .572 r
F P
0 g
s
.56122 .52319 m .55461 .52855 L .54773 .53145 L p 0 .05 .1 r
F P
0 g
s
.55461 .52855 m .54773 .53145 L p .57659 .54113 L 0 .314 .946 r
F P
0 g
s
.54244 .53781 m .54773 .53145 L p .54919 .55972 L 0 .349 .781 r
F P
0 g
s
.54244 .53781 m .54773 .53145 L .55461 .52855 L p 0 .05 .243 r
F P
0 g
s
.48481 .76523 m .46954 .78091 L .45561 .78469 L p 0 .05 .218 r
F P
0 g
s
.45561 .78469 m .46954 .78091 L .48481 .76523 L p 0 .05 .218 r
F P
0 g
s
.45561 .78469 m .42476 .75033 L .43841 .7462 L p 0 .305 .956 r
F P
0 g
s
.43841 .7462 m .46954 .78091 L .45561 .78469 L p 0 .305 .956 r
F P
0 g
s
.35749 .35103 m .32667 .35726 L .35252 .33306 L p 0 .349 .781 r
F P
0 g
s
.33939 .34928 m .32667 .35726 L .35252 .33306 L p 0 .05 .1 r
F P
0 g
s
.35252 .33306 m .36544 .32488 L .37055 .33067 L p 0 .314 .946 r
F P
0 g
s
.35252 .33306 m .36544 .32488 L .33939 .34928 L p 0 .05 .1 r
F P
0 g
s
.6714 .63633 m .67122 .6157 L .68598 .61211 L p 0 .35 .78 r
F P
0 g
s
.66293 .45046 m .65957 .43741 L .68777 .44619 L .57 0 0 r
F
0 g
.55615 .34076 m
.56533 .35125 L
s
.56533 .35125 m
.5682 .35122 L
s
.48256 .25069 m .46738 .23332 L .49827 .20435 L p 0 .35 .78 r
F P
0 g
s
.34194 .3745 m .32667 .35726 L .35749 .35103 L p 0 .349 .781 r
F P
0 g
s
.35749 .35103 m .35734 .37136 L .34194 .3745 L p 0 .349 .781 r
F P
0 g
s
.37006 .37955 m .35734 .37136 L .35749 .35103 L p 0 .349 .781 r
F P
0 g
s
.35734 .37136 m .35749 .35103 L .32667 .35726 L p 0 .349 .781 r
F P
0 g
s
.37006 .37955 m .35719 .39172 L .35734 .37136 L closepath p 0 .349 .781 r
F P
0 g
s
.3702 .38409 m .35719 .39172 L .37006 .37955 L p 0 .05 .1 r
F P
0 g
s
.37006 .37955 m .38316 .37182 L .3702 .38409 L p 0 .05 .1 r
F P
0 g
s
.37006 .37955 m .38316 .37182 L .39607 .35959 L p 0 .05 .1 r
F P
0 g
s
.38316 .37182 m .37006 .37955 L .35719 .39172 L p 0 .05 .1 r
F P
0 g
s
.35734 .37136 m .35719 .39172 L .37006 .37955 L closepath p 0 .349 .781 r
F P
0 g
s
.56103 .4634 m .55441 .4574 L p .57063 .46875 L 0 .346 .852 r
F P
0 g
s
.57063 .46875 m .56944 .4683 L .56103 .4634 L p 0 .346 .852 r
F P
0 g
s
.20585 .52567 m .22167 .51072 L .21546 .49429 L p 0 .349 .782 r
F P
0 g
s
.21546 .49429 m .19341 .49271 L .20585 .52567 L p 0 .349 .782 r
F P
0 g
s
.21546 .49429 m .22705 .48767 L .20481 .48607 L p 0 .458 1 r
F P
0 g
s
.20481 .48607 m .19341 .49271 L .21546 .49429 L p 0 .458 1 r
F P
0 g
s
.22705 .48767 m .21546 .49429 L .19341 .49271 L p 0 .458 1 r
F P
0 g
s
.21546 .49429 m .22705 .48767 L .24919 .48927 L p 0 .458 1 r
F P
0 g
s
.58875 .4543 m .5882 .45485 L .57063 .46875 L p 0 .05 .1 r
F P
0 g
s
.57063 .46875 m .5882 .45485 L .58875 .4543 L p 0 .05 .1 r
F P
0 g
s
.57564 .44054 m .5882 .45485 L .57063 .46875 L p 0 .346 .852 r
F P
0 g
s
.55441 .4574 m .57564 .44054 L p .57063 .46875 L 0 .346 .852 r
F P
0 g
s
.57063 .46875 m .5882 .45485 L p .59274 .47544 L 0 .346 .852 r
F P
0 g
s
.59274 .47544 m .57991 .47228 L .57063 .46875 L p 0 .346 .852 r
F P
0 g
s
.46738 .23332 m .43617 .26258 L .42256 .27136 L p 0 .05 .1 r
F P
0 g
s
.39127 .30067 m .42256 .27136 L .43617 .26258 L p 0 .05 .1 r
F P
0 g
s
.60404 .46585 m .63011 .48342 L .62572 .49056 L .562 0 0 r
F
0 g
.62572 .49056 m
.65839 .45773 L
s
.20585 .52567 m .22167 .51072 L .23333 .50427 L p 0 .05 .1 r
F P
0 g
s
.24919 .48927 m .23333 .50427 L .22167 .51072 L p 0 .05 .1 r
F P
0 g
s
.23333 .50427 m .22167 .51072 L .20585 .52567 L p 0 .05 .1 r
F P
0 g
s
.22167 .51072 m .23333 .50427 L .24919 .48927 L p 0 .05 .1 r
F P
0 g
s
.62661 .47043 m .61607 .4551 L .68188 .38946 L .885 0 0 r
F
0 g
.60404 .46585 m
.62572 .49056 L
s
.65957 .43741 m .68188 .38946 L .64916 .4221 L .885 0 0 r
F
.64916 .4221 m .68188 .38946 L .69911 .38131 L .157 0 0 r
F
0 g
.68445 .39328 m
.69218 .40475 L
s
.68445 .39328 m
.69218 .40475 L
s
.68188 .38946 m .69911 .38131 L .65543 .33103 L p .578 0 0 r
F P
0 g
s
.69911 .38131 m .68188 .38946 L .64916 .4221 L p .157 0 0 r
F P
0 g
s
.55441 .4574 m .54938 .45014 L p .56307 .42621 L 0 .346 .852 r
F P
0 g
s
.5762 .43999 m .57564 .44054 L .55441 .4574 L p 0 .05 .1 r
F P
0 g
s
.56307 .42621 m .57564 .44054 L .55441 .4574 L p 0 .346 .852 r
F P
0 g
s
.53798 .54551 m .54244 .53781 L p .54919 .55972 L 0 .349 .781 r
F P
0 g
s
.53798 .54551 m .54244 .53781 L .5496 .53481 L p 0 .05 .416 r
F P
0 g
s
.55461 .52855 m .5496 .53481 L .54244 .53781 L p 0 .05 .243 r
F P
0 g
s
.38094 .63649 m .36827 .62233 L .38137 .61696 L p 0 .307 .954 r
F P
0 g
s
.38137 .61696 m .39415 .63126 L .38094 .63649 L p 0 .307 .954 r
F P
0 g
s
.38137 .61696 m .36827 .62233 L .38094 .63649 L p 0 .307 .954 r
F P
0 g
s
.38094 .63649 m .39415 .63126 L .38137 .61696 L p 0 .307 .954 r
F P
0 g
s
.60433 .51923 m .62576 .49766 L .63021 .49773 L .191 0 0 r
F
0 g
.62767 .49984 m
.62861 .50092 L
s
.53668 .57227 m .54919 .55972 L .56405 .55374 L p 0 .05 .14 r
F P
0 g
s
.54919 .55972 m .53668 .57227 L .55145 .5664 L p 0 .05 .14 r
F P
0 g
s
.55145 .5664 m .56405 .55374 L .54919 .55972 L p 0 .05 .14 r
F P
0 g
s
.57659 .54113 m .56405 .55374 L .54919 .55972 L p 0 .05 .14 r
F P
0 g
s
.54919 .55972 m .53756 .54656 L .53798 .54551 L p 0 .349 .781 r
F P
0 g
s
.53756 .54656 m .54919 .55972 L .56405 .55374 L p 0 .313 .947 r
F P
0 g
s
.53109 .56595 m .53668 .57227 L .54919 .55972 L p 0 .349 .781 r
F P
0 g
s
.53424 .5548 m .53109 .56595 L p .54919 .55972 L 0 .349 .781 r
F P
0 g
s
.54919 .55972 m .53756 .54656 L .53424 .5548 L p 0 .349 .781 r
F P
0 g
s
.53756 .54656 m .54919 .55972 L .53668 .57227 L p 0 .349 .781 r
F P
0 g
s
.54919 .55972 m .53756 .54656 L .54578 .54316 L p 0 .313 .947 r
F P
0 g
s
.56405 .55374 m .54919 .55972 L p .54578 .54316 L 0 .313 .947 r
F P
0 g
s
.54938 .45014 m .54579 .44139 L p .56307 .42621 L 0 .346 .852 r
F P
0 g
s
.59274 .47544 m .60074 .46914 L .60129 .46859 L p 0 .05 .112 r
F P
0 g
s
.5882 .45485 m .60074 .46914 L .59274 .47544 L p 0 .346 .852 r
F P
0 g
s
.35734 .37136 m .35719 .39172 L .34194 .3745 L closepath p 0 .349 .781 r
F P
0 g
s
.32667 .35726 m .34194 .3745 L .35734 .37136 L p 0 .349 .781 r
F P
0 g
s
.34194 .3745 m .35719 .39172 L .35734 .37136 L closepath p 0 .349 .781 r
F P
0 g
s
.23711 .56045 m .24893 .55448 L .28037 .5895 L p 0 .305 .956 r
F P
0 g
s
.24893 .55448 m .23711 .56045 L .20585 .52567 L p 0 .305 .956 r
F P
0 g
s
.36827 .62233 m .38137 .61696 L .39573 .6028 L p 0 .05 .1 r
F P
0 g
s
.39573 .6028 m .38137 .61696 L .36827 .62233 L p 0 .05 .1 r
F P
0 g
s
.38137 .61696 m .36827 .62233 L .35559 .60815 L p 0 .307 .954 r
F P
0 g
s
.38137 .61696 m .36827 .62233 L .34245 .64776 L p 0 .05 .1 r
F P
0 g
s
.36857 .60264 m .35559 .60815 L .36827 .62233 L p 0 .307 .954 r
F P
0 g
s
.36827 .62233 m .38137 .61696 L .36857 .60264 L p 0 .307 .954 r
F P
0 g
s
.34245 .64776 m .35535 .64261 L .38137 .61696 L p 0 .05 .1 r
F P
0 g
s
.36827 .62233 m .38137 .61696 L .35535 .64261 L p 0 .05 .1 r
F P
0 g
s
.35535 .64261 m .34245 .64776 L .36827 .62233 L p 0 .05 .1 r
F P
0 g
s
.49093 .44045 m .4905 .44149 L .49829 .4376 L p 0 .066 .496 r
F P
0 g
s
.49829 .4376 m .49889 .43647 L .49093 .44045 L p 0 .066 .496 r
F P
0 g
s
.5496 .53481 m .54603 .54217 L .53798 .54551 L p 0 .05 .416 r
F P
0 g
s
.49291 .44569 m .49829 .4376 L .4905 .44149 L p 0 .05 .372 r
F P
0 g
s
.53756 .54656 m .53798 .54551 L .54603 .54217 L p 0 .086 .523 r
F P
0 g
s
.57616 .35113 m .53856 .32063 L .56084 .32008 L .57 0 0 r
F
0 g
.5682 .35122 m
.57616 .35113 L
s
.53856 .32063 m
.55615 .34076 L
s
.53856 .32063 m
.57174 .28869 L
s
.42476 .75033 m .39381 .71585 L .40718 .71138 L p 0 .305 .956 r
F P
0 g
s
.40718 .71138 m .43841 .7462 L .42476 .75033 L p 0 .305 .956 r
F P
0 g
s
.54578 .54316 m .53756 .54656 L p .56405 .55374 L 0 .313 .947 r
F P
0 g
s
.53424 .5548 m .53756 .54656 L p .53668 .57227 L 0 .349 .781 r
F P
0 g
s
.53424 .5548 m .53756 .54656 L .54578 .54316 L p 0 .086 .523 r
F P
0 g
s
.54603 .54217 m .54578 .54316 L .53756 .54656 L p 0 .086 .523 r
F P
0 g
s
.54579 .44139 m .54553 .4402 L .56307 .42621 L p 0 .346 .852 r
F P
0 g
s
.54553 .4402 m .54353 .43086 L p .55048 .41186 L 0 .346 .852 r
F P
0 g
s
.55048 .41186 m .56307 .42621 L .54553 .4402 L p 0 .346 .852 r
F P
0 g
s
.35559 .60815 m .36857 .60264 L .38137 .61696 L p 0 .307 .954 r
F P
0 g
s
.35559 .60815 m .36857 .60264 L .35575 .58831 L p 0 .307 .954 r
F P
0 g
s
.5882 .45485 m .58875 .4543 L .60129 .46859 L p 0 .35 .78 r
F P
0 g
s
.60129 .46859 m .60074 .46914 L .5882 .45485 L p 0 .35 .78 r
F P
0 g
s
.60461 .46488 m .62661 .47043 L .63011 .48342 L .562 0 0 r
F
0 g
.62572 .49056 m
.63011 .48342 L
s
.60461 .46488 m .60413 .46315 L .62661 .47043 L .562 0 0 r
F
0 g
.60404 .46585 m
.60461 .46488 L
s
.62402 .32643 m .62495 .3033 L .59422 .28783 L .578 0 0 r
F
.63861 .33972 m .62495 .3033 L .62402 .32643 L F
0 g
.60924 .31892 m
.62402 .32643 L
s
.60924 .31892 m
.62402 .32643 L
s
.35719 .39172 m .34194 .3745 L .31017 .40442 L p 0 .349 .781 r
F P
0 g
s
.35481 .3667 m .34194 .3745 L .35719 .39172 L p 0 .312 .948 r
F P
0 g
s
.35719 .39172 m .3702 .38409 L .38316 .37182 L p 0 .05 .1 r
F P
0 g
s
.35719 .39172 m .3702 .38409 L .35481 .3667 L p 0 .312 .948 r
F P
0 g
s
.33828 .41432 m .3702 .38409 L .35719 .39172 L p 0 .05 .1 r
F P
0 g
s
.35719 .39172 m .32552 .4217 L .33828 .41432 L p 0 .05 .1 r
F P
0 g
s
.3702 .38409 m .35719 .39172 L .34194 .3745 L p 0 .312 .948 r
F P
0 g
s
.31017 .40442 m .34194 .3745 L .35719 .39172 L p 0 .349 .781 r
F P
0 g
s
.53668 .57227 m .53109 .56595 L .53424 .5548 L p 0 .349 .781 r
F P
0 g
s
.53109 .56595 m .53424 .5548 L .54379 .55088 L p 0 .118 .59 r
F P
0 g
s
.54578 .54316 m .54379 .55088 L .53424 .5548 L p 0 .086 .523 r
F P
0 g
s
.37584 .67644 m .39142 .66095 L .37821 .6659 L p 0 .05 .112 r
F P
0 g
s
.37821 .6659 m .36275 .68126 L .37584 .67644 L p 0 .05 .112 r
F P
0 g
s
.36275 .68126 m .37821 .6659 L .39142 .66095 L p 0 .05 .112 r
F P
0 g
s
.69695 .57382 m .69392 .58094 L .66044 .54279 L .98 0 0 r
F
.69695 .57382 m .66044 .54279 L .66204 .53931 L F
.69695 .57382 m .66044 .54279 L .69392 .58094 L F
.69695 .57382 m .66364 .53584 L .66044 .54279 L F
.69392 .58094 m .61643 .5162 L .62683 .50449 L .889 0 0 r
F
.69392 .58094 m .68379 .59287 L .61643 .5162 L F
.69392 .58094 m .66044 .54279 L .65017 .5546 L F
.66044 .54279 m .66728 .54809 L .65601 .55238 L .228 0 0 r
F
.66044 .54279 m .65601 .55238 L .65017 .5546 L F
.66204 .53931 m .66044 .54279 L .62683 .50449 L .98 0 0 r
F
0 g
.68501 .50912 m
.68956 .50924 L
s
.69695 .57382 m .72217 .562 L .72815 .54746 L .262 0 0 r
F
.69695 .57382 m .69392 .58094 L .72217 .562 L F
0 g
.60676 .52594 m
.61423 .53443 L
s
.66989 .59773 m .61643 .5162 L .68379 .59287 L .554 0 0 r
F
0 g
.62817 .55029 m
.63653 .5598 L
s
.61423 .53443 m
.62817 .55029 L
s
.64074 .63729 m .68379 .59287 L .66989 .59773 L p .262 0 0 r
F P
0 g
s
.67067 .59746 m
.67571 .5957 L
s
.66989 .59773 m
.67067 .59746 L
s
.63653 .5598 m
.66989 .59773 L
s
.54353 .43086 m .54252 .41823 L .55048 .41186 L p 0 .346 .852 r
F P
0 g
s
.59091 .74356 m .62156 .71166 L .60613 .71612 L p 0 .05 .248 r
F P
0 g
s
.60613 .71612 m .5757 .74774 L .59091 .74356 L p 0 .05 .248 r
F P
0 g
s
.19341 .49271 m .17506 .4914 L .20585 .52567 L closepath p 0 .349 .782 r
F P
0 g
s
.19341 .49271 m .20481 .48607 L .18631 .48473 L p 0 .458 1 r
F P
0 g
s
.18631 .48473 m .17506 .4914 L .19341 .49271 L p 0 .458 1 r
F P
0 g
s
.20481 .48607 m .19341 .49271 L .17506 .4914 L p 0 .458 1 r
F P
0 g
s
.19341 .49271 m .20481 .48607 L .22705 .48767 L p 0 .458 1 r
F P
0 g
s
.29352 .45197 m .28126 .45895 L .24919 .48927 L p 0 .05 .1 r
F P
0 g
s
.57564 .44054 m .5762 .43999 L .58875 .4543 L p 0 .35 .78 r
F P
0 g
s
.58875 .4543 m .5882 .45485 L .57564 .44054 L p 0 .35 .78 r
F P
0 g
s
.58008 .51455 m .59291 .51099 L .60098 .51542 L p 0 .275 .686 r
F P
0 g
s
.5708 .51812 m .58008 .51455 L p .60098 .51542 L 0 .275 .686 r
F P
0 g
s
.60413 .46315 m .61607 .4551 L .62661 .47043 L .562 0 0 r
F
.60413 .46315 m .60273 .46112 L .61607 .4551 L F
0 g
.60413 .46315 m
.60461 .46488 L
s
.60273 .46112 m
.60413 .46315 L
s
.61798 .35998 m
.63861 .33972 L
s
.63861 .33972 m .65543 .33103 L .62495 .3033 L .578 0 0 r
F
0 g
.61798 .35998 m
.63861 .33972 L
s
.62402 .32643 m
.63861 .33972 L
s
.62402 .32643 m
.63861 .33972 L
s
.56962 .51857 m .5708 .51812 L .58853 .52793 L p 0 .275 .686 r
F P
0 g
s
.60098 .51542 m .58853 .52793 L .5708 .51812 L p 0 .275 .686 r
F P
0 g
s
.56122 .52319 m .56962 .51857 L p .58853 .52793 L 0 .275 .686 r
F P
0 g
s
.23333 .50427 m .21739 .51934 L .20585 .52567 L p 0 .05 .1 r
F P
0 g
s
.20585 .52567 m .21739 .51934 L .24893 .55448 L p 0 .305 .956 r
F P
0 g
s
.20585 .52567 m .21739 .51934 L .23333 .50427 L p 0 .05 .1 r
F P
0 g
s
.21739 .51934 m .20585 .52567 L .17506 .4914 L p 0 .305 .956 r
F P
0 g
s
.54496 .77968 m .53026 .78348 L .51514 .76657 L p 0 .307 .954 r
F P
0 g
s
.5 .77265 m .51514 .76657 L .53026 .78348 L p 0 .349 .781 r
F P
0 g
s
.53026 .78348 m .5 .79572 L .5 .77265 L p 0 .349 .781 r
F P
0 g
s
.53026 .78348 m .5 .81487 L .5 .79572 L closepath p 0 .349 .781 r
F P
0 g
s
.53026 .78348 m .5 .81487 L .51448 .81135 L p 0 .05 .248 r
F P
0 g
s
.51448 .81135 m .54496 .77968 L .53026 .78348 L p 0 .05 .248 r
F P
0 g
s
.51514 .76657 m .53026 .78348 L .54496 .77968 L p 0 .307 .954 r
F P
0 g
s
.5 .79572 m .53026 .78348 L .51514 .76657 L p 0 .349 .781 r
F P
0 g
s
.5 .79572 m .5 .81487 L .53026 .78348 L closepath p 0 .349 .781 r
F P
0 g
s
.56405 .55374 m .55145 .5664 L .53668 .57227 L p 0 .05 .14 r
F P
0 g
s
.53668 .57227 m .53109 .56595 L .54284 .56121 L p 0 .312 .948 r
F P
0 g
s
.55145 .5664 m .53668 .57227 L p .54284 .56121 L 0 .312 .948 r
F P
0 g
s
.60273 .46112 m
.61607 .4551 L
s
.29479 .38711 m .31017 .40442 L .34194 .3745 L p 0 .349 .781 r
F P
0 g
s
.34194 .3745 m .32667 .35726 L .29479 .38711 L p 0 .349 .781 r
F P
0 g
s
.33939 .34928 m .32667 .35726 L .34194 .3745 L p 0 .312 .948 r
F P
0 g
s
.34194 .3745 m .35481 .3667 L .33939 .34928 L p 0 .312 .948 r
F P
0 g
s
.33939 .34928 m .35481 .3667 L .34194 .3745 L p 0 .312 .948 r
F P
0 g
s
.34194 .3745 m .32667 .35726 L .33939 .34928 L p 0 .312 .948 r
F P
0 g
s
.34194 .3745 m .35481 .3667 L .3702 .38409 L p 0 .312 .948 r
F P
0 g
s
.29479 .38711 m .32667 .35726 L .34194 .3745 L p 0 .349 .781 r
F P
0 g
s
.34194 .3745 m .31017 .40442 L .29479 .38711 L p 0 .349 .781 r
F P
0 g
s
.6765 .65447 m .65191 .68008 L .66001 .64813 L p 0 .35 .78 r
F P
0 g
s
.66001 .64813 m .67151 .6488 L .6765 .65447 L p 0 .35 .78 r
F P
0 g
s
.39381 .71585 m .36275 .68126 L .37584 .67644 L p 0 .305 .956 r
F P
0 g
s
.37584 .67644 m .40718 .71138 L .39381 .71585 L p 0 .305 .956 r
F P
0 g
s
.54379 .55088 m .54284 .56121 L .53109 .56595 L p 0 .118 .59 r
F P
0 g
s
.48111 .4572 m .48724 .45216 L .48063 .45541 L p 0 .05 .1 r
F P
0 g
s
.48063 .45541 m .47425 .46058 L .48111 .4572 L p 0 .05 .1 r
F P
0 g
s
.55461 .52855 m .56122 .52319 L p .58853 .52793 L 0 .275 .686 r
F P
0 g
s
.56307 .42621 m .56363 .42566 L .5762 .43999 L p 0 .35 .78 r
F P
0 g
s
.5762 .43999 m .57564 .44054 L .56307 .42621 L p 0 .35 .78 r
F P
0 g
s
.48256 .25069 m .49771 .26803 L .46671 .29741 L p 0 .35 .78 r
F P
0 g
s
.49248 .27796 m .51846 .31877 L .52652 .31688 L .212 0 0 r
F
.49248 .27796 m .48478 .28028 L .51846 .31877 L F
.49525 .34386 m .52652 .31688 L .51846 .31877 L .1 0 0 r
F
0 g
.51846 .31877 m
.52218 .3179 L
s
.50078 .33573 m
.51846 .31877 L
s
.4939 .34232 m
.50078 .33573 L
s
.51514 .76657 m .52971 .7626 L .54496 .77968 L p 0 .307 .954 r
F P
0 g
s
.52971 .7626 m .51514 .76657 L .5 .74964 L p 0 .307 .954 r
F P
0 g
s
.5 .77265 m .5 .74964 L .51514 .76657 L closepath p 0 .349 .781 r
F P
0 g
s
.54496 .77968 m .52971 .7626 L .51514 .76657 L p 0 .307 .954 r
F P
0 g
s
.51514 .76657 m .5 .77265 L .5 .79572 L p 0 .349 .781 r
F P
0 g
s
.5 .74964 m .51514 .76657 L .52971 .7626 L p 0 .307 .954 r
F P
0 g
s
.51514 .76657 m .5 .74964 L .5 .77265 L closepath p 0 .349 .781 r
F P
0 g
s
.42174 .33528 m .43539 .32709 L .46671 .29741 L p 0 .05 .1 r
F P
0 g
s
.42003 .30963 m .43539 .32709 L .42174 .33528 L p 0 .315 .945 r
F P
0 g
s
.42174 .33528 m .40652 .31799 L .42003 .30963 L p 0 .315 .945 r
F P
0 g
s
.43539 .32709 m .42174 .33528 L .40893 .34741 L p 0 .05 .1 r
F P
0 g
s
.42174 .33528 m .43539 .32709 L .42003 .30963 L p 0 .315 .945 r
F P
0 g
s
.42003 .30963 m .40652 .31799 L .42174 .33528 L p 0 .315 .945 r
F P
0 g
s
.40893 .34741 m .42174 .33528 L .43539 .32709 L p 0 .05 .1 r
F P
0 g
s
.69449 .47318 m .68777 .44619 L .72049 .41321 L .954 0 0 r
F
0 g
.68481 .48795 m
.69449 .47318 L
s
.72815 .54746 m .68851 .52355 L .69485 .50938 L .982 0 0 r
F
.72815 .54746 m .72217 .562 L .68851 .52355 L F
.30726 .37938 m .29479 .38711 L .32667 .35726 L p 0 .05 .1 r
F P
0 g
s
.32667 .35726 m .33939 .34928 L .30726 .37938 L p 0 .05 .1 r
F P
0 g
s
.65957 .43741 m .66614 .41424 L .68777 .44619 L .57 0 0 r
F
.65957 .43741 m .64916 .4221 L .66614 .41424 L F
0 g
.65957 .43741 m
.66293 .45046 L
s
.64916 .4221 m
.65957 .43741 L
s
.61607 .4551 m
.64916 .4221 L
s
.55048 .41186 m .55104 .41131 L .56363 .42566 L p 0 .35 .78 r
F P
0 g
s
.56363 .42566 m .56307 .42621 L .55048 .41186 L p 0 .35 .78 r
F P
0 g
s
.58853 .52793 m .57603 .54049 L .55461 .52855 L p 0 .275 .686 r
F P
0 g
s
.57659 .54113 m .57603 .54049 L .55461 .52855 L p 0 .314 .946 r
F P
0 g
s
.55461 .52855 m .57603 .54049 L p .54578 .54316 L 0 .275 .686 r
F P
0 g
s
.5496 .53481 m .55461 .52855 L p .54578 .54316 L 0 .275 .686 r
F P
0 g
s
.46738 .23332 m .48256 .25069 L .45145 .28001 L p 0 .35 .78 r
F P
0 g
s
.46671 .29741 m .45145 .28001 L .48256 .25069 L p 0 .35 .78 r
F P
0 g
s
.47433 .46097 m .48111 .4572 L .47425 .46058 L p 0 .05 .1 r
F P
0 g
s
.21832 .45478 m .2506 .42458 L .26258 .41726 L p 0 .05 .1 r
F P
0 g
s
.29479 .38711 m .26258 .41726 L .2506 .42458 L p 0 .05 .1 r
F P
0 g
s
.60433 .51923 m .63021 .49773 L .6049 .51926 L .191 0 0 r
F
0 g
.60433 .51923 m
.62576 .49766 L
s
.60433 .51923 m
.6047 .51966 L
s
.66364 .53584 m .68851 .52355 L .66044 .54279 L .228 0 0 r
F
.66364 .53584 m .69485 .50938 L .68851 .52355 L F
0 g
.68956 .50924 m
.69485 .50938 L
s
.60098 .51542 m .60153 .51606 L .58909 .52857 L p 0 .35 .78 r
F P
0 g
s
.58909 .52857 m .58853 .52793 L .60098 .51542 L p 0 .35 .78 r
F P
0 g
s
.17506 .4914 m .18631 .48473 L .20481 .48607 L p 0 .458 1 r
F P
0 g
s
.17506 .4914 m .18631 .48473 L .21739 .51934 L p 0 .305 .956 r
F P
0 g
s
.5 .74964 m .51443 .7455 L .52971 .7626 L p 0 .307 .954 r
F P
0 g
s
.48481 .76523 m .5 .74964 L .5 .77265 L closepath p 0 .349 .781 r
F P
0 g
s
.52971 .7626 m .51443 .7455 L .5 .74964 L p 0 .307 .954 r
F P
0 g
s
.5 .77265 m .5 .74964 L .51443 .7455 L p 0 .181 .719 r
F P
0 g
s
.5 .77265 m .5 .74964 L .48481 .76523 L closepath p 0 .349 .781 r
F P
0 g
s
.51445 .76873 m .51443 .7455 L .5 .74964 L p 0 .181 .719 r
F P
0 g
s
.5 .74964 m .5 .77265 L .51445 .76873 L p 0 .181 .719 r
F P
0 g
s
.48481 .76523 m .5 .74964 L .51443 .7455 L p 0 .05 .218 r
F P
0 g
s
.51443 .7455 m .49912 .76123 L .48481 .76523 L p 0 .05 .218 r
F P
0 g
s
.49912 .76123 m .51443 .7455 L .5 .74964 L p 0 .05 .218 r
F P
0 g
s
.5 .74964 m .48481 .76523 L .49912 .76123 L p 0 .05 .218 r
F P
0 g
s
.48481 .76523 m .5 .74964 L .46908 .71505 L p 0 .349 .781 r
F P
0 g
s
.46908 .71505 m .5 .74964 L .51443 .7455 L p 0 .307 .954 r
F P
0 g
s
.46908 .71505 m .5 .74964 L .48481 .76523 L p 0 .349 .781 r
F P
0 g
s
.40465 .29213 m .42003 .30963 L .40652 .31799 L p 0 .315 .945 r
F P
0 g
s
.40652 .31799 m .39127 .30067 L .40465 .29213 L p 0 .315 .945 r
F P
0 g
s
.40465 .29213 m .39127 .30067 L .40652 .31799 L p 0 .315 .945 r
F P
0 g
s
.40652 .31799 m .42003 .30963 L .40465 .29213 L p 0 .315 .945 r
F P
0 g
s
.64091 .64703 m .66001 .64813 L .65191 .68008 L p 0 .35 .78 r
F P
0 g
s
.57616 .35113 m
.59091 .35878 L
s
.39142 .66095 m .37584 .67644 L .36275 .68126 L p 0 .05 .112 r
F P
0 g
s
.37584 .67644 m .36275 .68126 L .33726 .65287 L p 0 .305 .956 r
F P
0 g
s
.55526 .4086 m .53197 .38367 L .54271 .3837 L .562 0 0 r
F
0 g
.53197 .38367 m
.56533 .35125 L
s
.55721 .40964 m .55526 .4086 L .54271 .3837 L .562 0 0 r
F
0 g
.55382 .40858 m
.55526 .4086 L
s
.6049 .51926 m .62683 .50449 L .60444 .52017 L .191 0 0 r
F
.6049 .51926 m .63021 .49773 L .62683 .50449 L F
0 g
.60433 .51923 m
.6049 .51926 L
s
.62576 .49766 m
.63021 .49773 L
s
.45145 .28001 m .43617 .26258 L .46738 .23332 L p 0 .35 .78 r
F P
0 g
s
.3117 .6244 m .32733 .60914 L .34008 .60362 L p 0 .05 .1 r
F P
0 g
s
.34008 .60362 m .32733 .60914 L .3117 .6244 L p 0 .05 .1 r
F P
0 g
s
.54578 .54316 m .54603 .54217 L .5496 .53481 L p 0 .275 .686 r
F P
0 g
s
.55721 .40964 m .54271 .3837 L .55744 .39149 L .562 0 0 r
F
0 g
.53197 .38367 m
.55382 .40858 L
s
.55916 .41143 m .55721 .40964 L .55744 .39149 L .562 0 0 r
F
0 g
.55526 .4086 m
.55721 .40964 L
s
.47347 .46127 m .47433 .46097 L .46663 .46476 L p 0 .475 .892 r
F P
0 g
s
.46663 .46476 m .46561 .46513 L .47347 .46127 L p 0 .475 .892 r
F P
0 g
s
.35535 .64261 m .34245 .64776 L .33726 .65287 L p 0 .05 .1 r
F P
0 g
s
.33726 .65287 m .35012 .64777 L .35535 .64261 L p 0 .05 .1 r
F P
0 g
s
.35012 .64777 m .33726 .65287 L .34245 .64776 L p 0 .05 .1 r
F P
0 g
s
.34245 .64776 m .35535 .64261 L .35012 .64777 L p 0 .05 .1 r
F P
0 g
s
.43617 .26258 m .40465 .29213 L .39127 .30067 L p 0 .05 .1 r
F P
0 g
s
.37862 .31654 m .36544 .32488 L .39127 .30067 L p 0 .05 .1 r
F P
0 g
s
.39127 .30067 m .40465 .29213 L .37862 .31654 L p 0 .05 .1 r
F P
0 g
s
.62661 .47043 m
.63011 .48342 L
s
.55916 .41143 m .55744 .39149 L .57216 .40497 L .562 0 0 r
F
0 g
.55916 .41143 m
.57216 .40497 L
s
.55721 .40964 m
.55916 .41143 L
s
.46844 .44543 m .47347 .46127 L .46561 .46513 L p 0 .313 .947 r
F P
0 g
s
.46667 .46359 m .47347 .46127 L .46561 .46513 L p 0 .475 .892 r
F P
0 g
s
.46561 .46513 m .45757 .46807 L .46667 .46359 L p 0 .475 .892 r
F P
0 g
s
.53197 .38367 m
.54271 .3837 L
s
.4612 .30503 m .48478 .28028 L .49248 .27796 L .1 0 0 r
F
0 g
.48694 .28275 m
.51846 .31877 L
s
.4612 .30503 m .45763 .30601 L .48478 .28028 L .1 0 0 r
F
0 g
.46697 .29716 m
.48478 .28028 L
s
.59153 .33585 m .59422 .28783 L .62495 .3033 L .759 0 0 r
F
.59153 .33585 m .56084 .32008 L .59422 .28783 L F
0 g
.57174 .28869 m
.59422 .28783 L
s
.53856 .32063 m
.56084 .32008 L
s
.60444 .52017 m .61643 .5162 L .60305 .52172 L .191 0 0 r
F
.60444 .52017 m .62683 .50449 L .61643 .5162 L F
0 g
.60444 .52017 m
.6049 .51926 L
s
.60305 .52172 m
.60444 .52017 L
s
.48481 .76523 m .5 .77265 L .5 .79572 L p 0 .349 .781 r
F P
0 g
s
.5 .79572 m .5 .77265 L .51445 .76873 L p 0 .181 .719 r
F P
0 g
s
.51443 .7455 m .51445 .76873 L .5 .77265 L p 0 .181 .719 r
F P
0 g
s
.5 .77265 m .48481 .76523 L .46954 .78091 L p 0 .349 .781 r
F P
0 g
s
.46954 .78091 m .5 .79572 L .5 .77265 L p 0 .349 .781 r
F P
0 g
s
.51446 .79202 m .51445 .76873 L .5 .77265 L p 0 .181 .719 r
F P
0 g
s
.5 .77265 m .5 .79572 L .51446 .79202 L p 0 .181 .719 r
F P
0 g
s
.40953 .3516 m .42249 .33932 L .40893 .34741 L p 0 .05 .1 r
F P
0 g
s
.40893 .34741 m .39607 .35959 L .40953 .3516 L p 0 .05 .1 r
F P
0 g
s
.40893 .34741 m .42249 .33932 L .43539 .32709 L p 0 .05 .1 r
F P
0 g
s
.43539 .32709 m .42249 .33932 L .40893 .34741 L p 0 .05 .1 r
F P
0 g
s
.39607 .35959 m .40893 .34741 L .42249 .33932 L p 0 .05 .1 r
F P
0 g
s
.64916 .4221 m .69911 .38131 L .66614 .41424 L .157 0 0 r
F
.64916 .4221 m .66614 .41424 L .69911 .38131 L p F P
0 g
s
.62213 .36377 m .66614 .41424 L .64916 .4221 L p .57 0 0 r
F P
0 g
s
.6619 .40939 m
.68188 .38946 L
s
.64916 .4221 m .60557 .37217 L .62213 .36377 L p .57 0 0 r
F P
0 g
s
.64916 .4221 m
.65495 .41942 L
s
.57216 .40497 m
.60557 .37217 L
s
.24919 .48927 m .28052 .52429 L .29282 .51793 L p 0 .307 .954 r
F P
0 g
s
.32434 .55318 m .29282 .51793 L .28052 .52429 L p 0 .307 .954 r
F P
0 g
s
.62683 .50449 m
.63021 .49773 L
s
.35012 .64777 m .33726 .65287 L .3117 .6244 L p 0 .305 .956 r
F P
0 g
s
.33726 .65287 m .35012 .64777 L .37584 .67644 L p 0 .305 .956 r
F P
0 g
s
.46908 .71505 m .45378 .73059 L .48481 .76523 L p 0 .349 .781 r
F P
0 g
s
.51443 .7455 m .48323 .71056 L .46908 .71505 L p 0 .307 .954 r
F P
0 g
s
.43805 .68035 m .46908 .71505 L .48323 .71056 L p 0 .307 .954 r
F P
0 g
s
.48481 .76523 m .45378 .73059 L .46908 .71505 L p 0 .349 .781 r
F P
0 g
s
.43805 .68035 m .46908 .71505 L .45378 .73059 L p 0 .349 .781 r
F P
0 g
s
.58853 .52793 m .58909 .52857 L .57659 .54113 L p 0 .35 .78 r
F P
0 g
s
.4579 .46513 m .46667 .46359 L .45757 .46807 L p 0 .492 1 r
F P
0 g
s
.45757 .46807 m .44676 .47063 L .4579 .46513 L p 0 .492 1 r
F P
0 g
s
.57659 .54113 m .57603 .54049 L .58853 .52793 L p 0 .35 .78 r
F P
0 g
s
.68777 .44619 m .69911 .38131 L .72049 .41321 L .886 0 0 r
F
0 g
.72049 .41321 m
.7269 .44033 L
s
.65191 .68008 m .63682 .66301 L .64091 .64703 L p 0 .35 .78 r
F P
0 g
s
.49889 .43647 m .49829 .4376 L .49291 .44569 L p 0 .432 .873 r
F P
0 g
s
.48126 .43297 m .49401 .42057 L .49889 .43647 L p 0 .432 .873 r
F P
0 g
s
.48724 .45216 m .48126 .43297 L p .49889 .43647 L 0 .432 .873 r
F P
0 g
s
.49291 .44569 m .48724 .45216 L p .49889 .43647 L 0 .432 .873 r
F P
0 g
s
.49889 .43647 m .49401 .42057 L p .50891 .41547 L 0 .432 .873 r
F P
0 g
s
.50891 .41547 m .50357 .42763 L .49889 .43647 L p 0 .432 .873 r
F P
0 g
s
.5 .79572 m .5 .81487 L .46954 .78091 L closepath p 0 .349 .781 r
F P
0 g
s
.5 .79572 m .46954 .78091 L .48481 .76523 L p 0 .349 .781 r
F P
0 g
s
.46954 .78091 m .5 .81487 L .5 .79572 L closepath p 0 .349 .781 r
F P
0 g
s
.5 .81487 m .5 .79572 L .51446 .79202 L p 0 .181 .719 r
F P
0 g
s
.51445 .76873 m .51446 .79202 L .5 .79572 L p 0 .181 .719 r
F P
0 g
s
.51448 .81135 m .51446 .79202 L .5 .79572 L p 0 .181 .719 r
F P
0 g
s
.5 .79572 m .5 .81487 L .51448 .81135 L p 0 .181 .719 r
F P
0 g
s
.57603 .54049 m .56348 .5531 L .54578 .54316 L p 0 .275 .686 r
F P
0 g
s
.56405 .55374 m .56348 .5531 L .54578 .54316 L p 0 .313 .947 r
F P
0 g
s
.54578 .54316 m .56348 .5531 L .56405 .55374 L p 0 .313 .947 r
F P
0 g
s
.54578 .54316 m .56348 .5531 L p .54284 .56121 L 0 .275 .686 r
F P
0 g
s
.54284 .56121 m .54379 .55088 L .54578 .54316 L p 0 .275 .686 r
F P
0 g
s
.46954 .78091 m .48481 .76523 L .49912 .76123 L p 0 .05 .218 r
F P
0 g
s
.49912 .76123 m .48374 .77705 L .46954 .78091 L p 0 .05 .218 r
F P
0 g
s
.48374 .77705 m .49912 .76123 L .48481 .76523 L p 0 .05 .218 r
F P
0 g
s
.48481 .76523 m .46954 .78091 L .48374 .77705 L p 0 .05 .218 r
F P
0 g
s
.46954 .78091 m .48481 .76523 L .45378 .73059 L p 0 .349 .781 r
F P
0 g
s
.45378 .73059 m .48481 .76523 L .46954 .78091 L p 0 .349 .781 r
F P
0 g
s
.63682 .66301 m .65191 .68008 L .62156 .71166 L p 0 .35 .78 r
F P
0 g
s
.32552 .4217 m .31017 .40442 L .27806 .43463 L p 0 .349 .781 r
F P
0 g
s
.30603 .44486 m .33828 .41432 L .32552 .4217 L p 0 .05 .1 r
F P
0 g
s
.32552 .4217 m .29352 .45197 L .30603 .44486 L p 0 .05 .1 r
F P
0 g
s
.40848 .61707 m .4212 .63133 L .40692 .64553 L p 0 .349 .781 r
F P
0 g
s
.27806 .43463 m .31017 .40442 L .32552 .4217 L p 0 .349 .781 r
F P
0 g
s
.32552 .4217 m .29352 .45197 L .27806 .43463 L p 0 .349 .781 r
F P
0 g
s
.4212 .63133 m .40692 .64553 L .4205 .64035 L p 0 .05 .112 r
F P
0 g
s
.40692 .64553 m .4212 .63133 L .40848 .61707 L p 0 .349 .781 r
F P
0 g
s
.49401 .42057 m .50672 .40822 L .50891 .41547 L p 0 .432 .873 r
F P
0 g
s
.69392 .58094 m .65017 .5546 L .68379 .59287 L .889 0 0 r
F
.69392 .58094 m .70122 .58677 L .72217 .562 L .262 0 0 r
F
0 g
.69392 .58094 m
.69695 .57382 L
s
.69392 .58094 m .68379 .59287 L .70122 .58677 L .262 0 0 r
F
0 g
.69392 .58094 m
.69695 .57382 L
s
.3117 .6244 m .32433 .61901 L .35012 .64777 L p 0 .305 .956 r
F P
0 g
s
.34008 .60362 m .32433 .61901 L .3117 .6244 L p 0 .05 .1 r
F P
0 g
s
.3117 .6244 m .32433 .61901 L .34008 .60362 L p 0 .05 .1 r
F P
0 g
s
.32433 .61901 m .3117 .6244 L .28037 .5895 L p 0 .305 .956 r
F P
0 g
s
.55995 .7758 m .59091 .74356 L .5757 .74774 L p 0 .05 .248 r
F P
0 g
s
.5757 .74774 m .54496 .77968 L .55995 .7758 L p 0 .05 .248 r
F P
0 g
s
.24919 .48927 m .2612 .48256 L .29352 .45197 L p 0 .05 .1 r
F P
0 g
s
.23377 .47204 m .24919 .48927 L .2612 .48256 L p 0 .307 .954 r
F P
0 g
s
.29282 .51793 m .2612 .48256 L .24919 .48927 L p 0 .307 .954 r
F P
0 g
s
.23333 .50427 m .24919 .48927 L .2612 .48256 L p 0 .05 .1 r
F P
0 g
s
.2612 .48256 m .24521 .49769 L .23333 .50427 L p 0 .05 .1 r
F P
0 g
s
.24919 .48927 m .23333 .50427 L .24521 .49769 L p 0 .05 .1 r
F P
0 g
s
.24521 .49769 m .2612 .48256 L .24919 .48927 L p 0 .05 .1 r
F P
0 g
s
.2612 .48256 m .24919 .48927 L .23377 .47204 L p 0 .307 .954 r
F P
0 g
s
.22705 .48767 m .24919 .48927 L .2612 .48256 L p 0 .458 1 r
F P
0 g
s
.23887 .48093 m .2612 .48256 L .24919 .48927 L p 0 .458 1 r
F P
0 g
s
.24919 .48927 m .22705 .48767 L .23887 .48093 L p 0 .458 1 r
F P
0 g
s
.59091 .35878 m
.60557 .37217 L
s
.48724 .45216 m .48111 .4572 L p .46844 .44543 L 0 .432 .873 r
F P
0 g
s
.46844 .44543 m .48126 .43297 L .48724 .45216 L p 0 .432 .873 r
F P
0 g
s
.51446 .79202 m .51448 .81135 L .5 .81487 L p 0 .181 .719 r
F P
0 g
s
.48374 .77705 m .51448 .81135 L .5 .81487 L p 0 .305 .956 r
F P
0 g
s
.5 .81487 m .46954 .78091 L .48374 .77705 L p 0 .305 .956 r
F P
0 g
s
.45558 .45793 m .4579 .46513 L .44676 .47063 L p 0 .312 .948 r
F P
0 g
s
.45501 .45728 m .45558 .45793 L p .44676 .47063 L 0 .312 .948 r
F P
0 g
s
.38378 .32239 m .37055 .33067 L .39607 .35959 L p 0 .314 .946 r
F P
0 g
s
.42249 .33932 m .40953 .3516 L .39607 .35959 L p 0 .05 .1 r
F P
0 g
s
.39607 .35959 m .40953 .3516 L .38378 .32239 L p 0 .314 .946 r
F P
0 g
s
.39607 .35959 m .38316 .37182 L .39652 .36393 L p 0 .05 .1 r
F P
0 g
s
.39652 .36393 m .40953 .3516 L .39607 .35959 L p 0 .05 .1 r
F P
0 g
s
.39652 .36393 m .38316 .37182 L .39607 .35959 L p 0 .05 .1 r
F P
0 g
s
.39607 .35959 m .40953 .3516 L .39652 .36393 L p 0 .05 .1 r
F P
0 g
s
.40953 .3516 m .39607 .35959 L .37055 .33067 L p 0 .314 .946 r
F P
0 g
s
.43805 .68035 m .42265 .69583 L .45378 .73059 L p 0 .349 .781 r
F P
0 g
s
.48323 .71056 m .45192 .67551 L .43805 .68035 L p 0 .307 .954 r
F P
0 g
s
.40692 .64553 m .43805 .68035 L .45192 .67551 L p 0 .307 .954 r
F P
0 g
s
.45378 .73059 m .42265 .69583 L .43805 .68035 L p 0 .349 .781 r
F P
0 g
s
.40692 .64553 m .39415 .63126 L .40848 .61707 L p 0 .349 .781 r
F P
0 g
s
.40848 .61707 m .39415 .63126 L .40692 .64553 L p 0 .349 .781 r
F P
0 g
s
.62156 .71166 m .60638 .69453 L .63682 .66301 L p 0 .35 .78 r
F P
0 g
s
.26258 .41726 m .27806 .43463 L .31017 .40442 L p 0 .349 .781 r
F P
0 g
s
.31017 .40442 m .29479 .38711 L .26258 .41726 L p 0 .349 .781 r
F P
0 g
s
.26258 .41726 m .29479 .38711 L .31017 .40442 L p 0 .349 .781 r
F P
0 g
s
.31017 .40442 m .27806 .43463 L .26258 .41726 L p 0 .349 .781 r
F P
0 g
s
.60557 .37217 m
.61121 .3693 L
s
.45145 .28001 m .46671 .29741 L .43539 .32709 L p 0 .35 .78 r
F P
0 g
s
.21832 .45478 m .23377 .47204 L .24564 .46515 L p 0 .307 .954 r
F P
0 g
s
.2612 .48256 m .24564 .46515 L .23377 .47204 L p 0 .307 .954 r
F P
0 g
s
.23377 .47204 m .24564 .46515 L .2612 .48256 L p 0 .307 .954 r
F P
0 g
s
.24564 .46515 m .23377 .47204 L .21832 .45478 L p 0 .307 .954 r
F P
0 g
s
.57603 .54049 m .57659 .54113 L .56405 .55374 L p 0 .35 .78 r
F P
0 g
s
.56405 .55374 m .56348 .5531 L .57603 .54049 L p 0 .35 .78 r
F P
0 g
s
.36857 .60264 m .38297 .58851 L .39573 .6028 L p 0 .349 .781 r
F P
0 g
s
.39573 .6028 m .38137 .61696 L .36857 .60264 L p 0 .349 .781 r
F P
0 g
s
.36857 .60264 m .38137 .61696 L .39573 .6028 L p 0 .349 .781 r
F P
0 g
s
.39573 .6028 m .38297 .58851 L .36857 .60264 L p 0 .349 .781 r
F P
0 g
s
.39573 .6028 m .38137 .61696 L .39472 .61148 L p 0 .05 .1 r
F P
0 g
s
.39472 .61148 m .38137 .61696 L .39573 .6028 L p 0 .05 .1 r
F P
0 g
s
.45378 .73059 m .43841 .7462 L .46954 .78091 L p 0 .349 .781 r
F P
0 g
s
.43841 .7462 m .45378 .73059 L .42265 .69583 L p 0 .349 .781 r
F P
0 g
s
.46954 .78091 m .43841 .7462 L .45378 .73059 L p 0 .349 .781 r
F P
0 g
s
.42265 .69583 m .45378 .73059 L .43841 .7462 L p 0 .349 .781 r
F P
0 g
s
.55454 .5699 m
.558 .57382 L
s
.2748 .40979 m .26258 .41726 L .29479 .38711 L p 0 .05 .1 r
F P
0 g
s
.29479 .38711 m .30726 .37938 L .2748 .40979 L p 0 .05 .1 r
F P
0 g
s
.48111 .4572 m .47433 .46097 L p .46844 .44543 L 0 .432 .873 r
F P
0 g
s
.52914 .74127 m .51443 .7455 L .54537 .71368 L p 0 .05 .218 r
F P
0 g
s
.54537 .71368 m .56031 .70916 L .52914 .74127 L p 0 .05 .218 r
F P
0 g
s
.36544 .32488 m .37055 .33067 L .38378 .32239 L p 0 .314 .946 r
F P
0 g
s
.37055 .33067 m .38378 .32239 L .40953 .3516 L p 0 .314 .946 r
F P
0 g
s
.38378 .32239 m .37862 .31654 L .36544 .32488 L p 0 .314 .946 r
F P
0 g
s
.37862 .31654 m .38378 .32239 L .37055 .33067 L p 0 .314 .946 r
F P
0 g
s
.37055 .33067 m .36544 .32488 L .37862 .31654 L p 0 .314 .946 r
F P
0 g
s
.43617 .26258 m .45145 .28001 L .42003 .30963 L p 0 .35 .78 r
F P
0 g
s
.43539 .32709 m .42003 .30963 L .45145 .28001 L p 0 .35 .78 r
F P
0 g
s
.29271 .58376 m .28037 .5895 L .24893 .55448 L p 0 .305 .956 r
F P
0 g
s
.28037 .5895 m .29271 .58376 L .32433 .61901 L p 0 .305 .956 r
F P
0 g
s
.24564 .46515 m .23005 .44772 L .21832 .45478 L p 0 .307 .954 r
F P
0 g
s
.21832 .45478 m .23005 .44772 L .24564 .46515 L p 0 .307 .954 r
F P
0 g
s
.18631 .48473 m .21832 .45478 L .23005 .44772 L p 0 .05 .1 r
F P
0 g
s
.26258 .41726 m .23005 .44772 L .21832 .45478 L p 0 .05 .1 r
F P
0 g
s
.66044 .54279 m .68851 .52355 L .66728 .54809 L .228 0 0 r
F
0 g
.66044 .54279 m
.66364 .53584 L
s
.38297 .58851 m .36857 .60264 L .35575 .58831 L p 0 .349 .781 r
F P
0 g
s
.35575 .58831 m .36857 .60264 L .38297 .58851 L p 0 .349 .781 r
F P
0 g
s
.61607 .4551 m
.62661 .47043 L
s
.48374 .77705 m .46954 .78091 L .43841 .7462 L p 0 .305 .956 r
F P
0 g
s
.35237 .34114 m .33939 .34928 L .36544 .32488 L p 0 .05 .1 r
F P
0 g
s
.36544 .32488 m .37862 .31654 L .35237 .34114 L p 0 .05 .1 r
F P
0 g
s
.40692 .64553 m .39142 .66095 L .42265 .69583 L p 0 .349 .781 r
F P
0 g
s
.42265 .69583 m .39142 .66095 L .40692 .64553 L p 0 .349 .781 r
F P
0 g
s
.40488 .6559 m .39142 .66095 L .40692 .64553 L p 0 .05 .112 r
F P
0 g
s
.45192 .67551 m .4205 .64035 L .40692 .64553 L p 0 .307 .954 r
F P
0 g
s
.40692 .64553 m .4205 .64035 L .40488 .6559 L p 0 .05 .112 r
F P
0 g
s
.39415 .63126 m .40692 .64553 L .38718 .64442 L closepath p 0 .349 .781 r
F P
0 g
s
.40762 .62592 m .39415 .63126 L .40692 .64553 L p 0 .307 .954 r
F P
0 g
s
.40692 .64553 m .4205 .64035 L .40762 .62592 L p 0 .307 .954 r
F P
0 g
s
.4205 .64035 m .40692 .64553 L .39142 .66095 L p 0 .05 .112 r
F P
0 g
s
.39142 .66095 m .40692 .64553 L .38718 .64442 L closepath p 0 .349 .781 r
F P
0 g
s
.38718 .64442 m .40692 .64553 L .39415 .63126 L closepath p 0 .349 .781 r
F P
0 g
s
.4205 .64035 m .40692 .64553 L .39415 .63126 L p 0 .307 .954 r
F P
0 g
s
.43585 .32698 m .45763 .30601 L .4612 .30503 L .1 0 0 r
F
0 g
.45763 .30601 m
.46697 .29716 L
s
.45868 .30721 m
.45918 .30778 L
s
.43585 .32698 m .43539 .32709 L .45763 .30601 L .1 0 0 r
F
0 g
.43665 .3259 m
.45763 .30601 L
s
.38345 .37632 m .3702 .38409 L .38316 .37182 L p 0 .05 .1 r
F P
0 g
s
.38316 .37182 m .39652 .36393 L .38345 .37632 L p 0 .05 .1 r
F P
0 g
s
.39652 .36393 m .38316 .37182 L .3702 .38409 L p 0 .05 .1 r
F P
0 g
s
.21644 .47929 m .23887 .48093 L .22705 .48767 L p 0 .458 1 r
F P
0 g
s
.22705 .48767 m .20481 .48607 L .21644 .47929 L p 0 .458 1 r
F P
0 g
s
.20481 .48607 m .22705 .48767 L .23887 .48093 L p 0 .458 1 r
F P
0 g
s
.2612 .48256 m .23887 .48093 L .22705 .48767 L p 0 .458 1 r
F P
0 g
s
.42003 .30963 m .40465 .29213 L .43617 .26258 L p 0 .35 .78 r
F P
0 g
s
.21739 .51934 m .23333 .50427 L .24521 .49769 L p 0 .05 .1 r
F P
0 g
s
.24521 .49769 m .22914 .51289 L .21739 .51934 L p 0 .05 .1 r
F P
0 g
s
.23333 .50427 m .21739 .51934 L .22914 .51289 L p 0 .05 .1 r
F P
0 g
s
.22914 .51289 m .24521 .49769 L .23333 .50427 L p 0 .05 .1 r
F P
0 g
s
.54271 .3837 m
.55744 .39149 L
s
.36735 .64329 m .38137 .61696 L .39415 .63126 L p 0 .349 .781 r
F P
0 g
s
.39415 .63126 m .38718 .64442 L .36735 .64329 L p 0 .349 .781 r
F P
0 g
s
.39415 .63126 m .40762 .62592 L .39472 .61148 L p 0 .307 .954 r
F P
0 g
s
.39472 .61148 m .38137 .61696 L .39415 .63126 L p 0 .307 .954 r
F P
0 g
s
.38718 .64442 m .39415 .63126 L .38137 .61696 L p 0 .349 .781 r
F P
0 g
s
.39415 .63126 m .40762 .62592 L .4205 .64035 L p 0 .307 .954 r
F P
0 g
s
.40762 .62592 m .39415 .63126 L .38137 .61696 L p 0 .307 .954 r
F P
0 g
s
.42265 .69583 m .40718 .71138 L .43841 .7462 L p 0 .349 .781 r
F P
0 g
s
.40718 .71138 m .42265 .69583 L .39142 .66095 L p 0 .349 .781 r
F P
0 g
s
.43841 .7462 m .40718 .71138 L .42265 .69583 L p 0 .349 .781 r
F P
0 g
s
.39142 .66095 m .42265 .69583 L .40718 .71138 L p 0 .349 .781 r
F P
0 g
s
.56348 .5531 m .56405 .55374 L .55145 .5664 L p 0 .35 .78 r
F P
0 g
s
.47433 .46097 m .47347 .46127 L .46844 .44543 L p 0 .432 .873 r
F P
0 g
s
.56348 .5531 m .55088 .56577 L .54284 .56121 L p 0 .275 .686 r
F P
0 g
s
.55145 .5664 m .55088 .56577 L .56348 .5531 L p 0 .35 .78 r
F P
0 g
s
.68777 .44619 m .66614 .41424 L .69911 .38131 L .886 0 0 r
F
0 g
.68777 .44619 m
.69449 .47318 L
s
.65543 .33103 m .69911 .38131 L .66614 .41424 L p .859 0 0 r
F P
0 g
s
.69911 .38131 m
.72049 .41321 L
s
.61643 .5162 m .68379 .59287 L .64074 .63729 L p .859 0 0 r
F P
0 g
s
.68379 .59287 m .66728 .54809 L .70122 .58677 L .554 0 0 r
F
.68379 .59287 m .65017 .5546 L .66728 .54809 L F
.65784 .63162 m .70122 .58677 L .68379 .59287 L p .262 0 0 r
F P
0 g
s
.68379 .59287 m .64074 .63729 L .65784 .63162 L p .262 0 0 r
F P
0 g
s
.64074 .63729 m .68379 .59287 L .65017 .5546 L p .859 0 0 r
F P
0 g
s
.65017 .5546 m .68379 .59287 L .70122 .58677 L p .554 0 0 r
F P
0 g
s
.47347 .46127 m .46667 .46359 L p .45558 .45793 L 0 .432 .873 r
F P
0 g
s
.45558 .45793 m .46844 .44543 L .47347 .46127 L p 0 .432 .873 r
F P
0 g
s
.26098 .54839 m .24893 .55448 L .21739 .51934 L p 0 .305 .956 r
F P
0 g
s
.24893 .55448 m .26098 .54839 L .29271 .58376 L p 0 .305 .956 r
F P
0 g
s
.38137 .61696 m .35535 .64261 L .35544 .63 L closepath p 0 .349 .781 r
F P
0 g
s
.36735 .64329 m .35535 .64261 L .38137 .61696 L closepath p 0 .349 .781 r
F P
0 g
s
.3556 .60913 m .36857 .60264 L .38137 .61696 L p 0 .349 .781 r
F P
0 g
s
.38137 .61696 m .35544 .63 L .3556 .60913 L p 0 .349 .781 r
F P
0 g
s
.35544 .63 m .35535 .64261 L .38137 .61696 L closepath p 0 .349 .781 r
F P
0 g
s
.38137 .61696 m .35535 .64261 L .36735 .64329 L closepath p 0 .349 .781 r
F P
0 g
s
.38137 .61696 m .36735 .64329 L .38718 .64442 L p 0 .349 .781 r
F P
0 g
s
.38137 .61696 m .39472 .61148 L .40762 .62592 L p 0 .307 .954 r
F P
0 g
s
.39472 .61148 m .38137 .61696 L .35535 .64261 L p 0 .05 .1 r
F P
0 g
s
.38137 .61696 m .39472 .61148 L .3818 .59702 L p 0 .307 .954 r
F P
0 g
s
.3818 .59702 m .36857 .60264 L .38137 .61696 L p 0 .307 .954 r
F P
0 g
s
.35544 .63 m .38137 .61696 L .36857 .60264 L p 0 .349 .781 r
F P
0 g
s
.35535 .64261 m .3685 .63737 L .39472 .61148 L p 0 .05 .1 r
F P
0 g
s
.3685 .63737 m .35535 .64261 L .38137 .61696 L p 0 .05 .1 r
F P
0 g
s
.38137 .61696 m .39472 .61148 L .3685 .63737 L p 0 .05 .1 r
F P
0 g
s
.3818 .59702 m .39472 .61148 L .38137 .61696 L p 0 .307 .954 r
F P
0 g
s
.38137 .61696 m .36857 .60264 L .3818 .59702 L p 0 .307 .954 r
F P
0 g
s
.54284 .56121 m .55088 .56577 L .55145 .5664 L p 0 .312 .948 r
F P
0 g
s
.43841 .7462 m .45233 .742 L .48374 .77705 L p 0 .305 .956 r
F P
0 g
s
.45233 .742 m .43841 .7462 L .40718 .71138 L p 0 .305 .956 r
F P
0 g
s
.52526 .38875 m
.52917 .38254 L
s
.3556 .60913 m .35575 .58831 L .36857 .60264 L closepath p 0 .349 .781 r
F P
0 g
s
.36887 .58254 m .35575 .58831 L .36857 .60264 L p 0 .307 .954 r
F P
0 g
s
.36857 .60264 m .3818 .59702 L .36887 .58254 L p 0 .307 .954 r
F P
0 g
s
.36857 .60264 m .3556 .60913 L .35544 .63 L p 0 .349 .781 r
F P
0 g
s
.36857 .60264 m .35575 .58831 L .3556 .60913 L closepath p 0 .349 .781 r
F P
0 g
s
.36887 .58254 m .3818 .59702 L .36857 .60264 L p 0 .307 .954 r
F P
0 g
s
.36857 .60264 m .35575 .58831 L .36887 .58254 L p 0 .307 .954 r
F P
0 g
s
.36735 .64329 m .38718 .64442 L .39142 .66095 L p 0 .349 .781 r
F P
0 g
s
.38718 .64442 m .36735 .64329 L .37584 .67644 L p 0 .349 .781 r
F P
0 g
s
.37584 .67644 m .39142 .66095 L .38718 .64442 L p 0 .349 .781 r
F P
0 g
s
.62213 .36377 m .62495 .3033 L .65543 .33103 L .832 0 0 r
F
.62213 .36377 m .59153 .33585 L .62495 .3033 L F
0 g
.59422 .28783 m
.62495 .3033 L
s
.56084 .32008 m
.59153 .33585 L
s
.36792 .35875 m .35481 .3667 L .3702 .38409 L p 0 .312 .948 r
F P
0 g
s
.3702 .38409 m .38345 .37632 L .39652 .36393 L p 0 .05 .1 r
F P
0 g
s
.3702 .38409 m .38345 .37632 L .36792 .35875 L p 0 .312 .948 r
F P
0 g
s
.35128 .40681 m .38345 .37632 L .3702 .38409 L p 0 .05 .1 r
F P
0 g
s
.3702 .38409 m .33828 .41432 L .35128 .40681 L p 0 .05 .1 r
F P
0 g
s
.38345 .37632 m .3702 .38409 L .35481 .3667 L p 0 .312 .948 r
F P
0 g
s
.39142 .66095 m .37584 .67644 L .36735 .64329 L p 0 .349 .781 r
F P
0 g
s
.39142 .66095 m .37584 .67644 L .40718 .71138 L p 0 .349 .781 r
F P
0 g
s
.40718 .71138 m .37584 .67644 L .39142 .66095 L p 0 .349 .781 r
F P
0 g
s
.38919 .67153 m .37584 .67644 L .39142 .66095 L p 0 .05 .112 r
F P
0 g
s
.39142 .66095 m .40488 .6559 L .38919 .67153 L p 0 .05 .112 r
F P
0 g
s
.38919 .67153 m .40488 .6559 L .39142 .66095 L p 0 .05 .112 r
F P
0 g
s
.39142 .66095 m .37584 .67644 L .38919 .67153 L p 0 .05 .112 r
F P
0 g
s
.39142 .66095 m .40488 .6559 L .4205 .64035 L p 0 .05 .112 r
F P
0 g
s
.60638 .69453 m .62156 .71166 L .59091 .74356 L p 0 .35 .78 r
F P
0 g
s
.19778 .47793 m .21644 .47929 L .20481 .48607 L p 0 .458 1 r
F P
0 g
s
.20481 .48607 m .18631 .48473 L .19778 .47793 L p 0 .458 1 r
F P
0 g
s
.18631 .48473 m .20481 .48607 L .21644 .47929 L p 0 .458 1 r
F P
0 g
s
.23887 .48093 m .21644 .47929 L .20481 .48607 L p 0 .458 1 r
F P
0 g
s
.24564 .46515 m .2612 .48256 L .29352 .45197 L p 0 .349 .781 r
F P
0 g
s
.29352 .45197 m .27806 .43463 L .24564 .46515 L p 0 .349 .781 r
F P
0 g
s
.27345 .47572 m .30603 .44486 L .29352 .45197 L p 0 .05 .1 r
F P
0 g
s
.29352 .45197 m .2612 .48256 L .27345 .47572 L p 0 .05 .1 r
F P
0 g
s
.34008 .60362 m .35575 .58831 L .3556 .60913 L closepath p 0 .349 .781 r
F P
0 g
s
.35575 .58831 m .32434 .55318 L .30856 .56843 L p 0 .349 .781 r
F P
0 g
s
.3556 .60913 m .35575 .58831 L .34008 .60362 L closepath p 0 .349 .781 r
F P
0 g
s
.35308 .59799 m .36887 .58254 L .35575 .58831 L p 0 .05 .1 r
F P
0 g
s
.35575 .58831 m .34008 .60362 L .35308 .59799 L p 0 .05 .1 r
F P
0 g
s
.33717 .54705 m .32434 .55318 L .35575 .58831 L p 0 .307 .954 r
F P
0 g
s
.35575 .58831 m .36887 .58254 L .33717 .54705 L p 0 .307 .954 r
F P
0 g
s
.24564 .46515 m .27806 .43463 L .29352 .45197 L p 0 .349 .781 r
F P
0 g
s
.29352 .45197 m .2612 .48256 L .24564 .46515 L p 0 .349 .781 r
F P
0 g
s
.35575 .58831 m .36887 .58254 L .35308 .59799 L p 0 .05 .1 r
F P
0 g
s
.35308 .59799 m .34008 .60362 L .35575 .58831 L p 0 .05 .1 r
F P
0 g
s
.30856 .56843 m .32434 .55318 L .35575 .58831 L p 0 .349 .781 r
F P
0 g
s
.35575 .58831 m .34008 .60362 L .30856 .56843 L p 0 .349 .781 r
F P
0 g
s
.56804 .63202 m
.56984 .63404 L
s
.60009 .66819 m .53923 .65753 L .57326 .69583 L .858 0 0 r
F
.59117 .67738 m .60638 .69453 L .57563 .72638 L p 0 .35 .78 r
F P
0 g
s
.57563 .72638 m .56031 .70916 L .59117 .67738 L p 0 .35 .78 r
F P
0 g
s
.61118 .66224 m .60009 .66819 L .57326 .69583 L .262 0 0 r
F
0 g
.57091 .63526 m
.60009 .66819 L
s
.57091 .63526 m
.60009 .66819 L
s
.21644 .47929 m .19778 .47793 L .18631 .48473 L p 0 .458 1 r
F P
0 g
s
.21739 .51934 m .18631 .48473 L .19778 .47793 L p 0 .305 .956 r
F P
0 g
s
.19778 .47793 m .22914 .51289 L .21739 .51934 L p 0 .305 .956 r
F P
0 g
s
.21739 .51934 m .22914 .51289 L .26098 .54839 L p 0 .305 .956 r
F P
0 g
s
.55995 .7758 m .54496 .77968 L .52971 .7626 L p 0 .307 .954 r
F P
0 g
s
.55995 .7758 m .54496 .77968 L .51448 .81135 L p 0 .05 .248 r
F P
0 g
s
.54456 .75855 m .52971 .7626 L .54496 .77968 L p 0 .307 .954 r
F P
0 g
s
.54496 .77968 m .55995 .7758 L .54456 .75855 L p 0 .307 .954 r
F P
0 g
s
.65017 .5546 m .6068 .59883 L .64074 .63729 L p .859 0 0 r
F P
0 g
s
.70122 .58677 m .66728 .54809 L .65017 .5546 L p .554 0 0 r
F P
0 g
s
.64074 .63729 m .57274 .56023 L .61643 .5162 L p .859 0 0 r
F P
0 g
s
.62357 .59274 m .6068 .59883 L .65017 .5546 L p .228 0 0 r
F P
0 g
s
.65017 .5546 m .66728 .54809 L .62357 .59274 L p .228 0 0 r
F P
0 g
s
.65017 .5546 m
.66044 .54279 L
s
.65525 .56038 m
.68379 .59287 L
s
.61643 .5162 m
.65017 .5546 L
s
.65525 .56038 m
.68379 .59287 L
s
.35237 .34114 m .33939 .34928 L .35481 .3667 L p 0 .312 .948 r
F P
0 g
s
.35481 .3667 m .36792 .35875 L .35237 .34114 L p 0 .312 .948 r
F P
0 g
s
.36792 .35875 m .35481 .3667 L .33939 .34928 L p 0 .312 .948 r
F P
0 g
s
.35481 .3667 m .36792 .35875 L .38345 .37632 L p 0 .312 .948 r
F P
0 g
s
.46667 .46359 m .4579 .46513 L .45558 .45793 L p 0 .432 .873 r
F P
0 g
s
.40718 .71138 m .42081 .70683 L .45233 .742 L p 0 .305 .956 r
F P
0 g
s
.42081 .70683 m .40718 .71138 L .37584 .67644 L p 0 .305 .956 r
F P
0 g
s
.59091 .74356 m .57563 .72638 L .60638 .69453 L p 0 .35 .78 r
F P
0 g
s
.55571 .56875 m .54316 .58538 L .53232 .59168 L .191 0 0 r
F
0 g
.53232 .59168 m
.56627 .63001 L
s
.55768 .56722 m .54316 .58538 L .55571 .56875 L .191 0 0 r
F
0 g
.55427 .5696 m
.55571 .56875 L
s
.23005 .44772 m .24564 .46515 L .27806 .43463 L p 0 .349 .781 r
F P
0 g
s
.27806 .43463 m .26258 .41726 L .23005 .44772 L p 0 .349 .781 r
F P
0 g
s
.23005 .44772 m .26258 .41726 L .27806 .43463 L p 0 .349 .781 r
F P
0 g
s
.27806 .43463 m .24564 .46515 L .23005 .44772 L p 0 .349 .781 r
F P
0 g
s
.66614 .41424 m .62213 .36377 L .65543 .33103 L p .859 0 0 r
F P
0 g
s
.66614 .41424 m
.68777 .44619 L
s
.62495 .3033 m
.65543 .33103 L
s
.61121 .3693 m
.62213 .36377 L
s
.66614 .41424 m
.69911 .38131 L
s
.65495 .41942 m
.66614 .41424 L
s
.62213 .36377 m
.65543 .33103 L
s
.55744 .39149 m
.57216 .40497 L
s
.55963 .56542 m .55798 .57384 L .55768 .56722 L .191 0 0 r
F
.55963 .56542 m .57274 .56023 L .55798 .57384 L F
0 g
.55963 .56542 m
.57274 .56023 L
s
.55768 .56722 m .55798 .57384 L .54316 .58538 L .191 0 0 r
F
0 g
.55768 .56722 m
.55963 .56542 L
s
.55571 .56875 m
.55768 .56722 L
s
.53232 .59168 m
.55427 .5696 L
s
.3556 .60913 m .35544 .63 L .32433 .61901 L p 0 .349 .781 r
F P
0 g
s
.32433 .61901 m .34008 .60362 L .3556 .60913 L p 0 .349 .781 r
F P
0 g
s
.35544 .63 m .3556 .60913 L .34008 .60362 L p 0 .349 .781 r
F P
0 g
s
.52971 .7626 m .54456 .75855 L .55995 .7758 L p 0 .307 .954 r
F P
0 g
s
.54456 .75855 m .52971 .7626 L .51443 .7455 L p 0 .307 .954 r
F P
0 g
s
.52914 .74127 m .51443 .7455 L .52971 .7626 L p 0 .307 .954 r
F P
0 g
s
.52971 .7626 m .54456 .75855 L .52914 .74127 L p 0 .307 .954 r
F P
0 g
s
.41563 .32529 m .42003 .30963 L .43539 .32709 L closepath p 0 .35 .78 r
F P
0 g
s
.41563 .32529 m .43539 .32709 L .42249 .33932 L closepath p 0 .35 .78 r
F P
0 g
s
.43539 .32709 m
.43665 .3259 L
s
.43539 .32709 m
.43559 .32732 L
s
.45692 .31087 m .49525 .34386 L .4612 .30503 L .98 0 0 r
F
.45692 .31087 m .49115 .34988 L .49525 .34386 L F
.31999 .3715 m .30726 .37938 L .33939 .34928 L p 0 .05 .1 r
F P
0 g
s
.33939 .34928 m .35237 .34114 L .36792 .35875 L p 0 .312 .948 r
F P
0 g
s
.33939 .34928 m .35237 .34114 L .31999 .3715 L p 0 .05 .1 r
F P
0 g
s
.35012 .64777 m .35535 .64261 L .36735 .64329 L p 0 .349 .781 r
F P
0 g
s
.36735 .64329 m .37584 .67644 L .35012 .64777 L p 0 .349 .781 r
F P
0 g
s
.37584 .67644 m .36735 .64329 L .35535 .64261 L p 0 .349 .781 r
F P
0 g
s
.24201 .44052 m .23005 .44772 L .26258 .41726 L p 0 .05 .1 r
F P
0 g
s
.26258 .41726 m .2748 .40979 L .24201 .44052 L p 0 .05 .1 r
F P
0 g
s
.32434 .55318 m .29282 .51793 L .27694 .53312 L p 0 .349 .781 r
F P
0 g
s
.30536 .51145 m .29282 .51793 L .32434 .55318 L p 0 .307 .954 r
F P
0 g
s
.32434 .55318 m .33717 .54705 L .30536 .51145 L p 0 .307 .954 r
F P
0 g
s
.27694 .53312 m .29282 .51793 L .32434 .55318 L p 0 .349 .781 r
F P
0 g
s
.32434 .55318 m .30856 .56843 L .27694 .53312 L p 0 .349 .781 r
F P
0 g
s
.43526 .32777 m .43585 .32698 L .4612 .30503 L .1 0 0 r
F
0 g
.43539 .32709 m
.43585 .32698 L
s
.23005 .44772 m .19778 .47793 L .18631 .48473 L p 0 .05 .1 r
F P
0 g
s
.51443 .7455 m .52914 .74127 L .54456 .75855 L p 0 .307 .954 r
F P
0 g
s
.52918 .76473 m .51445 .76873 L .51443 .7455 L p 0 .181 .719 r
F P
0 g
s
.51443 .7455 m .52914 .74127 L .52918 .76473 L p 0 .181 .719 r
F P
0 g
s
.52914 .74127 m .51443 .7455 L .51445 .76873 L p 0 .181 .719 r
F P
0 g
s
.51443 .7455 m .52914 .74127 L .51372 .75715 L p 0 .05 .218 r
F P
0 g
s
.51372 .75715 m .52914 .74127 L .51443 .7455 L p 0 .05 .218 r
F P
0 g
s
.51372 .75715 m .49912 .76123 L .51443 .7455 L p 0 .05 .218 r
F P
0 g
s
.51443 .7455 m .49912 .76123 L .51372 .75715 L p 0 .05 .218 r
F P
0 g
s
.48323 .71056 m .51443 .7455 L .52914 .74127 L p 0 .307 .954 r
F P
0 g
s
.55702 .63942 m
.56627 .63001 L
s
.40465 .29213 m .42003 .30963 L .41563 .32529 L p 0 .35 .78 r
F P
0 g
s
.72217 .562 m .66728 .54809 L .68851 .52355 L .89 0 0 r
F
0 g
.68851 .52355 m
.69485 .50938 L
s
.72217 .562 m .70122 .58677 L .66728 .54809 L .89 0 0 r
F
0 g
.72217 .562 m
.72815 .54746 L
s
.32433 .61901 m .35544 .63 L .35535 .64261 L p 0 .349 .781 r
F P
0 g
s
.35012 .64777 m .35535 .64261 L .35544 .63 L p 0 .349 .781 r
F P
0 g
s
.35544 .63 m .32433 .61901 L .35012 .64777 L p 0 .349 .781 r
F P
0 g
s
.34008 .60362 m .32433 .61901 L .35544 .63 L p 0 .349 .781 r
F P
0 g
s
.37584 .67644 m .38919 .67153 L .42081 .70683 L p 0 .305 .956 r
F P
0 g
s
.35535 .64261 m .35012 .64777 L .37584 .67644 L p 0 .349 .781 r
F P
0 g
s
.38919 .67153 m .37584 .67644 L .35012 .64777 L p 0 .305 .956 r
F P
0 g
s
.61643 .5162 m
.62683 .50449 L
s
.60305 .52172 m
.61643 .5162 L
s
.29271 .58376 m .32433 .61901 L .34008 .60362 L p 0 .349 .781 r
F P
0 g
s
.34008 .60362 m .30856 .56843 L .29271 .58376 L p 0 .349 .781 r
F P
0 g
s
.3372 .61352 m .35308 .59799 L .34008 .60362 L p 0 .05 .1 r
F P
0 g
s
.34008 .60362 m .32433 .61901 L .3372 .61352 L p 0 .05 .1 r
F P
0 g
s
.32433 .61901 m .34008 .60362 L .35308 .59799 L p 0 .05 .1 r
F P
0 g
s
.29271 .58376 m .30856 .56843 L .34008 .60362 L p 0 .349 .781 r
F P
0 g
s
.34008 .60362 m .32433 .61901 L .29271 .58376 L p 0 .349 .781 r
F P
0 g
s
.49115 .34988 m .51833 .32913 L .52652 .31688 L .1 0 0 r
F
.48391 .28981 m .52652 .31688 L .51833 .32913 L .982 0 0 r
F
.48391 .28981 m .49248 .27796 L .52652 .31688 L F
.43526 .32777 m .4612 .30503 L .45692 .31087 L .1 0 0 r
F
.43379 .32925 m .43526 .32777 L .45692 .31087 L F
0 g
.43526 .32777 m
.43585 .32698 L
s
.35535 .64261 m .35012 .64777 L .32433 .61901 L p 0 .349 .781 r
F P
0 g
s
.3685 .63737 m .35535 .64261 L .35012 .64777 L p 0 .05 .1 r
F P
0 g
s
.35012 .64777 m .36323 .64257 L .3685 .63737 L p 0 .05 .1 r
F P
0 g
s
.35535 .64261 m .3685 .63737 L .36323 .64257 L p 0 .05 .1 r
F P
0 g
s
.36323 .64257 m .35012 .64777 L .35535 .64261 L p 0 .05 .1 r
F P
0 g
s
.37862 .31654 m .40465 .29213 L .39579 .32348 L p 0 .35 .78 r
F P
0 g
s
.41563 .32529 m .39579 .32348 L .40465 .29213 L p 0 .35 .78 r
F P
0 g
s
.45692 .31087 m .4612 .30503 L .49248 .27796 L .1 0 0 r
F
0 g
.45763 .30601 m
.4612 .30503 L
s
.45763 .30601 m
.4612 .30503 L
s
.38873 .37196 m .43379 .32925 L .44585 .32202 L p .1 0 0 r
F P
0 g
s
.43544 .33112 m
.43581 .33155 L
s
.43379 .32925 m .45692 .31087 L .44585 .32202 L .1 0 0 r
F
0 g
.43379 .32925 m
.43526 .32777 L
s
.52921 .78824 m .51446 .79202 L .51445 .76873 L p 0 .181 .719 r
F P
0 g
s
.51445 .76873 m .52918 .76473 L .52921 .78824 L p 0 .181 .719 r
F P
0 g
s
.52918 .76473 m .51445 .76873 L .51446 .79202 L p 0 .181 .719 r
F P
0 g
s
.51445 .76873 m .52918 .76473 L .52914 .74127 L p 0 .181 .719 r
F P
0 g
s
.42249 .33932 m .40953 .3516 L .39579 .32348 L p 0 .35 .78 r
F P
0 g
s
.39579 .32348 m .41563 .32529 L .42249 .33932 L p 0 .35 .78 r
F P
0 g
s
.24521 .49769 m .27694 .53312 L .29282 .51793 L p 0 .349 .781 r
F P
0 g
s
.29282 .51793 m .2612 .48256 L .24521 .49769 L p 0 .349 .781 r
F P
0 g
s
.27345 .47572 m .2612 .48256 L .29282 .51793 L p 0 .307 .954 r
F P
0 g
s
.29282 .51793 m .30536 .51145 L .27345 .47572 L p 0 .307 .954 r
F P
0 g
s
.24521 .49769 m .2612 .48256 L .29282 .51793 L p 0 .349 .781 r
F P
0 g
s
.29282 .51793 m .27694 .53312 L .24521 .49769 L p 0 .349 .781 r
F P
0 g
s
.36323 .64257 m .35012 .64777 L .32433 .61901 L p 0 .305 .956 r
F P
0 g
s
.35012 .64777 m .36323 .64257 L .38919 .67153 L p 0 .305 .956 r
F P
0 g
s
.52914 .74127 m .49766 .70599 L .48323 .71056 L p 0 .307 .954 r
F P
0 g
s
.45192 .67551 m .48323 .71056 L .49766 .70599 L p 0 .307 .954 r
F P
0 g
s
.53232 .59168 m
.54316 .58538 L
s
.26098 .54839 m .29271 .58376 L .30856 .56843 L p 0 .349 .781 r
F P
0 g
s
.30856 .56843 m .27694 .53312 L .26098 .54839 L p 0 .349 .781 r
F P
0 g
s
.26098 .54839 m .27694 .53312 L .30856 .56843 L p 0 .349 .781 r
F P
0 g
s
.30856 .56843 m .29271 .58376 L .26098 .54839 L p 0 .349 .781 r
F P
0 g
s
.51448 .81135 m .52924 .80776 L .55995 .7758 L p 0 .05 .248 r
F P
0 g
s
.52924 .80776 m .51448 .81135 L .51446 .79202 L p 0 .181 .719 r
F P
0 g
s
.51446 .79202 m .52921 .78824 L .52924 .80776 L p 0 .181 .719 r
F P
0 g
s
.52921 .78824 m .51446 .79202 L .51448 .81135 L p 0 .181 .719 r
F P
0 g
s
.51446 .79202 m .52921 .78824 L .52918 .76473 L p 0 .181 .719 r
F P
0 g
s
.45692 .31087 m .49248 .27796 L .48391 .28981 L .1 0 0 r
F
0 g
.48478 .28028 m
.49248 .27796 L
s
.51446 .40013 m
.52526 .38875 L
s
.49912 .76123 m .51372 .75715 L .49822 .77312 L p 0 .05 .218 r
F P
0 g
s
.49822 .77312 m .51372 .75715 L .49912 .76123 L p 0 .05 .218 r
F P
0 g
s
.49822 .77312 m .48374 .77705 L .49912 .76123 L p 0 .05 .218 r
F P
0 g
s
.49912 .76123 m .48374 .77705 L .49822 .77312 L p 0 .05 .218 r
F P
0 g
s
.61118 .66224 m .57326 .69583 L .59615 .68368 L .262 0 0 r
F
.62609 .65091 m .61118 .66224 L .59615 .68368 L F
0 g
.60009 .66819 m
.61118 .66224 L
s
.60009 .66819 m
.61118 .66224 L
s
.59615 .68368 m .57326 .69583 L .53923 .65753 L .669 0 0 r
F
0 g
.58848 .68015 m
.60009 .66819 L
s
.50396 .56692 m
.52422 .58978 L
s
.50166 .61523 m
.52552 .59125 L
s
.31878 .43761 m .35128 .40681 L .33828 .41432 L p 0 .05 .1 r
F P
0 g
s
.33828 .41432 m .30603 .44486 L .31878 .43761 L p 0 .05 .1 r
F P
0 g
s
.35308 .59799 m .3372 .61352 L .32433 .61901 L p 0 .05 .1 r
F P
0 g
s
.30529 .57791 m .3372 .61352 L .32433 .61901 L p 0 .305 .956 r
F P
0 g
s
.32433 .61901 m .29271 .58376 L .30529 .57791 L p 0 .305 .956 r
F P
0 g
s
.32433 .61901 m .3372 .61352 L .36323 .64257 L p 0 .305 .956 r
F P
0 g
s
.57563 .72638 m .59091 .74356 L .55995 .7758 L p 0 .35 .78 r
F P
0 g
s
.25774 .45813 m .27345 .47572 L .2612 .48256 L p 0 .307 .954 r
F P
0 g
s
.2612 .48256 m .24564 .46515 L .25774 .45813 L p 0 .307 .954 r
F P
0 g
s
.25733 .49098 m .24521 .49769 L .2612 .48256 L p 0 .05 .1 r
F P
0 g
s
.2612 .48256 m .27345 .47572 L .25733 .49098 L p 0 .05 .1 r
F P
0 g
s
.24564 .46515 m .2612 .48256 L .23887 .48093 L closepath p 0 .349 .781 r
F P
0 g
s
.23887 .48093 m .2612 .48256 L .24521 .49769 L closepath p 0 .349 .781 r
F P
0 g
s
.24564 .46515 m .2612 .48256 L .27345 .47572 L p 0 .307 .954 r
F P
0 g
s
.23887 .48093 m .2612 .48256 L .24564 .46515 L closepath p 0 .349 .781 r
F P
0 g
s
.2612 .48256 m .24521 .49769 L .25733 .49098 L p 0 .05 .1 r
F P
0 g
s
.25733 .49098 m .27345 .47572 L .2612 .48256 L p 0 .05 .1 r
F P
0 g
s
.24521 .49769 m .2612 .48256 L .23887 .48093 L closepath p 0 .349 .781 r
F P
0 g
s
.25093 .47405 m .27345 .47572 L .2612 .48256 L p 0 .458 1 r
F P
0 g
s
.2612 .48256 m .23887 .48093 L .25093 .47405 L p 0 .458 1 r
F P
0 g
s
.23887 .48093 m .2612 .48256 L .27345 .47572 L p 0 .458 1 r
F P
0 g
s
.59153 .33585 m
.62213 .36377 L
s
.51448 .81135 m .52924 .80776 L .52921 .78824 L p 0 .181 .719 r
F P
0 g
s
.52924 .80776 m .51448 .81135 L .48374 .77705 L p 0 .305 .956 r
F P
0 g
s
.40953 .3516 m .3837 .33486 L .38378 .32239 L closepath p 0 .35 .78 r
F P
0 g
s
.38358 .35557 m .3837 .33486 L .40953 .3516 L p 0 .35 .78 r
F P
0 g
s
.40953 .3516 m .39652 .36393 L .38358 .35557 L p 0 .35 .78 r
F P
0 g
s
.38378 .32239 m .39579 .32348 L .40953 .3516 L closepath p 0 .35 .78 r
F P
0 g
s
.49766 .70599 m .46606 .67058 L .45192 .67551 L p 0 .307 .954 r
F P
0 g
s
.4205 .64035 m .45192 .67551 L .46606 .67058 L p 0 .307 .954 r
F P
0 g
s
.39579 .32348 m .38378 .32239 L .37862 .31654 L p 0 .35 .78 r
F P
0 g
s
.43859 .46723 m
.45214 .45408 L
s
.65784 .63162 m .64074 .63729 L .6068 .59883 L p .541 0 0 r
F P
0 g
s
.64074 .63729 m .62726 .66008 L .65784 .63162 L .262 0 0 r
F
.64074 .63729 m .62609 .65091 L .62726 .66008 L F
.64074 .63729 m .62357 .59274 L .6068 .59883 L .541 0 0 r
F
.64074 .63729 m .65784 .63162 L .62357 .59274 L F
0 g
.62609 .65091 m
.64074 .63729 L
s
.55995 .7758 m .54456 .75855 L .57563 .72638 L p 0 .35 .78 r
F P
0 g
s
.56031 .70916 m .57563 .72638 L .54456 .75855 L p 0 .35 .78 r
F P
0 g
s
.22914 .51289 m .26098 .54839 L .27694 .53312 L p 0 .349 .781 r
F P
0 g
s
.27694 .53312 m .24521 .49769 L .22914 .51289 L p 0 .349 .781 r
F P
0 g
s
.22914 .51289 m .24521 .49769 L .27694 .53312 L p 0 .349 .781 r
F P
0 g
s
.27694 .53312 m .26098 .54839 L .22914 .51289 L p 0 .349 .781 r
F P
0 g
s
.24201 .44052 m .25774 .45813 L .24564 .46515 L p 0 .307 .954 r
F P
0 g
s
.24564 .46515 m .23005 .44772 L .24201 .44052 L p 0 .307 .954 r
F P
0 g
s
.21644 .47929 m .23005 .44772 L .24564 .46515 L p 0 .349 .781 r
F P
0 g
s
.24564 .46515 m .23887 .48093 L .21644 .47929 L p 0 .349 .781 r
F P
0 g
s
.23887 .48093 m .24564 .46515 L .23005 .44772 L p 0 .349 .781 r
F P
0 g
s
.23005 .44772 m .24564 .46515 L .25774 .45813 L p 0 .307 .954 r
F P
0 g
s
.27345 .47572 m .25774 .45813 L .24564 .46515 L p 0 .307 .954 r
F P
0 g
s
.44585 .32202 m .49115 .34988 L .45692 .31087 L .889 0 0 r
F
.44585 .32202 m .48022 .36115 L .49115 .34988 L F
0 g
.49115 .34988 m
.49525 .34386 L
s
.57723 .62388 m .56186 .645 L .53923 .65753 L .228 0 0 r
F
0 g
.56627 .63001 m
.57723 .62388 L
s
.28727 .40218 m .2748 .40979 L .30726 .37938 L p 0 .05 .1 r
F P
0 g
s
.30726 .37938 m .31999 .3715 L .28727 .40218 L p 0 .05 .1 r
F P
0 g
s
.59615 .68368 m .53923 .65753 L .56186 .645 L .669 0 0 r
F
0 g
.53923 .65753 m
.54971 .65173 L
s
.53923 .65753 m
.57326 .69583 L
s
.53923 .65753 m
.55702 .63942 L
s
.62609 .65091 m .59615 .68368 L .62726 .66008 L .262 0 0 r
F
0 g
.62609 .65091 m
.64074 .63729 L
s
.61118 .66224 m
.62609 .65091 L
s
.61118 .66224 m
.62609 .65091 L
s
.54456 .75855 m .52914 .74127 L .56031 .70916 L p 0 .35 .78 r
F P
0 g
s
.38378 .32239 m .3837 .33486 L .35237 .34114 L p 0 .35 .78 r
F P
0 g
s
.35237 .34114 m .37862 .31654 L .38378 .32239 L p 0 .35 .78 r
F P
0 g
s
.27327 .54218 m .30529 .57791 L .29271 .58376 L p 0 .305 .956 r
F P
0 g
s
.29271 .58376 m .26098 .54839 L .27327 .54218 L p 0 .305 .956 r
F P
0 g
s
.21644 .47929 m .19778 .47793 L .23005 .44772 L closepath p 0 .349 .781 r
F P
0 g
s
.25774 .45813 m .24201 .44052 L .23005 .44772 L p 0 .307 .954 r
F P
0 g
s
.23005 .44772 m .21644 .47929 L .23887 .48093 L p 0 .349 .781 r
F P
0 g
s
.23005 .44772 m .19778 .47793 L .21644 .47929 L closepath p 0 .349 .781 r
F P
0 g
s
.19778 .47793 m .23005 .44772 L .24201 .44052 L p 0 .05 .1 r
F P
0 g
s
.49822 .77312 m .48374 .77705 L .45233 .742 L p 0 .305 .956 r
F P
0 g
s
.48374 .77705 m .49822 .77312 L .52924 .80776 L p 0 .305 .956 r
F P
0 g
s
.41862 .65075 m .40488 .6559 L .4205 .64035 L p 0 .05 .112 r
F P
0 g
s
.46606 .67058 m .43436 .63505 L .4205 .64035 L p 0 .307 .954 r
F P
0 g
s
.4205 .64035 m .43436 .63505 L .41862 .65075 L p 0 .05 .112 r
F P
0 g
s
.42136 .62049 m .40762 .62592 L .4205 .64035 L p 0 .307 .954 r
F P
0 g
s
.4205 .64035 m .43436 .63505 L .42136 .62049 L p 0 .307 .954 r
F P
0 g
s
.43436 .63505 m .4205 .64035 L .40488 .6559 L p 0 .05 .112 r
F P
0 g
s
.43436 .63505 m .4205 .64035 L .40762 .62592 L p 0 .307 .954 r
F P
0 g
s
.49047 .57296 m
.50188 .56159 L
s
.3837 .33486 m .38358 .35557 L .36792 .35875 L p 0 .35 .78 r
F P
0 g
s
.36792 .35875 m .35237 .34114 L .3837 .33486 L p 0 .35 .78 r
F P
0 g
s
.39652 .36393 m .38345 .37632 L .38358 .35557 L closepath p 0 .35 .78 r
F P
0 g
s
.23887 .48093 m .24521 .49769 L .22914 .51289 L p 0 .349 .781 r
F P
0 g
s
.22914 .51289 m .21644 .47929 L .23887 .48093 L p 0 .349 .781 r
F P
0 g
s
.24521 .49769 m .23887 .48093 L .21644 .47929 L p 0 .349 .781 r
F P
0 g
s
.22831 .47238 m .25093 .47405 L .23887 .48093 L p 0 .458 1 r
F P
0 g
s
.23887 .48093 m .21644 .47929 L .22831 .47238 L p 0 .458 1 r
F P
0 g
s
.21644 .47929 m .23887 .48093 L .25093 .47405 L p 0 .458 1 r
F P
0 g
s
.27345 .47572 m .25093 .47405 L .23887 .48093 L p 0 .458 1 r
F P
0 g
s
.24114 .50632 m .22914 .51289 L .24521 .49769 L p 0 .05 .1 r
F P
0 g
s
.24521 .49769 m .25733 .49098 L .24114 .50632 L p 0 .05 .1 r
F P
0 g
s
.24521 .49769 m .22914 .51289 L .24114 .50632 L p 0 .05 .1 r
F P
0 g
s
.24114 .50632 m .25733 .49098 L .24521 .49769 L p 0 .05 .1 r
F P
0 g
s
.21644 .47929 m .22914 .51289 L .24521 .49769 L p 0 .349 .781 r
F P
0 g
s
.6068 .59883 m .62357 .59274 L .65784 .63162 L p .541 0 0 r
F P
0 g
s
.6068 .59883 m .62357 .59274 L .59288 .6212 L .228 0 0 r
F
0 g
.6068 .59883 m
.61252 .59676 L
s
.5921 .61245 m
.6068 .59883 L
s
.57274 .56023 m
.6068 .59883 L
s
.61139 .60403 m
.64074 .63729 L
s
.61139 .60403 m
.64074 .63729 L
s
.39472 .61148 m .40762 .62592 L .42136 .62049 L p 0 .307 .954 r
F P
0 g
s
.40762 .62592 m .42136 .62049 L .43436 .63505 L p 0 .307 .954 r
F P
0 g
s
.42136 .62049 m .40762 .62592 L .39472 .61148 L p 0 .307 .954 r
F P
0 g
s
.48254 .36379 m
.51446 .40013 L
s
.44585 .32202 m .45692 .31087 L .48391 .28981 L .1 0 0 r
F
0 g
.45692 .31087 m
.4612 .30503 L
s
.45692 .31087 m
.4612 .30503 L
s
.54316 .58538 m
.55798 .57384 L
s
.5921 .61245 m .59288 .6212 L .56186 .645 L .228 0 0 r
F
0 g
.57723 .62388 m
.5921 .61245 L
s
.38345 .37632 m .36792 .35875 L .38358 .35557 L closepath p 0 .35 .78 r
F P
0 g
s
.24114 .50632 m .27327 .54218 L .26098 .54839 L p 0 .305 .956 r
F P
0 g
s
.26098 .54839 m .22914 .51289 L .24114 .50632 L p 0 .305 .956 r
F P
0 g
s
.39472 .61148 m .40834 .6059 L .42136 .62049 L p 0 .307 .954 r
F P
0 g
s
.42136 .62049 m .40834 .6059 L .39472 .61148 L p 0 .307 .954 r
F P
0 g
s
.40834 .6059 m .39472 .61148 L .3685 .63737 L p 0 .05 .1 r
F P
0 g
s
.3818 .59702 m .39472 .61148 L .40834 .6059 L p 0 .307 .954 r
F P
0 g
s
.3953 .59129 m .40834 .6059 L .39472 .61148 L p 0 .307 .954 r
F P
0 g
s
.39472 .61148 m .3818 .59702 L .3953 .59129 L p 0 .307 .954 r
F P
0 g
s
.3685 .63737 m .38192 .63201 L .40834 .6059 L p 0 .05 .1 r
F P
0 g
s
.38192 .63201 m .3685 .63737 L .39472 .61148 L p 0 .05 .1 r
F P
0 g
s
.39472 .61148 m .40834 .6059 L .38192 .63201 L p 0 .05 .1 r
F P
0 g
s
.49138 .62556 m .51878 .65638 L .48446 .6912 L p .858 0 0 r
F P
0 g
s
.49138 .62556 m .48446 .6912 L .51878 .65638 L .858 0 0 r
F
.49518 .61895 m .49138 .62556 L .51878 .65638 L .521 0 0 r
F
.52696 .64299 m .51878 .65638 L .48446 .6912 L .853 0 0 r
F
0 g
.49676 .62015 m
.50166 .61523 L
s
.45233 .742 m .46653 .73771 L .49822 .77312 L p 0 .305 .956 r
F P
0 g
s
.46653 .73771 m .45233 .742 L .42081 .70683 L p 0 .305 .956 r
F P
0 g
s
.66728 .54809 m .70122 .58677 L .65784 .63162 L p .859 0 0 r
F P
0 g
s
.70122 .58677 m
.72217 .562 L
s
.38225 .57666 m .3953 .59129 L .3818 .59702 L p 0 .307 .954 r
F P
0 g
s
.3818 .59702 m .36887 .58254 L .38225 .57666 L p 0 .307 .954 r
F P
0 g
s
.40834 .6059 m .3953 .59129 L .3818 .59702 L p 0 .307 .954 r
F P
0 g
s
.38225 .57666 m .36887 .58254 L .3818 .59702 L p 0 .307 .954 r
F P
0 g
s
.3818 .59702 m .3953 .59129 L .38225 .57666 L p 0 .307 .954 r
F P
0 g
s
.39735 .43931 m
.42972 .47585 L
s
.33565 .38917 m .36792 .35875 L .38345 .37632 L p 0 .35 .78 r
F P
0 g
s
.38345 .37632 m .35128 .40681 L .33565 .38917 L p 0 .35 .78 r
F P
0 g
s
.38345 .37632 m .37086 .39069 L .36068 .3979 L .1 0 0 r
F
.38345 .37632 m .38481 .37535 L .37086 .39069 L F
0 g
.38369 .37659 m
.38549 .37862 L
s
.55798 .57384 m
.57274 .56023 L
s
.4028 .66653 m .38919 .67153 L .40488 .6559 L p 0 .05 .112 r
F P
0 g
s
.40488 .6559 m .41862 .65075 L .4028 .66653 L p 0 .05 .112 r
F P
0 g
s
.41862 .65075 m .40488 .6559 L .38919 .67153 L p 0 .05 .112 r
F P
0 g
s
.40488 .6559 m .41862 .65075 L .43436 .63505 L p 0 .05 .112 r
F P
0 g
s
.5255 .57172 m .52948 .5845 L .49518 .61895 L .951 0 0 r
F
.5255 .57172 m .49518 .61895 L .49311 .61261 L F
.49104 .60624 m .4605 .65379 L .45618 .64115 L F
.5255 .57172 m .49311 .61261 L .49104 .60624 L F
.49311 .61261 m .4605 .65379 L .49104 .60624 L F
.51458 .55633 m .5255 .57172 L .49104 .60624 L .885 0 0 r
F
.48552 .59855 m .49104 .60624 L .45618 .64115 L F
.51458 .55633 m .49104 .60624 L .48552 .59855 L F
.46968 .5056 m .51458 .55633 L .445 .62573 L p .859 0 0 r
F P
0 g
s
.47998 .59084 m .45618 .64115 L .445 .62573 L .885 0 0 r
F
.51458 .55633 m .48552 .59855 L .47998 .59084 L F
.48552 .59855 m .45618 .64115 L .47998 .59084 L F
.49563 .58457 m .44994 .53308 L .44132 .53695 L p .521 0 0 r
F P
0 g
s
.44132 .53695 m .43475 .53991 L p .45311 .55338 L .521 0 0 r
F P
0 g
s
.45311 .55338 m .49563 .58457 L .44132 .53695 L .521 0 0 r
F
.47998 .59084 m .49563 .58457 L p .45311 .55338 L F P
0 g
s
.43475 .53991 m .47998 .59084 L p .45311 .55338 L .521 0 0 r
F P
0 g
s
.48532 .5887 m .5186 .6167 L .49563 .58457 L .521 0 0 r
F
.47998 .59084 m .4877 .596 L .48532 .5887 L F
.4877 .596 m .5186 .6167 L .48532 .5887 L F
.4877 .596 m .49104 .60624 L .5186 .6167 L F
.47998 .59084 m .49104 .60624 L .4877 .596 L F
.49311 .61261 m .49518 .61895 L .4605 .65379 L .951 0 0 r
F
0 g
.5255 .57172 m
.52948 .5845 L
s
.50079 .63615 m
.51696 .65433 L
s
.52552 .59125 m
.52948 .5845 L
s
.46097 .31296 m .44585 .32202 L .48022 .36115 L p .554 0 0 r
F P
0 g
s
.48022 .36115 m .49568 .35252 L .51833 .32913 L .1 0 0 r
F
.48022 .36115 m .49568 .35252 L .46097 .31296 L p .554 0 0 r
F P
0 g
s
.4352 .40438 m .48022 .36115 L .44585 .32202 L p .859 0 0 r
F P
0 g
s
.44585 .32202 m .49568 .35252 L .48022 .36115 L .554 0 0 r
F
.42969 .4831 m .36979 .55208 L .35958 .55125 L .547 0 0 r
F
0 g
.41811 .49435 m
.42969 .4831 L
s
.40358 .50847 m
.41811 .49435 L
s
.42969 .4831 m
.44012 .4836 L
s
.22914 .51289 m .19778 .47793 L .21644 .47929 L closepath p 0 .349 .781 r
F P
0 g
s
.21644 .47929 m .19778 .47793 L .22914 .51289 L closepath p 0 .349 .781 r
F P
0 g
s
.20948 .47099 m .22831 .47238 L .21644 .47929 L p 0 .458 1 r
F P
0 g
s
.21644 .47929 m .19778 .47793 L .20948 .47099 L p 0 .458 1 r
F P
0 g
s
.19778 .47793 m .21644 .47929 L .22831 .47238 L p 0 .458 1 r
F P
0 g
s
.25093 .47405 m .22831 .47238 L .21644 .47929 L p 0 .458 1 r
F P
0 g
s
.28595 .46873 m .31878 .43761 L .30603 .44486 L p 0 .05 .1 r
F P
0 g
s
.30603 .44486 m .27345 .47572 L .28595 .46873 L p 0 .05 .1 r
F P
0 g
s
.36633 .59225 m .38225 .57666 L .36887 .58254 L p 0 .05 .1 r
F P
0 g
s
.36887 .58254 m .35308 .59799 L .36633 .59225 L p 0 .05 .1 r
F P
0 g
s
.35026 .54081 m .33717 .54705 L .36887 .58254 L p 0 .307 .954 r
F P
0 g
s
.36887 .58254 m .38225 .57666 L .35026 .54081 L p 0 .307 .954 r
F P
0 g
s
.36887 .58254 m .38225 .57666 L .36633 .59225 L p 0 .05 .1 r
F P
0 g
s
.36633 .59225 m .35308 .59799 L .36887 .58254 L p 0 .05 .1 r
F P
0 g
s
.38481 .37535 m .38547 .37864 L .37086 .39069 L .1 0 0 r
F
.38481 .37535 m .38675 .37375 L .38547 .37864 L F
0 g
.38345 .37632 m
.38481 .37535 L
s
.22831 .47238 m .20948 .47099 L .19778 .47793 L p 0 .458 1 r
F P
0 g
s
.22914 .51289 m .19778 .47793 L .20948 .47099 L p 0 .305 .956 r
F P
0 g
s
.20948 .47099 m .24114 .50632 L .22914 .51289 L p 0 .305 .956 r
F P
0 g
s
.55995 .7758 m .52924 .80776 L .52921 .78824 L closepath p 0 .35 .78 r
F P
0 g
s
.54456 .75855 m .55995 .7758 L .52921 .78824 L p 0 .35 .78 r
F P
0 g
s
.49138 .62556 m .45685 .66026 L .48446 .6912 L .858 0 0 r
F
.49518 .61895 m .45685 .66026 L .49138 .62556 L .875 0 0 r
F
.48446 .6912 m .45685 .66026 L .49138 .62556 L p .858 0 0 r
F P
0 g
s
.49138 .62556 m
.49239 .62381 L
s
.49138 .62556 m
.50079 .63615 L
s
.44585 .32202 m .40049 .36505 L .38873 .37196 L p .1 0 0 r
F P
0 g
s
.38675 .37375 m .38873 .37196 L .40049 .36505 L .1 0 0 r
F
0 g
.38904 .3723 m
.39056 .37403 L
s
.31999 .3715 m .35237 .34114 L .36792 .35875 L p 0 .35 .78 r
F P
0 g
s
.36792 .35875 m .33565 .38917 L .31999 .3715 L p 0 .35 .78 r
F P
0 g
s
.38675 .37375 m .40049 .36505 L .38547 .37864 L .1 0 0 r
F
0 g
.38481 .37535 m
.38675 .37375 L
s
.38675 .37375 m
.38873 .37196 L
s
.42081 .70683 m .43472 .70218 L .46653 .73771 L p 0 .305 .956 r
F P
0 g
s
.43472 .70218 m .42081 .70683 L .38919 .67153 L p 0 .305 .956 r
F P
0 g
s
.65784 .63162 m .62357 .59274 L .66728 .54809 L p .859 0 0 r
F P
0 g
s
.65017 .5546 m
.66728 .54809 L
s
.66728 .54809 m
.68851 .52355 L
s
.66728 .54809 m
.70122 .58677 L
s
.52921 .78824 m .52918 .76473 L .54456 .75855 L p 0 .35 .78 r
F P
0 g
s
.54456 .75855 m .52918 .76473 L .52914 .74127 L closepath p 0 .35 .78 r
F P
0 g
s
.36068 .3979 m .39526 .43695 L .36721 .46386 L p .858 0 0 r
F P
0 g
s
.36068 .3979 m .39526 .43695 L .40558 .42992 L .671 0 0 r
F
.39526 .43695 m .36721 .46386 L .38847 .44944 L .1 0 0 r
F
.36068 .3979 m .36721 .46386 L .39526 .43695 L .858 0 0 r
F
.25421 .43317 m .24201 .44052 L .2748 .40979 L p 0 .05 .1 r
F P
0 g
s
.2748 .40979 m .28727 .40218 L .25421 .43317 L p 0 .05 .1 r
F P
0 g
s
.44585 .32202 m .40049 .36505 L .4352 .40438 L p .859 0 0 r
F P
0 g
s
.44585 .32202 m .46097 .31296 L .49568 .35252 L .554 0 0 r
F
.40049 .36505 m .44585 .32202 L .46097 .31296 L p .1 0 0 r
F P
0 g
s
.44783 .32428 m
.48022 .36115 L
s
.43379 .32925 m
.44585 .32202 L
s
.44585 .32202 m .48391 .28981 L .46097 .31296 L .1 0 0 r
F
0 g
.44585 .32202 m
.45692 .31087 L
s
.44585 .32202 m
.45692 .31087 L
s
.31816 .50483 m .30536 .51145 L .33717 .54705 L p 0 .307 .954 r
F P
0 g
s
.33717 .54705 m .35026 .54081 L .31816 .50483 L p 0 .307 .954 r
F P
0 g
s
.24201 .44052 m .20948 .47099 L .19778 .47793 L p 0 .05 .1 r
F P
0 g
s
.52914 .74127 m .52918 .76473 L .51372 .75715 L closepath p 0 .35 .78 r
F P
0 g
s
.49766 .70599 m .52914 .74127 L .51372 .75715 L p 0 .35 .78 r
F P
0 g
s
.38919 .67153 m .4028 .66653 L .43472 .70218 L p 0 .305 .956 r
F P
0 g
s
.38919 .67153 m .4028 .66653 L .41862 .65075 L p 0 .05 .112 r
F P
0 g
s
.4028 .66653 m .38919 .67153 L .36323 .64257 L p 0 .305 .956 r
F P
0 g
s
.35033 .60792 m .36633 .59225 L .35308 .59799 L p 0 .05 .1 r
F P
0 g
s
.35308 .59799 m .3372 .61352 L .35033 .60792 L p 0 .05 .1 r
F P
0 g
s
.35033 .60792 m .3372 .61352 L .35308 .59799 L p 0 .05 .1 r
F P
0 g
s
.35308 .59799 m .36633 .59225 L .35033 .60792 L p 0 .05 .1 r
F P
0 g
s
.3766 .63727 m .38192 .63201 L .3685 .63737 L p 0 .05 .1 r
F P
0 g
s
.3685 .63737 m .36323 .64257 L .3766 .63727 L p 0 .05 .1 r
F P
0 g
s
.36323 .64257 m .3685 .63737 L .38192 .63201 L p 0 .05 .1 r
F P
0 g
s
.49822 .77312 m .51372 .75715 L .52918 .76473 L p 0 .35 .78 r
F P
0 g
s
.52918 .76473 m .52921 .78824 L .49822 .77312 L p 0 .35 .78 r
F P
0 g
s
.36721 .46386 m .33242 .42469 L .36068 .3979 L p .858 0 0 r
F P
0 g
s
.36068 .3979 m .40558 .42992 L .37086 .39069 L .671 0 0 r
F
.36068 .3979 m .33242 .42469 L .36721 .46386 L .858 0 0 r
F
.36068 .3979 m .3534 .40989 L .33242 .42469 L .1 0 0 r
F
.36068 .3979 m .37086 .39069 L .3534 .40989 L F
0 g
.36246 .39992 m
.39526 .43695 L
s
.36246 .39992 m
.39526 .43695 L
s
.36068 .3979 m
.38345 .37632 L
s
.46097 .31296 m .51833 .32913 L .49568 .35252 L .89 0 0 r
F
.46097 .31296 m .48391 .28981 L .51833 .32913 L F
0 g
.51833 .32913 m
.52652 .31688 L
s
.48391 .28981 m
.49248 .27796 L
s
.28595 .46873 m .27345 .47572 L .30536 .51145 L p 0 .307 .954 r
F P
0 g
s
.30536 .51145 m .31816 .50483 L .28595 .46873 L p 0 .307 .954 r
F P
0 g
s
.38192 .63201 m .3766 .63727 L .36323 .64257 L p 0 .05 .1 r
F P
0 g
s
.3766 .63727 m .36323 .64257 L .3372 .61352 L p 0 .305 .956 r
F P
0 g
s
.36323 .64257 m .3766 .63727 L .4028 .66653 L p 0 .305 .956 r
F P
0 g
s
.51372 .75715 m .48213 .72181 L .49766 .70599 L p 0 .35 .78 r
F P
0 g
s
.46606 .67058 m .49766 .70599 L .48213 .72181 L p 0 .35 .78 r
F P
0 g
s
.62726 .66008 m .59615 .68368 L .56186 .645 L .775 0 0 r
F
0 g
.57326 .69583 m
.59615 .68368 L
s
.37086 .39069 m .45486 .45716 L .44016 .469 L .776 0 0 r
F
0 g
.38566 .44616 m
.39526 .43695 L
s
.42972 .47585 m
.44016 .469 L
s
.51458 .55633 m
.5255 .57172 L
s
.52921 .78824 m .52924 .80776 L .49822 .77312 L closepath p 0 .35 .78 r
F P
0 g
s
.52696 .64299 m .48446 .6912 L .49232 .67811 L .853 0 0 r
F
.49518 .61895 m .4605 .65379 L .45685 .66026 L .875 0 0 r
F
.4605 .65379 m .48446 .6912 L .45685 .66026 L .509 0 0 r
F
.4605 .65379 m .49232 .67811 L .48446 .6912 L F
0 g
.48446 .6912 m
.51878 .65638 L
s
.46208 .655 m
.49138 .62556 L
s
.48213 .72181 m .51372 .75715 L .49822 .77312 L p 0 .35 .78 r
F P
0 g
s
.44012 .4836 m
.45478 .49183 L
s
.30304 .41991 m .33565 .38917 L .35128 .40681 L p 0 .35 .78 r
F P
0 g
s
.35128 .40681 m .31878 .43761 L .30304 .41991 L p 0 .35 .78 r
F P
0 g
s
.31813 .57194 m .35033 .60792 L .3372 .61352 L p 0 .305 .956 r
F P
0 g
s
.3372 .61352 m .30529 .57791 L .31813 .57194 L p 0 .305 .956 r
F P
0 g
s
.3372 .61352 m .35033 .60792 L .3766 .63727 L p 0 .305 .956 r
F P
0 g
s
.27009 .45097 m .28595 .46873 L .27345 .47572 L p 0 .307 .954 r
F P
0 g
s
.27345 .47572 m .25774 .45813 L .27009 .45097 L p 0 .307 .954 r
F P
0 g
s
.2697 .48413 m .25733 .49098 L .27345 .47572 L p 0 .05 .1 r
F P
0 g
s
.27345 .47572 m .28595 .46873 L .2697 .48413 L p 0 .05 .1 r
F P
0 g
s
.27009 .45097 m .25774 .45813 L .27345 .47572 L p 0 .307 .954 r
F P
0 g
s
.27345 .47572 m .28595 .46873 L .27009 .45097 L p 0 .307 .954 r
F P
0 g
s
.28595 .46873 m .27345 .47572 L .25093 .47405 L p 0 .458 1 r
F P
0 g
s
.28595 .46873 m .27345 .47572 L .25733 .49098 L p 0 .05 .1 r
F P
0 g
s
.26323 .46704 m .25093 .47405 L .27345 .47572 L p 0 .458 1 r
F P
0 g
s
.27345 .47572 m .28595 .46873 L .26323 .46704 L p 0 .458 1 r
F P
0 g
s
.48213 .72181 m .45043 .68634 L .46606 .67058 L p 0 .35 .78 r
F P
0 g
s
.43436 .63505 m .46606 .67058 L .45043 .68634 L p 0 .35 .78 r
F P
0 g
s
.45685 .66026 m
.48446 .6912 L
s
.49104 .60624 m .4605 .65379 L .49518 .61895 L .951 0 0 r
F
.49104 .60624 m .49518 .61895 L .52696 .64299 L .521 0 0 r
F
0 g
.49239 .62381 m
.49518 .61895 L
s
.39483 .51698 m .36979 .55208 L .40515 .51765 L .547 0 0 r
F
.39483 .51698 m .35958 .55125 L .36979 .55208 L F
.39483 .51698 m .38826 .48683 L .36706 .48575 L .521 0 0 r
F
.39483 .51698 m .40515 .51765 L .38826 .48683 L F
0 g
.40132 .51067 m
.40358 .50847 L
s
.39483 .51698 m .3316 .51989 L .35958 .55125 L .858 0 0 r
F
.39483 .51698 m .36706 .48575 L .3316 .51989 L F
.36706 .48575 m .39483 .51698 L .35958 .55125 L p F P
0 g
s
.38531 .50627 m
.39483 .51698 L
s
.39483 .51698 m
.39757 .51716 L
s
.28727 .40218 m .31999 .3715 L .33565 .38917 L p 0 .35 .78 r
F P
0 g
s
.33565 .38917 m .30304 .41991 L .28727 .40218 L p 0 .35 .78 r
F P
0 g
s
.62726 .66008 m .56186 .645 L .59288 .6212 L .775 0 0 r
F
0 g
.54971 .65173 m
.56186 .645 L
s
.37086 .39069 m .40558 .42992 L .42023 .41797 L .776 0 0 r
F
.37086 .39069 m .38547 .37864 L .45486 .45716 L F
.40558 .42992 m .41902 .42455 L .42023 .41797 L .1 0 0 r
F
.40558 .42992 m .38847 .44944 L .41902 .42455 L F
0 g
.39526 .43695 m
.40558 .42992 L
s
.33242 .42469 m .38847 .44944 L .36721 .46386 L .669 0 0 r
F
0 g
.36721 .46386 m
.37705 .45718 L
s
.3842 .44756 m
.38566 .44616 L
s
.43483 .63418 m .45685 .66026 L .43436 .63505 L .509 0 0 r
F
.43483 .63418 m .4605 .65379 L .45685 .66026 L F
0 g
.43506 .63436 m
.44289 .62655 L
s
.25421 .43317 m .27009 .45097 L .25774 .45813 L p 0 .307 .954 r
F P
0 g
s
.25774 .45813 m .24201 .44052 L .25421 .43317 L p 0 .307 .954 r
F P
0 g
s
.25421 .43317 m .24201 .44052 L .25774 .45813 L p 0 .307 .954 r
F P
0 g
s
.25774 .45813 m .27009 .45097 L .25421 .43317 L p 0 .307 .954 r
F P
0 g
s
.49123 .57962 m
.51458 .55633 L
s
.45486 .45716 m
.46977 .44356 L
s
.43667 .40604 m
.46977 .44356 L
s
.44016 .469 m
.45486 .45716 L
s
.49822 .77312 m .46653 .73771 L .48213 .72181 L p 0 .35 .78 r
F P
0 g
s
.45043 .68634 m .48213 .72181 L .46653 .73771 L p 0 .35 .78 r
F P
0 g
s
.65784 .63162 m .59288 .6212 L .62357 .59274 L .833 0 0 r
F
0 g
.61252 .59676 m
.62357 .59274 L
s
.65784 .63162 m .62726 .66008 L .59288 .6212 L .833 0 0 r
F
0 g
.56186 .645 m
.59288 .6212 L
s
.62726 .66008 m
.65784 .63162 L
s
.62357 .59274 m
.65784 .63162 L
s
.59615 .68368 m
.62726 .66008 L
s
.2858 .53584 m .31813 .57194 L .30529 .57791 L p 0 .305 .956 r
F P
0 g
s
.30529 .57791 m .27327 .54218 L .2858 .53584 L p 0 .305 .956 r
F P
0 g
s
.22142 .46392 m .20948 .47099 L .24201 .44052 L p 0 .05 .1 r
F P
0 g
s
.24201 .44052 m .25421 .43317 L .22142 .46392 L p 0 .05 .1 r
F P
0 g
s
.35958 .55125 m .3316 .51989 L .36706 .48575 L p .858 0 0 r
F P
0 g
s
.36706 .48575 m .35256 .52132 L .3316 .51989 L .538 0 0 r
F
.36706 .48575 m .38826 .48683 L .35256 .52132 L F
0 g
.37737 .49734 m
.38531 .50627 L
s
.45043 .68634 m .41862 .65075 L .43436 .63505 L p 0 .35 .78 r
F P
0 g
s
.43436 .63505 m .41862 .65075 L .41429 .63389 L closepath p 0 .35 .78 r
F P
0 g
s
.42136 .62049 m .43436 .63505 L .41429 .63389 L closepath p 0 .35 .78 r
F P
0 g
s
.43436 .63505 m
.45685 .66026 L
s
.4352 .40438 m .45029 .39615 L .49568 .35252 L p .1 0 0 r
F P
0 g
s
.41524 .35638 m .45029 .39615 L .4352 .40438 L p .541 0 0 r
F P
0 g
s
.4352 .40438 m .40049 .36505 L .41524 .35638 L p .541 0 0 r
F P
0 g
s
.40049 .36505 m .4352 .40438 L .45029 .39615 L .541 0 0 r
F
.38547 .37864 m .4352 .40438 L .40049 .36505 L .832 0 0 r
F
0 g
.38873 .37196 m
.40049 .36505 L
s
.38547 .37864 m .42023 .41797 L .4352 .40438 L .832 0 0 r
F
.26323 .46704 m .25093 .47405 L .22831 .47238 L p 0 .458 1 r
F P
0 g
s
.25093 .47405 m .26323 .46704 L .28595 .46873 L p 0 .458 1 r
F P
0 g
s
.24041 .46533 m .22831 .47238 L .25093 .47405 L p 0 .458 1 r
F P
0 g
s
.25093 .47405 m .26323 .46704 L .24041 .46533 L p 0 .458 1 r
F P
0 g
s
.25337 .49961 m .24114 .50632 L .25733 .49098 L p 0 .05 .1 r
F P
0 g
s
.25733 .49098 m .2697 .48413 L .25337 .49961 L p 0 .05 .1 r
F P
0 g
s
.2697 .48413 m .25733 .49098 L .24114 .50632 L p 0 .05 .1 r
F P
0 g
s
.25733 .49098 m .2697 .48413 L .28595 .46873 L p 0 .05 .1 r
F P
0 g
s
.37086 .39069 m .42023 .41797 L .38547 .37864 L .776 0 0 r
F
.37086 .39069 m .38386 .38478 L .3534 .40989 L .1 0 0 r
F
0 g
.36068 .3979 m
.37086 .39069 L
s
.37086 .39069 m .38547 .37864 L .38386 .38478 L .1 0 0 r
F
.33242 .42469 m .3534 .40989 L .38847 .44944 L .669 0 0 r
F
0 g
.33242 .42469 m
.36068 .3979 L
s
.33242 .42469 m
.36721 .46386 L
s
.43424 .63249 m .4605 .65379 L .43483 .63418 L .509 0 0 r
F
0 g
.43436 .63505 m
.43483 .63418 L
s
.45478 .49183 m
.46968 .5056 L
s
.40834 .6059 m .42136 .62049 L .41429 .63389 L p 0 .35 .78 r
F P
0 g
s
.42023 .41797 m .41902 .42455 L .45029 .39615 L .1 0 0 r
F
0 g
.42023 .41797 m
.4352 .40438 L
s
.4352 .40438 m
.44034 .40157 L
s
.40558 .42992 m
.42023 .41797 L
s
.46653 .73771 m .43472 .70218 L .45043 .68634 L p 0 .35 .78 r
F P
0 g
s
.41862 .65075 m .45043 .68634 L .43472 .70218 L p 0 .35 .78 r
F P
0 g
s
.59288 .6212 m
.62357 .59274 L
s
.43424 .63249 m .45618 .64115 L .4605 .65379 L .509 0 0 r
F
.43276 .63045 m .45618 .64115 L .43424 .63249 L F
0 g
.43424 .63249 m
.43483 .63418 L
s
.4457 .52915 m
.46968 .5056 L
s
.25337 .49961 m .2858 .53584 L .27327 .54218 L p 0 .305 .956 r
F P
0 g
s
.27327 .54218 m .24114 .50632 L .25337 .49961 L p 0 .305 .956 r
F P
0 g
s
.38192 .63201 m .38199 .61916 L .40834 .6059 L closepath p 0 .35 .78 r
F P
0 g
s
.41429 .63389 m .39412 .63272 L .40834 .6059 L p 0 .35 .78 r
F P
0 g
s
.3953 .59129 m .40834 .6059 L .38199 .61916 L p 0 .35 .78 r
F P
0 g
s
.40834 .6059 m .39412 .63272 L .38192 .63201 L closepath p 0 .35 .78 r
F P
0 g
s
.445 .62573 m .43276 .63045 L .38754 .57977 L p .509 0 0 r
F P
0 g
s
.44084 .62241 m
.44147 .62178 L
s
.43276 .63045 m .445 .62573 L .45618 .64115 L .509 0 0 r
F
0 g
.43276 .63045 m
.43424 .63249 L
s
.46097 .31296 m .41524 .35638 L .40049 .36505 L p .1 0 0 r
F P
0 g
s
.40049 .36505 m .45029 .39615 L .41524 .35638 L .541 0 0 r
F
.38547 .37864 m .40049 .36505 L .41524 .35638 L .1 0 0 r
F
0 g
.40175 .36647 m
.4352 .40438 L
s
.40175 .36647 m
.4352 .40438 L
s
.38199 .61916 m .38212 .59788 L .3953 .59129 L p 0 .35 .78 r
F P
0 g
s
.38212 .59788 m .38225 .57666 L .3953 .59129 L closepath p 0 .35 .78 r
F P
0 g
s
.39412 .63272 m .41429 .63389 L .41862 .65075 L p 0 .35 .78 r
F P
0 g
s
.49104 .60624 m .52696 .64299 L .5186 .6167 L .521 0 0 r
F
.5186 .6167 m .52696 .64299 L .49232 .67811 L .954 0 0 r
F
0 g
.51878 .65638 m
.52696 .64299 L
s
.49104 .60624 m .45618 .64115 L .4605 .65379 L .951 0 0 r
F
.47998 .59084 m .45618 .64115 L .49104 .60624 L .885 0 0 r
F
0 g
.49104 .60624 m
.49518 .61895 L
s
.43472 .70218 m .4028 .66653 L .41862 .65075 L p 0 .35 .78 r
F P
0 g
s
.41862 .65075 m .4028 .66653 L .39412 .63272 L p 0 .35 .78 r
F P
0 g
s
.38547 .37864 m .41524 .35638 L .38386 .38478 L .1 0 0 r
F
0 g
.38547 .37864 m
.40049 .36505 L
s
.37086 .39069 m
.38547 .37864 L
s
.24041 .46533 m .22831 .47238 L .20948 .47099 L p 0 .458 1 r
F P
0 g
s
.22831 .47238 m .24041 .46533 L .26323 .46704 L p 0 .458 1 r
F P
0 g
s
.22142 .46392 m .20948 .47099 L .22831 .47238 L p 0 .458 1 r
F P
0 g
s
.22831 .47238 m .24041 .46533 L .22142 .46392 L p 0 .458 1 r
F P
0 g
s
.27009 .45097 m .30304 .41991 L .31878 .43761 L p 0 .35 .78 r
F P
0 g
s
.31878 .43761 m .28595 .46873 L .27009 .45097 L p 0 .35 .78 r
F P
0 g
s
.33423 .55633 m .35026 .54081 L .38225 .57666 L p 0 .35 .78 r
F P
0 g
s
.38225 .57666 m .36633 .59225 L .33423 .55633 L p 0 .35 .78 r
F P
0 g
s
.38225 .57666 m .36979 .55208 L .38362 .57678 L .509 0 0 r
F
0 g
.38309 .57584 m
.39169 .56741 L
s
.38225 .57666 m .35958 .55125 L .36979 .55208 L .509 0 0 r
F
.38212 .59788 m .36633 .59225 L .38225 .57666 L closepath p 0 .35 .78 r
F P
0 g
s
.24114 .50632 m .25337 .49961 L .2697 .48413 L p 0 .05 .1 r
F P
0 g
s
.25337 .49961 m .24114 .50632 L .20948 .47099 L p 0 .305 .956 r
F P
0 g
s
.40515 .51765 m .38439 .56063 L .41978 .52604 L .76 0 0 r
F
.40515 .51765 m .36979 .55208 L .38439 .56063 L F
.40515 .51765 m .41869 .50413 L .38826 .48683 L .521 0 0 r
F
0 g
.39757 .51716 m
.40515 .51765 L
s
.40515 .51765 m .41978 .52604 L .41869 .50413 L .521 0 0 r
F
.46097 .31296 m .49568 .35252 L .45029 .39615 L p .859 0 0 r
F P
0 g
s
.49568 .35252 m
.51833 .32913 L
s
.38362 .57678 m .38439 .56063 L .38556 .57792 L .509 0 0 r
F
.38362 .57678 m .36979 .55208 L .38439 .56063 L F
0 g
.38225 .57666 m
.38362 .57678 L
s
.25421 .43317 m .28727 .40218 L .30304 .41991 L p 0 .35 .78 r
F P
0 g
s
.30304 .41991 m .27009 .45097 L .25421 .43317 L p 0 .35 .78 r
F P
0 g
s
.38556 .57792 m .39942 .5746 L .38754 .57977 L .509 0 0 r
F
0 g
.39068 .5767 m
.39603 .57145 L
s
.38556 .57792 m .38439 .56063 L .39942 .5746 L .509 0 0 r
F
0 g
.38362 .57678 m
.38556 .57792 L
s
.35033 .60792 m .36633 .59225 L .38212 .59788 L p 0 .35 .78 r
F P
0 g
s
.38212 .59788 m .38199 .61916 L .35033 .60792 L p 0 .35 .78 r
F P
0 g
s
.45618 .64115 m .49232 .67811 L .4605 .65379 L .509 0 0 r
F
0 g
.45685 .66026 m
.4605 .65379 L
s
.45685 .66026 m
.4605 .65379 L
s
.38754 .57977 m .39942 .5746 L .445 .62573 L p .509 0 0 r
F P
0 g
s
.38556 .57792 m
.38754 .57977 L
s
.35958 .55125 m .35256 .52132 L .36979 .55208 L .509 0 0 r
F
0 g
.36589 .54512 m
.39483 .51698 L
s
.35958 .55125 m .3316 .51989 L .35256 .52132 L .509 0 0 r
F
0 g
.35958 .55125 m
.38225 .57666 L
s
.38192 .63201 m .39412 .63272 L .4028 .66653 L p 0 .35 .78 r
F P
0 g
s
.47998 .59084 m .445 .62573 L .45618 .64115 L .885 0 0 r
F
.46036 .61981 m .49563 .58457 L .47998 .59084 L p .157 0 0 r
F P
0 g
s
.4839 .59629 m
.49104 .60624 L
s
.47998 .59084 m .445 .62573 L .46036 .61981 L p .157 0 0 r
F P
0 g
s
.445 .62573 m .47998 .59084 L .43475 .53991 L p .859 0 0 r
F P
0 g
s
.47998 .59084 m .46036 .61981 L .445 .62573 L .157 0 0 r
F
.47998 .59084 m .49563 .58457 L .46036 .61981 L F
0 g
.47998 .59084 m
.48532 .5887 L
s
.30202 .5203 m .31816 .50483 L .35026 .54081 L p 0 .35 .78 r
F P
0 g
s
.3316 .51989 m
.36706 .48575 L
s
.35026 .54081 m .33423 .55633 L .30202 .5203 L p 0 .35 .78 r
F P
0 g
s
.3316 .51989 m
.35958 .55125 L
s
.20948 .47099 m .22142 .46392 L .24041 .46533 L p 0 .458 1 r
F P
0 g
s
.20948 .47099 m .22142 .46392 L .25337 .49961 L p 0 .305 .956 r
F P
0 g
s
.3766 .63727 m .35033 .60792 L .38199 .61916 L p 0 .35 .78 r
F P
0 g
s
.38199 .61916 m .38192 .63201 L .3766 .63727 L p 0 .35 .78 r
F P
0 g
s
.4028 .66653 m .3766 .63727 L .38192 .63201 L p 0 .35 .78 r
F P
0 g
s
.45029 .39615 m .41524 .35638 L .46097 .31296 L p .859 0 0 r
F P
0 g
s
.46097 .31296 m
.49568 .35252 L
s
.46097 .31296 m
.48391 .28981 L
s
.44585 .32202 m
.46097 .31296 L
s
.31813 .57194 m .33423 .55633 L .36633 .59225 L p 0 .35 .78 r
F P
0 g
s
.36633 .59225 m .35033 .60792 L .31813 .57194 L p 0 .35 .78 r
F P
0 g
s
.2697 .48413 m .28595 .46873 L .31816 .50483 L p 0 .35 .78 r
F P
0 g
s
.31816 .50483 m .30202 .5203 L .2697 .48413 L p 0 .35 .78 r
F P
0 g
s
.41978 .52604 m .39942 .5746 L .43475 .53991 L .832 0 0 r
F
.41978 .52604 m .38439 .56063 L .39942 .5746 L F
0 g
.40515 .51765 m
.41978 .52604 L
s
.43475 .53991 m .39942 .5746 L .445 .62573 L p .859 0 0 r
F P
0 g
s
.41432 .56811 m .39942 .5746 L .43475 .53991 L p .1 0 0 r
F P
0 g
s
.43475 .53991 m .44994 .53308 L .41432 .56811 L p .1 0 0 r
F P
0 g
s
.43475 .53991 m .41432 .56811 L .44994 .53308 L .1 0 0 r
F
0 g
.41978 .52604 m
.43475 .53991 L
s
.43475 .53991 m .39942 .5746 L .41432 .56811 L .1 0 0 r
F
0 g
.43475 .53991 m
.43992 .53758 L
s
.2858 .53584 m .30202 .5203 L .33423 .55633 L p 0 .35 .78 r
F P
0 g
s
.33423 .55633 m .31813 .57194 L .2858 .53584 L p 0 .35 .78 r
F P
0 g
s
.3534 .40989 m .41902 .42455 L .38847 .44944 L .775 0 0 r
F
0 g
.37705 .45718 m
.38847 .44944 L
s
.5186 .6167 m .49232 .67811 L .4836 .65198 L .954 0 0 r
F
.45618 .64115 m .4836 .65198 L .49232 .67811 L .509 0 0 r
F
0 g
.48446 .6912 m
.49232 .67811 L
s
.28595 .46873 m .26323 .46704 L .27009 .45097 L closepath p 0 .35 .78 r
F P
0 g
s
.2697 .48413 m .26323 .46704 L .28595 .46873 L closepath p 0 .35 .78 r
F P
0 g
s
.445 .62573 m .4836 .65198 L .45618 .64115 L .509 0 0 r
F
0 g
.45618 .64115 m
.4605 .65379 L
s
.45618 .64115 m
.4605 .65379 L
s
.25337 .49961 m .2697 .48413 L .30202 .5203 L p 0 .35 .78 r
F P
0 g
s
.30202 .5203 m .2858 .53584 L .25337 .49961 L p 0 .35 .78 r
F P
0 g
s
.25421 .43317 m .27009 .45097 L .26323 .46704 L p 0 .35 .78 r
F P
0 g
s
.36979 .55208 m .38293 .53895 L .38439 .56063 L .509 0 0 r
F
.36979 .55208 m .35256 .52132 L .38293 .53895 L F
0 g
.35958 .55125 m
.36979 .55208 L
s
.35958 .55125 m
.36979 .55208 L
s
.24041 .46533 m .22142 .46392 L .25421 .43317 L closepath p 0 .35 .78 r
F P
0 g
s
.26323 .46704 m .24041 .46533 L .25421 .43317 L p 0 .35 .78 r
F P
0 g
s
.3534 .40989 m .38386 .38478 L .41902 .42455 L .775 0 0 r
F
0 g
.33242 .42469 m
.3534 .40989 L
s
.38826 .48683 m .38293 .53895 L .35256 .52132 L .759 0 0 r
F
0 g
.3316 .51989 m
.35256 .52132 L
s
.38826 .48683 m .41869 .50413 L .38293 .53895 L .759 0 0 r
F
0 g
.36706 .48575 m
.38826 .48683 L
s
.46036 .61981 m .445 .62573 L .39942 .5746 L p .509 0 0 r
F P
0 g
s
.45495 .61581 m
.47998 .59084 L
s
.445 .62573 m .46036 .61981 L .4836 .65198 L .509 0 0 r
F
0 g
.445 .62573 m
.45618 .64115 L
s
.445 .62573 m
.45618 .64115 L
s
.43276 .63045 m
.445 .62573 L
s
.24041 .46533 m .26323 .46704 L .2697 .48413 L p 0 .35 .78 r
F P
0 g
s
.2697 .48413 m .25337 .49961 L .24041 .46533 L p 0 .35 .78 r
F P
0 g
s
.38386 .38478 m .45029 .39615 L .41902 .42455 L .833 0 0 r
F
0 g
.38847 .44944 m
.41902 .42455 L
s
.38386 .38478 m .41524 .35638 L .45029 .39615 L .833 0 0 r
F
0 g
.3534 .40989 m
.38386 .38478 L
s
.41524 .35638 m
.45029 .39615 L
s
.41902 .42455 m
.45029 .39615 L
s
.40049 .36505 m
.41524 .35638 L
s
.49563 .58457 m .5186 .6167 L .4836 .65198 L .886 0 0 r
F
0 g
.5186 .6167 m
.52696 .64299 L
s
.38439 .56063 m .41432 .56811 L .39942 .5746 L .509 0 0 r
F
0 g
.40771 .56646 m
.43475 .53991 L
s
.38439 .56063 m .38293 .53895 L .41432 .56811 L .509 0 0 r
F
0 g
.36979 .55208 m
.38439 .56063 L
s
.38386 .38478 m
.41524 .35638 L
s
.39942 .5746 m .41432 .56811 L .46036 .61981 L p .509 0 0 r
F P
0 g
s
.38439 .56063 m
.39942 .5746 L
s
.38754 .57977 m
.39942 .5746 L
s
.25337 .49961 m .22142 .46392 L .24041 .46533 L closepath p 0 .35 .78 r
F P
0 g
s
.44994 .53308 m .49563 .58457 L .46036 .61981 L p .859 0 0 r
F P
0 g
s
.49563 .58457 m .4836 .65198 L .46036 .61981 L .886 0 0 r
F
0 g
.49563 .58457 m
.5186 .6167 L
s
.4836 .65198 m
.49232 .67811 L
s
.41869 .50413 m .41432 .56811 L .38293 .53895 L .832 0 0 r
F
0 g
.35256 .52132 m
.38293 .53895 L
s
.41869 .50413 m .44994 .53308 L .41432 .56811 L .832 0 0 r
F
0 g
.38826 .48683 m
.41869 .50413 L
s
.46036 .61981 m .41432 .56811 L .44994 .53308 L p .859 0 0 r
F P
0 g
s
.46036 .61981 m
.4836 .65198 L
s
.41869 .50413 m
.44994 .53308 L
s
.39942 .5746 m
.41432 .56811 L
s
.445 .62573 m
.46036 .61981 L
s
.46036 .61981 m
.49563 .58457 L
s
.41432 .56811 m
.44994 .53308 L
s
.38293 .53895 m
.41432 .56811 L
s
[ .01 .01 ] 0 setdash
.23791 .1018 m
.86416 .17258 L
s
.86416 .17258 m
.8766 .82824 L
s
.8766 .82824 m
.2283 .80295 L
s
.2283 .80295 m
.23791 .1018 L
s
.14118 .18726 m
.12911 .83347 L
s
.12911 .83347 m
.2283 .80295 L
s
.2283 .80295 m
.23791 .1018 L
s
.23791 .1018 m
.14118 .18726 L
s
.003 w
[ ] 0 setdash
.86416 .17258 m
.8766 .82824 L
s
.25 Mabswid
.86558 .24728 m
.85936 .24663 L
s
gsave
.87801 .24858 -61 -10.7155 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.87028 .4949 m
.86405 .49443 L
s
gsave
.88274 .49586 -61 -10.925 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.8751 .74898 m
.86886 .74868 L
s
gsave
.88759 .74958 -61 -11.1402 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.86651 .2963 m
.86278 .29593 L
s
.86745 .34557 m
.86371 .34522 L
s
.86839 .39509 m
.86465 .39477 L
s
.86933 .44487 m
.86559 .44456 L
s
.87123 .5452 m
.86749 .54493 L
s
.87219 .59575 m
.86845 .5955 L
s
.87316 .64656 m
.86941 .64634 L
s
.87413 .69764 m
.87038 .69743 L
s
.86466 .1985 m
.86093 .19809 L
s
.87608 .80059 m
.87233 .80043 L
s
gsave
.94506 .50064 -61 -10.925 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.187500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{489, 489},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007Y0001jA000`40O003h00OogoojWoo003oOooZ
Ool00?moonYoo`00ogoojWoo003oOooZOol00?moonYoo`00ogoojWoo003oOooZOol00?moonYoo`00
ogoojWoo003oOooZOol00?moonYoo`00ogoojWoo003oOooZOol00?moonYoo`00ogoojWoo003oOooZ
Ool00?moonYoo`00ogoojWoo003oOooZOol00?moonYoo`00ogoojWoo003oOol>Ool3003IOol00?mo
o`moo`03001oogoo0=Qoo`00ogoo3goo00<007ooOol0f7oo003oOol?Ool00`00Oomoo`3HOol00?mo
o`ioo`03001oo`000=Uoo`00ogoo3Woo00<007oo0000fGoo003oOol>Ool01000Oomoo`00f7oo003o
Ool=Ool00`00Oomoo`02Ool00`00Oomoo`3EOol00?moo`aoo`<0009oo`<00=Ioo`00ogoojWoo003o
OooZOol00?moonYoo`00ogoojWoo003oOooZOol00?moonYoo`00ogoojWoo003oOooZOol009Ioo`<0
00=oo`<000=oo`<00?moodEoo`00Ugoo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo
0?mood9oo`00Ugoo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo0?mood9oo`00SGoo
1`000goo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo0?mood9oo`00Ugoo00D007oo
Oomoo`0000=oo`03001oo`0000=oo`03001oogoo0?mood9oo`00Ugoo00D007ooOomoo`0000=oo`03
001oo`0000=oo`03001oogoo0?mood9oo`00Ugoo00D007ooOomoo`0000=oo`03001oo`0000=oo`03
001oogoo0?mood9oo`00UWoo0P000goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`3oOom2Ool0
09Moo`03001oogoo009oo`<000=oo`<00?moodEoo`00ogoojWoo003oOooZOol007Aoo`D00?moog5o
o`00Lgoo0P0000=oo`0000002P00ogooJ7oo001aOol2000=Ool:0026Ool3003FOol0071oo`03001o
ogoo00ioo`03001oogoo00Ioo`X007]oo`05001oogooOol0003EOol0085oo`03001oogoo00moo`T0
07=oo`05001oogooOol0003EOol009Yoo`X006]oo`05001oogooOol0003EOol007=oo`03001oogoo
02Aoo`03001oogoo00Moo`T0069oo`05001oogooOol0003EOol006aoo`03001oogoo00Aoo`03001o
ogoo02Aoo`03001oogoo011oo`T005Uoo`05001oogooOol0003EOol006]oo`03001oogoo00Eoo`03
001oogoo02Aoo`03001oogoo01Eoo`04001oogooOol9001@Ool01@00Oomoogoo0000eGoo001ZOol0
0`00Oomoo`06Ool00`00Oomoo`0lOol00`00Oomoo`0:Ool80018Ool01@00Oomoogoo0000eGoo001Y
Ool00`00Oomoo`07Ool00`00Oomoo`1>Ool<0010Ool3003FOol007=oo`03001oogoo05Aoo`04001o
ogooOol;003oOolAOol00<Yoo`03001oogoo00Yoo`X00?moo`Uoo`00IGoo00<007ooOol0NGoo2P00
oWoo001TOol00`00Oomoo`1kOol00`00Oomoo`05Ool:003eOol0069oo`8000moo`03001oogoo06ao
o`03001oogoo00ioo`T007moo`<000=oo`<000=oo`<005moo`00HGoo00<007ooOol03goo00<007oo
Ool0Q7oo2P00N7oo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo05aoo`00Lgoo00<0
07ooOol0Q7oo00<007ooOol01goo2@00Kgoo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001o
ogoo05aoo`00Lgoo00<007ooOol0Ugoo2@00IWoo00D007ooOomoo`0000=oo`03001oo`0000=oo`03
001oogoo05aoo`00Lgoo00<007ooOol0W7oo00@007ooOomoo`P005ioo`05001oogooOol00003Ool0
0`00Ool00003Ool00`00Oomoo`1LOol005ioo`03001oogoo019oo`03001oogoo09aoo`03001oogoo
00Uoo`X005Aoo`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`1LOol005eoo`03001o
ogoo0;9oo`03001oogoo019oo`T004aoo`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomo
o`1LOol005]oo`800<aoo`03001oogoo00=oo`X0049oo`8000=oo`07001oogooOol007oo00000goo
00<007ooOol0G7oo001JOol00`00Oomoo`3KOol:000jOol00`00Oomoo`02Ool30003Ool3001OOol0
0?mood5oo``009eoo`00Lgoo00<007ooOol0bWoo00<007ooOol01goo2`00U7oo001FOol00`00Oomo
o`0JOol00`00Oomoo`3MOol8002>Ool005Eoo`03001oogoo01]oo`03001oogoo0>5oo`04001oogoo
Ool90025Ool005Aoo`03001oogoo01aoo`03001oogoo0>5oo`03001oogoo00Yoo`X007]oo`00Dgoo
00<007ooOol07Goo00<007ooOol0mgoo2@00Lgoo001cOol00`00Oomoo`3gOol00`00Oomoo`06Ool9
001ZOol00?moogmoo`/0061oo`00ogooQ7oo00@007ooOomoo`T005Uoo`00Cgoo00<007ooOol0ogoo
<Woo00<007ooOol02Woo2@0000=oo`00Ool0CGoo001>Ool00`00Oomoo`3oOolcOol00`00Oomoo`0B
Ool;0016Ool004aoo`8002Eoo`03001oogoo0?moobEoo`03001oogoo00Aoo`D004=oo`00Bgoo00<0
07ooOol09Goo00<007ooOol0Rgoo00<007ooOol0WWoo00@007ooOol004=oo`00Lgoo00<007ooOol0
RGoo1000WWoo00D007ooOomoo`0004=oo`00Lgoo00<007ooOol0R7oo0P0000@1N0000GP009]oo`80
00Aoo`03001oogoo045oo`00B7oo00<007ooOol0:7oo00<007ooOol0Qgoo0P000P5h00@0005h0GP0
09Uoo`03001oogoo00Aoo`03001oogoo045oo`00Agoo00<007ooOol0:Goo00<007ooOol0QGoo0`00
0`5h00D0005h0GP1N00009moo`03001oogoo045oo`00AGoo0P00/goo00<0000S0000105h00D0005h
0GP1N00009=oo`8000Yoo`03001oogoo045oo`00A7oo1@00/7oo00<0000S00001@5h00<0005h0GP0
0P5h00<007ooOol0SWoo0P0037oo00<007ooOol0@Goo0014Ool00`00Oomoo`06Ool6002UOol00`00
02<000060GP00`000GP1N0030GP00`00Oomoo`2;Ool2000>Ool00`00Oomoo`11Ool004Aoo`03001o
ogoo011oo`H009Uoo`80000302<0005h00H1N0030001N05h00@1N003001oogoo09Yoo`03001oogoo
045oo`00A7oo00<007ooOol06Woo1P0037oo00<007ooOol0Ogoo0P0000<08`000GP01P5h0P001`5h
00<007ooOol0VGoo00<007ooOol0@Goo0014Ool00`00Oomoo`0SOol60003Ool00`00Oomoo`1nOol2
00000`0S0001N0040GP30000105h000000001P5h00<007ooOol0Q7oo00<007ooOol04Goo00<007oo
Ool0@Goo0014Ool00`00Oomoo`0/Ool7001hOol01@0002<0000S0000105h0P00105h00<0005h0GP0
0P001@5h00<007ooOol0PGoo0P004goo0P00@goo001cOol00`00Oomoo`08Ool6001/Ool20000100S
00008`000P5h0`001P5h00<0005h0GP00P5h0P00105h00<007ooOol0OWoo0P005Woo00<007ooOol0
@Goo001cOol00`00Oomoo`0BOol5001QOol300000`0S00008`0400090GP00`000GP1N0040GP20002
0GP00`00Oomoo`2FOol00`00Oomoo`11Ool007=oo`03001oogoo01]oo`H005Ioo`0600008`0002<0
000S0P00305h00<0005h0GP01P5h0P0000<1N000Ool0NWoo00<007ooOol06Goo00<007ooOol0@Goo
002KOol6001:Ool200000`0S00008`0300000`5h0001N00;0GP00`000GP1N0080GP3001hOol2000L
Ool00`00Oomoo`11Ool004Aoo`03001oogoo05ioo`H003ioo`<0000302<0000S00<000<1N0030001
N05h00T1N0030001N05h00X1N08007Eoo`8001ioo`03001oogoo045oo`00A7oo00<007ooOol0Igoo
1P00<goo0P0000<08`0002<00P0S0`00105h00<0005h0GP02@5h00<0005h0GP0305h00<007ooOol0
LGoo00<007ooOol07Woo00<007ooOol0@Goo0014Ool00`00Oomoo`0/Ool00`00Oomoo`12Ool6000X
Ool0100002<08`000`0S0`001P5h00<0005h0GP0205h00<0005h0GP02`5h00<0005h0000Tgoo0P00
@Woo0014Ool00`00Oomoo`0/Ool00`00Oomoo`1<Ool6000MOol0100002<08`000`0S00<0000S0000
205h00<0005h0GP01`5h00<0005h0GP02P5h00D0005h0GP1N00006eoo`03001oogoo029oo`80049o
o`00A7oo00<007ooOol0;7oo00<007ooOol0EWoo1@004goo00<0000S02<00P0000D08`0000008`00
00X1N0030001N05h00D1N08000/1N0030001N05h00<1N003001oogoo06Qoo`8002Eoo`80049oo`00
A7oo00<007ooOol0;7oo00<007ooOol0Ggoo1P0027oo00<0000S00001`002`5h00<0005h0GP00`5h
0P0000@1N000000000P1N0030001N05h00D1N003001oogoo06Eoo`8002Moo`80049oo`00Lgoo00<0
07ooOol0JGoo100000<08`0002<00P0000<08`0000003P5h00<0005h0GP00P000`5h00<0005h0GP0
0P001@5h00<0005h0GP01P5h00<007ooOol0SWoo0P00@Woo001cOol00`00Oomoo`1[Ool01@0002<0
000S00000P0S0P00405h0P001@5h00<0005h0GP00P5h0P000P5h00<0005h0GP0205h00<007ooOol0
SGoo0P00@Woo003POol00`0002<00002000202<2000@0GP00`000GP000050GP00`000GP1N0040GP2
000<0GP00`00Oomoo`1NOol00`00Oomoo`0[Ool00`00Oomoo`11Ool004Aoo`03001oogoo09Qoo`03
00008`00008000808`800101N0050001N05h0GP000040GP00`000GP1N0040GP00`000GP0000<0GP0
0`00Oomoo`1KOol2000^Ool00`00Oomoo`11Ool004Aoo`03001oogoo09Moo`0300008`0000800004
02<00000000@0GP00`000GP1N0030GP01@000GP1N05h00001@5h00D0005h0GP1N00000`1N003001o
ogoo05Qoo`80035oo`03001oogoo041oo`00A7oo00<007ooOol0UWoo00<0000S00000P0000@08`00
02<00101N0030001N05h00@1N0050001N05h0GP000040GP00`000GP1N0030GP00`000GP1N00:0GP0
0`00Oomoo`2:Ool00`00Oomoo`10Ool004Aoo`03001oogoo02aoo`03001oogoo06Ioo`0900008`00
02<0000S00008`000101N0030001N05h00H1N0040001N05h00020GP200070GP00`000GP1N00:0GP5
001@Ool00`00Oomoo`0dOol00`00Oomoo`10Ool004Aoo`03001oogoo02aoo`03001oogoo06Eoo`<0
000302<0000S00<000030GP0005h00d1N0030001N05h00P1N0050001N0000GP000090GP00`000GP1
N00;0GP00`00Oomoo`05Ool60015Ool00`00Oomoo`0eOol00`00Oomoo`10Ool004Aoo`03001oogoo
02aoo`03001oogoo06Aoo`D0000402<0000000030GP00`000GP1N0090GP2000<0GP3000;0GP00`00
0GP1N00:0GP00`00Oomoo`0?Ool5000jOol2000hOol00`00Oomoo`10Ool007=oo`03001oogoo06=o
o`@000808`<000@1N0030001N05h00P1N0030001N05h00d1N0030001N05h00/1N0030001N05h00X1
N003001oogoo01Moo`H002moo`03001oogoo03Qoo`03001oogoo041oo`00Lgoo00<007ooOol0HWoo
00@0000S000000808`<000H1N0030001N05h00H1N0030001N05h00d1N0030001GP0000d1N0030001
N05h00X1N003001oogoo021oo`H0061oo`03001oogoo041oo`00Lgoo00<007ooOol0HGoo00@0000S
000000808`0300008`0000P1N0030001N05h00@1N0030001N05h00d1N0050001GP5N0Eh0000=0GP0
0`000GP1N00:0GP00`00Oomoo`0YOol6000FOol00`00Oomoo`0mOol00`00Oomoo`10Ool00=Ioo`05
00008`0000008`0200000`0S0001N0090GP00`000GP1N0020GP00`000GP1N00=0GP00`000Eh1GP03
0Eh00`000GP1N00;0GP00`000GP1N00:0GP00`00Oomoo`0aOol6000;Ool20010Ool00`00Oomoo`0>
Ool30003Ool30003Ool3000SOol004Aoo`03001oogoo08eoo`P0000302<0005h00X1N0050001N05h
0GP0000?0GP00`000Eh1GP050Eh00`000GP1N00;0GP00`000GP1N0080GP00`000GP0000lOol7000o
Ool4000AOol01@00Oomoogoo00000goo00<007oo00000goo00<007ooOol087oo0014Ool00`00Oomo
o`2<Ool0100002<0000S0P0000@08`00000000d1N0030001N00000l1N0030001GP5N00H1GP030001
N05h00`1N0030001N05h00H1N0050001N05h0GP00010Ool00`00Oomoo`11Ool00`00Oomoo`0?Ool0
1@00Oomoogoo00000goo00<007oo00000goo00<007ooOol087oo0014Ool00`00Oomoo`2;Ool01@00
02<0000S00000P0S0P00405h00<0005h0GP03@5h0P002@5N00<0005h0GP02`5h00<0005h0GP01@5h
00<0005h0GP00`5h00<007ooOol0?Goo00<007ooOol0@Goo00<007ooOol01Woo1`000Woo00D007oo
Oomoo`0000=oo`03001oo`0000=oo`03001oogoo021oo`00A7oo00<007ooOol0;7oo00<007ooOol0
Fgoo00<0000S00000P000P0S0P00405h00<0005h0000305h0P000P5N00<0005N0Eh01`5N00<0005h
0GP02`5h00<0005h0GP00`5h00<0005h0GP01@5h00<007ooOol0?7oo00<007ooOol0@Goo00<007oo
Ool03goo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo021oo`00A7oo00<007ooOol0
;7oo00<007ooOol0FWoo00<0000S00000P000P0S0P00405h00D0005h0GP1N00000X1N0030001GP5N
00<1GP030001GP5N00L1GP030001N05h00/1N0050001N05h0GP000080GP00`00Oomoo`0lOol00`00
Oomoo`11Ool00`00Oomoo`0?Ool01@00Oomoogoo00000goo00<007oo00000goo00<007ooOol087oo
0014Ool00`00Oomoo`0/Ool00`00Oomoo`1IOol00`0002<000020000100S00000000405h00<0005h
0GP00`5h00<0005h0GP01P5h00<0005N0Eh0105N00<0005N0Eh0205N00<0005h0GP02`5h00<0005h
00002P5h00<007ooOol0Ogoo00<007ooOol03goo00D007ooOomoo`0000=oo`03001oo`0000=oo`03
001oogoo021oo`00LWoo00<007ooOol0FGoo00T0000S00008`0002<0000S0000405h00<0005h0GP0
105h00<0005h0GP01@5h00<0005N0Eh01P5N00<0005N0Eh0205N00<0005h0GP02`5h00<0005h0GP0
2P5h00<007ooOol0OWoo00<007ooOol03Woo0P000goo00L007ooOomoo`00Ool00003Ool00`00Oomo
o`0POol0079oo`03001oogoo05Moo`@0000602<0000S00008`00405h00<0005h0GP01P5h00<0005h
0GP00`5h0P002@5N00<0005N0Eh0205N00<0005h0GP02@5h00<0005h0000305h00<007ooOol0OGoo
00<007ooOol03goo00<007ooOol00Woo0`000goo0`008goo001bOol00`00Oomoo`1FOol400001P0S
00008`0002<00101N0030001N05h00P1N0070001N05h0GP0005N00002P5N00<0005N0Eh0205N00<0
005h0GP01`5h00D0005h0GP1N00000`1N003001oogoo07aoo`03001oogoo041oo`00bWoo0P0000D0
8`000000000S00<000030GP0005h00`1N08000`1N0030001N00000<1GP030001GP5N00P1GP030001
GP5N00L1GP030001N05h00H1N0030001N05h0081N0030001N05h00/1N003001oogoo03Moo`03001o
ogoo045oo`03001oogoo041oo`00A7oo00<007ooOol0PWoo00<0000S02<00P000P0S0`000`5h00<0
005h0GP02@5h00<0005h0GP03@5h00<0005N0Eh00`5N00<0005N0Eh0205N00<0005N0Eh01`5N00<0
005h0GP00`5h0P001P5h00<0005h0GP02`5h00<007ooOol0=Woo00<007ooOol0@Goo00<007ooOol0
@7oo0014Ool00`00Oomoo`21Ool00`0002<08`02000202<300050GP00`000GP1N0070GP00`000GP1
N00=0GP00`000Eh1GP050Eh00`000Eh1GP080Eh00`000Eh1GP070Eh01@000GP1N05h00002@5h00<0
005h0GP02`5h00<007ooOol0=Goo00<007ooOol0@Goo00<007ooOol0@7oo0014Ool00`00Oomoo`20
Ool00`0002<08`02000202<00`0002<000070GP00`000GP1N0050GP00`000GP1N00=0GP00`000Eh1
GP070Eh00`000Eh1GP080Eh00`000Eh1GP070Eh00`000GP0000;0GP00`000GP1N00:0GP00`00Oomo
o`0eOol00`00Oomoo`11Ool00`00Oomoo`10Ool004Aoo`03001oogoo02]oo`03001oogoo055oo`03
00008`000080000502<0000002<000090GP00`000GP1N0030GP00`000GP1N00=0GP2000:0Eh00`00
0Eh1GP070Eh00`000Eh1GP080Eh00`000GP1N00;0GP00`000GP1N00:0GP00`00Oomoo`0dOol00`00
Oomoo`11Ool00`00Oomoo`10Ool004Aoo`03001oogoo02]oo`03001oogoo051oo`0400008`0002<4
00000`0S0001N00:0GP01@000GP1N05h00003`5h00@0005N0Eh000T1GP030001GP5N00P1GP030001
GP5N00D1GP8000030Eh0005h00`1N0030001N05h00X1N003001oogoo03=oo`03001oogoo045oo`03
001oogoo041oo`00A7oo00<007ooOol0:goo00<007ooOol0Cgoo00@0000S00008`80000402<00000
000=0GP00`000GP0000?0GP01P000Eh000000Eh000T1GP030001GP5N00P1GP030001GP5N0081GP80
00@1GP030001N05h00X1N0030001N05h00/1N003001oogoo07Ioo`03001oogoo041oo`00LWoo00<0
07ooOol0CWoo00H0000S00008`0002<3000@0GP00`000GP1N00=0GP4000017`00Eh1GP002@5N00<0
005N0Eh0205N00@0005N000000L1GP030001N05h00X1N0030001N05h00/1N003001oogoo07Eoo`03
001oogoo041oo`00LWoo00<007ooOol0CGoo00<0000S00000P0000@08`0002<00101N0030001N000
00d1N005000<000030000002O0020Eh00`000Eh1GP070Eh00`000Eh1GP080Eh00`000Eh1GP080Eh0
0`000GP1N00:0GP00`000GP1N0090GP00`000GP0001fOol00`00Oomoo`10Ool0079oo`03001oogoo
04aoo`0300008`000080000402<0000S000@0GP01@000GP1N05h00002`5h00D000`0300<000000Al
00030Eh0005N00T1GP030001GP5N00D1GP8000030Eh0005N00P1GP030001N05h00/1N0030001N05h
00L1N0050001N05h0GP0001eOol00`00Oomoo`10Ool00<1oo`0300008`000080000402<0000S000@
0GP00`000GP1N0020GP00`000GP1N0080GP01@00300<00`000001W`000<1GP000Eh02@5N00<0005N
0Eh00`5N00<0005N0Eh00P5N00<0005N0Eh01`5N00<0005h0GP02`5h00<0005h0GP01@5h00<0005h
0GP00P5h00<007ooOol0;goo00<007ooOol0@Goo00<007ooOol0@7oo0013Ool00`00Oomoo`1iOol0
2@0002<0000S00008`0002<0000@0GP00`000GP1N0040GP00`000GP1N0060GP00`00300<00023000
0`00O01l0005O0000`5N0001GP080Eh00`000Eh1GP020Eh00`000Eh1GP040Eh00`000Eh1GP070Eh<
00020GP00`000GP1N0020GP200060GP00`00Oomoo`0^Ool00`00Oomoo`11Ool00`00Oomoo`10Ool0
04=oo`03001oogoo07Qoo`<0000602<0000S00008`00405h00<0005h0GP01P5h00<0005h0GP0105h
00<000`030000P`000<007`0O0001g`000<1GP000Eh0205N00@0005N000000P1GP030001GP5N00D1
GP8000U4009P00<000<1N0030001N05h00L1N003001oogoo02eoo`03001oogoo045oo`03001oogoo
041oo`00@goo00<007ooOol0Mgoo0`0000<08`0002<00P0S00<0005h0GP03P5h00<0005h0GP0205h
00<0005h0GP00P5h00<000`030000P`000<00700O00027`00P5N00<0005N0Eh01`5N00<0005N0Eh0
205N00<0005N0Eh00`5N0`002D@01F000P0000<1N0000GP02P5h00<007ooOol0;7oo00<007ooOol0
@Goo00<007ooOol0@7oo0013Ool00`00Oomoo`0/Ool00`00Oomoo`17Ool600000`0S00000002000>
0GP00`000GP1N0090GP01@000GP1N05h000010`000@00700L01`00Ul0081GP030001GP5N00@1GP80
00030Eh0005N00T1GP070001GP5N0Eh000`000002D@026000P00305h00<007ooOol0:goo00<007oo
Ool0@Goo00<007ooOol0@7oo0013Ool00`00Oomoo`0/Ool00`00Oomoo`16Ool01@0002<0000002<0
1@000P5h00<0005h0GP02@5h0P003@5h00<0005h000010`000<00700L0000g002G`000<1GP000Eh0
0`5N0P00105N00<0005N0Eh0205N0`0000<<0000A00024@02f000P002`5h00<007ooOol0KGoo0P00
@Woo0013Ool00`00Oomoo`0/Ool00`00Oomoo`15Ool01@0002<0000002<00P0000@08`000GP00081
N0030001N05h00P1N0030001N05h00h1N003000<00`0008<0003001`070000E`00Ul00030Eh0005N
008000L1GP030001GP5N00H1GP80008<0003001404@000M400iP008000T1N003001oogoo06ioo`03
001oogoo041oo`00LWoo00<007ooOol0A7oo00H0000S0000000S000202<010000GP1N0000`5h00<0
005h0GP01P5h00<0005h0GP03P5h00<000`030000P`000<00700L0001g002G`000<1GP000Eh02@5N
00<0005N0Eh0105N00D000`0300<000000U4015P008000P1N003001oogoo06eoo`03001oogoo041o
o`00LWoo00<007ooOol0@goo1P000P0S00D0005h0GP1N00000@1N0030001N05h00@1N0030001N05h
00h1N004000<00`03002000;L009O0000`5N0001GP090Eh010000Eh1GP5N0P000``000<004@0A000
1d@056000P001`5h00<007ooOol0K7oo00<007ooOol0@7oo002gOol200001@0S0000000002<00P00
0`5h00<0005h0GP0105h00<0005h0GP00P5h00<0005h0GP03P5h0P000P`000<00700L0002g002G`0
0P5N00<0005N0Eh0205N0`000``00P002D@05f0000<0005h0GP01@5h00<007ooOol09goo00<007oo
Ool0@Goo00<007ooOol0@7oo0013Ool00`00Oomoo`1`Ool200001P0S0000000002<000D1N0030001
N05h00@1N0050001N05h0GP0000@0GP2000230000`00L01`000=L009O0020Eh00`000Eh1GP070Eh0
0`00300<000230000`00A0140008A00GH002J0000`000GP1N0050GP00`00Oomoo`0VOol00`00Oomo
o`11Ool00`00Oomoo`10Ool004=oo`03001oogoo06moo`80000602<0000S00008`001P5h00<0005h
0GP01@5h00<0005h0000405h0P000P`000<00700L0003g002G`00P5N00<0005N0Eh0105N00<000`0
30000``000<004@0A00024@05f0016P000<0005h0GP01@5h00<007ooOol09Goo00<007ooOol0@Goo
00<007ooOol0@7oo0013Ool00`00Oomoo`1]Ool50000100S00008`001`5h00<0005h0GP01P5h00<0
005h0GP03P5h0P000P`000<00700L0004G002G`00P5N00@0005N0Eh1GP8000D<0003001404@000Q4
01MP00IX008000D1N003001oogoo02Eoo`03001oogoo045oo`03001oogoo041oo`00@goo00<007oo
Ool0;7oo00<007ooOol0?Goo00<0000S00000P0000@08`0002<000L1N0030001N05h00L1N08000d1
N0<0008<0003001`070001=`00Ul0081GP<000H<0003001404@000Q401MP00UX00030001N05h00<1
N003001oogoo02Aoo`03001oogoo045oo`03001oogoo041oo`00@goo00<007ooOol0;7oo00<007oo
Ool0?7oo00<0000S00000P0000@08`0002<000P1N0030001N05h00H1N0040001N05h000;0GP30000
1@`0000006`000005G002G`00P001``000<004@0A00024@05f002fP000<0005h0GP00`5h00<007oo
Ool08goo00<007ooOol0@Goo00<007ooOol0@7oo0013Ool00`00Oomoo`0/Ool00`00Oomoo`0kOol0
2@0002<0000S00008`0002<000090GP00`000GP1N0060GP01@000GP1N05h00002@5h00@000`0000<
008000=/0003001`0700019`00Ul0003000<00`000D<0003001404@000Q401MP00eX00040001N05h
0GP3001XOol00`00Oomoo`10Ool0079oo`03001oogoo03Yoo`<0000302<0000S00<000030GP0005h
00L1N0030001N05h00H1N0030001N05h0081N0030001N05h00D1N003000<00`000<000E/0003001`
0700019`00Ml0003000<00`000D<0003001404@000Q401MP00mX00070001N0000GP0005h0000Igoo
0P00@Goo001bOol00`00Oomoo`0iOol300000`0S00008`0300030GP00`000GP1N0040GP00`000GP1
N0070GP00`000GP1N0030GP00`000GP1N0030GP00`00300<00030006K0000`00L01`000CL006O000
0`00300<0004300=000EH00AJ0001`000GP1N05h0001N00006Ioo`80045oo`00LWoo00<007ooOol0
>7oo0`0000<08`0002<00`001@5h2`00105h00<0005h0GP01@5h00D0005h0GP1N000008<0003000<
000000Q/0003001`070001=`00Al0003000<00`000<<00800003B00004P000Y80080019P01=X0006
0001N05h0001N000IWoo0P00@Goo002/Ool02@0002<0000S00008`0002<000060GP200040GP00`00
0GP1N0020GP900040GP010000GP000`00P0000<<0000K0002F`000<00700L0004g000W`000<000`0
30000P`00P0014P000<004P0B0002TP00P003f005FP00`000P5h00<007ooOol07goo00<007ooOol0
@Goo00<007ooOol0@7oo0013Ool00`00Oomoo`1UOol0100002<0000S0`0000<08`000GP01P5h00<0
005h0000105h00<0005h0GP01P5h00@0005h0GP1N0T00003300006`000]/0003001`070001=`0004
O00000`030020007B0000`00B018000;B002000<H00HJ0001@000GP1N05h000087oo00<007ooOol0
@Goo00<007ooOol0@7oo0013Ool00`00Oomoo`1TOol300000`0S0000000300080GP010000GP1N000
0`5h00<0005h0GP01P5h00<0005h0GP01@5h0P0000@<0000300000i/0003001`0700019`0004000<
00000009B002000>B0020009H00JJ0001@000GP1N05h00007goo00<007ooOol0@Goo00<007ooOol0
@7oo0013Ool00`00Oomoo`1SOol2000202<4000:0GP010000GP1N000105h00<0005h0GP01P5h00<0
005h0GP00`5h00H000`0000000`0000@K0000`00L01`000@L0000`003000000<B0000`00B018000>
B0020006H00LJ0001@000GP1N05h00007Woo00<007ooOol0@Goo00<007ooOol0@7oo0013Ool00`00
Oomoo`0/Ool00`00Oomoo`0cOol2000202<0100002<000002`5h00D0005h0GP1N00000<1N0030001
N05h00H1N0030001N05h0081N006000<00`0000<00004F`000<00700L0003g000`003TP000<004P0
B0003dP00P000f0076P000<006`000000`5h00<007ooOol06goo00<007ooOol0@Goo0P00@Goo0013
Ool00`00Oomoo`0/Ool00`00Oomoo`0bOol20000100S0000000S0P002P5h0`00105h00D0005h0GP1
N00000P1N0040001N05h00023003000CK0000`00L01`000=L002000AB0000`00B018000@B002000L
J0001@00K01/06`000000`5h00<007ooOol06Woo00<007ooOol0@Goo0P00@Goo0013Ool00`00Oomo
o`0/Ool00`00Oomoo`0`Ool900060GP500020GP300030GP010000GP1N000205h00<0005h00000P`0
0P005V`000<00700L0002g0000<004P0B0004TP000<004P0B0004DP000<006P0J00066P000<006`0
K0000f`000@0005h0GP0061oo`80045oo`00LWoo00<007ooOol0;goo00D0000S0000000S00800003
02<0005h00H000L1N0040001N05h00030GP00`000GP000090GP00`00300<0002000HK0000`00L01`
0009L0000`00B018000DB0000`00B018000AB0000`00J01X000FJ0000`00K01/0005K00010000GP1
N000H7oo00<007ooOol0?goo001bOol00`00Oomoo`0^Ool00`0002<0000202<20000100S00000000
3@5h00@0005h0GP1N0800081N0030001N00000L1N003000<00`0008001Y/0003001`070000M`0003
001804P001I80003001804P001580003001X06P001AX0003001/06`000I/00050001N05h0GP0001O
Ool00`00Oomoo`0oOol0079oo`03001oogoo02eoo`<000808`@000030GP0005h00d1N0030001N05h
00<1N0030001N05h008000H1N003000<00`0008001a/0003001`070000I`0003001804P001M80003
001804P000A80003001804P000Y80003001X06P0019X0003001/06`000Q/00050001N05h0GP0001N
Ool00`00Oomoo`0oOol00:5oo`<0000302<0000000<000<1N0030001N05h00/1N0030001N05h00@1
N0<000030GP0005h0081N080000430000000000NK0000`00L01`0004L0000`00B018000HB002000C
B0000`00J01X000@J0000`00K01/000:K0001@000GP0005h00006Goo00<007ooOol0?goo0`00@Goo
0013Ool00`00Oomoo`1JOol300000`0S00008`0300050GP00`000GP1N00:0GP00`000GP1N0060GP3
00020GP2000010`0000<00007f`000<00700L0000g0000<004P0B0006TP000<004P0B0000TP000<0
04P0B0003DP000<006P0J0003VP000<006`0K00036`00P000P5h00<007ooOol05Woo00<007ooOol0
@Goo00<007ooOol0?goo0013Ool00`00Oomoo`1IOol02@0002<0000S00008`0002<000070GP00`00
0GP1N0090GP00`000GP1N0070GP5000010`0000<00008F`000D00700L01`000001i80003001804P0
0198008000eX0003001/06`000i/00050001N05h0GP0000GOol00`00Oomoo`11Ool00`00Oomoo`0o
Ool004=oo`03001oogoo05Qoo`0400008`0002<300000`0S0001N0070GP00`000GP1N0090GP00`00
0GP1N0090GP2000010`0000<00008f`000<0070000000W`07TP01`003dP000<006P0J0002FP000<0
06`0K00046`000@0005h0GP001Moo`03001oogoo045oo`03001oogoo03moo`00@goo00<007ooOol0
;7oo00<007ooOol0:7oo00@0000S00008`<0000302<0005h00T1N0030001N05h00P1N0030001N05h
00P1N006000<00`0000<00009F`000<007`0O0000W`06dP00P001D@00V000P003TP000<006P0J000
1fP000<006`0K0004V`000@0005h0GP001Ioo`03001oogoo045oo`03001oogoo03moo`00@goo00<0
07ooOol0;7oo00<007ooOol09goo00@0000S00008`<0000302<0005h00/1N0030001N05h00H1N080
00T1N006000<00`0000<00009F`000<00700O00017`064P00`001D@01F000P003DP000<006P0J000
1FP000<006`0K00056`000@0005h0GP001Eoo`03001oogoo045oo`03001oogoo03moo`00@goo00<0
07ooOol0;7oo00<007ooOol09Woo00T0000S00008`0002<0000S00003P5h00@0005h0GP1N0@00004
0GP0000000060GP00`00300<000300000fP0001/000RK0001000L01`07001G`05DP00P0000<<0000
A00014@026000P0034P000<006P0J0000fP000<006`0K0005F`000D0005h0GP1N00005Qoo`03001o
ogoo03moo`00LWoo00<007ooOol09Goo00<0000S00000P0000@08`0002<00101N0<000D1N0040001
N05h00040GP00`00300<00030003J0000`00K01/000OK0000`00L01`0003L005O00BB00200023000
0`00A0140003A00;H0000`00B018000:B0001@00J01X06P000006F`000D0005h0GP1N00005Moo`03
001oogoo03moo`00LWoo00<007ooOol08goo0P0000P08`000000000S00008`00405h00<0005h0000
1P5h00@0005h0GP1N08000040GP000`030030005J0000`00K01/000MK0000`00L01`0005L005O00?
B003000230000`00A0140003A00;H002J0000`00B018000:B0000`00J000000KK0001@000GP1N05h
0000EWoo00<007ooOol0?goo001bOol00`00Oomoo`0ROol00`0002<08`030000100S00008`00405h
00D0005h0GP1N00000D1N0030001N05h00<1N003000<00`000<000IX0003001/06`001a/0003001`
070000M`00Al00e800<000<<0003001404@000=400]P00AX0003001804P000Y80003001/06`001]/
00050001N05h0GP0001EOol00`00Oomoo`0oOol009Ioo`0300008`0S00D0000302<0005h00l1N003
0001N05h00<1N0030001N05h0081N0030001N05h0081N006000<00`0000<000026P000<006`0K000
6V`00P002W0017`02dP00P0000E/00`0300<000000E400]P00IX008000Q800800003B00006`001a/
00040001N05h000AOol00`00Oomoo`11Ool00`00Oomoo`0oOol004=oo`03001oogoo04moo`030000
8`000080000502<0000S02<0000?0GP200070GP01@000GP1N05h00000`5h00H000`0000000`0000:
J0000`00K01/000HK0001000K01/00002W0017`024P00P0000<<06`030000P`000<004@0A0000d@0
2f002FP000<004P0B0000dP00P0014P000<006`0K0006f`00P0000<1N000Ool03goo00<007ooOol0
@Goo00<007ooOol0?goo0013Ool00`00Oomoo`1>Ool500001@0S00008`0S00003`5h00<0005h0GP0
205h00@0005h0GP00081N0H000aX0003001/06`001I/0003001/06`0009/0003001`070000M`00El
00E800<000D<0003001404@000=400]P00]X0003001804P0008000M80003001/06`001]/00@000mo
o`03001oogoo045oo`03001oogoo03moo`00@goo00<007ooOol0CGoo0P0000D08`0000008`000080
8`030001N05h00d1N0030001N05h00X1N0040001N0000GP5000?J0000`00K01/000DK0000`00K01/
0003K0020009L005O002B002000730000`00A0140003A00;H00=J002000:B0000`00K01/000KK000
10000GP000003Woo00<007ooOol0@Goo00<007ooOol0?goo0013Ool00`00Oomoo`0/Ool00`00Oomo
o`0MOol00`0002<0000200000`0S00008`0200000`5h0001N00<0GP00`000GP1N00<0GP3000010`0
000<00004FP000<006`0K0004V`000<006`0K0001F`00P002G001G`000<000`030001P`000<004@0
A0000d@02f003FP000<006`000002TP000<006`0K0006f`000D0005h0001N00000eoo`03001oogoo
045oo`03001oogoo03moo`00@goo00<007ooOol0;7oo00<007ooOol077oo00H0000S00008`0002<4
00030GP00`000GP1N0090GP00`000GP1N00>0GP01@00300000`000004VP000<006`0K00046`00P00
2F`000<00700L00027001G`00P`000=/00`030000P`000<004@0A0000d@02f003FP000D006`0K01/
000000Y80003001/06`001]/00050001N05h0GP0001@Ool00`00Oomoo`0oOol004=oo`03001oogoo
02aoo`03001oogoo01]oo`0600008`0002<0000S0P0000<08`000GP0105h00<0005h0GP01`5h00<0
005h0GP03P5h00D000`0000<000001AX0003001/06`000i/0003001/06`000Y/0003001`070000Q`
00El0003K00<00`0008<0003001404@000=400]P00eX0003001/06`000=/0003001804P000Q80003
001/06`001]/00050001N05h0GP0001?Ool00`00Oomoo`0oOol0079oo`03001oogoo01Yoo`030000
8`000080000502<0000S02<000060GP00`000GP1N0060GP00`000GP1N00>0GP01@00300000`00000
5VP000<006`0K00036`000<006`0K00036`000<00700L00027001G`00``000<004@0A0000d@02f00
3FP000<006`0K00016`000<004P0B0002DP000<006`0K0006f`000D0005h0GP1N00004ioo`03001o
ogoo03moo`00LWoo00<007ooOol06Goo00D0000S0000000S008000808`030001N05h00H1N0030001
N05h00<1N0800101N0<00003300006P001MX0003001/06`000Y/0003001/06`000i/0003001`0700
00Q`00Al0003000<000000E400]P00eX0003001/06`000I/0003001804P000U80003001/06`001]/
00040001N05h001>Ool00`00Oomoo`0oOol008eoo`0300008`0000@000808`030001N05h00P1N005
0001N05h0GP0000A0GP2000230000`00J01X000HJ0000`00K01/0008K0000`00K01/000@K0000`00
L01`0008L002O0000`0030000005000;H00=J0000`00K01/0008K0000`00B0180009B0000`00K01/
000IK0000`00L00000020GP00`00Oomoo`07Ool00`00Oomoo`11Ool00`00Oomoo`0oOol008aoo`03
00008`0S0080000502<0000S02<0000<0GP00`000GP0000A0GP2000230000`00H01X000JJ0000`00
K01/0006K0000`00K01/000BK0000`00L01`0008L0001G`0000004@0000014@00P0026003FP000<0
06`0K0002V`000<004P0B0002DP000<006`0K0005f`000@00700L00000<1N003001oogoo00Ioo`03
001oogoo045oo`03001oogoo03moo`00@goo00<007ooOol0AGoo10000P0S00@0000S000000h1N003
0001N05h00l1N080008<0004001P0600H00KJ0000`00K01/0004K0000`00K01/000DK0000`00L01`
0007L0000`00A0140002A0000`00A0140003A0020005H00=J0000`00K01/000<K0000`00B0180009
B0000`00K01/000EK0000`00L01`0002L0001@000GP1N05h00001goo00<007ooOol0@Goo00<007oo
Ool0?goo0013Ool00`00Oomoo`14Ool4000202<00`0002<0000?0GP00`000GP0000?0GP00`00300<
00020005H00JJ0000`00K01/0003K0000`00K01/000FK0000`00L01`0005L0000`00A0140004A000
0`00A0140004A0020002H00=J0000`00K01/000>K0000`00B0180008B0000`00K01/000DK0000`00
L01`0004L0001@000GP1N05h00001Woo00<007ooOol0@Goo00<007ooOol0?goo0012Ool00`00Oomo
o`0]Ool00`00Oomoo`0DOol4000202<00`0002<0000?0GP01@000GP1N05h0000305h0P000P`000<0
0600H0001V006VP000D006`0K01/000001U/008000E`0003001404@000I40003001404@000E40080
00aX0003001/06`0011/0003001804P000Q80003001/06`0019/0003001`070000E`00030001N05h
0081N003001oogoo00=oo`03001oogoo045oo`03001oogoo03moo`00@Woo00<007ooOol0;Goo00<0
07ooOol04goo0P0000<08`0002<00P0000<08`000GP03P5h00<0005h0GP00`5h00<0005h0GP0205h
0P000P`000<00600H00026006VP000<006`000006f`000<00700L0000W0000<004@0A00024@000<0
04@0A0001T@000<006P0J00026P000<006`0K0004V`000<004P0B00024P000<006`0K00046`000<0
0700L0001g0000<0005h0GP00P5h00<007ooOol00Woo00<007ooOol0?goo0`00@Goo0012Ool00`00
Oomoo`0]Ool00`00Oomoo`0BOol20000100S00008`000P0S00<0005h0GP03@5h00<0005h0GP01@5h
00<0005h0GP01P5h0P000P`000<00600H0002V006VP000<006`0K0006f`000D00700L01`000000Y4
0003001404@000M40003001X06P000IX0003001/06`001=/0003001804P000U80003001/06`000i/
0003001`070000U`00030001N05h0081N003001oogoo04Eoo`03001oogoo03moo`00LWoo00<007oo
Ool04Goo0P0000@08`0002<000808`030001N05h00d1N0030001N05h00H1N0030001N05h00D1N080
008<0003001P060000]P01UX0003001/06`001e/0003001`000000a40003001404@000M4008000EX
0003001/06`001E/0003001804P000U80003001/06`000a/0003001`070000Y`00030001N05h0081
N003001oogoo04Eoo`03001oogoo03moo`00LWoo00<007ooOol047oo0P0000@08`0002<000808`03
0001N05h00d1N0030001N05h00P1N0030001N05h00<1N080008<0003001P060000eP01MX0003001/
06`001m/0003001404@000a40003001404@000Q40005001X06P0J000000IK0000`00B0180009B000
0`00K01/000:K0000`00L01`000<L0000`000GP1N0020GP00`00Oomoo`14Ool00`00Oomoo`0oOol0
079oo`03001oogoo00moo`80000402<0000S000202<00`000GP1N00=0GP00`000GP1N00:0GP01000
0GP1N05h0P000P`000<00600H0003f005FP000<006`0K0007f`000<004@0A0003T@000<004@0A000
24@000<006P000006f`000<004P0B0002DP000<006`0K00026`000<00700L0003W0000<0005h0GP0
0P5h00<007ooOol0@goo00<007ooOol0?goo0023Ool200001@0S00008`0002<00P0000<1N0000GP0
2`5h0P003P5h00D0005h000000`0008001=P01=X0003001/06`001m/0003001404@0011400030014
04@000M4008001e/0003001804P000U80003001/06`000I/0003001`070000m`00030001N05h00<1
N08004=oo`03001oogoo03moo`00@Woo00<007ooOol0?Goo00D08`0002<0000S00@000<1N0030001
N05h00P1N0030001N05h00l1N08000033000060001EP015X0003001/06`001m/0003001404@00194
0003001404@000A4008000940003001/06`001]/0003001804P000Q80003001/06`000E/0003001`
0700015`00030001N05h00<1N003001oogoo045oo`03001oogoo03moo`00@Woo00<007ooOol0?7oo
00D08`0002<0000S0080000302<0005h00@1N0030001N05h00H1N0030001N05h00l1N08000033000
060001MP00mX0080021/0003001404@001=400<00094008000E40003001/06`001]/0003001804P0
00Q80003001/06`000=/0003001`070001=`00070001N05h0GP0005h0000@Woo00<007ooOol0?goo
0012Ool00`00Oomoo`0jOol0100002<0000S0`000P0S00<0005h0GP0105h00<0005h0GP01@5h00<0
005h0GP03`5h0P0000<<0000H0006F0036P00P000VP000<006`0K00076`00P004d@00`000P5h0P00
1d@00P007F`000<004P0B00024P000D006`0K01/000001I`00040001N05h00030GP00`00Oomoo`0o
Ool00`00Oomoo`0oOol0049oo`03001oogoo02aoo`03001oogoo00Yoo`0400008`0002<3000202<0
0`000GP1N0060GP00`000GP1N0030GP00`000GP1N00?0GP400000e@0H01P000HH00;J0000`00J01X
0003J0000`00K01/000JK00010000K/1^`0044@00`0000<1N`000GP00P5h00<004@0A0001T@000<0
06`0K0006f`000<004P0B0002DP000<006`0000067000P00105h00<007ooOol0?goo00<007ooOol0
?goo0012Ool00`00Oomoo`0/Ool00`00Oomoo`09Ool0100002<0000S0`000P0S00<0005h0GP0205h
00D0005h0GP1N0000141N003000<000000AD01YP00UX0003001X06P000EX0003001/06`001Q/0005
0001^`6k0K/0000>A00200000`0S0001N`020G/01@000GP1N05h000024@000<006`0K0006f`000<0
04P0B00024P00P00670000=h00000GP01@5h00<007ooOol0?Woo00<007ooOol0?goo0012Ool00`00
Oomoo`0/Ool00`00Oomoo`08Ool01`0002<0000S00008`0000808`030001N05h00X1N0030001N000
0141N003000<000000ID01YP00MX0003001X06P000IX0003001/06`001M/00050001^`6k0K/0000=
A00300000`0S0001N`040G/01@000GP1N05h000024@000<006`0K0006f`000<004P0B00014P00`00
0TP000<00700L00057000WP000<0005h0GP01@5h00<007ooOol0?Goo00<007ooOol0?goo001aOol0
0`00Oomoo`07Ool202<300000`0S00008`02000>0GP00`000GP1N00?0GP30008E00JH005J0000`00
J01X0008J0000`00K01/000EK0000`000K/1^`020K/00`00A0140009A00300000`0S000000060G/2
00030GP00`00A0140006A0000`00K01/000KK0000`00B01800030005B0000`00L01`000CL004N000
0`000GP1N0050GP00`00Oomoo`0lOol20010Ool0075oo`03001oogoo00Ioo`808`<0000402<0000S
000?0GP00`000GP0000?0GP2000;E00JH003J0000`00J01X000:J0000`00K01/000CK0000`000K/1
^`020K/00`00A0140008A00600000`3j0001N`060G/200020GP20008A0000`00K01/000KK0020009
B0000`00L01`000AL005N0000`000GP1N0060GP00`00Oomoo`0kOol20010Ool0075oo`03001oogoo
00Eoo`808`<0000402<0000S000?0GP01@000GP1N05h0000305h0`003E@06V0000=X0000H0003FP0
00<006`0K00046`00`00106k00<004@0A0001T@00`0000<08`0000000`3j00<0005k0G/01P5k0P00
00@1N000000000M4008001]/0003001`000000Y80003001`070000m`00Ih00030001N05h00L1N003
001oogoo03Yoo`80041oo`00Mgoo00D0000S02<0000S00<0000302<0005h00h1N0030001N05h00<1
N0030001N05h00P1N080011D01UP0004001P0600H00=J0000`00K01/000>K00200020K/010000K/1
^`001d@00`0000@08`00000000@0nP030001N`5k00L1N`800081N08000M40003001/06`001Q/0004
001`0700000:B0000`00L01`000>L007N0000`000GP1N0070GP00`00Oomoo`0jOol00`00Oomoo`0o
Ool0049oo`03001oogoo035oo`0500008`0000008`02000202<00`000GP1N00=0GP00`000GP1N005
0GP00`000GP1N0060GP200000d00001D000?E00GH0000`00H01P0003H00=J0000`00K01/000<K002
00030K/010000K/1^`001D@00`0000<08`0000000P3j00<0003j0?X00`3j00<0005k0G/01@5k00@0
005k00000081N08000M40003001/06`001I/0003001`0700009`0003001804P000Q80003001`0700
00a`00Uh00030001N05h00L1N003001oogoo03Uoo`03001oogoo03moo`00@Woo00<007ooOol0<7oo
100000<08`0000000P0S00<0005h0GP03@5h00<0005h0GP01P5h00<0005h0GP01@5h00<00400@000
0T0000<005@0E0003U@056000P001f003FP000<006`0K0002V`000<0006k0K/00`6k00<0006k0000
14@00P000P0S0P00103j00<0003j0?X00`3j00<0005k0G/0105k00@0005k0G/1N`800081N0030014
04@000I40003001/06`001A/0003001`070000=`0003001804P000U80003001`070000Y`00Yh0003
0001N05h00P1N003001oogoo03Qoo`03001oogoo03moo`00@Woo00<007ooOol0;goo0P0000<08`00
02<00P000P0S00<0005h0GP03@5h00<0005h0GP0205h00<0005h0GP00`5h00<00400@000140000<0
05@0E0003E@04f0000<00600H0001f003VP000<006`0K00026`000<0006k0K/0106k00<0006k0000
0T@00`0000<08`0000001`3j00@0003j0?X0nP8000D1N`030001N`5k00<1N`800081N003001404@0
00I40003001/06`0019/0003001`070000E`0003001804P000Q80003001`070000U`00]h00030001
N05h00T1N003001oogoo03Moo`03001oogoo03moo`00@Woo00<007ooOol0;7oo00@007oo00008`D0
00808`030001N05h00d1N0030001N05h00X1N0050001N05h0GP00008@0000`00E01D000=E00AH000
0`00H01P0009H00>J0000`00K01/0006K0000`000K/1^`060K/00`00A000000200001@0S0000003j
00001`3j00H0003j0000004K00030G/200060G/200030GP00`00A0140006A0000`00K01/000@K000
0`00L01`0007L0000`00B0180008B0000`00L01`0007L00<N0000`000GP1N00:0GP00`00Oomoo`0f
Ool20010Ool0049oo`03001oogoo02aoo`80000702<0000S00008`0002<010003@5h00<0005h0GP0
305h00<0005h00002D0000<005@0E0003U@03f0000<005@0H0002f003FP000<006`0K0001F`00P00
206k1P000`3j00<0003j0?X0103j0`000`4K00@0005k0G/000T1N`8000<1N003001404@000I40003
001/06`000i/0003001`070000Q`0003001804P000U80003001`070000E`00ih00030001N05h00X1
N003001oogoo03Eoo`80041oo`00@Woo00<007ooOol0;7oo00H0000S00008`0002<500020GP00`00
0GP1N0090GP00`000GP1N00>0GP00`00@0100009@0000`00E01D000>E00<H0020003E00<H00=J000
0`00K01/0003K00010000K/1^`001`6k00@0000S000000H0nP040000nP3j0?X200000`4K00016`04
0A/2000;0G/20000105h000000001d@000<006`0K0003F`000<00700L0002W0000<004P0B00024P0
00<00700L00017003gP00P002`5h00<007ooOol0=Goo0P00@7oo001`Ool300000`0S00008`020000
100S0001N0000P5h00<0005h0GP0205h00<0005h0GP03P5h00<00400@0002d0000<005@0E0003U@0
2V0000<005@0E00015@036003FP000D006`0K01/000000<1^`030001^`6k00@1^`@000L0nP040000
nP0000040A/00`000A/16`020A/00`000G/1N`0;0G/200020GP20007A0000`00K01/000<K0000`00
L01`0009L0000gP00018000:B0000`00L01`0002L00@N002000<0GP00`00Oomoo`0dOol20010Ool0
06moo`0400008`0002<3000202<00`000GP000040GP00`000GP1N0060GP00`000GP1N00>0GP00`00
@010000=@0000`00E01D000>E008H0000`00E01D0006E00<H00=J0000`00K00000040K/00`000K/1
^`040K/010000?X0nP001`3j0P001P4K00H0004K0A/0004K000<0G/010000G/000000P5h0P001d@0
00<006`0K0002V`000<00700L0002G000gP000<004P0B0002DP000<00700L00047P000@0005h0GP0
00`1N003001oogoo03=oo`80041oo`00KWoo00<0000S000010000P0S00@0005h0GP000D1N0030001
N05h00@1N0030001N05h00h1N0030010040000m00003001D05@000iD00IP00030014000000QD00aP
00eX00030001^`6k00@1^`030001^`6k0081^`050000nP3j0?X000050?X300080A/5000;0G/01000
0G/1N`5k0P000P5h00<004@0A0001T@000<006`0K00026`000<00700L0002G0017P000<004P0B000
2DP000<00700N0003gP000=/00000GP00P5h00<0005h0GP0205h00<0005h0000<goo0P00@Goo001]
Ool0100002<08`0S0`000P0S00@0005h0GP000L1N0030001N05h0081N0030001N05h00h1N0030010
040001500003001D05@000iD00=P008000=40003001D05@000ID00]P00aX00030001^`6k00D1^`05
0001^`6k0K/000050?X00`000?X0nP0200030A/00`000A/16`030A/400030A`00`000G/1N`070G/0
0`000G/1N`030G/200020GP00`00A0140006A0000`00K01/0006K0000`00L01`0009L005N0000`00
B018000:B0000`00N01h000=N0000f`00001N0040GP00`000GP1N0060GP01@000GP1N05h0000<goo
0P00@7oo0012Ool00`00Oomoo`0VOol3000202<00`0002<0000202<01@000GP1N05h00001`5h00D0
005h0GP1N0000101N0030010040001=00003001D05@000iD0003H00004@000A4008000QD00]P00YX
008000L1^`030001^`6k008000D0nP<000D16`0400016`4K0A/300000`4L000170030A`00`000G/1
N`060G/00`000G/1N`050G/01@000GP1N05h000024@000<006`0K00016`000<00700L0002G001gP0
00<004P0B0002DP000<007P0N00037P000=/00000GP01P5h00<0005h0GP0105h00<0005h0GP00`5h
00<007ooOol0<Goo00<007ooOol0?Woo0012Ool00`00Oomoo`0UOol0100002<0000S0P0000<08`00
02<00P000`5h00<0005h0GP01`5h00<0005h0000405h00<00400@0005D0000<005@0E0003E@000<0
04@0A0001D@000<005@0E0001U@0360026P000@0006k0K/000L1^`80009400030000nP3j0080nP03
00016`4K00H16`@000@170030001704L008170030001N`5k00<1N`8000T1N`050001N05h0GP00007
A0000`00K01/0003K0000`00L01`0009L008N0000`00B0180009B0000`00N01h000;N002K0000`00
0GP1N0060GP00`000GP1N0020GP00`000GP1N0050GP00`00Oomoo`0`Ool00`00Oomoo`0nOol0049o
o`03001oogoo02Aoo`0300008`0000<0000402<0000S00050GP00`000GP1N0080GP00`000GP1N00>
0GP00`00@010000G@0000`00E01D000;E0000`00A0140007A0000`00E01D0006E00<H005J0020003
0K/00`000K/1^`050K/01@00Ool004@000000P3j0`001`4K0`001P4L00<0004L0A`00`00105k00<0
005k0G/02P5k00D0005h0001N00000M40005001/06`0K000000;L008N0000f`0B018000;B0000`00
N01h0009N002K0000`000GP1N0070GP01@000GP1N05h00002@5h00<007ooOol0;goo00<007ooOol0
?Woo0012Ool00`00Oomoo`0SOol02P0002<0000002<0000S00008`001P5h00<0005h0GP0205h0P00
3@5h0P006d0000<005@0E00025@00P002d@000<005@0E0001U@0360000<006P0J0000P00106k00<0
006k0K/0106k00H007ooOomoo`00A00200030A/00`000A/16`020A/200000`4L000170060A`30003
0Cd010000G/1N`003P5k00<0005h0GP00P001d@000<006`000002g0027P000=/04P0B00034P000<0
07P0N00027P00V`00P002P5h00<0005h00002`5h00<007ooOol0;Woo00<007ooOol0?Woo0012Ool0
0`00Oomoo`0ROol3000202<300000`0S000000050GP00`000GP1N0080GP010000GP1N0002`5h00<0
0400@0006d0000<005@0E0001e@000<004@0A00034@000<005@0E0001U@0360000=X000000001P6k
00<0006k0K/00P6k00<007ooOol00Woo00<004@00000104K00<0004K0A/00P00104L00<0004L0A`0
0P4L0P000P4m00L0004m0Cd1?@000G/0000>0G/00`000G/000020GP00`00A0140005A002000;L008
N002K00>B0000`00N01h0007N003K0000`000GP1N00:0GP00`000GP1N00;0GP00`00Oomoo`0]Ool0
0`00Oomoo`0nOol0049oo`03001oogoo025oo`<000808`8000808`030001N00000D1N0030001N05h
00P1N0050001N05h0GP000090GP00`00@010000M@0000`00E01D0005E0000`00A014000>A0000`00
E01D0006E00;H00200070K/00`000K/1^`020006Ool00`00A00000040A/200060A`00`000A`17002
00050Cd00`000Cd1?@02000=0G/200030G/010000GP1N0001D@00P0000=40000L000270027P00V`0
00<004P0B00034P000<007P0N0001WP00f`000<0005N00002P5h00<0005h0000305h00<007ooOol0
;Goo00<007ooOol0?Woo001UOol3000202<2000202<010000GP1N000105h00<0005h0GP0205h00<0
005h0GP00`5h00<0005h0GP01@5h00<00400@0007d0000<005@0E0000U@00P004T@000<005@0E000
1U@026000P0000<1?P000K/01`6k0P002Goo0P000P4K0`001`4L0`00204m0P000P5N00<0005k0G/0
2@5k00<0005k0G/0105k00@0005h0GP00094008000=40003001`070000I`00Qh009/000300180000
00i80003001h07P000Ah00=/00050001GP5N0Eh000080GP01@000GP1N05h0000305h00<007ooOol0
;7oo00<007ooOol0?Woo001TOol00`0002<0000202<2000202<01@000GP1N05h0000105h00<0005h
0GP0205h00<0005h0GP0105h00<0005h0GP00`5h00<00400@0008D0000@005@0000001E40003001D
05@000ID00IP00030001?P4n0081?P030001^`6k00@1^`8000]oo`<000<170030001704L00817080
0081?@030001?@4m00@1?@8000030Eh0005N0081GP030001N`5k00L1N`030001N`5k00D1N`040001
N05h0GP20006A0000`00L01`0004L008N002K0001@00B01804P000003DP000<007P0N0000gP00f`0
00<0005N0Eh00`5N00<0005h0GP0105h00<0005h0GP00`5h00<0005h0GP02P5h00<007ooOol0:goo
00<007ooOol0?Woo001SOol0100002<0000S0`000P0S1@00105h00<0005h0GP0205h00<0005h0GP0
1P5h00@0005h0GP1N0<002=00003001404@001I40003001D05@000ID00AP00030001?P4n00<1?PL0
00ioo`8000<170030001704L008000@1?@030001?@4m0081?@8000@1GP030001GP5N008000H1N`80
00T1N`030001N05h008000M40003001`0700009`00Qh009/0003001804P000980003001804P000]8
0003001h07P0009h00=/00030001GP5N00D1GP030001N05h0081N0030001N05h00D1N0030001N05h
00X1N003001oogoo02Yoo`03001oogoo03ioo`00HWoo00P0000S00008`0002<0000S0P0000<1?P00
0GP00P5h5@00105h00<0005h00000P`000<00400@0007d000P006T@000<005@0E0001U@000=P0000
0000104n0P000P7o0P004Woo00<0004L0A`00P4L0P001`4m00@0004m000000L1GP800081O`8000<1
N`030001N`5k00X1N`030001N000009/00M40003001`070000Qh009/0003001804P000A800030018
04P000Y80004001h07P0N003K0000`000Eh1GP060Eh01@000GP1N05h00002@5h00<0005h0GP02P5h
00<007ooOol0:Goo00<007ooOol0?Woo0012Ool00`00Oomoo`0LOol01P0002<0000S00008`<000@1
?P030001N05h00@1N0030001N05h00P1N0030001N05h00<1N0H0009oo`8<00030010040001a00080
01a40003001D05@000ID00050001?P4n0001?P06000EOol01P000A`000000Cd000L1?@8000L1GP80
00030Gl0005o00<1O`<000h1N`0500140000A01/0006A0000`00L01h0007N002K0000`00B0180006
B0000`00B018000:B0000`00N01/0002K00200090Eh00`000GP0000;0GP00`000GP1N00:0GP00`00
Oomoo`0XOol00`00Oomoo`0nOol0049oo`03001oogoo01]oo`<0000302<0000S008000L1?P030001
N05h00@1N0030001N05h00P1N0030001N05h00H1N0030001N000009oo`8<00030010040001U00080
01m40003001D05@000AD00040001?P4n0Ch7000GOol01@000Cd1?@4m00001@4m0P000P5N00<0005N
0Eh00P5N0P00105o00<0005o0Gl00`0000<1W`0000002`5k00L004@0A0140000A01/0006A0000`00
N01h0005N002K0000`00B0180008B0000`00B0180009B0001@00K01/06`000000P5N00<0005N0Eh0
1P5N0P003@5h00<0005h0GP02P5h00<007ooOol09goo00<007ooOol0?Woo0012Ool00`00Oomoo`0J
Ool2000202<300000`4n0001?P070Ch200040GP00`000GP1N0080GP00`000GP1N0050GP01P000GP1
N05h001oo`8<008001Q0008002940004001D05@0E00200020Ch200000`7o00000002000IOol20003
0Cd00`000Cd1?@0200050Eh010000Eh000001P5o10001@6O0`001`5k00<004@0A0000d@000@004@0
A01/00A40003001h07P000Ah009/0003001804P000Y80003001804P000Q80004001/06`000040Eh0
0`000Eh1GP030Eh200020Eh00`000GP1N00:0GP00`000GP1N00;0GP00`00Oomoo`0VOol00`00Oomo
o`0nOol0049oo`03001oogoo01Uoo`8000808`8000@1?P030001?P4n00D1?P8000@1N0030001N05h
00P1N0030001N05h00@1N0030001N05h00<1N004001oo``03002000E@003000TA0000`00E0000002
0Ch7000LOol200020Cd300070Eh200060Gl300020Il200030Il200020Il400020G/00`00A0140005
A0001000A01406`014@000<007P0N0000WP00V`000<004P0B00034P000<004P0B0001TP000D006`0
K01/000000D1GP030001GP5N008000D1GP030001N05h00X1N0030001N05h00/1N003001oogoo02Eo
o`03001oogoo03ioo`00@Woo00<007ooOol05goo0`000P0S0P001@4n00<0004n0Ch01P4n00<0005h
0GP00`5h00<0005h0GP0205h00<0005h0GP00P5h00<0005h0GP01@5h00@007oo300<008001900080
00=oo`03001404@0029400030001?P0000H001moo`<00081GP030001GP5N00<1GP800081O`800081
O`<000H1W`<000P1W`8000U40003001404@000A40004001h07P0N002K0000`00B018000>B0000`00
B0180005B0001000K01/00001P5N0`00205N00<0005h0GP02P5h00<0005h0GP02@5h0`009Woo00<0
07ooOol0?Woo001KOol00`0002<0000202<00`000Ch1?P060Ch00`000Ch1?P050Ch200040GP00`00
0GP1N0080GP01@000GP1N05h0000205h00<007ooOol00P`00P003d000P001Goo0P008D@02@008Woo
0P000`5N00<0005N0Eh00P001@5o10001P6O0P000`6O0P000`6O0`002d@000<004@0A0000T@000=/
04@000000WP00V`000<004P0B0003dP000<004P0B00014P000@006`0K00000D1GP800081GP030001
GP5N00L1GP030001N05h00X1N0030001N05h00L1N0030001N05h008002Eoo`03001oogoo03ioo`00
FWoo00@0000S00008`8000030Ch0004n00L1?P030001?P4n00@1?P030001?P0000@1N0030001N05h
00L1N0040001N05h000:0GP00`00Oomoo`023002000<@0020008Ool00`00A014000MA009000UOol0
10000Eh1GP5N0`001@5o100000<1W`0000000`6O0P001`6O0`003d@000<004@0A00014@000@006`0
K00001=80003001804P000=80004001/000000020Eh300050Eh00`000Eh1GP070Eh00`000GP1N00:
0GP00`000GP1N0050GP010000GP1N05h0P009Goo00<007ooOol0?Woo001IOol00`0002<000020004
0Ch00`000Ch1?P060Ch00`000Ch1?P030Ch010000Ch1?P000`5h00<0005h0GP0205h0P00305h00<0
07ooOol00P`000<00400@00024000P002goo00<004@0A0006T@030009Goo0`000P5o0P000P5o1000
1@6O0`001`6O0P004d@000<004@0A0000d@000<006`000005DP000P004P0B0180000K000005N0`00
205N00<0005N0Eh0205N00<0005h0GP02P5h00<0005h0GP00`5h00<0005h0GP00P5h00<0005h0000
97oo00<007ooOol0?Woo001HOol0100002<000001`4n00<0004n0Ch01P4n00<0004n0Ch01P4n00@0
005h0GP000X1N0030001N05h00`1N003001oogoo008<00030010040000E0008000ioo`03001404@0
01M400P000A4009P008002Aoo`030001O`5o00<1O`@000H1W`800081W`8000<1W`8001I400070014
04@0A00006`000005dP000<004P0B00010000P5N00<0005N0Eh01`5N00<0005N0Eh0205N00<0005h
0GP02P5h00D0005h0GP1N00000H1N0030001N00002=oo`03001oogoo03ioo`00@Woo00<007ooOol0
4Woo0`0000<1?P000Ch01`4n00<0004n0Ch01P4n00<0004n0Ch01P4n00@0005h0GP000P1N0030001
N00000h1N003001oogoo008<00030010040000900080015oo`030014000000/000U400T000A400EP
0003001oogoo029oo`8000030Gl00000008000H1W`8000H1W`<001U40003001404@0008001U800@0
00D1GP030001GP5N00L1GP030001GP5N00L1GP030001N05h00/1N0030001N00000L1N0040001N05h
000ROol00`00Oomoo`0nOol0049oo`03001oogoo015oo`8000@1?P030001?P4n00D1?P030001?P4n
00H1?P030001?P4n00L1?P030001N00000L1N0050001N05h0GP0000>0GP01000Oomoo``00P0000=0
000000004goo0`002D@00V000P001D@0200000<<0000A0000d@01f0000<007ooOol08Goo00<004@0
00000P000P6O0P000P6O0P001P6O0P007D@00`006DP00`001`5N00<0005N0Eh0205N00<0005N0Eh0
1`5N00<0005h0GP02`5h00<0005h0GP01`5h00@0005h0GP0025oo`03001oogoo03ioo`00@Woo00<0
07ooOol047oo00<0004n0Ch01@4n00<0004n0Ch01@4n00<0004n0Ch01P4n00<0004n0Ch01P4n00<0
005h00001P5h00<0005h0GP00`5h00<0005h0GP0305h00<007oo00000`004goo0P0000<<0000A000
24@01F000P0000=40000000017oo0P000P`000=40000A0000T@02F000P008Woo00<004@000001@6O
1000106O0P007d@00P006DP00`002@5N00<0005N0Eh0205N00<0005N0Eh01`5N00<0005h0GP02@5h
0P002@5h00D0005h0GP1N000021oo`03001oogoo03ioo`00@Woo00<007ooOol04Goo00<0004n0Ch0
1@4n00<0004n0Ch01@4n00<0004n0Ch01P4n00<0004n00001P4n00<0005h00000`5h0P001`5h00<0
005h0GP0305h00<007ooOol04goo0P000P`000<004@0A0001d@0260000<007ooOol00Woo0P000``0
00=40000A0000T@0360000<007ooOol087oo00<004@000000P6O0P00106O10007d@00P0064P00`00
0`5N00<0005N0Eh01`5N00<0005N0Eh0205N00<0005N0Eh01`5N00<0005h0GP01`5h00@0005h0GP0
00P1N0050001N05h0GP0000POol00`00Oomoo`06Ool3000eOol0049oo`03001oogoo019oo`030001
?P4n00D1?P030001?P4n00D1?P030001?P4n00H1?P8000L1?P800081N0030001N05h00P1N0030001
N05h00`1N003001oogoo011oo`80008<008000U400YP00@000@<0003A00004@0009400aP009X0003
001oogoo021oo`@000H1W`8001i400<001Q8008000L1GP030001GP5N00L1GP030001GP5N00L1GP03
0001GP5N00P1GP030001N05h00D1N0050001N05h0GP000090GP01@000GP1N05h000077oo10001goo
00D007ooOomoo`0003Aoo`00@Woo00<007ooOol04goo00<0004n0Ch01@4n00<0004n0Ch01@4n00<0
004n0Ch01P4n00<0004n0Ch01P4n0`00305h00<0005h0GP02`5h00<007ooOol03Woo0P000``000<0
04@0A00024@03F000P000``000=40000A0000T@0360016P00P008Goo00@004@0000000<1W`800003
A00004@001]4008000E800@000m800@000T1GP030001GP5N00L1GP030001GP5N00L1GP030001GP5N
00P1GP030001N05h00<1N0030001N05h0081N0030001N05h00L1N0030001N05h0081N003001oogoo
01aoo`03001oogoo00Eoo`05001oogooOol0000JOol7000COol005Uoo`030001?P4n00D1?P030001
?P4n00D1?P030001?P4n00D1?P8000P1?P030001N05h00`1N0030001N05h00/1N003001oogoo00]o
o`8000@<0003001404@000Q4011P0004000<04@00003A00<H007J0000`00Oomoo`0OOol00`00A014
00030004A0000`00A014000GA00200000dP000180002B00300000aP0001l000=B0020004Ool00`00
0Eh1GP060Eh00`000Eh1GP080Eh00`000Eh1GP070Eh00`000Eh1GP080Eh01@000GP1N05h00001P5h
00<0005h0GP01P5h00<0005h0GP00`5h00<007ooOol06goo00<007ooOol01Goo00D007ooOomoo`00
01]oo`03001oogoo009oo`03001oogoo015oo`00FGoo00<0004n0Ch01P4n00<0004n0Ch01@4n00<0
004n0Ch0104n0P001P4n0P0000<1?P000GP03@5h00<0005h0GP02`5h00<007ooOol027oo0P001@`0
00<004@0A00024@04V000P000d@036002FP000<007ooOol07goo0P0024@000<004@0A00024@000=/
04@0A00024@00`0014P00`0000DH0000600H0000009l00U800<000Moo`030001GP5N00H1GP030001
GP5N00L1GP030001GP5N00P1GP030001GP5N00P1GP030001N00000L1N0030001N05h00L1N0030001
N05h00<1N003001oogoo01Yoo`03001oogoo00Eoo`05001oogooOol0000KOol00`00Oomoo`02Ool0
0`00Oomoo`0AOol005Yoo`030001?P4n00D1?P030001?P4n00H1?P030001?P4n00<1?P030001?P00
00@1?P030001?P4n0081?P030001N05h00/1N0030001N05h00`1N003001oogoo00Eoo`8000H<0003
001404@000Q401EP008000aP00]X0080025oo`03001404@000I40003001404@000I40003K01404@0
00M4008000I80080008H0004000H01P00004O006B002000:Ool00`000Eh1GP070Eh00`000Eh1GP07
0Eh00`000Eh1GP080Eh00`000Eh1GP080Eh500050GP00`000GP1N0060GP00`000GP1N0040GP00`00
Oomoo`0IOol00`00Oomoo`05Ool01@00Oomoogoo000077oo00<007ooOol05Goo001KOol00`000Ch1
?P050Ch00`000Ch1?P050Ch00`000Ch1?P060Ch010000Ch000001P4n00<0005h0GP02`5h00<0005h
0GP0305h00<007ooOol00Woo0P001``000<004@0A00024@0660000<00600H00026003VP000<007oo
Ool07goo00<004@0A0001D@000<004@0A0003D@00`001DP00`000aP000D001P0600H000000El0098
00<000eoo`030001GP5N00L1GP030001GP5N00L1GP030001GP5N00P1GP030001GP5N00D1GP800003
0GP0005h0081N0X000D1N0030001N05h00<1N003001oogoo01Uoo`03001oogoo00Eoo`05001oogoo
Ool0000MOol00`00Oomoo`0DOol0045oo`03001oogoo01Qoo`030001?P4n00D1?P030001?P4n00D1
?P030001?P4n00H1?P030001?P4n00L1?P030001N05h00/1N0030001N05h00X1N0040001N000Ool2
000830000`00A0140008A00HH002J0000`00H01P0006H00>J0000`00K000000QOol00`00A0140005
A0000`00A014000:A0020002Ool20002B002000560001P00600H01P0001`00Il0003001oogoo00mo
o`030001GP5N00L1GP030001GP5N00L1GP030001GP5N00L1GP030001GP5N00<1GP<000<1N0030001
N05h00D1N0030001N05h0081N0T000<1N003001oogoo01Qoo`03001oogoo00Eoo`05001oogooOol0
000MOol00`00Oomoo`0DOol0045oo`03001oogoo01Uoo`030001?P4n00D1?P030001?P4n00D1?P03
0001?P4n00<1?P8000030Ch0004n00L1?P030001N05h00`1N0030001N05h00P1N0050001N05h0GP0
000930000`00A0140008A00HH004J0000`00H01P0004H00>J0001@00K01/06`000008Goo0P001T@0
00<004@0A0000T@000=/04@0A0000T@00P001Woo0P001QP000D001P0600H000000=`00Il019oo`03
0001GP0000H000030Eh0005N00P1GP030001GP5N00L1GP030001GP5N0080000302H0005h00<1N003
0001N05h00@1N0030001N05h00P1N0040001N05h0GP5000IOol00`00Oomoo`06Ool3000OOol00`00
Oomoo`0COol0045oo`03001oogoo01Yoo`030001?P4n00D1?P030001?P4n00D1?P030001?P4n0080
00@1?P030001?P4n00H1?P030001N05h00`1N0030001N05h00H1N0030001N05h00<1N003000<00`0
00@<008000Y401QP00IX0003001P0600009P00iX0003001/06`000=/0003001oogoo021oo`8000E4
0003001404@000=400<000Eoo`<000LH0005000H01P060000005L005O00BOol3000470001@00O001
GP5N00002@5N00<0005N0Eh01P5N0`000P0V00<0005h0GP0105h00<0005h0GP00`5h00<0005h0GP0
1`5h00<0005h0GP01@5h00<007ooOol067oo00<007ooOol09Goo00D007ooOomoo`0001Aoo`00@Goo
00<007ooOol06goo00<0004n0Ch01@4n00<0004n0Ch01@4n0`001P4n00<0004n0Ch01P4n00<0005h
0GP0305h00<0005h0GP00`5h0P001`5h00<000`030000P`000<004@0A0002D@0660026P000<00600
H0003VP000<006`0K0001F`000<007ooOol08Goo0P0014@000<004@0A0000P001Goo0`000P4E0P00
1AP000D001P0600H000000M`00El00ioo`<00003700001`0008L0003000L0000009l0081GP030001
GP5N00H1GP030001GP5N00@1GP<000<09P030001N05h00H1N0050001N05h0GP0000:0GP00`000GP1
N0040GP00`00Oomoo`0IOol00`00Oomoo`0UOol6000COol0045oo`03001oogoo01aoo`030001?P4n
00D1?P030001?P4n0081?P8000030Ch0000000L1?P030001?P4n00H1?P030001N05h00`1N0050001
N05h0GP000090GP01@00300<00`000002d@066002VP000<006P0J00036P000<006`0K0001V`000<0
07ooOol08goo1`000goo10001`4E0P000QP000D001P0600H000000U`00El00]oo`8000<L0003000L
01`000<L0003001l07`0009l00030Eh0005N00P1GP030001GP5N00<0000302H0000V00809P030001
N05h00P1N0040001N05h00090GP00`000GP1N0040GP00`00Oomoo`0JOol00`00Oomoo`0nOol0045o
o`03001oogoo01aoo`030001?P4n00H1?P040001?P0000040Ch00`000Ch1?P060Ch00`000Ch1?P06
0Ch00`000GP1N00<0GP00`000GP0000;0GP00`003000000;A00HH00<J0000`00J01X000:J0000`00
K01/0008K0000`00Oomoo`0YOol00`000AD15@0;0AD010000GP000000QP00P0000=/0000L0002700
1G`01goo0`000a`00P001Q`000<007`0O0000g`000<1GP000Eh01`5N0`000`0V00D0000V02H09P00
00/1N0040001N05h00090GP00`000GP1N0030GP00`00Oomoo`0KOol00`00Oomoo`0nOol0065oo`03
0001?P4n00H1?P030001?P4n00@1?P8000P1?P030001?P4n00H1?P030001N05h00`1N0030001N05h
00/1N0H000I401QP00iX008000UX0003001/06`000Y/0003001oogoo02Ioo`8000030AD0000000X1
5@030001N05h00D000=/0003001`070000M`00El00Aoo`8000DL0005000L01`0701/000370000`00
O01l0005O0000`5N0001GP040Eh3000402H00`0002H09P0202H00`000GP1N00:0GP2000:0GP00`00
0GP1N0020GP00`00Oomoo`0LOol00`00Oomoo`0nOol0069oo`030001?P4n00<1?P8000030Ch0004n
00@1?P030001?P0000P1?P030001?P4n00H1?P030001N05h00X1N0030001N00000d1N00300100400
009000H001MP015X0003001X06P000EX0003001/06`000a/0003001oogoo029oo`@000@15@8000L1
5@040001N05h0GP200000aP0001/0004K0000`00L01`0007L005O003000670000`00700L00067000
0`00O01l0006O000105N0001GP5N0P0000<09P0002H00`0V00<0000V02H00P0V00<0005h0GP0305h
00<0005h0GP01`5h00<0005h0GP00P5h00<007ooOol07Goo00<007ooOol0?Woo001SOol00`000Ch1
?P0200040Ch00`000Ch1?P020Ch010000Ch1?P00204n00<0004n0Ch01P4n00<0005h0GP0205h00D0
005h0GP1N00000d1N0030010040000M0008001AP01=X0003001X06P000=X0003001/06`000i/0003
001oogoo01moo`@000P15@8000@15@050001N05h0GP0000260000`00K01/0004K0020009L004O008
70000`00700L000670000`00O01l0007O000105N000000000P0V00<0000V02H00P0V00<0000V02H0
0P0V00<0005h0GP0305h00<0005h0000205h00D0005h0GP1N000021oo`03001oogoo03ioo`00I7oo
0P001`4n00<0004n0Ch01@4n00<0004n0Ch01@4n00<0004n0Ch01`4n00<0005h0GP01P5h00<0005h
0GP00`5h00<0005h0GP02`5h00<00400@000240000<00600H00046005FP000D006P0J01X0000019/
0003001oogoo01]oo`D000`15@8000030AD0005h0081N004000H01P00008K0000`00L01`0007L000
0f`0O01l0002O00670000`00700L000670000`00L01l0009O0001@0002H09P0V0000100V00<0000V
02H00P0V00<0005h0GP0305h00D0005h0GP1N00000H1N0050001N05h0GP0000QOol00`00Oomoo`0n
Ool0045oo`03001oogoo025oo`030001?P4n00H1?P030001?P4n00D1?P030001?P4n00D1?P030001
?P4n00H1?P030001N05h00D1N0030001N05h00D1N0030001N05h00X1N08000Y0008000mP01MX0003
001X000001A/0003001oogoo01Moo`H001015@050001N05h0GP0000260000`00K01/0008K0000`00
L01`0007L0000f`0O01l0002O00470000`00700L000670001000L01`07002W`00P0V00<0000V02H0
0P0V00<0000V02H00P0V00<0005h0GP0305h00<0005h0GP00`5h00<0005h0GP00`5h00@0005h0GP0
029oo`03001oogoo03ioo`00@Goo00<007ooOol08Woo00<0004n0Ch01@4n00<0004n0Ch01P4n00<0
004n0Ch01@4n00<0004n0Ch01P4n00<0005h0GP00`5h00<0005h0GP01P5h00<0005h0GP02`5h0P00
2d0000<00600H0002f006FP000<006`0K00056`000<007ooOol057oo100000@08`0000015@8000d1
5@050001N0000GP0000260000`00K01/000:K0000`00L01`0007L0000f`0O01l0002O00270000`00
701/000670000`00L01`0003L00:O0000`0002H09P0202H00`0002H09P0202H00`000GP1N00<0GP0
0`000GP1N0040GP00`000GP1N0030GP00`000GP0000SOol00`00Oomoo`0nOol0045oo`03001oogoo
02=oo`030001?P4n00D1?P030001?P4n00D1?P030001?P4n00H1?P030001?P4n00H1?P050001N05h
0GP0000:0GP00`000GP1N00;0GP00`00@010000:@002000:H00KJ0000`00K01/000CK0000`00Oomo
o`0BOol400001@0S0000000W00000`4E0P002P4E00P0005h0GP1N000K00H00003V`000<00700L000
1g0000=/07`0O0000W`000<L000070001a`000<00700L00017002W`00`0V00<0000V02H00P0V00<0
005h0GP0305h00<0005h0GP01P5h00L0005h0GP1N0000GP0000TOol2000oOol0045oo`03001oogoo
02Aoo`030001?P4n00D1?P8000H1?P030001?P4n00H1?P030001?P4n00H1?P030001N00000`1N003
0001N05h00/1N0030010040000]0008000MP01eX0003001/06`001=/0003001oogoo00moo`@00006
02<0000000009`001P4E0P001`4E00P0005h0GP1N1P0K00H000046`000<00700L0001g0000E/07`0
O01l000000PL0003001`070000I`00Yl000302H0000V00809P8000h1N0030001N05h00P1N0030001
N05h008002Eoo`8003moo`00@Goo00<007ooOol097oo00<0004n0Ch01P4n00<0004n0Ch01@4n00<0
004n0Ch01P4n00<0004n0Ch01P4n00<0005h0GP0305h00<0005h0GP02`5h00<00400@000340000<0
0600H0000f007FP000<006`000005F`000<007ooOol037oo0`0000D08`000000000W00<000T15@80
00@15@800081N004601/01P0000BK0000`00L01`0007L0001F`0O01l07`000001Q`000<00700L000
27002G`000<0000V02H00`0000<1N0000GP02`5h00<0005h0GP02P5h0`009Woo0P00?goo0011Ool0
0`00Oomoo`0UOol00`000Ch1?P050Ch200070Ch00`000Ch1?P060Ch00`000Ch1?P030Ch200000`4n
0001N00=0GP00`000GP1N00;0GP00`00@010000<@0020002H00MJ0001@00K01/06`000005F`000<0
07ooOol02Woo0P0000D08`000000000W00<0000302d0004E00X15@8000030AD000000081N0<H0003
001/06`0019/0003001`070000M`0004K01l07`0000570000`00L01`000:L009O00200000`0V0001
N0020GP00`000GP1N0080GP00`000GP1N00<0GP00`00Oomoo`0UOol2000oOol006Yoo`030001?P4n
00@1?P030001?P0000L1?P030001?P4n00H1?P030001?P4n008000@1?P030001N05h00`1N0030001
N05h00/1N0030010040000e00003001X06P001]X0003001/06`000=/0003001/06`001=/0003001o
ogoo00Moo`80000502<0000000009`03000202d00`000AD15@0<0AD200020GP460000`00K01/000B
K0020009L0000f`0000L000470000`00L01`000<L009O0000`0V0001N0040GP00`000GP1N0060GP0
0`000GP1N00<0GP00`00Oomoo`0VOol2000oOol006]oo`030001?P4n00<1?P040001?P4n00070Ch0
0`000Ch1?P060Ch200070Ch00`000GP1N00<0GP00`000GP1N0090GP00`000GP0000?@0000`00J01X
000IJ0000`00K01/0005K0000`00K01/000CK0000`00Oomoo`04Ool00`0002<000020000100W0000
00000P0]00@0000]02d000d15@800081N08H0003K00H000001I/008000U`0003000L01`0008L0003
001`070000i`00Ul00H1N0030001N05h00D1N0030001N05h00`1N003001oogoo02Moo`8003moo`00
K7oo00<0004n0Ch00P4n00D0004n0Ch1?P0000L1?P030001?P4n00<1?P8000030Ch0004n00L1?P03
0001N05h00`1N0030001N05h00L1N0040001N05h000@@0000`00J01X000GJ0000`00K01/0006K000
0`00K01/000DK0000`00Oomoo`02Ool40000100W000000000`0]00<0000]05000P00304E0P0000<1
N00060000aP000<006`0K0005V`00P001g0000<001`070000a`000<00700L0003W002W`01P5h00<0
005h0GP00`5h00<0005h0GP0305h00<007ooOol09goo0P00@7oo001]Ool00`000Ch1?P050Ch00`00
0Ch1?P060Ch00`000Ch1?P0200040Ch00`000Ch1?P050Ch00`000GP1N00=0GP00`000GP1N0050GP0
0`000GP1N0020GP00`00@0100003@0000`00@0100008@0000`00J01X000EJ0000`00K01/0008K000
0`00K01/000DK0000`00Oomoo`030000100W00000000100]100000@0D000000000P15@<00081N0@H
0003001/06`001Q/0003001`070000A`0003000L01`000<L0003001`0700011`00Yl00H1N0050001
N05h0GP0000>0GP00`00Oomoo`0YOol2000oOol0045oo`03001oogoo02Yoo`030001?P4n00D1?P03
0001?P4n00H1?P8000H1?P030001?P4n00H1?P030001N05h00`1N0030001N05h00@1N0030001N05h
00@1N0030010040000i0008001AX0003001/06`000Y/0003001/06`001=/0004001oo`0002L30002
02d00`0002d0;@030003050010000AD15@4E0P001@4E00<0005h00000P5h11P000<006`0K0006V`0
00<00700L0000W0000<001`070000Q`00P0057002G`000<0005h0GP0105h00<0005h00003P5h00<0
07ooOol0:Woo00<007ooOol0?Woo0011Ool00`00Oomoo`0[Ool00`000Ch1?P050Ch00`000Ch1?P03
0Ch200000`4n0001?P060Ch00`000Ch1?P060Ch00`000GP1N00<0GP00`000GP1N0030GP00`000GP1
N0050GP00`00@010000?@0000`00J01X000@J0000`00K01/000<K0000`00K01/000CK004000302d0
100002d000000P1@00<0001@05000P001@4E0P000P4E00<0005h00000P5h11P000<006`0K00076`0
00D00700L01`0000008L00<00003K000070001=`00Ql00030001N05h00D1N0030001N05h00`1N003
001oogoo02]oo`03001oogoo03ioo`00@Goo00<007ooOol0:goo00<0004n00001P4n00<0004n0Ch0
0P00104n00<0004n0Ch01@4n00<0004n0Ch01P4n00<0005h0GP0305h00D0005h0GP1N00000T1N0H0
00a00003001X06P000iX0003001/06`000i/0003001/06`001=/00030000;@0]0080;@<000<0D006
0000D0000000LP001`4E0P0000@1N0000GP1N0@H0003001/06`001i/0003001`000000<000037000
06`0009/0003001`0700019`00Il00030001N05h00D1N0030001N00000`1N003001oogoo02aoo`80
03moo`00@Goo00<007ooOol0;7oo0P001`4n0P001`4n00<0004n0Ch01@4n00<0004n0Ch01P4n00<0
005h0GP0305h00<0005h00002`5h00<00400@0000T000P002d0000<006P0J00036P000<006`0K000
46`000<006`0K0004f`000<0000]00000P00101@0`000`1b00<0004E0AD01@4E00<0005h00000P5h
11P000<006`0K0007f`00`000a`000<006`0K0000f`000<00700L0004W001G`000<0005h0GP0105h
00D0005h0GP1N00000/1N003001oogoo02aoo`8003moo`00@Goo00<007ooOol0;Goo00<0004n0Ch0
0`4n0P0000<1?P000Ch01`4n00<0004n0Ch01@4n00<0004n0Ch01P4n00<0005h0GP0305h00<0005h
0GP02`5h00<00400@0000d000P002T0000<006P0J0002VP000<006`0K0004V`000<006`0K0004f`0
00@0001@05000080D08000030780001b0080LP0300015@4E00D15@050001N0000GP0000460000`00
K01/000PK0000`00700L000270000`00K01/0005K0000`00L01`000BL003O0000`000GP1N0040GP0
0`000GP1N0020GP00`000GP1N0080GP00`00Oomoo`0^Ool00`00Oomoo`0mOol0071oo`03001oo`00
0081?P8000@1?P030001?P4n00D1?P030001?P4n00H1?P030001?P4n00H1?P030001N05h00X1N003
0001N00000d1N0030010040000A0008000U00003001X06P000QX0003001/06`001A/0003001/06`0
015/0005001`00000000D002000307801@000780LP1b00001P4E00<0005h00000P5h11P000<006`0
K00086`000<001`070000Q`000<006`0K0001V`000<00700L0004g000W`000<0005h0GP00`5h00<0
005h0GP0105h00<0005h0GP01P5h00<007ooOol0;goo00<007ooOol0?Goo001`Ool00`00Oomoo`02
00070Ch00`000Ch1?P050Ch00`000Ch1?P050Ch00`000Ch1?P070Ch00`000GP1N0080GP01@000GP1
N05h00003@5h00<00400@0001D0000<00400@0001d0000<006P0J0001VP000<006`0K0005F`000<0
06`0K00046`000<00700L0000`00101b00<0001b07800P1b00<0004E0AD0104E0P000P5h0aP00P00
8V`000<001`070000Q`000<006`0K00026`000<00700L0004g0000<0005h0GP00`5h00<0005h0GP0
1P5h00<0005h0GP0105h00<007ooOol0<7oo00<007ooOol0?Goo001`Ool01@00Oomoogoo0000204n
00<0004n0Ch01@4n00<0004n0Ch01@4n00<0004n0Ch01`4n00<0005h0GP01P5h00<0005h0GP00P5h
00<0005h0GP0305h00<00400@0001D0000<00400@0001d000P001FP000<006`0K0005f`000<006`0
K0003V`000<00700L0000W0000<0001b07800`1b00<0001b07800P0000<1?P000AD00`4E0P000P5h
00<H000000000P0000=X0000K0007f`000<001`070000Q`000<006`0K0002V`000<00700L0004W00
00<0005h0GP00P5h00<0005h0GP0205h00<0005h0GP00P5h00<007ooOol0<Goo00<007ooOol0?Goo
001eOol00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000GP1
N0050GP00`000GP1N0040GP00`000GP1N00;0GP00`00@0100006@0000`00@0100008@0001@00J01X
06P000006f`000<006`0K00036`000<00700L000170000<0001b07800P1b0`00104n0P0000<15@00
00000P5h0P000QP000D006P0J01X000001i/0003000L01`0008L0003001/06`000a/0003001`0700
011`00030001N05h0081N0030001N05h00T1N0050001N05h0GP0000dOol00`00Oomoo`0mOol0045o
o`03001oogoo039oo`030001?P4n00D1?P030001?P4n00H1?P030001?P4n00D1?P030001?P4n00H1
?P030001N05h00<1N0030001N05h00H1N0030001N05h00/1N0030010040000I000030010040000E0
000600100400001X00007F`000<006`0K0002V`000<00700L0001W0000<0001b07800P00204n0P00
0P5h00D001P0600H000000EX0003001/06`001Y/0003000L01`0008L0003001/06`000i/0003001`
070000i`00030001N05h00<1N0030001N05h00X1N0030001N00003Eoo`03001oogoo03eoo`00@Goo
00<007ooOol0<goo00<0004n0Ch01@4n00<0004n0Ch01P4n00<0004n0Ch01@4n00<0004n0Ch01P4n
00D0005h0GP1N00000X1N0030001N05h00/1N0030010040000I000030010040000M0008001m/0003
001/06`000M/008000U`00<00081?P030001?P4n00<1?P8000040Ch00000000360000`00J01X0005
J0000`00K01/000HK0000`00700L000270000`00K01/000@K0000`00L01`000<L0000`000GP1N003
0GP00`000GP1N00<0GP00`00Oomoo`0dOol00`00Oomoo`0mOol0045oo`03001oogoo03=oo`030001
?P4n00H1?P030001?P4n00H1?P030001?P4n00D1?P030001?P4n00H1?P030001N00000`1N0030001
N05h00/1N0030010040000I000030010040000A0008000900003001/06`001e/0003001/06`000E/
0003001`070000Y`00050001?P4n0Ch000020Ch30000104n0000000011P000<006P0J0001VP000<0
06`0K0005f`000<001`070000Q`000<006`0K0004V`000<00700L0002g0000<0005h0GP00P5h00<0
005h0GP0305h00<007ooOol0=Goo00<007ooOol0?Goo0011Ool00`00Oomoo`0/Ool00`00Oomoo`05
Ool00`000Ch1?P060Ch00`000Ch1?P060Ch00`000Ch1?P040Ch00`000Ch1?P060Ch2000>0GP00`00
0GP1N00;0GP00`00@0100006@0000`00@01000030005@0000`00K01/000MK0000`00K01/0003K000
0`00L01`000:L0000gP00001?P020Ch300020Ch200000aP0000H000360000`00J01X0008J0000`00
K01/000EK0000`00700L000370000`00K01/000CK0000`00L01`0009L0000`000GP1N0020GP00`00
0GP1N00<0GP00`00Oomoo`0fOol00`00Oomoo`0mOol0045oo`03001oogoo02aoo`03001oogoo00Io
o`030001?P4n00H1?P030001?P4n00D1?P030001?P4n00D1?P030001?P4n00<1?P800081?P030001
N05h00/1N0030001N05h00`1N0030010040000E000<000U00003001/06`001e/0005001/06`0K000
000<L003N00300020Ch3000260000`00600H000260000`00J01X000:J0000`00K01/000CK0000`00
700L000370000`00K01/000EK0000`00L01`0007L0000`000GP1N0020GP00`000GP1N00<0GP00`00
Oomoo`0gOol00`00Oomoo`0mOol0045oo`03001oogoo02aoo`03001oogoo00Moo`030001?P4n00H1
?P030001?P4n00D1?P030001?P4n00D1?P030001?P4n008000D1?P030001N05h00/1N0030001N05h
00`1N08000=00080009000030010040000Q00003001/06`001a/0004001/06`0000<L004N0001000
0Ch1?P4n1AP000@001P0600H00800003H01X06P000]X0003001/06`0015/0003000L01`000<L0003
001/06`001M/0003001`070000E`008000<1N0030001N05h00`1N003001oogoo03Qoo`03001oogoo
03eoo`00L7oo00<007ooOol027oo00<0004n0Ch01P4n00<0004n0Ch01@4n00<0004n0Ch0104n0`00
204n00<0005h0GP02`5h00<0005h0GP02P5h1P001D0000<00400@0001d0000<006`0K0007F`00P00
37001GP000<0004n60001AP000D001P0600H000000AP00eX0003001/06`0011/0003000L01`0008L
0003001/06`001Q/0003001`070000A`00060001N05h0001N0003P5h00<007ooOol0>Goo00<007oo
Ool0?Goo001`Ool00`00Oomoo`09Ool00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P030002
0Ch00`000Ch1?P070Ch00`000GP1N00;0GP00`000GP1N0080GP01`000GP0005h0001N00000I00003
0010040000M00003001/06`001e/0003001`070000U`00Ih0003000H01P000@H0005000H01P06000
0006H00=J0000`00K01/000>K0000`00700L000270000`00K01/000JK0000`00L01`0002L0000`00
0GP1N0020GP00`000GP1N00<0GP00`00Oomoo`0jOol00`00Oomoo`0mOol0071oo`03001oogoo00Yo
o`030001?P4n00D1?P030001?P4n00H1?P8000H1?P030001?P4n00H1?P030001N05h00`1N0030001
N05h00H1N0040001N05h00020GP00`000GP00006@0000`00@0100007@0000`00K01/000MK0000`00
L01`0007L008N0000`00600H000260000`00600H00020008H00=J0000`00K01/000<K0000`00700L
000270000`00K01/000LK0001@00L01`070000000`5h00<0005h0000305h00<007ooOol0>goo00<0
07ooOol0?Goo001nOol00`000Ch1?P050Ch00`000Ch1?P030Ch200000`4n0001?P060Ch00`000Ch1
?P060Ch00`000GP1N00<0GP00`000GP1N0040GP01@000GP1N05h00000P5h00@0005h0GP000I00003
0010040000M00003001/06`001e/0003001`070000E`00Uh0005000H01P06000000260000`00H01P
0009H00=J0000`00K01/000:K0000`00700L000270000`00K01/000NK0000`00L00000030GP01@00
0GP1N05h00002P5h00<007ooOol0?7oo00<007ooOol0?Goo0011Ool00`00Oomoo`0jOol00`000Ch1
?P060Ch00`000Ch1?P0200040Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000GP1N00;0GP00`00
0GP1N0030GP00`000GP1N0020GP01@000GP1N05h00000P5h00<00400@000140000<00400@0001d00
00<006`0K0006f`000<0070000001G002GP000H001P0600H0000600200000e@0H01P000:H00=J000
0`00K01/0008K0000`00700L000270000`00K01/000PK0001@000GP1N05h00001@5h00<0005h0GP0
1P5h00<007ooOol0?Goo00<007ooOol0?Goo0011Ool00`00Oomoo`0kOol00`000Ch1?P060Ch20007
0Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000GP1N00;0GP01@000GP1N05h00001@5h00<0005h
0GP00P5h00<0005h00001T0000<00400@000240000<006`0K0006F`000D00700L01`000000=`00Uh
0004K00001P060030004E00<H00<J0020008K0000`00700L000270000`00K01/000PK0001@000GP1
N05h00001P5h00<0005h0GP01@5h00<007ooOol0?Woo00<007ooOol0?Goo0011Ool00`00Oomoo`0l
Ool00`000Ch1?P030Ch200000`4n0001?P070Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000GP1
N00;0GP00`000GP000060GP00`000GP1N0030GP00`000GP00006@0000`00@0100008@0000`00K01/
000GK0000`00L01`0002L0000`00L01`0009N0000f`0000H00030007E00<H00<J0000`00K01/0005
K0000`00700L000270000`00K01/000PK0001@000GP1N05h0000205h00<0005h0GP00`5h00<007oo
Ool0?goo00<007ooOol0?Goo0011Ool00`00Oomoo`0/Ool00`00Oomoo`0>Ool00`000Ch1?P020004
0Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P060Ch00`000GP1N00;0GP200060GP01000
0GP1N05h0P0000@1N0000GP000I000030010040000Q00003001/06`001E/0003001`070000A`0003
001h07P000Mh0004K00000000002A0000`00E01D0006E00;H0000f`0J01X000:J0000`00K01/0003
K0001000700L01`00P008V`000D0005h0GP1N00000X1N0050001N05h0GP00012Ool00`00Oomoo`0m
Ool0045oo`03001oogoo02aoo`03001oogoo00moo`8000L1?P030001?P4n00D1?P030001?P4n00H1
?P030001?P4n00H1?P030001N05h00T1N0030001N05h00@00081N0040001N00000040GP00`000GP0
0006@0000`00@0100007@0000`00K01/000DK0000`00L01`0006L0000`00N01h0005N0000f`00000
0005A0000`00E01D0006E00;H00=J0001P00K01/06`0000L00@00003J00006`001m/00050001N05h
0GP0000<0GP00`000GP00011Ool3000oOol0045oo`03001oogoo02aoo`03001oogoo011oo`030001
?P4n00H1?P030001?P4n00D1?P030001?P4n00D1?P030001?P4n00L1?P030001N05h00L1N0030001
N05h00D1N0@000L1N0030001N00000I000030010040000M00003001/06`0019/0003001`070000Q`
0003001h07P000=h0003K00004@000M40003001D05@000ID00]P00eX0003001/00000080008L0005
001X06P0J000000NK0001@000GP1N05h00003P5h00<007ooOol0@Woo00<007ooOol0?Goo001`Ool0
0`00Oomoo`0AOol00`000Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1?P050Ch00`000Ch1?P060Ch0
0`000GP1N0060GP00`000GP1N0080GP00`000GP1N0070GP00`000GP00006@0000`00@0100007@000
0`00K01/000@K0000`00L01`000:L0001P00N01h07P0K00000Y40003001D05@000ED0003K01P0600
00UP00eX008000<L0003001X06P000=X0003001/06`001Y/00050001N05h0GP0000>0GP00`00Oomo
o`13Ool00`00Oomoo`0mOol0071oo`03001oogoo019oo`030001?P4n00H1?P030001?P4n00D1?P03
0001?P4n00D1?P030001?P4n00H1?P030001N05h00<1N08000/1N0030001N05h00P1N0030001N000
00I000030010040000M00003001/06`000i/0003001`070000]`0005001h07P0K000000;A0000`00
E01D0006E00<H00;J0000`00700L000270000`00J01X0005J0000`00K01/000HK0001@000GP1N05h
00003P5h00<007ooOol0A7oo00<007ooOol0?Goo001`Ool00`00Oomoo`0COol00`000Ch1?P060Ch0
0`000Ch1?P050Ch00`000Ch1?P050Ch00`000Ch1?P060Ch01@000GP1N05h00003@5h00<0005h0GP0
2@5h00<0005h00001T0000<00400@0001d0000<006`0K00036`000<00700L0003G0000<006`00000
3D@000<005@0K0001U@0360026P00P000a`00P0026P000<006`0K0005f`000D0005h0GP1N00000h1
N003001oogoo04Eoo`03001oogoo03eoo`00Qgoo00<0004n0Ch01P4n00<0004n0Ch01@4n00<0004n
0Ch01@4n00<0004n0Ch01P4n00<0005h00003P5h00<0005h0GP02P5h0P001d0000<00400@0001d00
00<006`0K0002V`000<00700L0003g0000<004@0A0003D@000<005@0K0001U@036001VP000<001`0
J0000a`000<006P0J00026P000<006`0K0005F`000D0005h0GP1N00000h1N005001oogooOol00014
Ool00`00Oomoo`0mOol0045oo`03001oogoo04Aoo`030001?P4n00D1?P030001?P4n00H1?P030001
?P4n00D1?P030001?P4n00H1?P8000h1N0030001N05h00P1N08000030GP0000000M0000300100400
00M00003001/06`000Q/0003001`0700015`0003001404@000e40003001D06`000ID00aP00AX0003
000L06P0008L008000aX0003001/06`001=/00050001N05h0GP0000>0GP00`00Oomoo`02Ool00`00
Oomoo`12Ool00`00Oomoo`0mOol0045oo`03001oogoo04Eoo`030001?P4n00D1?P030001?P4n00H1
?P030001?P4n00D1?P030001?P4n00<1?P8000040Ch00000000<0GP00`000GP1N0060GP400020GP2
0007@0000`00@0100007@0000`00K01/0006K0000`00L01`000CL0000`00A014000=A0000`00E01D
0006E00<H0000fP00000000470000`00J01X000=J0000`00K01/000AK0001@000GP0005h00003P5h
00<007ooOol00goo00<007ooOol0@Woo00<007ooOol0?Goo0011Ool00`00Oomoo`16Ool00`000Ch1
?P050Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P0200040Ch00`000GP0000200090GP0
0`000GP1N0040GP200000`5h000000040GP20007@0000`00@0100006@0000`00K01/0005K0000`00
L01`000DL0000`00A014000>A0000`00E01D0005E0000f`0H01P0009H0001`00700L01`0J00L0000
015X0003001/06`0011/00040001N000000>0GP00`00Oomoo`04Ool00`00Oomoo`12Ool00`00Oomo
o`0mOol0041oo`03001oogoo02eoo`03001oogoo01Moo`030001?P4n00H1?P030001?P4n00D1?P03
0001?P4n00H1?P8000L1?P040001N05h0GP300060GP00`000GP1N0020GP200020GP00`000GP00004
0GP00`000GP00006@0000`00@0100007@0000`00K01/0003K0000`00L01`000FL0000`00A014000>
A0000`00E01D0005E0000f`0H01P0007H0000`00700L000370000`00J01X000AJ0000`00K01/000>
K00300020GP00`000GP1N00;0GP00`00Oomoo`04Ool00`00Oomoo`12Ool00`00Oomoo`0mOol0041o
o`03001oogoo02eoo`03001oogoo01Qoo`030001?P4n00H1?P030001?P4n00D1?P030001?P4n00<1
?P8000030Ch0004n00L1?P030001N05h00<1N08000@1N0030001N05h008000<1N0030001N00000H1
N0030001N00000I000030010040000M00005001/06`0K000000JL0000`00A014000>A0001000E01D
06`015@000=/0600H0001F0000<001`070000a`000<006P0J0004fP000<006`0K00036`000<0005h
0GP0105h00<0005h0GP02@5h00<007ooOol01Goo00<007ooOol0@Woo00<007ooOol0?Goo0010Ool0
0`00Oomoo`0]Ool00`00Oomoo`0IOol00`000Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1?P020004
0Ch00`000Ch1?P060Ch00`000GP1N0040GP30000105h00000000105h00@0005h0GP000L1N0030001
N00000I000030010040000M00003001/000001Y`0003N00004@001140004001D05@0K004E005H002
000570000`00J01X000EJ0000`00K01/000:K0000`000GP1N0060GP00`000GP1N0070GP00`00Oomo
o`1;Ool00`00Oomoo`0mOol0071oo`03001oogoo01Yoo`030001?P4n00H1?P030001?P4n00@1?P<0
00L1?P030001?P4n00H1?P030001N05h00H1N08000D1N0040001N05h00090GP00`000GP00006@000
0`00@0100006@002000JL003N0000`00A014000?A0001000E01D06`015@00f0000<001`0700011`0
00<006P0J0005fP000<006`0K00026`000<0005h0GP0205h00<0005h0GP01@5h00<007ooOol0C7oo
00<007ooOol0?Goo001`Ool00`00Oomoo`0KOol00`000Ch1?P060Ch00`000Ch1?P0300020Ch00`00
0Ch1?P060Ch00`000Ch1?P050Ch00`000GP1N0070GP00`000GP1N0020GP01@000GP1N05h00002@5h
0`001d0000<00400@0000d000P000T0000<00700L0005W0017P000<004@0A0003d@000D005@0E01D
06`000AD0003H00001`000DL0003001X06P001UX0003001/06`000I/008000/1N0030001N05h00<1
N003001oogoo04eoo`03001oogoo03eoo`00L7oo00<007ooOol077oo00<0004n0Ch01P4n0P001P4n
00<0004n0Ch01P4n00<0004n0Ch01@4n00<0005h0GP01P5h00D0005h0GP1N00000<1N0030001N05h
00L1N0030001N05h008000M0000300100400008000A00003001`070001E`00Eh0003001404@00114
0005001D05@0E01/0003E0000`00700L0003700200000f00J01X000IJ0000`00K01/0005K0000`00
0GP0000<0GP01@000GP1N05h00002goo00<007ooOol0@Woo00<007ooOol0?Goo002@Ool00`000Ch1
?P030Ch200000`4n0001?P060Ch00`000Ch1?P060Ch00`000Ch1?P050Ch00`000GP1N0050GP01000
0GP1N000105h00<0005h0GP01`5h00@0005h0GP1N08000I000<000M00003001`070001=`00Mh0003
001404@001140005001D05@0E01/0002000570000`00H01P0002H00KJ0000`00K01/0003K0001000
0GP1N0003@5h00<0005h000037oo00<007ooOol0@Woo00<007ooOol0?Goo0010Ool00`00Oomoo`1>
Ool00`000Ch1?P0200040Ch00`000Ch1?P040Ch00`000Ch1?P060Ch00`000Ch1?P060Ch00`000GP1
N0040GP00`000GP000040GP00`000GP1N0070GP00`000GP1N0020GP00`000GP00002@0030002@000
0`00@0100006@0000`00L01`000AL008N0000`00A014000AA0001000E00000001Q`000<00600H000
16006fP000D006`0K01/000000<1N0030001N05h00/1N08000eoo`03001oogoo049oo`03001oogoo
03eoo`00@7oo00<007ooOol0Cgoo0P001`4n00<0004n0Ch0104n00<0004n0Ch01P4n00<0004n0Ch0
1P4n00<0005h0GP00`5h0P001@5h00<0005h0GP01`5h00<0005h0GP00`5h00@0005h000000E00003
0010040000I00003001`0700011`00Uh0003001404@00154008000HL008000QP01]X0004001/0000
00030GP00`000GP1N0070GP5000>Ool00`00Oomoo`12Ool00`00Oomoo`0mOol0041oo`03001oogoo
02eoo`03001oogoo021oo`030001?P4n00D1?P030001?P4n00D1?P030001?P4n00H1?P030001?P4n
00H1?P030001N05h0081N0/000D1N0030001N05h00D1N08000M000030010040000I00003001`0700
00i`00Yh0003001404@000i400@000HL0003001P060000UP01]X00040001N05h00020GP00`000GP1
N0030GP400030GP00`00Oomoo`0=Ool00`00Oomoo`12Ool00`00Oomoo`0mOol0041oo`03001oogoo
02eoo`03001oogoo025oo`030001?P4n00D1?P030001?P4n00D1?P030001?P4n00H1?P030001?P4n
00H1?P040001N00000060GP00`000GP1N0020GP@0007@0000`00@0100006@0000`00L01`000<L00<
N0000`00A014000;A002000270001@00700L01`000000Q`000<00600H0002f006FP00P000`5h0`00
00<1N00000000P001P5h00<007ooOol03Woo00<007ooOol0@Woo00<007ooOol0?Goo0010Ool00`00
Oomoo`0]Ool00`00Oomoo`0ROol00`000Ch1?P050Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`00
0Ch1?P060Ch00`000GP1N0060GP00`000GP1N0070GP00`000GP1N0050GP00`000GP00008@0000`00
@0100005@0000`00L01`000;L00=N0000`00A0140008A003000370000`00700L00037002000?H00G
J00010000GP1N000105h0P002@5h00<007ooOol0E7oo00<007ooOol0?Goo001`Ool00`00Oomoo`0R
Ool00`000Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P030Ch200000`4n0001
N0070GP00`000GP1N0060GP00`000GP1N0040GP01@000GP1N05h00001d0000<00400@0001T0000<0
0700L0002G003WP000<004@0A0001D@00`001A`000<001`070000a`000<00600H00046005FP00P00
0`5h00D0005h0GP1N00000T1N003001oogoo05Eoo`8003ioo`00L7oo00<007ooOol08goo00<0004n
0Ch01P4n00<0004n0Ch01@4n00<0004n0Ch01P4n00<0004n0Ch00P00104n00<0005h0GP01@5h00<0
005h0GP01`5h00<0005h0GP00P5h00<0005h0GP00`5h00<00400@0001D0000<00400@0001T0000<0
0700L0001g0047P000<004@0A00010001a`000<001`070000a`000<00600H0004V004fP000@0005h
0GP000<1N0040001N05h00080GP00`00Oomoo`1FOol2000nOol0071oo`03001oogoo02Aoo`030001
?P4n00H1?P030001?P4n00@1?P030001?P4n00H1?P<000L1?P030001N05h00@1N0030001N05h00L1
N0050001N05h0GP000060GP00`00@0100005@0000`00@0100007@0000`00L01`0005L00AN0040009
70000`00700L00027002000EH00BJ0001@000GP1N05h00000`5h00@0005h0GP000P1N003001oogoo
05Ioo`8003ioo`00V7oo00<0004n0Ch01P4n00<0004n0Ch0104n00<0004n0Ch00`4n0P000P4n00<0
004n0Ch01@4n00<0005h0GP0105h00<0005h0GP01`5h00D0005h0GP1N00000L1N0030010040000E0
00030010040000I00003001`070000A`015h008000/L0003000L01`0008L0003001P060001IP011X
00030001N05h00<1N0070001N05h0GP0005h00001`5h00<007ooOol04Woo00<007ooOol0@Woo00<0
07ooOol0?Goo0010Ool00`00Oomoo`1FOol00`000Ch1?P050Ch00`000Ch1?P050Ch00`000Ch1?P02
00050Ch00`000Ch1?P050Ch00`000GP1N0040GP00`000GP1N0060GP010000GP1N0002@5h00<00400
@000140000<00400@0001d0000<00700L0000W004GP000=/000070002Q`000@001`0700L00800003
E01P060001MP00eX00@000@1N0030001N05h0081N08000H1N003001oogoo01=oo`03001oogoo045o
o`<003ioo`00@7oo00<007ooOol0Egoo00<0004n0Ch01@4n00<0004n0Ch0104n0`00204n00<0004n
0Ch01@4n00<0005h0GP00`5h00<0005h0GP01`5h0P002`5h00<00400@0000d0000<00400@0002400
00<00700L0004GP000=/000070002Q`000D001`0700L000000AD01UP00]X00030001N05h0081N0/0
00D1N003001oogoo01Aoo`03001oogoo049oo`03001oogoo03eoo`00@7oo00<007ooOol0F7oo00<0
004n0Ch01@4n00<0004n0Ch00`000P4n00<0004n0Ch01P4n00<0004n0Ch01P4n00<0005h0GP00P5h
00<0005h0GP01`5h00<0005h0GP02`5h00<00400@0000T0000<00400@000240000<00700N00047P0
0V`000<001`0700021`000<001`070000P001U@06F002FP000<0005h0GP0205h00<0005h0GP00`5h
00D0005h0GP1N00001Moo`03001oogoo049oo`03001oogoo03eoo`00@7oo00<007ooOol0;Goo00<0
07ooOol0:7oo00<0004n0Ch01P4n0P001P4n00<0004n0Ch01P4n00<0004n0Ch01P4n00D0005h0GP1
N00000P1N0030001N00000d1N00300100400009000030010040000Q00003001h07P000ih009/0003
000L01`000PL0004000L00000009E00IH007J00200090GP00`000GP1N0050GP00`000GP0000HOol0
0`00Oomoo`12Ool2000nOol0041oo`03001oogoo02eoo`03001oogoo02Uoo`030001?P4n00<1?P80
00030Ch0004n00H1?P030001?P4n00H1?P030001?P4n00H1?P050001N05h0GP000060GP01@000GP1
N05h0000305h00<00400@0000T0000<00400@000240000<007P0N0003GP000A/0000K00000TL00<0
00aD01UP00EX00030001N00000T1N0030001N05h00H1N003001oogoo01Moo`03001oogoo049oo`80
03ioo`00@7oo00<007ooOol0;Goo00<007ooOol0:Woo00<0004n0Ch00P00104n00<0004n0Ch01@4n
00<0004n0Ch01P4n00<0004n0Ch01P4n00@0005h0GP000D1N0030001N05h00<1N0030001N05h00X1
N00400100400000<@0000`00N01h000;N003K0000`00700L00067003000?E00IH003J00010000GP1
N0002@5h00<0005h0GP01@5h00<007ooOol0GGoo0P00?Woo001`Ool00`00Oomoo`0[Ool200070Ch0
0`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P060Ch00`000GP000040GP00`000GP1N0050GP0
0`000GP1N00:0GP00`00@000000<@0000`00N01h000:N003K0000`00700L000470030002@0000`00
E01D000=E00JH0001FP00000005h00002P5h00<0005h0GP0105h00<007ooOol0GWoo0P00?Woo001`
Ool00`00Oomoo`0/Ool00`000Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P05
0Ch00`000GP000030GP00`000GP1N0060GP00`000GP1N00;0GP2000=@0000`00N01h0008N003K000
0`00700L000370020006@0000`00E01D000=E00IH0000`000GP1N00200090GP00`000GP1N0040GP0
0`00Oomoo`1OOol2000nOol0071oo`03001oogoo02eoo`030001?P4n00H1?P030001?P4n00@1?P03
0001?P4n00L1?P030001?P4n00D1?P050001N0000GP0000:0GP00`000GP1N00;0GP00`00@010000;
@0000`00N01h0007N003K0001000700L01`00`002D0000<005@0E0003E@05V000P00105h00<0005h
0GP01`5h00<0005h0GP00`5h00<007ooOol0H7oo0P00?Woo002QOol00`000Ch1?P060Ch00`000Ch1
?P040Ch00`000Ch1?P060Ch00`000Ch1?P060Ch3000<0GP00`000GP1N00;0GP00`00@010000:@000
0`00N01h0006N003K0000`0070000002000<@0000`00E01D000>E00DH0000`000GP1N0030GP00`00
0GP000080GP00`000GP1N0020GP00`00Oomoo`0LOol00`00Oomoo`12Ool00`00Oomoo`0mOol0041o
o`03001oogoo05moo`030001?P4n00D1?P030001?P4n00D1?P030001?P4n00H1?P030001?P4n00D1
?P8000h1N0030001N05h00/1N0030010040000Y00003001h07P000Ah00=/00<001100003001D05@0
00iD015P008000D1N0050001N05h0GP000070GP01@000GP1N05h00007goo00<007ooOol0@goo00<0
07ooOol0?7oo0010Ool00`00Oomoo`1POol00`000Ch1?P050Ch00`000Ch1?P050Ch00`000Ch1?P06
0Ch00`000Ch1?P0400020Ch00`000GP1N00<0GP00`000GP1N00;0GP00`00@0100009@0000`00N01h
0003N003K0000`00@010000B@0000`00E01D000>E00?H0000`000GP1N0040GP00`000GP1N0030GP0
0`000GP1N0030GP01@000GP1N05h000087oo00<007ooOol0@goo00<007ooOol0?7oo0010Ool00`00
Oomoo`1QOol00`000Ch1?P050Ch00`000Ch1?P050Ch00`000Ch1?P060Ch200070Ch00`000GP1N00<
0GP00`000GP1N00;0GP00`00@0100009@0001000N01h07P00f`000<00400@000540000<005@0E000
3E@03V0000<0005h0GP0105h00<0005h0GP01@5h00<0005h0GP00P5h00@0005h0GP0025oo`03001o
ogoo04=oo`03001oogoo03aoo`00@7oo00<007ooOol0;Goo00<007ooOol0<Goo00<0004n0Ch01P4n
00<0004n0Ch01@4n00<0004n0Ch00`4n0P0000<1?P000Ch01`4n00<0005h0GP0305h00<0005h0GP0
2@5h00<0005h00002T0000<007P0N0000f`000<00400@0005T0000<005@0E0003E@02f000P001P5h
00<0005h0GP01`5h00L0005h0GP1N0000GP0000ROol00`00Oomoo`13Ool00`00Oomoo`0lOol0041o
o`03001oogoo02eoo`03001oogoo039oo`030001?P4n00H1?P030001?P4n00D1?P030001?P4n0080
00@1?P030001?P4n00H1?P030001N05h00`1N0030001N05h00L1N0050001N05h0GP0000:@0001@00
K01/06`000006T0000<005@0E0003E@02F0000<0005h0GP01@5h00<0005h0GP02@5h00<0005h0GP0
0P008goo00<007ooOol0@goo00<007ooOol0?7oo0010Ool00`00Oomoo`0]Ool00`00Oomoo`0cOol0
0`000Ch1?P060Ch00`000Ch1?P040Ch300070Ch00`000Ch1?P060Ch00`000GP1N00;0GP00`000GP1
N0060GP00`000GP1N0020GP00`00@0100008@0001000K01/00006d0000<005@0E0003U@01V000P00
1`5h00<0005h0GP02`5h0`00JWoo00<007ooOol0?7oo001`Ool00`00Oomoo`0dOol00`000Ch1?P06
0Ch00`000Ch1?P0300020Ch00`000Ch1?P060Ch00`000Ch1?P060Ch00`000GP1N00;0GP00`000GP1
N0030GP200060GP00`00@0100006@0001000K01/00007D0000<005@0E0003U@0160000<0005h0GP0
1P5h00<0005h0GP03@5h00<007ooOol0JGoo00<007ooOol0?7oo001`Ool00`00Oomoo`0eOol00`00
0Ch1?P050Ch300060Ch00`000Ch1?P060Ch00`000Ch1?P060Ch00`000GP1N00;0GP01@000GP1N05h
00002@5h00<00400@0001D0000<006`000007d0000<005@0E0003U@000=P00000000205h00<0005h
0GP03@5h00<007ooOol0JWoo00<007ooOol0?7oo001`Ool00`00Oomoo`0fOol00`000Ch1?P040002
0Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P060Ch00`000GP1N00;0GP00`000GP0000;
0GP00`00@0100003@0000`00K000000Q@0000`00E01D000=E00200080GP00`000GP1N00=0GP00`00
Oomoo`1[Ool00`00Oomoo`0lOol00:Yoo`8000L1?P030001?P4n00D1?P030001?P4n00H1?P030001
?P4n00D1?P030001N05h00`1N0030001N05h00/1N003001004000090008002=00003001D05@000YD
008000030GP0005h00H1N0030001N05h00d1N003001oogoo02Ioo`03001oogoo04=oo`03001oogoo
03aoo`00@7oo00<007ooOol0J7oo00<0004n0Ch01P4n00<0004n0Ch0104n00<0004n0Ch01`4n00<0
004n0Ch01@4n00<0005h0GP02P5h00<0005h00003@5h00<00400@0000P0000<<0000@0008T0000<0
05@0E0001e@00P00105h00<0005h0GP00`5h00<0005h0GP03@5h00<007ooOol09goo00<007ooOol0
@goo00<007ooOol0?7oo0010Ool00`00Oomoo`1YOol00`000Ch1?P060Ch00`000Ch1?P040Ch00`00
0Ch1?P060Ch00`000Ch1?P060Ch00`000GP1N0080GP01@000GP1N05h00003@5h00<0040000000``0
00<00400@000840000<005@0E0001E@00P001`5h00D0005h0GP1N00000l1N003001oogoo02Qoo`03
001oogoo04=oo`03001oogoo03aoo`00@7oo00<007ooOol0JWoo00<0004n0Ch01@4n00<0004n0Ch0
1@4n00<0004n0Ch01P4n00<0004n0Ch01P4n00<0005h0GP01P5h00<0005h0GP00`5h00<0005h0GP0
2`5h00<007ooOol00``000<00400@000840000<005@0E0000U@00P002P5h00<0005h00003`5h00<0
07ooOol0:Woo00<007ooOol0@Woo00<007ooOol0?7oo0010Ool00`00Oomoo`0]Ool00`00Oomoo`0k
Ool00`000Ch1?P050Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P060Ch00`000GP1N004
0GP00`000GP1N0050GP00`000GP1N00;0GP00`00Ool<000230000`00@010000Q@0001000E0000000
3@5h00<0005h0GP03@5h00<007ooOol0:goo00<007ooOol0@Woo00<007ooOol0?7oo0010Ool00`00
Oomoo`0]Ool00`00Oomoo`0kOol00`000Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`00
0Ch1?P060Ch00`000GP1N0030GP00`000GP1N0050GP00`000GP1N00<0GP00`00Ool<000230000`00
@010000P@003000=0GP00`000GP0000=0GP00`00Oomoo`0/Ool00`00Oomoo`12Ool00`00Oomoo`0l
Ool0041oo`03001oogoo02eoo`03001oogoo03aoo`030001?P4n00H1?P030001?P4n00D1?P030001
?P4n00H1?P030001?P4n00H1?P050001N05h0GP000090GP00`000GP1N00;0GP00`00Oomoo`033000
0`00@010000L@00300000`0V0001N00<0GP01@000GP1N05h0000305h00<007ooOol0Kgoo0`00?Woo
001`Ool00`00Oomoo`0mOol00`000Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1
?P060Ch00`000GP0000;0GP00`000GP1N00;0GP00`00Oomoo`0330000`00@010000I@002000302H0
0`000GP1N00;0GP00`000GP1N0030GP00`000GP1N0080GP00`00Oomoo`1bOol00`00Oomoo`0lOol0
071oo`03001oogoo03ioo`030001?P4n00H1?P030001?P4n00D1?P030001?P4n00H1?P030001?P4n
00D1?P8000d1N0030001N05h00/1N003001oogoo00<<00030010040001E000<000@09P030001N05h
00/1N0030001N05h00D1N0030001N05h00H1N003001oogoo07=oo`03001oogoo03aoo`00L7oo00<0
07ooOol0?goo00<0004n0Ch01P4n00<0004n0Ch0104n00<0004n0Ch01`4n00<0004n0Ch010000P4n
00<0005h0GP02`5h00<0005h0GP02`5h00<007ooOol00``000<00400@0004D000`0000<09P0002H0
0`0V00<0005h0GP02`5h00<0005h0GP01P5h00<0005h0GP01@5h00<007ooOol0;goo00<007ooOol0
@Woo00<007ooOol0?7oo002cOol00`000Ch1?P060Ch00`000Ch1?P040Ch00`000Ch1?P060Ch30007
0Ch00`000GP1N00;0GP00`000GP1N00;0GP00`00Oomoo`0330000`00@010000=@003000302H00`00
02H09P0202H00`000GP1N00;0GP00`000GP1N0080GP00`000GP1N0030GP00`00Oomoo`0`Ool00`00
Oomoo`12Ool00`00Oomoo`0lOol0041oo`03001oogoo075oo`030001?P4n00D1?P030001?P4n00D1
?P030001?P4n00<1?P800081?P030001?P4n00H1?P030001N05h00/1N0030001N05h00T1N0030001
N000009oo`8<00030010040000U000@000D09P0300009P0V00809P030001N05h00/1N0030001N05h
00X1N0050001N05h0GP0000cOol00`00Oomoo`12Ool00`00Oomoo`0lOol0041oo`03001oogoo079o
o`030001?P4n00D1?P030001?P4n00D1?P030001?P4n008000D1?P030001?P4n00H1?P030001N05h
00/1N0030001N05h00L1N0050001N05h0GP00002Ool230000`00@0100005@003000202H00`0002H0
9P0302H0100002H09P0V0P003@5h00<0005h0GP0305h00<0005h0000=7oo00<007ooOol0@Woo00<0
07ooOol0?7oo0010Ool00`00Oomoo`0/Ool00`00Oomoo`13Ool00`000Ch1?P060Ch00`000Ch1?P04
0Ch300070Ch00`000Ch1?P060Ch00`000GP1N00<0GP00`000GP1N0050GP00`000GP1N0030GP01P00
Ool000003000009000@000@09P0300009P0V00<09PH000030GP0005h00/1N0030001N05h00d1N003
001oogoo03=oo`03001oogoo049oo`03001oogoo03aoo`00@7oo00<007ooOol0;7oo00<007ooOol0
A7oo00<0004n0Ch01P4n00<0004n0Ch00`000P4n00<0004n0Ch01P4n00<0004n0Ch01P4n00<0005h
0GP02`5h00<0005h0GP0105h00<0005h0GP01@5h00<007ooOol010000P0V00<0000V02H00P0V00<0
000V02H00P0V0`000`0V00D0005h0GP1N00000X1N0030001N05h00d1N003001oogoo03Aoo`03001o
ogoo049oo`03001oogoo03aoo`00@7oo00<007ooOol0;7oo00<007ooOol0AGoo00<0004n0Ch01@4n
0`001P4n00<0004n0Ch01P4n00<0004n0Ch01P4n00<0005h0GP02`5h00<0005h0GP00`5h00<0005h
0GP01P5h00@007ooOol000<09P0300009P0V00809P0300009P0000@000@09P030001N05h00<1N003
0001N05h00H1N0030001N05h00d1N003001oogoo07Yoo`03001oogoo03aoo`00@7oo00<007ooOol0
;7oo00<007ooOol0AWoo00<0004n0Ch010000P4n00<0004n0Ch01@4n00<0004n0Ch01P4n00<0004n
0Ch01P4n00<0005h0GP02`5h00D0005h0GP1N00000X1N08000<09P0400009P0V02H4000302H00`00
02H09P0202H00`000GP1N0040GP00`000GP1N0050GP00`000GP1N00=0GP00`00Oomoo`1kOol00`00
Oomoo`0lOol006moo`03001oogoo04Moo`8000L1?P030001?P4n00D1?P030001?P4n00H1?P030001
?P4n00H1?P030001N05h00/1N0030001N00000`1N00300009P0V00H000D09P0300009P0V00809P03
0001N05h00H1N0030001N05h00<1N0030001N05h00d1N003001oogoo07aoo`03001oogoo03aoo`00
Kgoo00<007ooOol0B7oo00<0004n0Ch01P4n00<0004n0Ch0104n00<0004n0Ch01`4n00<0004n0Ch0
1P4n00<0005h0GP02`5h00<0005h0GP0305h0`000`0V00<0000V02H00`0V00<0000V02H00P0V00<0
005h0GP0205h00D0005h0GP1N00000l1N003001oogoo07eoo`03001oogoo03aoo`00^goo00<0004n
0Ch01P4n00<0004n0Ch0104n00<0004n0Ch01P4n00<0004n0Ch01`4n00<0005h0GP02@5h00<0005h
00003@5h00<0000V02H00P0V00<0000V02H00`0V00<0000V02H00P0V00<0005h0GP02P5h00<0005h
00003`5h00<007ooOol0>Goo00<007ooOol0@Woo00<007ooOol0?7oo000oOol00`00Oomoo`1jOol0
0`000Ch1?P050Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P070Ch00`000GP1N0070GP0
1@000GP1N05h00003@5h00@0000V02H000D09P0300009P0V00809P030001N05h00`1N0030001N05h
00d1N003001oogoo03Yoo`03001oogoo049oo`03001oogoo03aoo`00?goo00<007ooOol0Ngoo00<0
004n0Ch01@4n00<0004n0Ch01@4n00<0004n0Ch01P4n00<0004n0Ch01P4n00<0005h0GP01P5h00<0
005h0GP00`5h00<0005h0GP02`5h0P001@0V00<0000V02H00P0V00<0005h0GP0305h00<0005h0000
3@5h00<007ooOol0>goo00<007ooOol0@Woo00<007ooOol0?7oo000oOol00`00Oomoo`1kOol00`00
0Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P060Ch00`000GP1N0030GP20007
0GP00`000GP1N00;0GP00`0002H09P0202H00`0002H09P0202H00`000GP1N00<0GP01@000GP1N05h
00002`5h00<007ooOol0?7oo00<007ooOol0@Woo00<007ooOol0?7oo000oOol00`00Oomoo`0]Ool0
0`00Oomoo`1<Ool00`000Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P060Ch0
1@000GP1N05h00002@5h00<0005h0GP0305h00@0000V02H000@09P030001N05h00`1N0030001N05h
00<1N0030001N05h00L1N003001oogoo03eoo`03001oogoo049oo`03001oogoo03aoo`00?goo00<0
07ooOol0;Goo00<007ooOol0CGoo00<0004n0Ch01P4n00<0004n0Ch01@4n00<0004n0Ch01P4n00<0
004n0Ch01P4n00<0005h00002`5h00<0005h0GP0305h0P00100V00<0005h0GP0305h00<0005h0GP0
1@5h00<0005h0GP01@5h00<007ooOol0?Woo00<007ooOol0@Woo00<007ooOol0?7oo000oOol00`00
Oomoo`0]Ool00`00Oomoo`1>Ool00`000Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1?P050Ch00`00
0Ch1?P060Ch2000=0GP00`000GP1N00<0GP01@0002H09P0V00003P5h00<0005h0GP01`5h00<0005h
0GP00`5h00<007ooOol0Q7oo00<007ooOol0?7oo001_Ool00`00Oomoo`1?Ool00`000Ch1?P060Ch0
0`000Ch1?P040Ch00`000Ch1?P060Ch00`000Ch1?P030Ch200020Ch00`000GP1N00;0GP00`000GP1
N00<0GP00`0002H0000>0GP00`000GP1N0090GP01@000GP1N05h0000Qgoo00<007ooOol0?7oo001_
Ool00`00Oomoo`1@Ool00`000Ch1?P060Ch00`000Ch1?P040Ch00`000Ch1?P060Ch00`000Ch1?P02
00050Ch00`000GP1N00;0GP00`000GP1N00<0GP00`000GP1N00<0GP00`000GP1N00;0GP00`000GP0
0028Ool00`00Oomoo`0lOol006moo`03001oogoo055oo`030001?P4n00D1?P030001?P4n00D1?P03
0001?P4n00D1?P<000P1?P030001N05h00/1N0030001N05h00X1N0<000`1N0030001N05h00d1N003
001oogoo08Moo`03001oogoo03aoo`00a7oo00<0004n0Ch01@4n00<0004n0Ch01@4n00<0004n0Ch0
10000P4n00<0004n0Ch01`4n00<0005h0GP02`5h00<0005h0GP0205h00D0005h0001N00000/1N003
0001N05h00`1N003001oogoo04=oo`03001oogoo049oo`03001oogoo03aoo`00?goo00<007ooOol0
PWoo00<0004n0Ch01P4n00<0004n0Ch0104n0`001`4n00<0004n0Ch01P4n00<0005h0GP0305h00<0
005h0GP01P5h00H0005h0GP0005h000:0GP00`000GP1N00<0GP00`00Oomoo`14Ool00`00Oomoo`12
Ool00`00Oomoo`07Ool30003Ool30003Ool3000VOol003moo`03001oogoo08=oo`030001?P4n00H1
?P030001?P4n00<00081?P030001?P4n00H1?P030001?P4n00H1?P030001N05h00/1N0030001N05h
00D1N0050001N05h0GP000020GP00`000GP1N0060GP00`000GP1N00<0GP00`00Oomoo`15Ool00`00
Oomoo`10Ool40009Ool01@00Oomoogoo00000goo00<007oo00000goo00<007ooOol08goo000oOol0
0`00Oomoo`24Ool00`000Ch1?P050Ch300060Ch00`000Ch1?P060Ch00`000Ch1?P060Ch00`000GP1
N00;0GP00`000GP1N0030GP00`000GP1N0020GP01@000GP1N05h00001P5h00<0005h0GP0305h00<0
07ooOol0AWoo00<007ooOol0@Woo00<007ooOol027oo00D007ooOomoo`0000=oo`03001oo`0000=o
o`03001oogoo02=oo`00?goo00<007ooOol0;Goo00<007ooOol0EGoo00<0004n0Ch010000P4n00<0
004n0Ch01@4n00<0004n0Ch01P4n00<0004n0Ch01P4n00<0005h0GP02`5h00D0005h0GP1N00000D1
N0030001N05h0081N0030001N05h0081N0030001N05h00`1N003001oogoo04Moo`03001oogoo049o
o`8000Uoo`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`0SOol003moo`03001oogoo
02eoo`03001oogoo05Ioo`8000L1?P030001?P4n00D1?P030001?P4n00H1?P030001?P4n00H1?P03
0001N05h00/1N0030001N00000H1N0030001N05h0081N0050001N05h0GP0000>0GP00`00Oomoo`18
Ool00`00Oomoo`12Ool20009Ool01@00Oomoogoo00000goo00<007oo00000goo00<007ooOol08goo
000oOol00`00Oomoo`0]Ool00`00Oomoo`1GOol00`000Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1
?P060Ch00`000Ch1?P060Ch00`000GP1N00;0GP00`000GP1N0050GP00`000GP1N0030GP00`000GP0
000>0GP00`00Oomoo`2>Ool20009Ool01@00Oomoogoo00000goo00<007oo00000goo00<007ooOol0
8goo001_Ool00`00Oomoo`1HOol00`000Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`00
0Ch1?P060Ch00`000GP1N0090GP010000GP000001@5h00<0005h0GP00`5h0P003P5h00<007ooOol0
Sgoo0P002Goo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo02=oo`00Kgoo00<007oo
Ool0FGoo00<0004n0Ch01P4n00<0004n0Ch01@4n00<0004n0Ch01@4n00<0004n0Ch01`4n00<0005h
0GP01`5h00<0005h0GP00P5h0P000`5h00@0005h0GP1N0800081N0030001N05h00/1N003001oogoo
08moo`8000Qoo`8000=oo`07001oogooOol007oo00000goo00<007ooOol08goo001_Ool00`00Oomo
o`1JOol00`000Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1?P050Ch00`000Ch1?P070Ch00`000GP1
N0050GP00`000GP1N0050GP200000`5h0001N00200050GP00`000GP1N0090GP00`00Oomoo`2@Ool2
0009Ool00`00Oomoo`02Ool30003Ool3000VOol00<eoo`030001?P4n00H1?P030001?P4n00@1?P03
0001?P4n00H1?P030001?P4n00H1?P030001N05h00@1N0030001N05h00P1N0<000P1N0030001N05h
00L1N003001oogoo04aoo`03001oogoo049oo`03001oogoo03aoo`00?goo00<007ooOol0S7oo00<0
004n0Ch01@4n00<0004n0Ch01@4n00<0004n0Ch01P4n00<0004n0Ch01P4n00<0005h0GP00`5h00<0
005h0GP02@5h00<0005h0GP0205h00<0005h0GP01@5h00<007ooOol0CGoo00<007ooOol0@Woo00<0
07ooOol0?7oo000oOol00`00Oomoo`2=Ool00`000Ch1?P050Ch00`000Ch1?P050Ch00`000Ch1?P06
0Ch00`000Ch1?P060Ch01@000GP1N05h0000305h00<0005h0GP02@5h00<0005h0GP00`5h00<007oo
Ool0CWoo00<007ooOol0@Woo00<007ooOol0?7oo000oOol00`00Oomoo`2=Ool00`000Ch1?P060Ch0
0`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P060Ch00`000GP0000=0GP00`000GP1N00:0GP0
1@000GP1N05h0000DGoo00<007ooOol0@Woo0P00?Goo000oOol00`00Oomoo`0]Ool00`00Oomoo`1N
Ool00`000Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P050Ch3000=0GP00`00
0GP1N00;0GP00`000GP0001BOol00`00Oomoo`12Ool2000mOol003moo`03001oogoo02eoo`03001o
ogoo05moo`030001?P4n00H1?P030001?P4n00D1?P030001?P4n00H1?P030001?P4n00@00081?P<0
00/1N0030001N05h00/1N08005=oo`03001oogoo04=oo`03001oogoo03]oo`00?goo00<007ooOol0
;Goo00<007ooOol0H7oo00<0004n0Ch01P4n00<0004n0Ch01@4n00<0004n0Ch01@4n0`001`4n00@0
005h000000T1N0030001N05h00T1N0<009Yoo`03001oogoo03]oo`00Kgoo00<007ooOol0HGoo00<0
004n0Ch01P4n00<0004n0Ch01@4n00<0004n0Ch010000P4n00<0004n0Ch01P4n00<0005h0GP00P00
1`5h00<0005h0GP01P5h0`0000<1N000Ool0VWoo00<007ooOol0>goo001_Ool00`00Oomoo`1ROol0
0`000Ch1?P060Ch00`000Ch1?P020Ch500070Ch00`000Ch1?P060Ch010000GP1N05h0P001@5h00<0
005h0GP0105h0P000`5h00<007ooOol0VWoo00<007ooOol0>goo001_Ool00`00Oomoo`1SOol00`00
0Ch1?P050Ch500040Ch00`000Ch1?P060Ch00`000Ch1?P050Ch00`000GP1N0030GP200030GP01000
0GP1N05h0`00105h00<007ooOol0Vgoo00<007ooOol0>goo003FOol00`000Ch1?P0400020Ch00`00
0Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P050Ch00`000GP1N0040GP200000`5h0001N0020006
0GP00`00Oomoo`1FOol00`00Oomoo`13Ool00`00Oomoo`0kOol003moo`03001oogoo09Eoo`8000L1
?P030001?P4n00D1?P030001?P4n00H1?P030001?P4n00D1?P030001N05h00D1N0<000L1N003001o
ogoo05Moo`03001oogoo04=oo`03001oogoo03]oo`00?goo00<007ooOol0UWoo00<0004n0Ch01P4n
00<0004n0Ch01@4n00<0004n0Ch01P4n00<0004n0Ch01@4n00<0005h0GP01@5h00<0005h0GP01@5h
00<007ooOol0F7oo00<007ooOol0@goo00<007ooOol0>goo000oOol00`00Oomoo`0]Ool00`00Oomo
o`1WOol00`000Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P050Ch00`000GP1
N0040GP00`000GP1N0040GP00`00Oomoo`1IOol00`00Oomoo`13Ool00`00Oomoo`0kOol003moo`03
001oogoo02eoo`03001oogoo06Qoo`030001?P4n00D1?P030001?P4n00H1?P030001?P4n00D1?P03
0001?P4n00H1?P030001N05h00<1N0030001N05h00@1N003001oogoo05Uoo`03001oogoo04=oo`03
001oogoo03]oo`00?goo00<007ooOol0;Goo00<007ooOol0JGoo00<0004n0Ch01@4n00<0004n0Ch0
1P4n00<0004n0Ch01@4n00<0004n0Ch01P4n00<0005h0GP00P5h00<0005h0GP00`5h00<007ooOol0
X7oo00<007ooOol0>goo000oOol00`00Oomoo`0]Ool00`00Oomoo`1ZOol00`000Ch1?P050Ch00`00
0Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P060Ch01@000GP1N05h0000105h00<007ooOol0XGoo
00<007ooOol0>goo001_Ool00`00Oomoo`1[Ool00`000Ch1?P050Ch00`000Ch1?P050Ch00`000Ch1
?P060Ch00`000Ch1?P050Ch01@000GP1N05h00000`5h00<007ooOol0X7oo0`00?Goo001_Ool2001]
Ool00`000Ch1?P050Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P050Ch010000GP1N000
0P5h00<007ooOol0Xgoo00<007ooOol0>goo001]Ool20002Ool30004Ool60004Ool60004Ool2001@
Ool00`000Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1?P050Ch01@000GP0005h
0000H7oo00<007ooOol0@goo00<007ooOol0>goo000oOol00`00Oomoo`0VOol00`00Oomoo`0SOol3
0004Ool60004Ool6000jOol00`000Ch1?P060Ch00`000Ch1?P050Ch00`000Ch1?P060Ch00`000Ch1
?P050Ch3001QOol00`00Oomoo`13Ool00`00Oomoo`0kOol003moo`03001oogoo02Aoo`80045oo`H0
00Aoo`D000Aoo`<0025oo`030001?P4n00H1?P030001?P4n00D1?P030001?P4n00H1?P030001?P4n
0081?P@0069oo`03001oogoo04=oo`03001oogoo03]oo`00?goo00<007ooOol08Woo0P00FGoo0`00
17oo1P0017oo1P002goo00<0004n0Ch01@4n00<0004n0Ch01P4n00<0004n0Ch01@4n1@00IWoo00<0
07ooOol0@goo00<007ooOol0>goo000oOol00`00Oomoo`0LOol2001jOol50003Ool70000104n0001
?P4n1`000P4n1000Jgoo00<007ooOol0@goo00<007ooOol0>goo000oOol00`00Oomoo`0JOol20025
Ool00`000Ch1?P050Ch00`000Ch1?P050Ch300000goo000000040004Ool50004Ool3001HOol00`00
Oomoo`13Ool00`00Oomoo`0kOol003moo`03001oogoo01Qoo`8008Qoo`030001?P4n00D1?P030001
?P4n00@001Yoo`<000Aoo`H000Aoo`H008Moo`03001oogoo03]oo`00EGoo0P00SWoo00<0004n0Ch0
0P4n1@00>Goo1@0017oo1P0017oo0`00KGoo00<007ooOol0>goo001COol2002AOol4001DOol30004
Ool60004Ool50004Ool3001@Ool00`00Oomoo`0kOol0055oo`800?moo`Uoo`<000Aoo`H000Aoo`H0
03Uoo`03001oogoo03]oo`00Bgoo0P00ogoo6Goo00<007ooOol03Woo1@0017oo1P0017oo0`005goo
00<007ooOol00goo00<007oo0000?Goo000oOol00`00Oomoo`06Ool3003oOolKOol00`00Oomoo`0T
Ool30004Ool60004Ool5000017oo001oogoo100000=oo`00Ool0?7oo000oOol00`00Oomoo`3oOolT
Ool00`00Oomoo`0eOol00`00Oomoo`03Ool00`00Oomoo`03Ool3000mOol003moo`03001oogoo0080
0?moob9oo`03001oogoo03Eoo`03001oogoo00T0041oo`00?goo1@00ogoo8Woo00<007ooOol0<7oo
00<007ooOol00Woo1P00AWoo0018Ool60004Ool60004Ool6003oOol4Ool00`00Oomoo`0OOol00`00
Oomoo`08Ool01000Oomoogoo2000Bgoo001VOol50004Ool60004Ool6003oOol9Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool7001@Ool008=oo`H000Aoo`D000Aoo`<00>ioo`03001oogoo009oo`L005Io
o`00VGoo0`0017oo1P0017oo1P0017oo0P00c7oo00<007ooOol00Woo00<007oo00001000Fgoo002f
Ool30004Ool60004Ool60004Ool3002XOol00`00Oomoo`03Ool7001POol00=Aoo`<000Aoo`D000Ao
o`H000Aoo`<007Aoo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo009oo`03001oo`0000@0
06Ioo`00lGoo0`0017oo1P0017oo1@0017oo0`00Egoo00<007ooOol01Goo00<007ooOol00Woo00<0
07ooOol00Woo1`00Jgoo003oOol?Ool30004Ool60004Ool60010Ool01000Oomoo`0017oo00<007oo
Ool02@00L7oo003oOolZOol50004Ool60004Ool6000SOol01000Oomoo`0017oo1P00MWoo003oOom7
Ool60004Ool50004Ool60006Ool00`00Ool00006001kOol00?moofAoo`D003Eoo`<000Aoo`<0049o
o`00ogooXGoo00@007ooOol000=oo`03001oogoo03moo`00ogooXWoo00<007oo00000goo00<007oo
Ool0?goo003oOonROol00`00Ool00003Ool00`00Oomoo`0oOol00?mooj9oo`03001oo`0000=oo`03
001oogoo03moo`00ogooQWoo0`0067oo00@007ooOol000=oo`03001oogoo03moo`00ogooQGoo00D0
07ooOomoo`0001Eoo`8000=oo`05001oogooOol00011Ool00?moohEoo`05001oogooOol0000EOol0
0`00Oomoo`02Ool01@00Oomoogoo0000@Goo003oOon5Ool01@00Oomoogoo00005Woo0`000Woo0`00
@Woo003oOon5Ool01@00Oomoogoo0000H7oo003oOom/Ool30004Ool3000?Ool01@00Oomoogoo0000
H7oo003oOom_Ool01000Oomoo`000goo00<007ooOol037oo00D007ooOomoo`00061oo`00ogooL7oo
00<007oo00000goo00<007ooOol037oo00D007ooOomoo`00061oo`00ogooI7oo1`001Goo00<007oo
00000goo00<007ooOol03Goo0`00HGoo003oOom`Ool00`00Ool00003Ool00`00Oomoo`1aOol00?mo
ofmoo`04001oogoo0003Ool00`00Oomoo`1aOol00?moofeoo`8000=oo`05001oogooOol0001cOol0
0?moofeoo`03001oogoo009oo`05001oogooOol0001cOol00?moofioo`<0009oo`<007Aoo`00ogoo
jWoo003oOooZOol00?moonYoo`00ogoojWoo003oOooZOol00?moonYoo`00ogoojWoo003oOooZOol0
0?moonYoo`00ogoojWoo003oOooZOol00?moonYoo`00ogoojWoo003oOooZOol00?moonYoo`00ogoo
jWoo003oOon3Ool30002Ool3001OOol00?moohAoo`03001oogoo009oo`03001oogoo05ioo`00ogoo
QGoo00@007ooOol0065oo`00ogooQWoo0P00HWoo003oOon7Ool00`00Oomoo`1POol00?moohIoo`80
069oo`00ogooQGoo00@007ooOol0065oo`00ogooQ7oo00<007ooOol00Woo00<007ooOol0GWoo003o
Oon3Ool30002Ool3001OOol00?moonYoo`00ogoojWoo003oOooZOol00?moonYoo`00ogoojWoo003o
OooZOol00?moonYoo`00ogoojWoo003oOooZOol00?moonYoo`00ogoojWoo003oOooZOol00?moonYo
o`00ogoojWoo003oOooZOol00?moonYoo`00ogoojWoo003oOooZOol00?moonYoo`00ogoojWoo003o
OooZOol00?moonYoo`00ogoojWoo003oOooZOol00?moonYoo`00ogoojWoo003oOooZOol00001\
\>"],
  ImageRangeCache->{{{0, 488}, {488, 0}} -> {-5.00005*^-06, -5.00005*^-06, 
  0.0020492, 0.0020492}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[" Saving the Magnetic Field Data  into a Text file", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "In this example, one save the data in  bz1 (generated in the section \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  "Magnetic Field Plots",
  StyleBox[
  "\") into a tab delimited text file ready for postcprocessing in a \
spreadsheet software fro example. ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(tab = bz1; \n
    tmp = OpenWrite["\<file.dta\>", FormatType \[Rule] OutputForm]; \n
    Do[Write[tmp, CForm[tab\[LeftDoubleBracket]i, 1\[RightDoubleBracket]], 
        "\<\t\>", CForm[tab\[LeftDoubleBracket]i, 2\[RightDoubleBracket]]], {
        i, Length[tab]}]; \nClose[tmp]\)], "Input"],

Cell[BoxData[
    \("file.dta"\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[" Exporting the geometry to a DXF File", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "To check carefully the geometry with CAD software, it may be usefull to \
export in the DXF Format. Here is the method. The file ",
    Evaluatable->False,
    AspectRatioFixed->True],
  "\"file.dxf\"",
  StyleBox[
  " is created in the default directory. All styles, axes and boxes are lost. \
",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(<< Utilities`DXF`; \)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"WriteDXF", "[", 
        RowBox[{"\"\<file.dxf\>\"", ",", 
          RowBox[{"Graphics3D", "[", 
            RowBox[{
              StyleBox["radObjDrw",
                FontColor->RGBColor[1, 0, 0]], "[", "g", "]"}], "]"}]}], 
        "]"}], ";"}]], "Input"]
}, Closed]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1024}, {0, 748}},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Working",
WindowToolbars->{},
Evaluator->"Local",
CellGrouping->Manual,
WindowSize->{639, 565},
WindowMargins->{{Automatic, 126}, {Automatic, 45}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\

Modify the definitions below to change the default appearance of all cells in \

a given style.  Make modifications to any definition using commands in the 
Format menu.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\

The options defined for the style below will be used at the Notebook level.
\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    Background->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{22, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\

The cells in this section define styles used for input and output to the 
kernel.  Be careful when modifying, renaming, or removing these styles, 
because the front end associates special meanings with these style names.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.8, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{62, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {4, 4}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{44, 0}, {6, 6}},
    Background->GrayLevel[0.8]]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{62, Inherited}, {12, 5}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{40, Inherited}, {4, 1}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{44, 0}, {6, 2}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->16,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->20],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->12],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    ShowCellBracket->False,
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{17, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellDingbat->None,
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{62, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{74, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{52, 10}, {2, 2}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{54, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\

The following styles are useful for numbered equations, figures, etc.  They 
automatically give the cell a FrameLabel containing a reference to a 
particular counter, and also increment that counter.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\

The cells below define styles useful for making hypertext ButtonBoxes.  The 
\"Hyperlink\" style is for links within the same Notebook, or between 
Notebooks.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell["\<\

The following styles are for linking automatically to the on-line help 
system.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000c82>?odoo<3?P960dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 140, 3, 40, "Title",
  Evaluatable->False],
Cell[1852, 54, 102, 3, 26, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1979, 61, 79, 2, 53, "Section",
  Evaluatable->False],
Cell[2061, 65, 655, 12, 90, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2753, 82, 92, 2, 33, "Section",
  Evaluatable->False],
Cell[2848, 86, 488, 15, 44, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3361, 105, 141, 6, 92, "Input"],
Cell[3505, 113, 346, 7, 22, "Print"],
Cell[3854, 122, 126, 2, 37, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4029, 130, 85, 2, 33, "Section",
  Evaluatable->False],
Cell[4117, 134, 97, 2, 26, "Text",
  Evaluatable->False],
Cell[4217, 138, 2391, 83, 1262, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6645, 226, 100, 2, 33, "Section",
  Evaluatable->False],
Cell[6748, 230, 1586, 24, 274, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[8359, 258, 1355, 50, 737, "Input"],
Cell[9717, 310, 631, 14, 22, "Print"],
Cell[10351, 326, 273, 6, 22, "Print"],
Cell[10627, 334, 542, 11, 22, "Print"],
Cell[11172, 347, 343, 7, 22, "Print"],
Cell[11518, 356, 351, 7, 22, "Print"],
Cell[11872, 365, 368, 7, 22, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[12289, 378, 107, 2, 33, "Section",
  Evaluatable->False],
Cell[12399, 382, 679, 22, 58, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[13103, 408, 179, 3, 95, "Input"],
Cell[13285, 413, 3268, 87, 122, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[16602, 506, 88, 2, 33, "Section",
  Evaluatable->False],
Cell[16693, 510, 98, 1, 26, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[16816, 515, 594, 9, 271, "Input"],
Cell[17413, 526, 33768, 960, 235, 10022, 662, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51218, 1491, 401, 6, 159, "Input"],
Cell[51622, 1499, 52677, 1528, 263, 21526, 1139, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[104348, 3033, 93, 2, 33, "Section",
  Evaluatable->False],
Cell[104444, 3037, 502, 9, 74, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[104971, 3050, 326, 6, 159, "Input"],
Cell[105300, 3058, 67509, 3076, 358, 40955, 2744, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[172846, 6139, 321, 6, 159, "Input"],
Cell[173170, 6147, 383888, 28732, 421, 322966, 27975, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[557095, 34884, 878, 15, 479, "Input"],
Cell[557976, 34901, 142, 3, 22, "Print"],
Cell[558121, 34906, 75518, 1869, 586, 20282, 1183, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[633688, 36781, 89, 2, 33, "Section",
  Evaluatable->False],
Cell[633780, 36785, 631, 18, 62, "Text",
  Evaluatable->False],
Cell[634414, 36805, 91, 1, 63, "Input"],
Cell[634508, 36808, 112, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[634657, 36815, 144, 6, 33, "Section",
  Evaluatable->False],
Cell[634804, 36823, 602, 13, 74, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[635431, 36840, 446, 11, 127, "Input"],
Cell[635880, 36853, 717408, 34005, 497, 623857, 32846, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1353337, 70864, 116, 2, 33, "Section",
  Evaluatable->False],
Cell[1353456, 70868, 389, 12, 42, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1353870, 70884, 310, 5, 111, "Input"],
Cell[1354183, 70891, 44, 1, 46, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1354276, 70898, 104, 2, 33, "Section",
  Evaluatable->False],
Cell[1354383, 70902, 440, 14, 42, "Text",
  Evaluatable->False],
Cell[1354826, 70918, 56, 1, 47, "Input"],
Cell[1354885, 70921, 301, 8, 47, "Input"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

